(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[  11432636,     272046]
NotebookOptionsPosition[  11426741,     271864]
NotebookOutlinePosition[  11428051,     271909]
CellTagsIndexPosition[  11428008,     271906]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Protocol S1: ",
  FontSize->30],
 StyleBox["Step-By-Step Example of Active Learning",
  FontSize->24]
}], "Title",
 CellChangeTimes->{{3.599298902453614*^9, 3.5992989187956142`*^9}, {
  3.5993001870001707`*^9, 3.599300188598885*^9}, {3.600903801338162*^9, 
  3.600903804033133*^9}, {3.600968885847969*^9, 3.6009689246016397`*^9}, {
  3.600971850108322*^9, 3.6009718715449057`*^9}, {3.600971907236191*^9, 
  3.600971907345344*^9}, {3.600974800337644*^9, 3.600974802173485*^9}, {
  3.601017832366911*^9, 3.601017840019925*^9}}],

Cell["Problem domain", "Subtitle",
 CellChangeTimes->{{3.599298934116749*^9, 3.599298937531086*^9}, {
  3.6001712364901533`*^9, 3.600171247985406*^9}, {3.600971472559767*^9, 
  3.6009714726796083`*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell[TextData[{
 StyleBox["In this example, we use the ACKLEY function as core for our \
simulation model. \n[",
  FontSize->16],
 "D. H. Ackley. \[OpenCurlyDoubleQuote]A connectionist machine for genetic \
hillclimbing\[CloseCurlyDoubleQuote]. Boston: Kluwer Academic Publishers, \
1987.]"
}], "Text",
 CellChangeTimes->{{3.599300008981069*^9, 3.599300055827039*^9}, 
   3.599904209537731*^9, {3.600171225370635*^9, 3.600171225922388*^9}, {
   3.60096927819058*^9, 3.600969304826765*^9}, {3.600971917025738*^9, 
   3.600971921633185*^9}, {3.600972116980262*^9, 3.60097213832232*^9}, {
   3.600972245029541*^9, 3.600972264443377*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", 
   RowBox[{"(", 
    RowBox[{"x", ",", "a", ",", "b", ",", "c", ",", "d"}], ")"}]}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "a"}], "*", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "b"}], 
      SqrtBox[
       RowBox[{
        FractionBox["1", "d"], "*", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"i", "=", "1"}], "d"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "i"], "^", "2"}], ")"}]}]}]]}]]}], "-", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox["1", "d"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "1"}], "d"], 
      RowBox[{"(", 
       RowBox[{"Cos", "[", 
        RowBox[{"c", " ", 
         SubscriptBox["x", "i"]}], "]"}], ")"}]}]}]], "+", 
   RowBox[{"a", "*", "\[ExponentialE]"}]}]}]], "Text",
 CellChangeTimes->{{3.60101640874504*^9, 3.601016436208757*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "a"}], "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "b"}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "d"}], ")"}], "*", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "1"}], "d"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "^", "2"}], ")"}]}]}], "]"}]}], 
    "]"}]}]}], "\n", 
 RowBox[{"\t\t\t\t\t\t", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "d"}], ")"}], "*", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "1"}], "d"], 
        RowBox[{"(", 
         RowBox[{"Cos", "[", 
          RowBox[{"c", "*", 
           RowBox[{"x", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ")"}]}]}], "]"}]}], "+", 
    "a", "+", 
    RowBox[{"Exp", "[", "1", "]"}]}], ";"}]}]}], "Code",
 CellChangeTimes->{{3.599558428639811*^9, 3.599558437515839*^9}, {
   3.59990418344448*^9, 3.599904188707334*^9}, 3.5999042470733633`*^9, {
   3.600072544661208*^9, 3.600072545044241*^9}, {3.600161856268709*^9, 
   3.600161930062276*^9}, 3.600162833395289*^9, {3.600169305014674*^9, 
   3.600169308614005*^9}, {3.6008765772285433`*^9, 3.60087658813978*^9}, {
   3.6008773163596783`*^9, 3.600877320991181*^9}, {3.6008779633770447`*^9, 
   3.600877993589575*^9}, 3.6009723158968153`*^9, {3.60101849159935*^9, 
   3.601018506263391*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 StyleBox["We define a simulator with parameters ",
  FontSize->16],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FontSize->16],
 StyleBox[" to ",
  FontSize->16],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "15"], TraditionalForm]],
  FontSize->16],
 StyleBox[" where only ",
  FontSize->16],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FontSize->16],
 StyleBox[" and ",
  FontSize->16],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]],
  FontSize->16],
 StyleBox[" are really used.",
  FontSize->16]
}], "Text",
 CellChangeTimes->{
  3.600072541983733*^9, {3.60016172919421*^9, 3.600161813394988*^9}, {
   3.600969320364984*^9, 3.600969371443343*^9}, {3.60097227418923*^9, 
   3.600972315896261*^9}, {3.601017175724277*^9, 3.601017176174337*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Simulator", "[", 
    RowBox[{
    "x1_", ",", " ", "x2_", ",", " ", "x3_", ",", " ", "x4_", ",", " ", "x5_",
      ",", " ", "\n", "\t\t\t", "x6_", ",", " ", "x7_", ",", " ", "x8_", ",", 
     " ", "x9_", ",", " ", "x10_", ",", " ", "\n", "\t\t\t", "x11_", ",", " ",
      "x12_", ",", " ", "x13_", ",", " ", "x14_", ",", " ", "\n", "\t\t\t", 
     "x15_"}], "]"}], ":=", " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2"}], "}"}], ",", " ", "20", ",", " ", "0.2", ",", 
     " ", 
     RowBox[{"2", "*", "Pi"}], ",", " ", "2"}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.599558428639811*^9, 3.599558437515839*^9}, {
   3.59990418344448*^9, 3.599904188707334*^9}, 3.5999042470733633`*^9, {
   3.600072544661208*^9, 3.600072545044241*^9}, {3.600161856268709*^9, 
   3.600161930062276*^9}, 3.600162833395289*^9, {3.600169305014674*^9, 
   3.600169308614005*^9}, {3.6008765772285433`*^9, 3.60087658813978*^9}, {
   3.6008773163596783`*^9, 3.600877320991181*^9}, {3.6008779633770447`*^9, 
   3.600877993589575*^9}, 3.6009723158968153`*^9},
 Background->GrayLevel[0.85]],

Cell[TextData[StyleBox["A plot of the ACKLEY function:",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.600072498676588*^9, 3.6000725155467157`*^9}, 
   3.600161836008628*^9, 3.600162556861641*^9}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", "\n", "\t", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2"}], "}"}], ",", "20", ",", "0.2", ",", 
     RowBox[{"2", "*", "Pi"}], ",", "2"}], "]"}], ",", "\n", "\t", 
   RowBox[{"{", 
    RowBox[{"x1", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x2", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", "\n", "\t", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
   RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", "\n", "\t", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(x\), \(2\)]\)\>\"", ",", 
      "\"\<f(\!\(\*SubscriptBox[\(x\), \(1\)]\),\!\(\*SubscriptBox[\(x\), \(2\
\)]\))\>\""}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<DarkRainbow\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.599506394701109*^9, 3.599506430203771*^9}, {
   3.599506606328302*^9, 3.599506633887867*^9}, {3.5995072149745617`*^9, 
   3.599507223892832*^9}, {3.5995076373641243`*^9, 3.59950763920791*^9}, {
   3.5999042858890047`*^9, 3.599904356712967*^9}, {3.599904464301269*^9, 
   3.599904464529018*^9}, {3.599904573489747*^9, 3.599904573706069*^9}, 
   3.599906720642828*^9, {3.600161956273189*^9, 3.600162002205145*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQdcFFmivn3v9929d/fuzs44jhklCkrOdNN0DnTOGZoGmpwRURQUFTCi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    "], {{0, 402}, {424, 0}}, {0,
     255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{396., Automatic},
  ImageSizeRaw->{424, 402},
  PlotRange->{{0, 424}, {0, 402}}]], "Input",
 CellChangeTimes->{{3.600968954909965*^9, 3.600968955084268*^9}, 
   3.600969079344057*^9},
 ImageSize->{428, 402},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["", "PageBreak",
 CellOpen->True,
 PageBreakBelow->True],

Cell[CellGroupData[{

Cell["1. Design of experiment", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.6001710989041557`*^9, 3.6001711037897463`*^9}, {3.600171261690658*^9, 
  3.6001712623296328`*^9}, {3.6009714695679197`*^9, 3.600971469807272*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell["\<\
Select an initial design with 50 points for 15 parameters:\
\>", "Text",
 CellChangeTimes->{{3.599299018146338*^9, 3.5992990322719517`*^9}, {
  3.600969427027528*^9, 3.600969446186205*^9}, {3.600972343725836*^9, 
  3.600972344299986*^9}, {3.600974858483388*^9, 3.600974862142569*^9}},
 FontSize->16],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], "  ", ";"}], 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Set", " ", "the", " ", "working", " ", "directory"}], 
   " ", "**)"}]}], "\n", 
 RowBox[{
  RowBox[{"spaceFillingDesign", "=", 
   RowBox[{"Import", "[", "\n", "\t\t", 
    RowBox[{"\"\<Design15D_50points.csv\>\"", ",", " ", "\n", "\t\t", 
     RowBox[{"\"\<FieldSeparators\>\"", "\[Rule]", 
      RowBox[{"{", "\"\<,\>\"", "}"}]}]}], "\n", "\t", "]"}]}], 
  ";"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.6009030107332487`*^9, 3.600903035381971*^9}, {
  3.601017247057444*^9, 3.601017248033132*^9}},
 Background->GrayLevel[0.85]],

Cell["\<\
Use a good space filling design generator or a precomputed design.\
\>", "Text",
 CellChangeTimes->{{3.599299519004363*^9, 3.599299552353619*^9}, {
   3.6009693821874123`*^9, 3.6009694044513617`*^9}, {3.600969454563175*^9, 
   3.600969460963122*^9}, 3.600973419218773*^9},
 FontSize->16],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.600162257831327*^9, 3.600162259179188*^9}}],

Cell["\<\
Scale the initial design [0,1] to fit the parameter ranges of the simulator:\
\>", "Text",
 CellChangeTimes->{{3.599299018146338*^9, 3.5992990322719517`*^9}, {
   3.5992998262663813`*^9, 3.5992998494405327`*^9}, 3.600972354298811*^9, {
   3.60097279243848*^9, 3.600972806758437*^9}},
 FontSize->16],

Cell[TextData[{
 "We use values for ",
 Cell[BoxData[
  SubscriptBox["x", "1"]],
  CellChangeTimes->{{3.599299590793103*^9, 3.599299596898182*^9}, {
   3.599299629705296*^9, 3.599299677063979*^9}}],
 " to ",
 Cell[BoxData[
  SubscriptBox["x", "15"]],
  CellChangeTimes->{{3.599299590793103*^9, 3.599299596898182*^9}, {
   3.599299629705296*^9, 3.599299677063979*^9}}],
 " in ]-5, 5[."
}], "Text",
 CellChangeTimes->{{3.5992998632733173`*^9, 3.5992999275938263`*^9}, {
  3.600072577666647*^9, 3.600072591488656*^9}, {3.6007567066705837`*^9, 
  3.600756709726716*^9}, {3.600757134684511*^9, 3.600757140641635*^9}, {
  3.600972795486732*^9, 3.600972796206949*^9}, {3.60101720429943*^9, 
  3.601017204488577*^9}},
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"initialDesign", "=", 
   RowBox[{
    RowBox[{"spaceFillingDesign", "/", "5"}], "-", "5"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"initialDesign", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "1"]}], "}"}]}], ",", " ", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.599299933989599*^9, 3.599299946407206*^9}, {
  3.599558570072987*^9, 3.5995585728444443`*^9}, {3.599560757308139*^9, 
  3.599560758106365*^9}, {3.600162306475264*^9, 3.600162306698735*^9}, {
  3.6007567221719227`*^9, 3.6007567280661097`*^9}, {3.600876234412642*^9, 
  3.600876235873354*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3S+P69oVxmFX/ST9Av4GV5VJVWapOKggKqtpqFupCjSomlupCgoKCgoK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    "], {{0, 236}, {360, 0}}, {0, 
    255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 236},
  PlotRange->{{0, 360}, {0, 236}}]], "Output",
 CellChangeTimes->{
  3.600162312444888*^9, {3.6007567135260963`*^9, 3.600756728715762*^9}, 
   3.600876236242811*^9},
 ImageSize->{364, 236},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.6001693822130117`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Simulation model", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.6001710989041557`*^9, 3.600171118085607*^9}, {3.600171265618634*^9, 
  3.6001712662330837`*^9}, {3.600971460073779*^9, 3.600971480279573*^9}, {
  3.6009715176978903`*^9, 3.600971525866523*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell["\<\
Run the simulator with the input combinations from the design:\
\>", "Text",
 CellChangeTimes->{{3.5992998632733173`*^9, 3.5992999275938263`*^9}, {
  3.600072577666647*^9, 3.600072591488656*^9}, {3.600164468895385*^9, 
  3.60016448040554*^9}, {3.600168764765994*^9, 3.600168791355599*^9}, {
  3.600168944680109*^9, 3.6001690054289207`*^9}, {3.600969472491124*^9, 
  3.600969474099115*^9}, {3.600971530817027*^9, 3.600971544375877*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"simulatorOutput", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Apply", "[", 
      RowBox[{"Simulator", ",", "x"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", "initialDesign"}], "}"}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.600169008361443*^9, 3.600169019822435*^9}, {
   3.6001691099653378`*^9, 3.60016911023519*^9}, {3.6001692248567877`*^9, 
   3.600169238326797*^9}, {3.600169283323197*^9, 3.6001692836374683`*^9}, {
   3.600169360588479*^9, 3.600169376788178*^9}, 3.600585610795953*^9, 
   3.600756769832467*^9},
 Background->GrayLevel[0.85]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.600168990798588*^9, 3.600171174932328*^9, 
  3.60097469533871*^9}],

Cell["Join the input parameters with the simulator output:", "Text",
 CellChangeTimes->{{3.5992998632733173`*^9, 3.5992999275938263`*^9}, {
  3.600072577666647*^9, 3.600072591488656*^9}, {3.600164468895385*^9, 
  3.60016448040554*^9}, {3.600168764765994*^9, 3.600168791355599*^9}, {
  3.600168944680109*^9, 3.6001690054289207`*^9}, {3.6001700306872*^9, 
  3.600170070428995*^9}, {3.600969486219355*^9, 3.600969533955432*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"initialDataSet", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#1", ",", 
        RowBox[{"{", "#2", "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"initialDesign", ",", "simulatorOutput"}], "}"}]}], "]"}]}], 
  ";"}]], "Code",
 CellChangeTimes->{{3.599300383867648*^9, 3.599300416698269*^9}, 
   3.599558666838325*^9, 3.600756773999239*^9},
 Background->GrayLevel[0.85]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.600877396298091*^9, 3.60087739701989*^9}}],

Cell["", "PageBreak",
 CellOpen->True,
 PageBreakBelow->True],

Cell["The simulator output:", "Text",
 CellChangeTimes->{{3.5992998632733173`*^9, 3.5992999275938263`*^9}, {
  3.600072577666647*^9, 3.600072591488656*^9}, {3.600164468895385*^9, 
  3.60016448040554*^9}, {3.600168764765994*^9, 3.600168791355599*^9}, {
  3.600168944680109*^9, 3.6001690054289207`*^9}, {3.6001700306872*^9, 
  3.600170070428995*^9}, {3.6001701126460247`*^9, 3.6001701306827717`*^9}, {
  3.600969540155285*^9, 3.600969541235305*^9}, {3.6009736137258463`*^9, 
  3.6009736429319897`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", "\n", "\t", 
  RowBox[{
   RowBox[{"initialDataSet", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "16"}], "}"}]}], "]"}], "]"}], ",", "\n", 
   "\t", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(x\), \(2\)]\)\>\"", ",", 
      "\"\<f(\!\(\*SubscriptBox[\(x\), \(1\)]\),\!\(\*SubscriptBox[\(x\), \(2\
\)]\))\>\""}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<DarkRainbow\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]], "Code",
 CellChangeTimes->{{3.60017022944372*^9, 3.600170279912697*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvVVwW1m6t5+vTk3VnJqqc3tmLr+bqTp1rr/pTtMkRjEzk23ZYWZm5jjg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    "], {{0, 361}, {456, 0}}, {0, 
    255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{456, 361},
  PlotRange->{{0, 456}, {0, 361}}]], "Input",
 CellChangeTimes->{{3.601017001132375*^9, 3.6010170012353153`*^9}, 
   3.601017045158794*^9},
 ImageSize->{460, 361},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Surrogate modeling", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.5993008258216963`*^9, 3.5993008286762953`*^9}, {3.6001623397538767`*^9, 
  3.6001623438470097`*^9}, {3.600171183507821*^9, 3.600171186339514*^9}, {
  3.60017127213841*^9, 3.600171274936657*^9}, {3.600971558591898*^9, 
  3.600971558903894*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell["\<\
The DataModeler package is required for the symbolic regression function that \
we use.
See \[OpenCurlyDoubleQuote]http://www.evolved-analytics.com/?q=datamodeler\
\[CloseCurlyDoubleQuote] for more information.

Load the DataModeler package:\
\>", "Text",
 CellChangeTimes->{{3.5992998632733173`*^9, 3.5992999275938263`*^9}, {
  3.600072577666647*^9, 3.600072591488656*^9}, {3.600164468895385*^9, 
  3.60016448040554*^9}, {3.600168764765994*^9, 3.600168791355599*^9}, {
  3.600168944680109*^9, 3.6001690054289207`*^9}, {3.6001700306872*^9, 
  3.600170070428995*^9}, {3.600170311630595*^9, 3.600170333524988*^9}, {
  3.60096955043624*^9, 3.6009695600915613`*^9}, {3.600972874838799*^9, 
  3.600972875190703*^9}, {3.601017227837075*^9, 3.601017229593116*^9}, {
  3.601017368286736*^9, 3.6010173723554163`*^9}},
 FontSize->16],

Cell[BoxData[{
 RowBox[{"<<", "DataModeler`"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"modelingRunName1", "=", "\"\<RUN1\>\""}], ";"}]}], "Code",
 CellChangeTimes->{{3.600170419404643*^9, 3.600170439068366*^9}, 
   3.600170691875339*^9, {3.601017377006513*^9, 3.601017377509025*^9}},
 Background->GrayLevel[0.85]],

Cell["\<\


Create surrogate models with symbolic regression:\
\>", "Text",
 CellChangeTimes->{{3.5992998632733173`*^9, 3.5992999275938263`*^9}, {
   3.600072577666647*^9, 3.600072591488656*^9}, {3.600164468895385*^9, 
   3.60016448040554*^9}, {3.600168764765994*^9, 3.600168791355599*^9}, {
   3.600168944680109*^9, 3.6001690054289207`*^9}, {3.6001700306872*^9, 
   3.600170070428995*^9}, {3.600170311630595*^9, 3.600170333524988*^9}, {
   3.600170476553998*^9, 3.6001704875123262`*^9}, {3.600969565899976*^9, 
   3.60096956675506*^9}, {3.6009728828502483`*^9, 3.600972906487225*^9}, 
   3.600974699989236*^9},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"modelSet1", "=", "\n", "\t", 
   RowBox[{"SymbolicRegression", "[", "\n", "\t\t\t", 
    RowBox[{"initialDataSet", ",", "16", ",", " ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"*", " ", "The", " ", "dataset"}], ",", " ", 
       RowBox[{
       "column", " ", "16", " ", "contains", " ", "the", " ", "response", " ",
         "variable"}]}], " ", "**)"}], "\n", "\t\t\t", 
     RowBox[{"TimeConstraint", "\[Rule]", "500"}], ",", " ", 
     RowBox[{"(*", 
      RowBox[{
      "*", " ", "Do", " ", "500", " ", "seconds", " ", "of", " ", 
       "modeling"}], " ", "**)"}], "\n", "\t\t\t", 
     RowBox[{"FunctionPatterns", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"BuildFunctionPatterns", "[", 
         RowBox[{"\"\<PowerMath\>\"", ",", "\"\<Sinusoids\>\""}], "]"}]}], 
       "}"}]}]}], " ", "\n", "\t\t\t\t\t\t\t\t", 
    RowBox[{"(*", 
     RowBox[{
     "*", " ", "We", " ", "will", " ", "allow", " ", "power", " ", 
      "functions", " ", "and", " ", "sinusoids"}], " ", "**)"}], "\n", "\t\t",
     "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.5993006460759363`*^9, 3.5993007032653*^9}, {
   3.599300749546574*^9, 3.5993007551038933`*^9}, {3.59930084626998*^9, 
   3.599300869798443*^9}, {3.5993009054982*^9, 3.5993009059044027`*^9}, {
   3.599300952154573*^9, 3.599300954180038*^9}, {3.599301077455058*^9, 
   3.5993010864867887`*^9}, 3.59955868960465*^9, {3.599865797363655*^9, 
   3.599865863378807*^9}, 3.599865946530307*^9, {3.599866141538903*^9, 
   3.599866158050363*^9}, 3.59986640234067*^9, 3.5999047495657177`*^9, {
   3.600170505795113*^9, 3.600170620454958*^9}, {3.600170907102783*^9, 
   3.600170931622046*^9}, {3.600876604589971*^9, 3.600876612818947*^9}, {
   3.601018581515471*^9, 3.60101862641383*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.600170777892336*^9}],

Cell["", "PageBreak",
 PageBreakBelow->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. System understanding", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.5993008258216963`*^9, 3.5993008286762953`*^9}, {3.5993010107053013`*^9, 
  3.599301013542656*^9}, {3.6001711914512777`*^9, 3.6001711945150337`*^9}, {
  3.6001712802345123`*^9, 3.600171281104623*^9}, {3.600971561104061*^9, 
  3.600971561687839*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell[CellGroupData[{

Cell["Pareto Front Log Plot", "Subsection",
 CellChangeTimes->{{3.5328537953091717`*^9, 3.532853800428466*^9}, {
  3.6009695856838093`*^9, 3.600969588659457*^9}}],

Cell["\<\
Plot the surrogate models. The vertical axis shows the model accuracy and the \
horizontal axis shows the complexity.\
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, 3.600969578710575*^9, {
   3.600972946815785*^9, 3.60097297253577*^9}, 3.601017393303917*^9},
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParetoFrontLogPlot", "[", 
  RowBox[{"modelSet1", ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"LabelForm", "@", "modelingRunName1"}]}]}], "]"}]], "Code",
 CellChangeTimes->{{3.599300867983315*^9, 3.599300878452086*^9}, {
  3.599301063863853*^9, 3.599301096352862*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztfX2MI8d1Z2tWluPVSt4vybuSVlYExzgkARHAAWLAQGwGNqIgUhjHyB9S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    "], {{0, 267}, {400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 267},
  PlotRange->{{0, 400}, {0, 267}}]], "Output",
 CellChangeTimes->{
  3.599300879462144*^9, 3.5993010245373993`*^9, {3.59930107106544*^9, 
   3.599301097589788*^9}, 3.599558765523838*^9, 3.599560905997018*^9, 
   3.599866061831156*^9, 3.5998669077642193`*^9, 3.599904741442173*^9, 
   3.6000328576000338`*^9, 3.600175307761478*^9, 3.600588353867981*^9, 
   3.6007701267058487`*^9, 3.600868384988093*^9},
 ImageSize->{404, 267},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Selecting high quality models", "Subsection",
 CellChangeTimes->{{3.5328537953091717`*^9, 3.532853800428466*^9}, {
  3.599301136108684*^9, 3.599301141051126*^9}}],

Cell["\<\
Only models with high accuracy and low complexity are used for predictions.\
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
  3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
  3.600176282388323*^9}, {3.600176353667214*^9, 3.600176364586282*^9}, {
  3.600876362221963*^9, 3.600876362646076*^9}, {3.6009696226678247`*^9, 
  3.600969659787463*^9}, {3.6009729787118807`*^9, 3.6009730438477097`*^9}, {
  3.600973685734952*^9, 3.6009736916682*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"highQualityModels1", "=", 
    RowBox[{"SelectModels", "[", 
     RowBox[{"modelSet1", ",", 
      RowBox[{"QualityBox", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"650", ",", "0.04"}], "}"}]}]}], "]"}]}], ";"}], 
  " "}]], "Code",
 CellChangeTimes->{{3.599301264041849*^9, 3.599301274562275*^9}, {
  3.5995587750885363`*^9, 3.5995587783271093`*^9}, {3.599560926766809*^9, 
  3.599560927015238*^9}, {3.599904863928639*^9, 3.5999048687744513`*^9}, {
  3.600032869898353*^9, 3.600032870249195*^9}, {3.600868397200481*^9, 
  3.600868401944351*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParetoFrontLogPlot", "[", "\n", "\t", 
  RowBox[{"highQualityModels1", ",", "\n", "\t", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"LabelForm", "@", 
     RowBox[{"(", 
      RowBox[{"modelingRunName1", "<>", "\"\< High Accuracy Models\>\""}], 
      ")"}]}]}]}], "]"}]], "Code",
 CellChangeTimes->{{3.599301284748062*^9, 3.599301296744111*^9}, {
  3.600876423230057*^9, 3.600876424950058*^9}, {3.6008766203437357`*^9, 
  3.600876626344714*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0, 0, 1], PointSize[0.01], PointBox[CompressedData["
1:eJxVm3c81f3//0+TEMpIEUeJEtGQlIunlEqEFoqy9zjnOPY6RigVMhKV1TJT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      "]]}, 
    {RGBColor[1, 0, 0], PointSize[0.02], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYHoh0iHq2u7+LgOgDhxzj4ZJikNiVC+QxxDstk
Xked7obx4x0KCq44hhRxQ9UnOmiu+9U3fwaMn+QgpDF51/ZvUH5CssPN5abf
J+TxQPgLUh3+urLlvtkJ5TtkOBj7WN2ZdhrKT8h0sMvz4tn+A8pXyHN4MHez
5pwuXgj/Q4HDEZXFb9+sg/IdihxkdhzImHUDyhcodjCYocBytZ0P6p5Sh2NK
x6ddnATlfyh1qPd12fhtKpRfUOag/H6ia+kWKN+h3MFFp9bpZjs/lF/hMOWQ
fQerhACE/6DGwX5xY/EWXSg/oM7h4f5jF87GQPkaDQ7T8xNuMHbD+M0OW1O9
V1QwCB4AAMfodR8=
      "]]}, {}}, {
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{111., -3.2541704153375512`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.759985507522625`", "\[VeryThinSpace]"}], "-", 
         FractionBox["321.2839933641992`", 
          RowBox[{
            RowBox[{"21.50655541560061`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "49"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Sin", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.759985507522625` - 321.2839933641992/(21.50655541560061 + ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "15"]], 
          Hue[
           Rational[15, 16], 1, 
           Rational[5, 6]]]] + Cos[Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + Cos[Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]]^49] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{115., -3.2976119906061623`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "327.7676755295721`"}], "+", 
         RowBox[{"219.51836128295156`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"17", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Sin", "[", "2", "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-327.7676755295721 + 219.51836128295156` ArcTan[17 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Sin[2] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{120., -3.3182589629173718`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.964627732210918`", "\[VeryThinSpace]"}], "-", 
         FractionBox["266.7665124303018`", 
          RowBox[{"17", "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "49"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Sin", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", "1", "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[17.964627732210918` - 266.7665124303018/(17 + ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "15"]], 
          Hue[
           Rational[15, 16], 1, 
           Rational[5, 6]]]] + Cos[Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + Cos[Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]]^49] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[1]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{124., -3.4308247702556898`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "310.69438568620933`"}], "+", 
         RowBox[{"208.52383342064797`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.225597132501772`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-310.69438568620933` + 
       208.52383342064797` ArcTan[16.225597132501772` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{142., -3.4495230837108193`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "316.8592169070334`"}], "+", 
         RowBox[{"212.4831479836076`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.7610364928194`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-316.8592169070334 + 
       212.4831479836076 ArcTan[15.7610364928194 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{150., -3.4954676223906143`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.1766131444263115`"}], "+", 
         RowBox[{"4.635549217341963`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"6.361011137933576`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"0.30384906247115673`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.1766131444263115` + 
       4.635549217341963 
        Log[6.361011137933576 + ArcTan[(0.30384906247115673` + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{155., -3.5539874375581175`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.6406815067580778`"}], "+", 
         RowBox[{"1.7066159248785278`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.8047949685514126`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.883770826008501`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.6406815067580778` + 
       1.7066159248785278` (
         ArcTan[1.8047949685514126` + (3.883770826008501 + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])^2] + ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2] + (Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]])^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.5907829778232085`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.91930896255793`", "\[VeryThinSpace]"}], "-", 
         FractionBox["422.880907229359`", 
          RowBox[{
            RowBox[{"26.845493341154025`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.840444646718434`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.91930896255793 - 422.880907229359/(26.845493341154025` + 
       Cos[13.641553316454072` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.840444646718434 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{194., -3.599408836869338}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.839760622270273`", "\[VeryThinSpace]"}], "-", 
         FractionBox["414.4935191381362`", 
          RowBox[{
            RowBox[{"26.354895765283672`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.0359518910482919`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.839760622270273` - 414.4935191381362/(26.354895765283672` + 
       Cos[1.0359518910482919` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{203., -3.6214428863729884`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.62042181670319`", "\[VeryThinSpace]"}], "-", 
         FractionBox["480.56864025483645`", 
          RowBox[{
            RowBox[{"29.271011306981283`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"14", "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.62042181670319 - 480.56864025483645`/(29.271011306981283` + 
       Cos[14 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[2 Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{241., -3.692680669588057}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.042777414541497`", "\[VeryThinSpace]"}], "-", 
         FractionBox["441.8865514977323`", 
          RowBox[{
            RowBox[{"28.182535564890905`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Sin", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"6.9704156052152895`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.3655872124935087`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"8.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"0.9460399306011027`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.042777414541497` - 441.8865514977323/(28.182535564890905` + 
       Cos[0.42089736482602796` + Sin[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[6.9704156052152895` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[1.3655872124935087` - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[8.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[0.9460399306011027 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{271., -3.7104128423130494`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "437.3378853185767`"}], "+", 
         RowBox[{"290.0294830104925`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.89254821129124`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.6003508331343324`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-437.3378853185767 + 
       290.0294830104925 
        ArcTan[17.89254821129124 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.6003508331343324` + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{292., -3.7307632621587015`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.077089680156202`", "\[VeryThinSpace]"}], "-", 
         FractionBox["442.6592733816677`", 
          RowBox[{
            RowBox[{"27.4286333105476`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Sin", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"6.9704156052152895`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"8.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Tan", "[", 
                RowBox[{"Sin", "[", 
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "]"}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"0.9460399306011027`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.077089680156202` - 442.6592733816677/(27.4286333105476 + 
       Cos[0.42089736482602796` + Sin[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[6.9704156052152895` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[8.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[
         Tan[
          Sin[
           Tan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[0.9460399306011027 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.8163242647597357`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "459.64554281762685`"}], "+", 
         RowBox[{"304.37719141320065`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.14783074519155`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"1583.4898206311666`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-459.64554281762685` + 
       304.37719141320065` 
        ArcTan[16.14783074519155 + ArcTan[1583.4898206311666` Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{348., -3.821688821746963}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "413.9804627902741`"}], "+", 
         RowBox[{"275.0255183326565`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.601244994848019`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", "4", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.167257443853776`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-413.9804627902741 + 
       275.0255183326565 
        ArcTan[14.601244994848019` + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[4]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (7.167257443853776 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{351., -3.8232244347543083`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "415.1332080614732`"}], "+", 
         RowBox[{"275.76785272805296`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.621450523904594`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"226.21283151873808`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"403.57546805050436`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-415.1332080614732 + 
       275.76785272805296` 
        ArcTan[14.621450523904594` + ArcTan[(226.21283151873808` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(403.57546805050436` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{359., -3.8381143031273424`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.904830046344218`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19082962107576024`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.904830046344218 - 0.19082962107576024` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{372., -3.941332358784651}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8885022818520762`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19126612394207465`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8885022818520762` - 0.19126612394207465` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + 2 Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{388., -4.023458603755575}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9162755175839314`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19047997994393376`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9162755175839314` - 0.19047997994393376` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{462., -4.044633679187256}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8735761014385757`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18561737438919954`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8735761014385757` - 0.18561737438919954` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{485., -4.0906288739497265`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.820737010009064`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18673601085163793`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.820737010009064 - 0.18673601085163793` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[
                 Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{517., -4.1357492264613915`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.919638964727381`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18436443329168598`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.919638964727381 - 0.18436443329168598` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + ArcTan[ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{613., -4.250460271455656}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9991219611506588`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18098829743981493`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9991219611506588` - 0.18098829743981493` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - (-Sin[5] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2)^2 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{117., -3.265643323505438}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.404270672213803`"}], "+", 
         RowBox[{"4.471968309770261`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.966229539619121`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    ")"}], 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.404270672213803 + 4.471968309770261 Log[4.966229539619121 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[(ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2)^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{124., -3.4307329951725603`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "308.42686055799345`"}], "+", 
         RowBox[{"207.0643160837035`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.134127323142476`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-308.42686055799345` + 
       207.0643160837035 ArcTan[16.134127323142476` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{142., -3.4357832363852867`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "349.84565223152885`"}], "+", 
         RowBox[{"233.71653816845293`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"17", "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-349.84565223152885` + 233.71653816845293` ArcTan[17 + Cos[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{153., -3.4923496475833815`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "325.22136042354066`"}], "+", 
         RowBox[{"217.9104260798201`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.432619979209903`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-325.22136042354066` + 
       217.9104260798201 ArcTan[16.432619979209903` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{171., -3.512075759426133}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "337.3324379240007`"}], "+", 
         RowBox[{"225.69510659233669`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.193656472029303`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-337.3324379240007 + 
       225.69510659233669` ArcTan[16.193656472029303` + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.590300440953341}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.90993405882763`", "\[VeryThinSpace]"}], "-", 
         FractionBox["422.4161557692899`", 
          RowBox[{
            RowBox[{"26.845493341154025`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.0359518910482919`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.840444646718434`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.90993405882763 - 422.4161557692899/(26.845493341154025` + 
       Cos[1.0359518910482919` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.840444646718434 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{217., -3.5983874083527243`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "441.75707388385945`"}], "+", 
         RowBox[{"292.8635829623247`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"19", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"1.043724405250461`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.489081786789796`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-441.75707388385945` + 292.8635829623247 ArcTan[19 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[(1 + Sin[2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(1.043724405250461 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[1.489081786789796 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{243., -3.6068144234838773`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "319.23653944293915`"}], "+", 
         RowBox[{"214.34725540072628`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.496793274856977`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-319.23653944293915` + 
       214.34725540072628` ArcTan[12.496793274856977` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{258., -3.618526494632794}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "317.54781863075567`"}], "+", 
         RowBox[{"213.2416811560436`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.496793274856977`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"11.51586795572331`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-317.54781863075567` + 
       213.2416811560436 ArcTan[12.496793274856977` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[11.51586795572331 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{259., -3.638793368109293}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "424.61487820780536`"}], "+", 
         RowBox[{"281.87361576667325`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"19", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", "9", "]"}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-424.61487820780536` + 281.87361576667325` ArcTan[19 + ArcTan[
            Cos[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[Sin[9] + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{261., -3.6453675765749525`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "409.73896972098`"}], "+", 
         RowBox[{"272.2849608967138`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.99394469241401`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-409.73896972098 + 
       272.2849608967138 
        ArcTan[16.99394469241401 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{271., -3.7095798362714456`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "427.4196522311703`"}], "+", 
         RowBox[{"283.6533348142715`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.54816398174844`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"605.3632020757566`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-427.4196522311703 + 
       283.6533348142715 
        ArcTan[17.54816398174844 + ArcTan[(605.3632020757566 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{324., -3.7463903535990632`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "404.5413901215796`"}], "+", 
         RowBox[{"268.9485676814971`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"15.603884208136735`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                "2"], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-404.5413901215796 + 
       268.9485676814971 ArcTan[15.79037150445428 + ArcTan[
             ArcTan[(15.603884208136735` Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]]^2 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{343., -3.7909329993864036`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8862166774471953`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19122035635058077`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8862166774471953` - 0.19122035635058077` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + 2 Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{365., -3.820811668962269}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.7827639570700593`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19399378184769858`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.7827639570700593` - 0.19399378184769858` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        2 Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{374., -3.8690808600169935`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8557068596839685`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19043738327457935`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8557068596839685` - 0.19043738327457935` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + 2 Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{395., -3.884430698578644}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.091035531247189`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1907500056213427`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"Cos", "[", 
                  RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.091035531247189 - 0.1907500056213427 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] + E^Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - (E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{404., -3.890857092142469}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8493327431591227`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.192482443357406`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8493327431591227` - 0.192482443357406 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{425., -3.9448856142333057`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8529935833561426`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19215015856295709`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.02841438402168173`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8529935833561426` - 0.19215015856295709` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (-0.02841438402168173 + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{440., -3.975938787174815}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8748274568745154`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18542176356475248`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8748274568745154` - 0.18542176356475248` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{492., -4.069821915294586}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9188508019999104`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18460207377434726`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9188508019999104` - 0.18460207377434726` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-ArcTan[4] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{608., -4.113428915538808}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9089111542127384`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18306232473312628`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
                   "]"}]}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9089111542127384` - 0.18306232473312628` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                 Cos[(5 E^5) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[6 - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^4] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + 2 Tan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{626., -4.1262192039510905`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9694477994646777`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18157165205159198`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Sin", "[", "5", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
                   "]"}]}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9694477994646777` - 0.18157165205159198` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                 Cos[(E^5 Sin[5]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[6 - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^4] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + 2 Tan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{118., -3.242721895876029}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "322.1156342758938`"}], "+", 
         RowBox[{"215.93792240229214`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.844526102154662`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-322.1156342758938 + 
       215.93792240229214` ArcTan[15.844526102154662` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{119., -3.265523610570103}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "359.1871532130529`"}], "+", 
         RowBox[{"239.7639543259404`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-359.1871532130529 + 239.7639543259404 ArcTan[18 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{124., -3.4295280313918397`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "299.235084096628`"}], "+", 
         RowBox[{"201.14727402191863`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.7610364928194`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-299.235084096628 + 
       201.14727402191863` ArcTan[15.7610364928194 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{168., -3.449378891099465}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "719.427222030351`"}], "+", 
         RowBox[{"733.47027519999`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"16.15382675867967`", "\[VeryThinSpace]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-719.427222030351 + 733.47027519999 ArcTan[
          ArcTan[16.15382675867967 + Cos[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[
               Rational[1, 2]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{171., -3.5035022372745854`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "301.0951553142869`"}], "+", 
         RowBox[{"202.3718377712142`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.7610364928194`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-301.0951553142869 + 
       202.3718377712142 ArcTan[14.7610364928194 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.539500598494939}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.41520535773284`", "\[VeryThinSpace]"}], "-", 
         FractionBox["463.83222363127845`", 
          RowBox[{
            RowBox[{"28.630641204532072`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.134779112795807`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.839094563784812`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"7.0080912590032725`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.41520535773284 - 463.83222363127845`/(28.630641204532072` + 
       Cos[7.134779112795807 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.839094563784812` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7.0080912590032725` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{179., -3.5838148222253956`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.261980492773536`"}], "+", 
         RowBox[{"4.669256723280024`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"6.16758295420913`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"0.30384906247115673`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.261980492773536 + 
       4.669256723280024 
        Log[6.16758295420913 + ArcTan[(0.30384906247115673` + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{194., -3.5850478666714056`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.085087723240715`", "\[VeryThinSpace]"}], "-", 
         FractionBox["358.9331688934226`", 
          RowBox[{
            RowBox[{"23.86230696403765`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.835636492419482`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"7.1347286973964295`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.085087723240715` - 358.9331688934226/(23.86230696403765 + 
       Cos[13.835636492419482` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7.1347286973964295` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{231., -3.598342831444213}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.943036538147744`", "\[VeryThinSpace]"}], "-", 
         FractionBox["242.35980097613856`", 
          RowBox[{
            RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"9.759352828904287`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"2.0131650035986226`", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], " ", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.943036538147744` - 242.35980097613856`/(14.085903183616281` + 
       ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + ArcTan[9.759352828904287 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "11"]], 
          Hue[
           Rational[11, 16], 1, 
           Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "6"]], 
           Hue[
            Rational[3, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]^2] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{243., -3.6063395593168646`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "361.46088378516595`"}], "+", 
         RowBox[{"241.53450666025122`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.037945466171522`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-361.46088378516595` + 
       241.53450666025122` ArcTan[14.037945466171522` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{260., -3.610456519102597}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.48849511696294`", "\[VeryThinSpace]"}], "-", 
         FractionBox["315.35157445152043`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"15.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.48849511696294 - 315.35157445152043`/(22.258641845677218` + 
       Cos[15.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{264., -3.6413723984905952`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "334.9754447882774`"}], "+", 
         RowBox[{"224.20381628979777`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"15", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Sin", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"1.043724405250461`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "7"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-334.9754447882774 + 224.20381628979777` ArcTan[15 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Sin[1] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(1.043724405250461 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 7]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{271., -3.7095251166644982`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "411.5378686746398`"}], "+", 
         RowBox[{"273.44402475780817`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.99394469241401`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"403.57546805050436`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-411.5378686746398 + 
       273.44402475780817` 
        ArcTan[16.99394469241401 + ArcTan[(403.57546805050436` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{326., -3.7381549960601053`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.268218722914032`", "\[VeryThinSpace]"}], "-", 
         FractionBox["458.4205753242682`", 
          RowBox[{
            RowBox[{"28.01254410002052`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Sin", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.134779112795807`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"8.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Tan", "[", 
                RowBox[{"Sin", "[", 
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "]"}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"6.222006034561666`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.268218722914032` - 458.4205753242682/(28.01254410002052 + 
       Cos[0.42089736482602796` + Sin[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.134779112795807 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[8.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[
         Tan[
          Sin[
           Tan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[6.222006034561666 + Cos[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{352., -3.790503403881603}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "447.9815863393701`"}], "+", 
         RowBox[{"296.88269084689415`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"162", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", "6", "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-447.9815863393701 + 
       296.88269084689415` 
        ArcTan[15.79037150445428 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(162 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[6]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{384., -3.8161048286732497`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "951.8602762776122`"}], "+", 
         RowBox[{"617.7795481791188`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.570146097880794`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}]}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-951.8602762776122 + 
       617.7795481791188 ArcTan[39.570146097880794` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + 2 Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{389., -3.820334375526351}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "448.8608171956052`"}], "+", 
         RowBox[{"297.4461472393946`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"162", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-448.8608171956052 + 
       297.4461472393946 
        ArcTan[15.79037150445428 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(162 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.8314559736980334`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "448.7888138095067`"}], "+", 
         RowBox[{"297.40058353176477`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"605.3632020757566`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"26.984271053493075`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-448.7888138095067 + 
       297.40058353176477` 
        ArcTan[15.79037150445428 + ArcTan[(605.3632020757566 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(26.984271053493075` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "15"]], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]^4]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{426., -3.88698411133672}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.7356746960793026`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18899664913236497`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                 "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.7356746960793026` - 0.18899664913236497` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{434., -3.901806868320432}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.092748138682931`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18658616338475884`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6015660467699249`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.092748138682931 - 0.18658616338475884` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-1.6015660467699249` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{454., -3.9589584406711507`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.722760910350078`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18918931327147245`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.722760910350078 - 0.18918931327147245` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{505., -4.000983189199677}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.988744005295915`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1886150803810753`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.988744005295915 - 0.1886150803810753 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{567., -4.045635544202072}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "806.3625569726408`"}], "+", 
         RowBox[{"524.6291798810953`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"35.8017148826577`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "7", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-806.3625569726408 + 
       524.6291798810953 ArcTan[35.8017148826577 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[7] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + ArcTan[
            Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[7 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{633., -4.058758909441095}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.941262170137053`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18234632004451473`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Sin", "[", "5", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.941262170137053 - 0.18234632004451473` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                 Cos[(E^5 Sin[5]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[6 - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^4] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{119., -3.2478966343538036`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "455.3005040330607`"}], "+", 
         RowBox[{"301.5494413184634`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"21.461184901177464`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-455.3005040330607 + 
       301.5494413184634 ArcTan[21.461184901177464` - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{124., -3.428711754175067}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "330.11328822706963`"}], "+", 
         RowBox[{"221.02053752714104`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"17", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-330.11328822706963` + 221.02053752714104` ArcTan[17 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.5060573559450527`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.227351384321754`", "\[VeryThinSpace]"}], "-", 
         FractionBox["532.9048401504235`", 
          RowBox[{
            RowBox[{"31.405853952846194`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.835636492419482`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"8.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.227351384321754` - 532.9048401504235/(31.405853952846194` + 
       Cos[13.835636492419482` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[8.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{199., -3.577930383559953}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "372.1125742803559`"}], "-", 
         RowBox[{"248.63272298474698`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"18.911661864745632`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}], 
               "+", 
               FractionBox["1", 
                RowBox[{"50", " ", 
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.523787171020679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], 
                    ")"}]}]]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-372.1125742803559 - 
       248.63272298474698` (-ArcTan[18.911661864745632` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[
               Rational[1, 2]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
        Rational[1, 50]/(5.523787171020679 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "15"]], 
            Hue[
             Rational[15, 16], 1, 
             Rational[5, 6]]]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "4"]], 
            Hue[
             Rational[1, 4], 1, 
             Rational[1, 2]]]])), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{236., -3.5840989866515423`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "362.6945173835135`"}], "+", 
         RowBox[{"242.33007121886627`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.000729881412367`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-362.6945173835135 + 
       242.33007121886627` 
        ArcTan[14.085903183616281` + ArcTan[10.000729881412367` - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{259., -3.5924313765064015`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "439.78568852436894`"}], "+", 
         RowBox[{"291.5252639051631`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.827975683168354`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"281.77144863952043`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.619162989965877`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-439.78568852436894` + 
       291.5252639051631 
        ArcTan[18.827975683168354` + ArcTan[(281.77144863952043` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[9.619162989965877 - Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]] - Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{271., -3.7085716795046304`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "427.19685495548777`"}], "+", 
         RowBox[{"283.5097266974011`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.54816398174844`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-427.19685495548777` + 
       283.5097266974011 
        ArcTan[17.54816398174844 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{361., -3.7090813451052584`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "948.3182625982731`"}], "+", 
         RowBox[{"615.496554849997`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"40.27703715194244`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-948.3182625982731 + 
       615.496554849997 ArcTan[40.27703715194244 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{372., -3.7129803617961894`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "303.89473170419825`"}], "+", 
         RowBox[{"204.2417690645599`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.82681789174209`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-303.89473170419825` + 
       204.2417690645599 ArcTan[12.82681789174209 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Sin[Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{373., -3.7568855269326002`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.796272239316569`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1934472644448655`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.796272239316569 - 0.1934472644448655 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{379., -3.775957015111861}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "296.91396402951796`"}], "+", 
         RowBox[{"199.7635701202385`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.888694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.4999960813102842`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-296.91396402951796` + 199.7635701202385 ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.888694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[1.4999960813102842` + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{380., -3.78773760051467}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "934.8000428375897`"}], "+", 
         RowBox[{"606.8638239268383`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.570146097880794`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-934.8000428375897 + 
       606.8638239268383 ArcTan[39.570146097880794` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{403., -3.797456693439948}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.025662240922804`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18790975166839105`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.4413791701244898`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.025662240922804 - 0.18790975166839105` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-1.4413791701244898` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{406., -3.8275890304205618`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "448.61162939540066`"}], "+", 
         RowBox[{"297.2877092454775`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", "4", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.5653750033553298`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-448.61162939540066` + 
       297.2877092454775 
        ArcTan[15.79037150445428 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[4]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "15"]], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.5653750033553298` + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{442., -3.8340462765737633`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.980409009343133`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18878295540482584`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.980409009343133 - 0.18878295540482584` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                 Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{454., -3.8984682871019003`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9090159884081928`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18485630886008195`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9090159884081928` - 0.18485630886008195` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-ArcTan[4] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{476., -3.932679387068872}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8588137111259035`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19200938690029534`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "]"}], "]"}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8588137111259035` - 0.19200938690029534` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           ArcTan[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{498., -3.950679637704963}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.7425422324813375`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18862588247243153`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "]"}], "]"}], "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.7425422324813375` - 0.18862588247243153` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           ArcTan[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2]]]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{517., -3.9603328599647196`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.3283683492944445`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7666846465140634`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                   SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], "]"}],
                "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.3283683492944445` + 0.7666846465140634 (ArcTan[
           ArcTan[(-1 + E^Style[
                 TraditionalForm[
                  Subscript["x", "5"]], 
                 Hue[
                  Rational[5, 16], 1, 
                  Rational[5, 6]]] - (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 - (Style[
                  TraditionalForm[
                   Subscript["x", "4"]], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]]] - Style[
                 TraditionalForm[
                  Subscript["x", "8"]], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]]])^2)^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]]]] - ArcTan[ArcTan[Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]^4] - (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{526., -3.9875566857285993`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.6196924204588524`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.786484118105147`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.6196924204588524 + 0.786484118105147 (-ArcTan[ArcTan[Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]^2] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{562., -3.9958612403441025`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8288436580991168`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7753997821537677`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.8288436580991168 + 0.7753997821537677 (-ArcTan[ArcTan[(E - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                  TraditionalForm[
                   Subscript["x", "4"]], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]]] - Style[
                 TraditionalForm[
                  Subscript["x", "8"]], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]]])^2)^2] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[(-1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{599., -4.025102681740463}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.031696853935302`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7586545885384739`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.031696853935302 + 0.7586545885384739 (-ArcTan[ArcTan[(E - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] - (Style[
                  TraditionalForm[
                   Subscript["x", "4"]], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]]] - Style[
                 TraditionalForm[
                  Subscript["x", "8"]], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]]])^2)^2] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{648., -4.054037132067384}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1056.449238205619`"}], "+", 
         RowBox[{"684.5822646766793`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.14185438768466`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.6073934555129563`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                  "2"]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1056.449238205619 + 
       684.5822646766793 ArcTan[43.14185438768466 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[0.6073934555129563 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + 2 Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]] (1 + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "7"]], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]]]]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{119., -3.2251011621324217`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.91813922378245`", "\[VeryThinSpace]"}], "-", 
         FractionBox["340.94748776652807`", 
          RowBox[{
            RowBox[{"22.83722369573487`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Sin", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"5.300057815055593`", "\[VeryThinSpace]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.91813922378245 - 340.94748776652807`/(22.83722369573487 + 
       Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Sin[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[5.300057815055593 + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] - Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{124., -3.422490377005265}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "280.768980815613`"}], "+", 
         RowBox[{"189.25670229777566`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"15", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-280.768980815613 + 189.25670229777566` ArcTan[15 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{167., -3.4270584140892066`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.9676944142206167`"}], "+", 
         RowBox[{"4.333358164227001`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.966229539619121`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                   "]"}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    ")"}], 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.9676944142206167` + 
       4.333358164227001 Log[4.966229539619121 + ArcTan[
            Sin[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^7]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[(ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2)^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{179., -3.4922957535948154`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "730.6587455667687`"}], "+", 
         RowBox[{"744.7841393646526`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"16.693656472029303`", "\[VeryThinSpace]"}], "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-730.6587455667687 + 744.7841393646526 ArcTan[
          ArcTan[16.693656472029303` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{184., -3.4943612464493348`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.06575139540751`", "\[VeryThinSpace]"}], "-", 
         FractionBox["357.7696663383793`", 
          RowBox[{
            RowBox[{"23.881422078486978`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.835636492419482`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.06575139540751 - 357.7696663383793/(23.881422078486978` + 
       Cos[13.222006034561666` - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[13.835636492419482` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{186., -3.4983490159034663`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "375.49869051813937`"}], "-", 
         RowBox[{"251.25850558514682`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"18.911661864745632`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}], 
               "+", 
               FractionBox["1", 
                RowBox[{"20", " ", 
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.842096298764343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], 
                    ")"}]}]]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-375.49869051813937` - 
       251.25850558514682` (-ArcTan[18.911661864745632` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[
               Rational[1, 2]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
        Rational[1, 20]/(7.842096298764343 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "15"]], 
            Hue[
             Rational[15, 16], 1, 
             Rational[5, 6]]]])), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{199., -3.57073630552822}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "371.201546037342`"}], "-", 
         RowBox[{"248.42719623956026`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"18.911661864745632`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}], 
               "+", 
               FractionBox["1", 
                RowBox[{"20", " ", 
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.285984840096106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], 
                    ")"}]}]]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-371.201546037342 - 
       248.42719623956026` (-ArcTan[18.911661864745632` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[
               Rational[1, 2]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
        Rational[1, 20]/(8.285984840096106 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "15"]], 
            Hue[
             Rational[15, 16], 1, 
             Rational[5, 6]]]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "4"]], 
            Hue[
             Rational[1, 4], 1, 
             Rational[1, 2]]]])), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{252., -3.574849943014137}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.40945423125396`", "\[VeryThinSpace]"}], "-", 
         FractionBox["312.961070557969`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"15.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.40945423125396 - 312.961070557969/(22.258641845677218` + 
       Cos[15.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{271., -3.708499474083849}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "411.32460571413503`"}], "+", 
         RowBox[{"273.3065368731026`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.99394469241401`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-411.32460571413503` + 
       273.3065368731026 
        ArcTan[16.99394469241401 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{372., -3.712967249643026}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "303.8939775934938`"}], "+", 
         RowBox[{"204.24129060504984`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.82681789174209`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.5130495600995655`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-303.8939775934938 + 
       204.24129060504984` ArcTan[12.82681789174209 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Sin[Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.5130495600995655` + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{381., -3.750411937912377}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8487099814267784`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19216456771065638`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8487099814267784` - 0.19216456771065638` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{385., -3.755453538939587}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.888884428767227`", "\[VeryThinSpace]"}], "-", 
         FractionBox["596.9413929192414`", 
          RowBox[{
            RowBox[{"33.75418502449384`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.888884428767227` - 596.9413929192414/(33.75418502449384 + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{396., -3.7609203948190943`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.059143706102766`", "\[VeryThinSpace]"}], "-", 
         FractionBox["531.1603411172293`", 
          RowBox[{
            RowBox[{"31.05496990829101`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[21.059143706102766` - 531.1603411172293/(31.05496990829101 + Cos[
         Cos[
          Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]]] + Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{406., -3.8254472232961825`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "448.3025066590155`"}], "+", 
         RowBox[{"297.08663038441796`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", "4", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-448.3025066590155 + 
       297.08663038441796` 
        ArcTan[15.79037150445428 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[4]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "15"]], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{419., -3.827505861453107}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "448.6664879720309`"}], "+", 
         RowBox[{"297.32169726489656`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", "4", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-448.6664879720309 + 
       297.32169726489656` 
        ArcTan[15.79037150445428 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[4]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "15"]], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]^4]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{454., -3.858377504648405}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.6018659661218297`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19195703216925597`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.6018659661218297` - 0.19195703216925597` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]])^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[6 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{461., -3.871642868512586}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8883878630652035`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7677842224204977`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", "\[ExponentialE]", "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.8883878630652035 + 0.7677842224204977 (-ArcTan[ArcTan[E] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[(-1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{470., -3.8775945259366464`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.5746992190368996`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19153005358826802`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", "5"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.5746992190368996` - 0.19153005358826802` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]])^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[E^5 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{479., -3.8943432179982436`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8847453299062717`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7674709660023765`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", "\[ExponentialE]", "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.8847453299062717 + 0.7674709660023765 (-ArcTan[ArcTan[E] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[(-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{503., -3.929197648900743}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.640694309316869`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7846998436724545`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.640694309316869 + 0.7846998436724545 (-ArcTan[ArcTan[Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]^2] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{537., -3.9833707904057203`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.801673137233256`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18838456819966276`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7.683763484795428`", " ", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.801673137233256 - 0.18838456819966276` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + ArcTan[ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[(7.683763484795428 E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{597., -3.9921512167570157`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.0039308602855816`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7598900208063374`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[ExponentialE]"}], ")"}], "2"],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]], "]"}], 
                    "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", "2", "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.0039308602855816` + 
       0.7598900208063374 (-ArcTan[ArcTan[((-1 + E)^2 + Style[
                  TraditionalForm[
                   Subscript["x", "12"]], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]]]^4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^Rational[1, 2]] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{629., -3.994106001408381}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.026779009825024`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7583364897091888`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[ExponentialE]"}], ")"}], "2"],
                     "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]], "]"}], 
                    "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", "2", "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.026779009825024 + 
       0.7583364897091888 (-ArcTan[ArcTan[((-1 + E)^2 + E^(2 Style[
                   TraditionalForm[
                    Subscript["x", "5"]], 
                   Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]]]) + Style[
                  TraditionalForm[
                   Subscript["x", "12"]], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]]]^4)^Rational[1, 2]] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{131., -3.280775962934733}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.581372157218713`", "\[VeryThinSpace]"}], "-", 
         FractionBox["392.2170535479978`", 
          RowBox[{
            RowBox[{"25.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.0359518910482919`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"6.975908288904971`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.581372157218713` - 392.2170535479978/(25.258641845677218` + 
       Cos[1.0359518910482919` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[6.975908288904971 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{139., -3.336409860277719}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.595104862594002`"}], "+", 
         RowBox[{"4.491906003575881`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"5.555607246963022`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"0.30384906247115673`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.595104862594002 + 
       4.491906003575881 
        Log[5.555607246963022 + ArcTan[(0.30384906247115673` + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{145., -3.3753097760433746`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.48165246476497`", "\[VeryThinSpace]"}], "-", 
         FractionBox["476.1902261087251`", 
          RowBox[{
            RowBox[{"29.678189127569624`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"5.141237406564134`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.48165246476497 - 476.1902261087251/(29.678189127569624` + 
       Cos[5.141237406564134 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "8"]], 
          Hue[
           Rational[1, 2], 1, 
           Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.641553316454072` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{157., -3.3791478687404046`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.312632065286284`", "\[VeryThinSpace]"}], "-", 
         FractionBox["462.143201866125`", 
          RowBox[{
            RowBox[{"29.10671222806029`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.312632065286284` - 462.143201866125/(29.10671222806029 + 
       Cos[13.641553316454072` - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{167., -3.4174514664890734`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.547656657558406`", "\[VeryThinSpace]"}], "-", 
         FractionBox["483.6900619321934`", 
          RowBox[{
            RowBox[{"30.08431299859932`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.547656657558406` - 483.6900619321934/(30.08431299859932 + 
       Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{172., -3.4187176694776977`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "479.6159121482054`"}], "+", 
         RowBox[{"317.18120836192213`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"21.923368892471313`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-479.6159121482054 + 
       317.18120836192213` ArcTan[21.923368892471313` - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{182., -3.4417303554529255`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "316.4914413797525`"}], "+", 
         RowBox[{"212.32255687325596`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"49.40238095339426`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-316.4914413797525 + 
       212.32255687325596` ArcTan[10 + ArcTan[(((49.40238095339426 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{184., -3.4684692349508737`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.848102664542072`", "\[VeryThinSpace]"}], "-", 
         FractionBox["504.2173154985724`", 
          RowBox[{
            RowBox[{"30.527951991586754`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.835636492419482`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.848102664542072` - 504.2173154985724/(30.527951991586754` + 
       Cos[13.222006034561666` - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[13.835636492419482` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{185., -3.483163362640673}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.92015882620674`"}], "+", 
         RowBox[{"4.825986288272368`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"7", "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.92015882620674 + 
       4.825986288272368 Log[7 + ArcTan[(Rational[50, 7] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{200., -3.5115141593202295`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "742.6155890817951`"}], "+", 
         RowBox[{"756.739648051422`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"16.193656472029303`", "\[VeryThinSpace]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-742.6155890817951 + 756.739648051422 ArcTan[
          ArcTan[16.193656472029303` + Cos[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{210., -3.520102546670253}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "342.996460745687`"}], "+", 
         RowBox[{"229.3990199538925`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.95204228255524`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-342.996460745687 + 
       229.3990199538925 ArcTan[13.95204228255524 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[6.95204228255524 - 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]]] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{226., -3.5320870096787504`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "279.1308233291725`"}], "+", 
         RowBox[{"188.26109934706102`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.699584028132579`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-279.1308233291725 + 
       188.26109934706102` ArcTan[13.699584028132579` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{243., -3.550377783808986}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "363.8934981366589`"}], "+", 
         RowBox[{"243.09088242083277`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"9.57359898311001`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-363.8934981366589 + 
       243.09088242083277` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[9.57359898311001 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{258., -3.554427934935716}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "364.3721405771579`"}], "+", 
         RowBox[{"243.39437423505044`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-364.3721405771579 + 
       243.39437423505044` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{267., -3.572655677915437}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "360.94661754836926`"}], "+", 
         RowBox[{"241.1926176553739`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.037945466171522`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-360.94661754836926` + 
       241.1926176553739 ArcTan[14.037945466171522` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` - Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{271., -3.6082968306826864`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "409.94900482126064`"}], "+", 
         RowBox[{"272.41557676242695`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.99394469241401`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"403.57546805050436`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"15.75450151296159`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-409.94900482126064` + 
       272.41557676242695` 
        ArcTan[16.99394469241401 + ArcTan[(403.57546805050436` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[15.75450151296159 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.653001243982077}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.721761783155866`", "\[VeryThinSpace]"}], "-", 
         FractionBox["326.8754185058969`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.071748728398591`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.721761783155866` - 326.8754185058969/(22.258641845677218` + 
       Cos[7.071748728398591 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{290., -3.67431049861637}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "330.7122571625774`"}], "+", 
         RowBox[{"221.48420685367591`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.999996081310284`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.4398392697365887`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-330.7122571625774 + 
       221.48420685367591` ArcTan[13.999996081310284` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Cos[
               Rational[1, 8]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[1.4398392697365887` + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{301., -3.6871050293371477`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "299.2327175109612`"}], "+", 
         RowBox[{"201.23981127432933`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.651363175316126`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.4398392697365887`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-299.2327175109612 + 
       201.23981127432933` ArcTan[12.651363175316126` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[1.4398392697365887` + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{341., -3.7007848428479178`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.26438776836955`", "\[VeryThinSpace]"}], "-", 
         FractionBox["377.2695275820407`", 
          RowBox[{
            RowBox[{"25.281411615239396`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.26438776836955 - 377.2695275820407/(25.281411615239396` + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{356., -3.704879576105563}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.4123080150925285`"}], "+", 
         RowBox[{"1.9494209167835905`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                   "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1.6654238281788025`*^-6", "+", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.4123080150925285` + 
       1.9494209167835905` (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1.6654238281788025`*^-6 + 4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{372., -3.711336128278737}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.603411143490334`", "\[VeryThinSpace]"}], "-", 
         FractionBox["407.74542710151`", 
          RowBox[{
            RowBox[{"27.02196237996359`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.603411143490334` - 407.74542710151/(27.02196237996359 + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{383., -3.7350289479243286`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.62856837336365`", "\[VeryThinSpace]"}], "-", 
         FractionBox["408.88574794577505`", 
          RowBox[{
            RowBox[{"26.925986272411212`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                  "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.62856837336365 - 408.88574794577505`/(26.925986272411212` + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[
           Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{403., -3.7547568978751533`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "358.923587556838`"}], "+", 
         RowBox[{"239.86945165356556`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"11.089501984603473`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    FractionBox["1", "5"], "-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-358.923587556838 + 
       239.86945165356556` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + 
          ArcTan[11.089501984603473` - ArcTan[Rational[1, 5] - ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{410., -3.809174041076527}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.606549832366674`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1913606886062005`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.606549832366674 - 0.1913606886062005 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "13"]], 
           Hue[
            Rational[13, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{418., -3.8103323153504634`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.7801352674422364`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18805699145347182`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.7801352674422364` - 0.18805699145347182` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] - ArcTan[ArcTan[
           Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]]^2] + ArcTan[
          Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{458., -3.85228112605538}}]},
      StyleBox[
       RowBox[{
         RowBox[{"22.17479059950336`", "\[VeryThinSpace]"}], "-", 
         FractionBox["639.9721113665632`", 
          RowBox[{
            RowBox[{"35.27401328300785`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                RowBox[{"0.22722309525110254`", " ", 
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
             "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[22.17479059950336 - 639.9721113665632/(35.27401328300785 + Cos[
         Cos[
          Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]]] + Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[7 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + 0.22722309525110254` Tan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{485., -3.891353597032519}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.6263789114200202`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1915761276707424`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.6263789114200202` - 0.1915761276707424 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[6 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{498., -3.8929054166388433`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8343930859021658`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18514417656294296`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8343930859021658` - 0.18514417656294296` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                 Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - ArcTan[(-Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{515., -3.8963465260431382`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8779320035698921`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7684620753978073`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]], "]"}], 
                    "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.8779320035698921 + 0.7684620753978073 (-ArcTan[ArcTan[(6 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^Rational[1, 2]] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[(-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{532., -3.9066942286121584`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8380225297652886`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18505509992439267`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8380225297652886` - 0.18505509992439267` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - ArcTan[(-Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{550., -3.9533331399026586`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9572792435291575`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18292633364812405`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"68.4785728025659`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.9050499066996167`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9572792435291575` - 0.18292633364812405` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           Cos[(68.4785728025659 Cos[1.9050499066996167` + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]]]) Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + ArcTan[ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{592., -3.9595948120965905`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8550527977659093`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7690687812324746`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"1", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.8550527977659093 + 0.7690687812324746 (-ArcTan[ArcTan[E^(2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]) + Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]]] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] - ArcTan[1 - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]] - (-1 + E^Style[
              TraditionalForm[
               Subscript["x", "5"]], 
              Hue[
               Rational[5, 16], 1, 
               Rational[5, 6]]] - (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - (Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]])^2)^2)^2] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{597., -3.961334580508624}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.964728701785188`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18164710290259092`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Sin", "[", "5", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
                   "]"}]}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.964728701785188 - 0.18164710290259092` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                 Cos[(E^5 Sin[5]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[6 - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^4] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + 2 Tan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{623., -3.9848318986734577`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1030.367138620254`"}], "+", 
         RowBox[{"667.9097569452287`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.261171969451944`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 FractionBox[
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                  SqrtBox[
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1030.367138620254 + 
       667.9097569452287 ArcTan[43.261171969451944` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]] (1 + Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{632., -3.990027250512347}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1040.1413418426641`"}], "+", 
         RowBox[{"674.151405309191`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.467440001759`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                   "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1040.1413418426641` + 
       674.151405309191 ArcTan[43.467440001759 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Sin[Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] (1 + Tan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{131., -3.274731352538948}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.50126457065278`", "\[VeryThinSpace]"}], "-", 
         FractionBox["384.9135921707265`", 
          RowBox[{
            RowBox[{"24.839094563784812`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.0359518910482919`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.50126457065278 - 384.9135921707265/(24.839094563784812` + 
       Cos[1.0359518910482919` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.641553316454072` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{139., -3.3362341382318674`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.5624206223198565`"}], "+", 
         RowBox[{"4.483367645484092`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"5.528594092142706`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"0.30384906247115673`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.5624206223198565` + 
       4.483367645484092 
        Log[5.528594092142706 + ArcTan[(0.30384906247115673` + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{146., -3.37444951669695}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.550860825180344`", "\[VeryThinSpace]"}], "-", 
         FractionBox["483.58397295099263`", 
          RowBox[{
            RowBox[{"30.08431299859932`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.420897364826028`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.550860825180344` - 483.58397295099263`/(30.08431299859932 + 
       Cos[7.420897364826028 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{167., -3.416471641508288}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "439.6652309137149`"}], "+", 
         RowBox[{"291.4671476459897`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"19.441340542305888`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"9", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"5.000324575710058`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-439.6652309137149 + 
       291.4671476459897 ArcTan[19.441340542305888` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[9 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (5.000324575710058 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]])^Rational[1, 2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{186., -3.4360832797167764`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "378.76381344104897`"}], "-", 
         RowBox[{"252.76417626336587`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"18.911661864745632`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}], 
               "+", 
               FractionBox["1", 
                RowBox[{"20", " ", 
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18.08246665574996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], 
                    ")"}]}]]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-378.76381344104897` - 
       252.76417626336587` (-ArcTan[18.911661864745632` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[
               Rational[1, 2]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
        Rational[1, 20]/(18.08246665574996 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "15"]], 
            Hue[
             Rational[15, 16], 1, 
             Rational[5, 6]]]])), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{197., -3.4822120114990565`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "371.31829747337235`"}], "+", 
         RowBox[{"247.60974002122674`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.613704133394698`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"ArcTan", "[", "2", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-371.31829747337235` + 
       247.60974002122674` ArcTan[16.613704133394698` + ArcTan[E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + ArcTan[2] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{213., -3.485606910033761}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "437.1358035878041`"}], "+", 
         RowBox[{"289.9033844207276`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"19", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-437.1358035878041 + 289.9033844207276 ArcTan[19 + ArcTan[
            Cos[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{220., -3.513674157946717}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "377.61449261931625`"}], "+", 
         RowBox[{"251.62296774536705`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.133927007988085`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"310.9151516609087`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-377.61449261931625` + 
       251.62296774536705` 
        ArcTan[16.133927007988085` + ArcTan[(310.9151516609087 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[7 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{227., -3.529176786561669}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.736002865675296`", "\[VeryThinSpace]"}], "-", 
         FractionBox["333.43936265097136`", 
          RowBox[{
            RowBox[{"22.97487397989041`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.736002865675296` - 333.43936265097136`/(22.97487397989041 + Cos[2 Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{236., -3.5310934472453392`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.115598615616243`", "\[VeryThinSpace]"}], "-", 
         FractionBox["359.7535698738925`", 
          RowBox[{
            RowBox[{"23.881422078486978`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.835636492419482`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], 
                  "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.115598615616243` - 359.7535698738925/(23.881422078486978` + 
       Cos[13.222006034561666` - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[13.835636492419482` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[
           Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{246., -3.5331496788572387`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "286.4501121064916`"}], "+", 
         RowBox[{"192.97441920290495`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"14", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-286.4501121064916 + 192.97441920290495` ArcTan[14 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{255., -3.5392305492299743`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "501.42770906987226`"}], "+", 
         RowBox[{"331.13365156180623`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"21.923368892471313`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "]"}], "]"}], 
                  "]"}]], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-501.42770906987226` + 
       331.13365156180623` ArcTan[21.923368892471313` + E^ArcTan[
             ArcTan[
              Cos[E^(E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]])]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{263., -3.5408588390860958`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.290227405689869`"}], "+", 
         RowBox[{"1.6518396746491222`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"2", "+", "\[ExponentialE]", "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.290227405689869 + 1.6518396746491222` (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[2.2010988964402785` + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[2 + E + (Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.6243561830926474`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "306.3524138655538`"}], "+", 
         RowBox[{"206.0401485079849`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.569403082427442`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-306.3524138655538 + 
       206.0401485079849 ArcTan[12.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.569403082427442` + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{275., -3.6481583286807964`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "460.7681846461237`"}], "+", 
         RowBox[{"305.1054833913362`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"19", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", "9", "]"}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-460.7681846461237 + 305.1054833913362 ArcTan[19 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[Sin[9] + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{295., -3.6569072557773468`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "458.7946395280018`"}], "+", 
         RowBox[{"303.82678809620967`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"19", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}]],
                "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", "9", "]"}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-458.7946395280018 + 303.82678809620967` ArcTan[19 + E^ArcTan[
             Cos[E^(4 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]])]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[Sin[9] + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.656949484729949}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "304.79084348489783`"}], "+", 
         RowBox[{"204.78940876979883`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"14", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-304.79084348489783` + 204.78940876979883` ArcTan[14 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[(2 Cos[
                Rational[1, 8]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{319., -3.6609398261054418`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "304.9112679400598`"}], "+", 
         RowBox[{"204.86656110143227`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"14", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-304.9112679400598 + 204.86656110143227` ArcTan[14 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[(2 Cos[
                Rational[1, 8]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{320., -3.667751431033122}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "318.8316211087171`"}], "+", 
         RowBox[{"213.85131876176726`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.51712276484343`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-318.8316211087171 + 
       213.85131876176726` ArcTan[13.51712276484343 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Sin[2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{327., -3.678242626280484}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.537388079639783`", "\[VeryThinSpace]"}], "-", 
         FractionBox["319.3756729213468`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "+", 
                RowBox[{"Sin", "[", "3", "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.835373968998163`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "7", "]"}], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.537388079639783` - 319.3756729213468/(22.258641845677218` + 
       Cos[7 + Sin[3] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[2 Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.835373968998163 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[
            Cos[7]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{341., -3.698831208968118}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.682698980782053`", "\[VeryThinSpace]"}], "-", 
         FractionBox["410.3984663837893`", 
          RowBox[{
            RowBox[{"26.84777789893777`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.682698980782053` - 410.3984663837893/(26.84777789893777 + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{364., -3.702873313019093}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.620780462210256`", "\[VeryThinSpace]"}], "-", 
         FractionBox["408.4696306680916`", 
          RowBox[{
            RowBox[{"26.925986272411212`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.620780462210256` - 408.4696306680916/(26.925986272411212` + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{377., -3.7031873252705854`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "626.1732222470823`"}], "+", 
         RowBox[{"294.0121500276539`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"19.708499536878648`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.562823659582913`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-626.1732222470823 + 
       294.0121500276539 (E^
          ArcTan[19.708499536878648` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.562823659582913` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{389., -3.70371617595403}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.6605214176349542`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8654179003321797`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "\[ExponentialE]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.6605214176349542 + 0.8654179003321797 (ArcTan[(-E + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (9 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{392., -3.705206823121643}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7487514110287584`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8598256422591889`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7487514110287584 + 0.8598256422591889 (ArcTan[(-1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.725806543634071}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.394465771121098`", "\[VeryThinSpace]"}], "-", 
         FractionBox["473.99685434741997`", 
          RowBox[{
            RowBox[{"29.12737741069591`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "]"}], "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.394465771121098` - 473.99685434741997`/(29.12737741069591 + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[
          Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{411., -3.765218096980058}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.861778300624995`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19186480978288117`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.42358941220425095`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.861778300624995 - 0.19186480978288117` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-0.42358941220425095` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{412., -3.7745070616815095`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.653392160734803`", "\[VeryThinSpace]"}], "-", 
         FractionBox["585.6667107328716`", 
          RowBox[{
            RowBox[{"33.75418502449384`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.653392160734803` - 585.6667107328716/(33.75418502449384 + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{416., -3.7785293635161725`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "295.88284033036973`"}], "+", 
         RowBox[{"199.1001230972554`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.388694565552804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.4999960813102842`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-295.88284033036973` + 199.1001230972554 ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + 
          Log[6.388694565552804 + Log[6.488694565552803 + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[1.4999960813102842` + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{425., -3.795596444923887}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9478273467407377`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1897779787044502`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9478273467407377` - 0.1897779787044502 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{450., -3.7977956169329987`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "934.1523845447808`"}], "+", 
         RowBox[{"606.4095473016702`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.6195936515727`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-934.1523845447808 + 
       606.4095473016702 ArcTan[39.6195936515727 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]^2 + Sin[
            Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{458., -3.8059500436203595`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.041605263351013`", "\[VeryThinSpace]"}], "-", 
         FractionBox["449.8597111944745`", 
          RowBox[{
            RowBox[{"28.808872162634312`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.041605263351013` - 449.8597111944745/(28.808872162634312` + 
       Cos[7 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{461., -3.8150864216633313`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.136790267727186`", "\[VeryThinSpace]"}], "-", 
         FractionBox["547.1748987936043`", 
          RowBox[{
            RowBox[{"32.01389418295415`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "]"}], "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.136790267727186` - 547.1748987936043/(32.01389418295415 + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[
          Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]]] + Tan[
         Cos[7 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{466., -3.8490477367833}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "443.157068300986`"}], "+", 
         RowBox[{"293.7620313110619`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"313.89203070594783`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"]}], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.6003508331343324`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-443.157068300986 + 
       293.7620313110619 
        ArcTan[15.79037150445428 + ArcTan[(313.89203070594783` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "12"]], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]]]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (
              Log[4.189126509606261 + Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.6003508331343324` + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{489., -3.8537059852540265`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "936.5489809962949`"}], "+", 
         RowBox[{"607.9381749163398`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.28119298697581`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                "2"], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-936.5489809962949 + 
       607.9381749163398 ArcTan[39.28119298697581 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]^2 + Sin[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]^2] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{506., -3.863701046087586}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7284759125349766`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.778480010163303`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"1", "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7284759125349766 + 0.778480010163303 (-ArcTan[1 - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[
            Style[
             TraditionalForm[
              Subscript["x", "5"]], 
             Hue[
              Rational[5, 16], 1, 
              Rational[5, 6]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{515., -3.8829317882156}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7132655730431001`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7794568477882422`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"1", "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7132655730431001 + 0.7794568477882422 (-ArcTan[1 - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{523., -3.8928161438003883`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "794.4596547597231`"}], "+", 
         RowBox[{"517.0529581262542`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"34.81525491663513`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.6073934555129563`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-794.4596547597231 + 
       517.0529581262542 ArcTan[34.81525491663513 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[0.6073934555129563 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[7 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{586., -3.9378311900376586`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.676192587784721`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1894177078058831`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.6837634847954277`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.676192587784721 - 0.1894177078058831 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^4] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - ArcTan[1.6837634847954277` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 + (-Sin[5] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2)^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{590., -3.9389919193276666`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.829433229844661`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19388499500508696`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox[
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], 
                  SqrtBox[
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.4413791701244898`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], ")"}], 
                    "2"]}]]], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.829433229844661 - 0.19388499500508696` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[(E^5 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]) (1 + (6 - (-1.4413791701244898` + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2)^2 - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4)^2)^Rational[-1, 2]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{131., -3.243256892243823}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "316.0448299780475`"}], "+", 
         RowBox[{"212.0508591982146`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"16", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"2", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-316.0448299780475 + 212.0508591982146 ArcTan[16 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{139., -3.3353475643992665`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.4363627982602405`"}], "+", 
         RowBox[{"4.4503844211777395`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"5.424609607911959`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"0.30384906247115673`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.4363627982602405` + 
       4.4503844211777395` 
        Log[5.424609607911959 + ArcTan[(0.30384906247115673` + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{146., -3.3671296337978256`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.308859067306823`", "\[VeryThinSpace]"}], "-", 
         FractionBox["379.52151078489476`", 
          RowBox[{
            RowBox[{"25.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.840444646718434`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"6.975908288904971`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.308859067306823` - 379.52151078489476`/(25.258641845677218` + 
       Cos[7.840444646718434 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[6.975908288904971 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{147., -3.3700423782995514`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.5520222010525904`"}], "+", 
         RowBox[{"1.677693107540803`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.8047949685514126`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.883770826008501`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.5520222010525904` + 
       1.677693107540803 (
         ArcTan[1.8047949685514126` + (3.883770826008501 + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])^2] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + (Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]])^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{155., -3.373252405209059}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.465210466289726`", "\[VeryThinSpace]"}], "-", 
         FractionBox["302.08742278403025`", 
          RowBox[{
            RowBox[{"20.222006034561666`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.0359518910482919`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.720139825636043`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Sin", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.465210466289726` - 302.08742278403025`/(20.222006034561666` + 
       Cos[1.0359518910482919` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.720139825636043 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.641553316454072` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{167., -3.4158315405319755`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.587812884922283`", "\[VeryThinSpace]"}], "-", 
         FractionBox["485.6190796921407`", 
          RowBox[{
            RowBox[{"30.08431299859932`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.587812884922283` - 485.6190796921407/(30.08431299859932 + Cos[7 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{188., -3.4165121564501586`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "298.40242351650875`"}], "+", 
         RowBox[{"200.6458689746235`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.913588932593228`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.7863225731137681`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-298.40242351650875` + 
       200.6458689746235 
        ArcTan[14.913588932593228` + ArcTan[0.7863225731137681 + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{198., -3.441078881086605}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "460.7408681133991`"}], "+", 
         RowBox[{"304.99355739736905`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"19.689417786393427`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"89.89430809482145`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-460.7408681133991 + 
       304.99355739736905` 
        ArcTan[19.689417786393427` + ArcTan[(89.89430809482145 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{203., -3.4416685002465717`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "276.99929741280647`"}], "+", 
         RowBox[{"186.93332863682195`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.7863225731137682`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-276.99929741280647` + 186.93332863682195` ArcTan[13 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[1.7863225731137682` + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + 2 Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{209., -3.4433120863723032`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "153.81400715314263`"}], "+", 
         RowBox[{"69.27524885514717`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{"10", "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"49.14364661598448`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                   "]"}], "4"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-153.81400715314263` + 
       69.27524885514717 ArcTan[10 + ArcTan[(((49.14364661598448 Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]) Style[
                  TraditionalForm[
                   Subscript["x", "13"]], 
                  Hue[
                   Rational[13, 16], 1, 
                   Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])) (6 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])]^4 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{212., -3.455539107271967}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.7346633319082`", "\[VeryThinSpace]"}], "-", 
         FractionBox["333.5599059350475`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[15, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.840444646718434`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[18.7346633319082 - 333.5599059350475/(22.258641845677218` + Cos[
         Cos[
          Style[
           TraditionalForm[
            Subscript["x", "15"]], 
           Hue[
            Rational[15, 16], 1, 
            Rational[5, 6]]]]] + Cos[7.840444646718434 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{215., -3.47776735127672}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "286.8511438237086`"}], "+", 
         RowBox[{"193.2606179305333`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.582566600065597`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-286.8511438237086 + 
       193.2606179305333 ArcTan[13.582566600065597` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{222., -3.5103410444052505`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "427.4999051697289`"}], "+", 
         RowBox[{"283.66519553461865`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.681009726246316`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-427.4999051697289 + 
       283.66519553461865` ArcTan[18.681009726246316` + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{230., -3.5109488568214613`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1166.3221008781643`"}], "+", 
         RowBox[{"1502.9730831338793`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"ArcTan", "[", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"16.193656472029303`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], 
               "]"}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1166.3221008781643` + 1502.9730831338793` ArcTan[
          ArcTan[
           ArcTan[16.193656472029303` + Cos[
              Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{239., -3.512595755220218}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "275.7586864766107`"}], "+", 
         RowBox[{"186.0918688034968`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.8926435134864008`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
                "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-275.7586864766107 + 186.0918688034968 ArcTan[13 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[1.8926435134864008` + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + 2 Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]] + 2 Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{246., -3.533118870876874}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "286.29213968319436`"}], "+", 
         RowBox[{"192.8726847900544`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.993481307310054`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-286.29213968319436` + 
       192.8726847900544 ArcTan[13.993481307310054` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{259., -3.537858008092957}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "445.5964719893786`"}], "+", 
         RowBox[{"295.267138418344`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"16", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"845.3143459185612`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"38.04008947444624`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-445.5964719893786 + 
       295.267138418344 ArcTan[16 + ArcTan[845.3143459185612 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(38.04008947444624 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{265., -3.54002230317851}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "348.5298144946639`"}], "+", 
         RowBox[{"232.9652392192865`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.199134013005816`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"176.36678892248207`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-348.5298144946639 + 
       232.9652392192865 
        ArcTan[12.199134013005816` + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(176.36678892248207` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (3 - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.614436395250894}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "360.264754471063`"}], "+", 
         RowBox[{"240.76252249832874`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.037945466171522`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-360.264754471063 + 
       240.76252249832874` ArcTan[14.037945466171522` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` + ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{297., -3.6178314159295435`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "321.17581503093663`"}], "+", 
         RowBox[{"215.57941363505375`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.544750992301736`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-321.17581503093663` + 
       215.57941363505375` ArcTan[12.544750992301736` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` - ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{307., -3.6326231359288386`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "280.03880150568824`"}], "+", 
         RowBox[{"188.85148378411148`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-280.03880150568824` + 188.85148378411148` ArcTan[13 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[(1 + Cos[
               Rational[1, 8]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{311., -3.6388238052937947`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "259.4867638171122`"}], "+", 
         RowBox[{"175.60983018104324`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               FractionBox["97", "8"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-259.4867638171122 + 
       175.60983018104324` ArcTan[Rational[97, 8] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[(2 Cos[
                Rational[1, 8]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{321., -3.666710217682923}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "298.5347636016468`"}], "+", 
         RowBox[{"200.79417232812756`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.651363175316126`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-298.5347636016468 + 
       200.79417232812756` ArcTan[12.651363175316126` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{334., -3.668965460470199}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.60398386035688`", "\[VeryThinSpace]"}], "-", 
         FractionBox["321.014910731475`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.809479223554499`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "7", "]"}], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.60398386035688 - 321.014910731475/(22.258641845677218` + 
       Cos[7 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.809479223554499 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[
            Cos[7]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{347., -3.68647554581815}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9206287697794546`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18913958732571748`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9206287697794546` - 0.18913958732571748` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{360., -3.6946826601888896`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "308.0244673899478`"}], "+", 
         RowBox[{"206.90245460392794`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.999996081310284`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-308.0244673899478 + 
       206.90245460392794` ArcTan[12.999996081310284` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{364., -3.7026250940497527`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.557624361923367`", "\[VeryThinSpace]"}], "-", 
         FractionBox["403.3879521214345`", 
          RowBox[{
            RowBox[{"26.688957490446313`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.557624361923367` - 403.3879521214345/(26.688957490446313` + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{377., -3.7028501919835133`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "626.5904484746538`"}], "+", 
         RowBox[{"294.204384332953`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"19.708499536878648`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.599419225281405`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-626.5904484746538 + 
       294.204384332953 (E^
          ArcTan[19.708499536878648` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.599419225281405` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{410., -3.7225375871424786`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7456819952197229`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8593425072128837`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7456819952197229 + 0.8593425072128837 (ArcTan[(-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{411., -3.726727957178266}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "334.72452297223236`"}], "+", 
         RowBox[{"224.07743772379112`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.98822900605531`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.499126084842551`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-334.72452297223236` + 
       224.07743772379112` ArcTan[13.98822900605531 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.499126084842551 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{412., -3.7647497782981225`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.123045819244993`", "\[VeryThinSpace]"}], "-", 
         FractionBox["536.1016750982685`", 
          RowBox[{
            RowBox[{"31.777803940697005`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.123045819244993` - 536.1016750982685/(31.777803940697005` + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{436., -3.768317111533966}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "742.4533912298407`"}], "+", 
         RowBox[{"483.8354504815381`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"32.94914769094571`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.147695761381096`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-742.4533912298407 + 
       483.8354504815381 ArcTan[32.94914769094571 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[1.147695761381096 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[7 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]] (1 + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "7"]], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]]]]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{437., -3.7906734484877243`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.12042430692212827`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8202450114481409`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.12042430692212827` + 0.8202450114481409 (ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[(-1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{458., -3.8059455468353356`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.275380729212`", "\[VeryThinSpace]"}], "-", 
         FractionBox["470.01768433163664`", 
          RowBox[{
            RowBox[{"29.70371032461711`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.275380729212 - 470.01768433163664`/(29.70371032461711 + Cos[7 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{466., -3.84828136421506}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "442.9912127169346`"}], "+", 
         RowBox[{"293.6551470130712`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"]}], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.6003508331343324`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-442.9912127169346 + 
       293.6551470130712 
        ArcTan[15.79037150445428 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "12"]], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]]]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (
              Log[4.189126509606261 + Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.6003508331343324` + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{515., -3.875818374543215}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "788.6878577390172`"}], "+", 
         RowBox[{"513.2959291473254`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"35.8017148826577`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.6073934555129563`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-788.6878577390172 + 
       513.2959291473254 ArcTan[35.8017148826577 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[0.6073934555129563 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + ArcTan[
            Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{523., -3.879820129018053}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1049.593183890689`"}], "+", 
         RowBox[{"680.2137166935071`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.75967055048048`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.6073934555129563`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1049.593183890689 + 
       680.2137166935071 ArcTan[43.75967055048048 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[0.6073934555129563 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[7 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{610., -3.8845873292108566`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "979.9878696978468`"}], "+", 
         RowBox[{"635.6922559737033`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"41.620442165576655`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 FractionBox[
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                  SqrtBox[
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-979.9878696978468 + 
       635.6922559737033 ArcTan[41.620442165576655` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]] (1 + Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{132., -3.2197574633972597`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "252.80610803153036`"}], "+", 
         RowBox[{"171.38004191542245`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-252.80610803153036` + 171.38004191542245` ArcTan[12 + 2 ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{134., -3.219817768357711}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "276.62930870305075`"}], "+", 
         RowBox[{"186.71629538795628`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.862736623538936`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-276.62930870305075` + 
       186.71629538795628` ArcTan[13.862736623538936` + ArcTan[
            ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + ArcTan[
            Sin[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{136., -3.2285176583115884`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "487.2060869471598`"}], "+", 
         RowBox[{"321.9262603175524`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"22.913612779668988`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"7.224787465235757`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-487.2060869471598 + 
       321.9262603175524 
        ArcTan[22.913612779668988` - ArcTan[7.224787465235757 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]]^2] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{139., -3.234042002129488}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "249.18582095166065`"}], "+", 
         RowBox[{"169.03460103820152`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-249.18582095166065` + 169.03460103820152` ArcTan[12 + 2 ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{140., -3.3041913678701875`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "310.3724551171421`"}], "+", 
         RowBox[{"208.39286368056875`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-310.3724551171421 + 
       208.39286368056875` 
        ArcTan[14.085903183616281` + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{146., -3.3632119503862414`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.30580795720293`", "\[VeryThinSpace]"}], "-", 
         FractionBox["379.3679982275815`", 
          RowBox[{
            RowBox[{"25.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.840444646718434`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.30580795720293 - 379.3679982275815/(25.258641845677218` + 
       Cos[7.840444646718434 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{167., -3.4137757588058064`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.323964253126245`", "\[VeryThinSpace]"}], "-", 
         FractionBox["463.07206392675755`", 
          RowBox[{
            RowBox[{"29.10671222806029`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.323964253126245` - 463.07206392675755`/(29.10671222806029 + 
       Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.641553316454072` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{198., -3.439699569016936}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "461.3490609750236`"}], "+", 
         RowBox[{"305.38513040321016`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"19.689417786393427`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"403.57546805050436`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-461.3490609750236 + 
       305.38513040321016` 
        ArcTan[19.689417786393427` + ArcTan[(403.57546805050436` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{205., -3.44134928824149}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "317.9811732370562`"}], "+", 
         RowBox[{"213.2847613573387`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.535602384520983`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-317.9811732370562 + 
       213.2847613573387 
        ArcTan[13.535602384520983` + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{216., -3.4490251091224144`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "449.0974868770854`"}], "+", 
         RowBox[{"297.5024938615732`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.588728100774986`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"89.89430809482145`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-449.0974868770854 + 
       297.5024938615732 
        ArcTan[18.588728100774986` + ArcTan[(89.89430809482145 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{218., -3.4558774573560123`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "472.80140042595514`"}], "+", 
         RowBox[{"312.8011449281774`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"22", "-", 
               FractionBox["9", 
                SqrtBox["82"]], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-472.80140042595514` + 
       312.8011449281774 ArcTan[22 - 9 82^Rational[-1, 2] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{219., -3.4732356356225673`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "454.0994028158185`"}], "+", 
         RowBox[{"300.7799508042444`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.99394469241401`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-454.0994028158185 + 
       300.7799508042444 ArcTan[20.99394469241401 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{227., -3.507006664667653}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.28563694142453`", "\[VeryThinSpace]"}], "-", 
         FractionBox["301.8405875169299`", 
          RowBox[{
            RowBox[{"21.35617150596153`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.28563694142453 - 301.8405875169299/(21.35617150596153 + Cos[2 Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{231., -3.5078600781228437`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "315.37862646001844`"}], "+", 
         RowBox[{"211.61543008401503`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.7863225731137681`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], 
                RowBox[{
                  RowBox[{"23.02708890961`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "+", 
               RowBox[{"Tan", "[", "1", "]"}]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-315.37862646001844` + 
       211.61543008401503` ArcTan[13 + ArcTan[0.7863225731137681 + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (23.02708890961 - Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1) Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]] + Tan[1]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{252., -3.513042879435787}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "401.4327119977782`"}], "+", 
         RowBox[{"266.88934273982477`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"16", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"845.3143459185612`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"38.04008947444624`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", "10", "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-401.4327119977782 + 
       266.88934273982477` ArcTan[16 + ArcTan[845.3143459185612 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(38.04008947444624 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[10] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{257., -3.5283550724048025`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.4941650054779567`"}], "+", 
         RowBox[{"1.5542223024988548`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.4941650054779567` + 1.5542223024988548` (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[2.2010988964402785` + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[2.2010988964402785` + (Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{258., -3.5292777154829036`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "274.41660348857255`"}], "+", 
         RowBox[{"185.223822329381`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               FractionBox["27", "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-274.41660348857255` + 
       185.223822329381 ArcTan[Rational[27, 2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{262., -3.535126796344092}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "500.1674672410574`"}], "+", 
         RowBox[{"330.31851667869694`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"21.923368892471313`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "]"}], "]"}], 
                  "]"}]], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-500.1674672410574 + 
       330.31851667869694` ArcTan[21.923368892471313` + E^ArcTan[
             ArcTan[
              Cos[E^(E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]])]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{264., -3.536500399831727}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "281.1578168289475`"}], "+", 
         RowBox[{"189.56741074978567`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-281.1578168289475 + 189.56741074978567` ArcTan[13 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.5907670224691897`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "363.8249229637563`"}], "+", 
         RowBox[{"243.03380395621002`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"10", "+", 
                   RowBox[{"ArcTan", "[", "5", "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-363.8249229637563 + 
       243.03380395621002` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10 + ArcTan[5] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{291., -3.598820492398446}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.936952651286745`", "\[VeryThinSpace]"}], "-", 
         FractionBox["242.48792882914975`", 
          RowBox[{
            RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"0.3087771196507995`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"2.0131650035986226`", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], " ", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.936952651286745` - 242.48792882914975`/(14.085903183616281` + 
       ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + ArcTan[10.544750992301736` - ArcTan[
          Cos[(0.3087771196507995 Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]) Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "11"]], 
          Hue[
           Rational[11, 16], 1, 
           Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "6"]], 
           Hue[
            Rational[3, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]^2] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{297., -3.6002610690537304`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.521252456612608`", "\[VeryThinSpace]"}], "-", 
         FractionBox["318.5029411635791`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "+", 
                RowBox[{"Sin", "[", "3", "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.3655872124935087`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.835373968998163`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "7", "]"}], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.521252456612608` - 318.5029411635791/(22.258641845677218` + 
       Cos[7 + Sin[3] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[1.3655872124935087` - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.835373968998163 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[
            Cos[7]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{302., -3.6021510838335944`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.9363428140655`", "\[VeryThinSpace]"}], "-", 
         FractionBox["242.48043594881852`", 
          RowBox[{
            RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"0.3179607928615242`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                  "]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"2.0131650035986226`", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], " ", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.9363428140655 - 242.48043594881852`/(14.085903183616281` + ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + ArcTan[10.544750992301736` - ArcTan[
          Cos[(0.3179607928615242 Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "11"]], 
          Hue[
           Rational[11, 16], 1, 
           Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "6"]], 
           Hue[
            Rational[3, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]^2] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{322., -3.610405114147851}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "432.88660482849264`"}], "+", 
         RowBox[{"287.1405014229677`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"26.984271053493075`", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"605.3632020757566`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-432.88660482849264` + 
       287.1405014229677 
        ArcTan[15.79037150445428 + ArcTan[(26.984271053493075` Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]) Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(605.3632020757566 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{330., -3.6654121773067736`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "282.47941376484897`"}], "+", 
         RowBox[{"190.46582890051593`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"7.126622684847211`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-282.47941376484897` + 190.46582890051593` ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Cos[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[7.126622684847211 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{331., -3.665496576901393}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "312.02593311211524`"}], "+", 
         RowBox[{"209.44242664605568`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.974148527217302`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-312.02593311211524` + 
       209.44242664605568` ArcTan[13.974148527217302` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{349., -3.6771690888719597`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "308.16226836627436`"}], "+", 
         RowBox[{"206.98771053966612`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.999996081310284`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", "6", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-308.16226836627436` + 
       206.98771053966612` ArcTan[12.999996081310284` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[6] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{376., -3.677497277554136}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.003110608037457`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1903121926969925`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.003110608037457 - 0.1903121926969925 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Sin[
           Style[
            TraditionalForm[
             Subscript["x", "14"]], 
            Hue[
             Rational[7, 8], 1, 
             Rational[1, 2]]]]] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{377., -3.701443654148636}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "627.0420928111864`"}], "+", 
         RowBox[{"294.41247244215197`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"19.708499536878648`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.639143700803533`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-627.0420928111864 + 
       294.41247244215197` (E^
          ArcTan[19.708499536878648` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.639143700803533` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.7026619985265743`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "312.6286943446779`"}], "+", 
         RowBox[{"209.84767075806474`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.999996081310284`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-312.6286943446779 + 
       209.84767075806474` ArcTan[12.999996081310284` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{412., -3.7565516266792014`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"23.258326183131224`", "\[VeryThinSpace]"}], "-", 
         FractionBox["749.842905923444`", 
          RowBox[{
            RowBox[{"39.835919262570016`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      23.258326183131224` - 749.842905923444/(39.835919262570016` + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{437., -3.7630574594891577`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.020417716405652`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1879510063825085`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.020417716405652 - 0.1879510063825085 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{458., -3.804865106032673}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.409620232092767`", "\[VeryThinSpace]"}], "-", 
         FractionBox["481.80476613619663`", 
          RowBox[{
            RowBox[{"30.219576915276033`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.409620232092767` - 481.80476613619663`/(30.219576915276033` + 
       Cos[7 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{466., -3.8135682295979834`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.025894264022976673`"}], "+", 
         RowBox[{"0.8199910277736677`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", "2", "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.025894264022976673` + 0.8199910277736677 (ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{478., -3.8168219224837583`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.27896806988712`", "\[VeryThinSpace]"}], "-", 
         FractionBox["463.4204313795246`", 
          RowBox[{
            RowBox[{"28.147292267370727`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "]"}], "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.27896806988712 - 463.4204313795246/(28.147292267370727` + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "12"]], 
           Hue[
            Rational[3, 4], 1, 
            Rational[1, 2]]] + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[
          Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{486., -3.8376026892017703`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.59228599357639`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7853683407664575`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.59228599357639 + 0.7853683407664575 (-ArcTan[ArcTan[Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]]] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[(-1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{526., -3.846846406655414}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.95227468496055`", "\[VeryThinSpace]"}], "-", 
         FractionBox["527.7404504693675`", 
          RowBox[{
            RowBox[{"32.01389418295415`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
            "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.95227468496055 - 527.7404504693675/(32.01389418295415 + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{567., -3.8499547203128714`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1063.8762647594065`"}], "+", 
         RowBox[{"689.3575605888391`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"44.92689708855325`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                   "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1063.8762647594065` + 
       689.3575605888391 ArcTan[44.92689708855325 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Sin[Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] (1 + Tan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{602., -3.869059784969227}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.002310783610753`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18277529920918234`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]]], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.9050499066996167`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.002310783610753 - 0.18277529920918234` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           Cos[(E^(E^Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]) Cos[1.9050499066996167` + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]]]) Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + ArcTan[ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{631., -3.8700133964012564`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1029.316747384709`"}], "+", 
         RowBox[{"667.228669698377`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.261171969451944`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 FractionBox[
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                  SqrtBox[
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1029.316747384709 + 
       667.228669698377 ArcTan[43.261171969451944` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]] (1 + Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{136., -3.2194682503175085`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "300.90992814449424`"}], "+", 
         RowBox[{"202.3330721706009`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"5760", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-300.90992814449424` + 
       202.3330721706009 ArcTan[9 + ArcTan[((5760 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{137., -3.225914790361306}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.732884015188574`"}], "+", 
         RowBox[{"1.7014719086110714`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.379682254762987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.732884015188574 + 
       1.7014719086110714` (ArcTan[7.1182925689352174` + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.379682254762987 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + Log[7.1182925689352174` + (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{139., -3.23394225567069}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "247.1877491575992`"}], "+", 
         RowBox[{"167.74660606000825`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.913588932593228`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-247.1877491575992 + 
       167.74660606000825` ArcTan[11.913588932593228` + 2 ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{140., -3.2462159327334157`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "225.54333054420707`"}], "+", 
         RowBox[{"153.79128242420163`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.726655926794734`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-225.54333054420707` + 
       153.79128242420163` ArcTan[11.726655926794734` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{142., -3.2512990732211566`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "375.320050174823`"}], "+", 
         RowBox[{"250.13667638608376`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.500123430271337`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}]], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-375.320050174823 + 
       250.13667638608376` ArcTan[17.500123430271337` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[E^Sin[Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]^2]] + Sin[E^Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{145., -3.2702812308031737`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "426.27568610940597`"}], "+", 
         RowBox[{"282.8777975926839`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"19", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", "8", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-426.27568610940597` + 
       282.8777975926839 ArcTan[19 + ArcTan[Cos[8] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{146., -3.3186406368299814`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.10530499170082`", "\[VeryThinSpace]"}], "-", 
         FractionBox["442.0669839942774`", 
          RowBox[{
            RowBox[{"28.061100598346478`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.10530499170082 - 442.0669839942774/(28.061100598346478` + 
       Cos[14.419547281892406` - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{147., -3.362218909385288}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.5538044940775801`"}], "+", 
         RowBox[{"1.679752385726243`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.8047949685514126`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.601269800430636`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.5538044940775801` + 
       1.679752385726243 (
         ArcTan[1.8047949685514126` + (3.601269800430636 + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])^2] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + (Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]])^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{154., -3.3628099963993625`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "443.5086523393778`"}], "+", 
         RowBox[{"293.9623783375182`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"19.47099665724813`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-443.5086523393778 + 
       293.9623783375182 ArcTan[19.47099665724813 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{167., -3.3949589810106606`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.492796034558857`", "\[VeryThinSpace]"}], "-", 
         FractionBox["568.6322515810598`", 
          RowBox[{
            RowBox[{"33.526259509952695`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.492796034558857` - 568.6322515810598/(33.526259509952695` + 
       Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.641553316454072` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{191., -3.411257717565657}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "315.0184337218772`"}], "+", 
         RowBox[{"211.36900758575456`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-315.0184337218772 + 
       211.36900758575456` ArcTan[10 + ArcTan[(((54 Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{203., -3.4239412742413493`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "164.66297356758034`"}], "+", 
         RowBox[{"73.7453311974488`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"17.18912650960626`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Sin", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-164.66297356758034` + 
       73.7453311974488 ArcTan[17.18912650960626 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{205., -3.435052451659506}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "295.07553001534063`"}], "+", 
         RowBox[{"198.5757677516932`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.786322573113768`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.7863225731137682`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
                "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-295.07553001534063` + 
       198.5757677516932 ArcTan[13.786322573113768` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[1.7863225731137682` + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + 2 Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]] + 2 Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{208., -3.438257087474676}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "313.1662004102921`"}], "+", 
         RowBox[{"210.1678590871687`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"118.00546841524245`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "4"], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-313.1662004102921 + 
       210.1678590871687 
        ArcTan[10 + 
          ArcTan[(((118.00546841524245` ArcTan[2.0096060494165187` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]) ArcTan[6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{216., -3.448139000444881}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "496.6843203355562`"}], "+", 
         RowBox[{"328.0728291860115`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.18912650960626`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"89.89430809482145`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-496.6843203355562 + 
       328.0728291860115 
        ArcTan[20.18912650960626 + ArcTan[(89.89430809482145 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{220., -3.471828022132295}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "474.8965154813108`"}], "+", 
         RowBox[{"314.1468319030311`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"19.567379528818783`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"310.9151516609087`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-474.8965154813108 + 
       314.1468319030311 
        ArcTan[19.567379528818783` + ArcTan[(310.9151516609087 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[7 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{227., -3.4800208079614254`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "412.62199303363116`"}], "+", 
         RowBox[{"274.1169808823292`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.599725492723756`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"15.603884208136735`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-412.62199303363116` + 
       274.1169808823292 
        ArcTan[17.599725492723756` + ArcTan[(15.603884208136735` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[7 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{228., -3.5040799699194514`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "342.6995924744258`"}], "+", 
         RowBox[{"229.19454041171196`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", "2", "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", "1", "]"}]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-342.6995924744258 + 
       229.19454041171196` ArcTan[13 + ArcTan[2] + ArcTan[E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Cos[
              Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[1]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{257., -3.5133693761939373`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "252.8046054880665`"}], "+", 
         RowBox[{"171.29841956321664`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"Cos", "[", "2", "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-252.8046054880665 + 
       171.29841956321664` ArcTan[13 + Cos[2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{274., -3.5822039234674463`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1278.3960753477045`"}], "+", 
         RowBox[{"1647.5786495803916`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"18.911661864745632`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], "-", 
                 
                 FractionBox["1", 
                  RowBox[{"20", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.285984840096106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], 
                    ")"}]}]]}], "]"}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1278.3960753477045` + 1647.5786495803916` ArcTan[
          ArcTan[ArcTan[18.911661864745632` + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]] + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + (1 + Cos[
                 Rational[1, 2]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]])^(-1)] + 
           Rational[-1, 20]/(8.285984840096106 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]])]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.5951381407007905`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "157.59011531309665`"}], "+", 
         RowBox[{"71.00215727751906`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"12.630654175918018`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"2.0131650035986226`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-157.59011531309665` + 
       71.00215727751906 ArcTan[12.630654175918018` + ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + ArcTan[10.544750992301736` - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{307., -3.5978475038055433`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "363.35969209773526`"}], "+", 
         RowBox[{"242.74370223261403`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-363.35969209773526` + 
       242.74370223261403` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` - ArcTan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{322., -3.601334619438163}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.087328524992071`"}], "+", 
         RowBox[{"1.9143827389680592`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1.6654238281788025`*^-6", "+", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.087328524992071 + 
       1.9143827389680592` (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1.6654238281788025`*^-6 + 4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{329., -3.6048651973387362`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7314617719273345`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.859453533014663`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "4"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7314617719273345 + 0.859453533014663 (ArcTan[(9 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^4 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{330., -3.661160012362118}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "330.1628136644005`"}], "+", 
         RowBox[{"221.1332799381058`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"14", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-330.1628136644005 + 221.1332799381058 ArcTan[14 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Cos[
               Rational[1, 8]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.488694565552803 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{349., -3.6653672452430697`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "335.00399371793924`"}], "+", 
         RowBox[{"224.23081275030458`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"14", "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-335.00399371793924` + 224.23081275030458` ArcTan[14 + Cos[
            Rational[1, 2]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{361., -3.6691011408388303`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8432717107127927`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19084618422213112`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8432717107127927` - 0.19084618422213112` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{377., -3.6992922799014005`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "285.9119459810452`"}], "+", 
         RowBox[{"192.68757760180114`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               FractionBox["121", "10"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-285.9119459810452 + 
       192.68757760180114` ArcTan[Rational[121, 10] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{418., -3.7041283294945684`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.6317008609403634`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1923410459007634`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"59.040221290275575`", "\[VeryThinSpace]"}], "-", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.6317008609403634` - 0.1923410459007634 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[59.040221290275575` - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]]] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{419., -3.73810373249731}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "295.3015515783451`"}], "+", 
         RowBox[{"198.73030439385985`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"8.388694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-295.3015515783451 + 198.73030439385985` ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[8.388694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{429., -3.7483534881104776`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7166532061306878`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8616229252927906`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.4081203015320267`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.7166532061306878 + 
       0.8616229252927906 (ArcTan[1.4081203015320267` + Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{458., -3.802236747830156}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.04494395875837652`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8152437241610969`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.04494395875837652 + 0.8152437241610969 (ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] - Style[
            TraditionalForm[
             Subscript["x", "5"]], 
            Hue[
             Rational[5, 16], 1, 
             Rational[5, 6]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{467., -3.810004919470153}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.651172061278967`", "\[VeryThinSpace]"}], "-", 
         FractionBox["503.0830938181761`", 
          RowBox[{
            RowBox[{"31.05496990829101`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.651172061278967` - 503.0830938181761/(31.05496990829101 + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{494., -3.8135967764607193`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "916.3682806339813`"}], "+", 
         RowBox[{"594.9958874842004`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.28119298697581`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                "2"], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-916.3682806339813 + 
       594.9958874842004 ArcTan[39.28119298697581 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]^2 + Sin[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]^2] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{497., -3.828340621726359}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.235498075789057`", "\[VeryThinSpace]"}], "-", 
         FractionBox["466.07560823655115`", 
          RowBox[{
            RowBox[{"28.566839549263133`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "]"}], "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.235498075789057` - 466.07560823655115`/(28.566839549263133` + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[
          Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{522., -3.833695768333231}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "447.0194475950065`"}], "+", 
         RowBox[{"296.2591366024369`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", "7", "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.6003508331343324`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-447.0194475950065 + 
       296.2591366024369 
        ArcTan[15.79037150445428 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + 
          ArcTan[((54 Cos[4.189126509606261 + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "15"]], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]] + Cos[Log[7]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.6003508331343324` + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{524., -3.834777745426767}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1051.435367117042`"}], "+", 
         RowBox[{"681.4051420486295`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.75967055048048`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.6073934555129563`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1051.435367117042 + 
       681.4051420486295 ArcTan[43.75967055048048 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[0.6073934555129563 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + 2 Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[7 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{615., -3.8627396295742624`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1048.5921891900398`"}], "+", 
         RowBox[{"679.5842974786423`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.601311474478905`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 FractionBox[
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                  SqrtBox[
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1048.5921891900398` + 
       679.5842974786423 ArcTan[43.601311474478905` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]] (1 + Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{136., -3.2194604957549178`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "300.9011123956513`"}], "+", 
         RowBox[{"202.3273772495946`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"4050.7120072146413`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-300.9011123956513 + 
       202.3273772495946 ArcTan[9 + ArcTan[((4050.7120072146413` Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{140., -3.222716440600135}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "257.72202229744335`"}], "+", 
         RowBox[{"174.54591114903755`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.1740019304426`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-257.72202229744335` + 
       174.54591114903755` ArcTan[12.1740019304426 + 2 ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Sin[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{141., -3.2292994627134535`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "369.05230604522166`"}], "+", 
         RowBox[{"246.1432459271547`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"16", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-369.05230604522166` + 246.1432459271547 ArcTan[16 + ArcTan[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "10"]], 
                Hue[
                 Rational[5, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Cos[Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{146., -3.2423141181959885`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.6809459537608017`"}], "+", 
         RowBox[{"1.5576245642468558`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.6809459537608017 + 1.5576245642468558` (ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2] + (Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]])^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{147., -3.3315964151024953`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "330.728653046767`"}], "+", 
         RowBox[{"221.4948276090741`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.03028706728751`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-330.728653046767 + 
       221.4948276090741 ArcTan[15.03028706728751 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{152., -3.350109288326901}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.272056480398727`"}], "+", 
         RowBox[{"4.917820872563908`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"7", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["1.811563375773954`", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.272056480398727 + 4.917820872563908 Log[7 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[1.811563375773954^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{167., -3.377432906975616}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.73901217882481`", "\[VeryThinSpace]"}], "-", 
         FractionBox["337.8672803544945`", 
          RowBox[{
            RowBox[{"23.276450674857116`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.73901217882481 - 337.8672803544945/(23.276450674857116` + Cos[7 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.389628855842475}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "338.724972016313`"}], "+", 
         RowBox[{"226.62685410117163`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.1992294621115942`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-338.724972016313 + 
       226.62685410117163` 
        ArcTan[14.085903183616281` + ArcTan[1.1992294621115942` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{205., -3.4313691047012815`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "376.0951924865342`"}], "+", 
         RowBox[{"250.67400751004445`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.7605492945042`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"205.64729061781878`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-376.0951924865342 + 
       250.67400751004445` 
        ArcTan[15.7605492945042 + ArcTan[(205.64729061781878` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.4369929672675146`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "621.5302125737356`"}], "+", 
         RowBox[{"408.3017915531842`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"24.47537709687036`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-621.5302125737356 + 
       408.3017915531842 ArcTan[24.47537709687036 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{218., -3.443011430605715}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.912653693104282`", "\[VeryThinSpace]"}], "-", 
         FractionBox["243.42723249812008`", 
          RowBox[{
            RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"13.111045832267948`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"2.0131650035986226`", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], " ", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.912653693104282` - 243.42723249812008`/(14.085903183616281` + 
       ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + ArcTan[13.111045832267948` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "11"]], 
          Hue[
           Rational[11, 16], 1, 
           Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]^2] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{220., -3.4570917711881326`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "307.2285346350739`"}], "+", 
         RowBox[{"206.3038839607138`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.147906316000817`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                    RowBox[{"Sin", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "7"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-307.2285346350739 + 
       206.3038839607138 ArcTan[15.147906316000817` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(1 + Sin[1] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 7]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{238., -3.459374420006289}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "73.40625386093947`"}], "+", 
         RowBox[{"60.69069235713004`", " ", 
           RowBox[{"ArcTan", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"8.189126509606261`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"208.67572389064014`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Sin", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-73.40625386093947 + 
       60.69069235713004 
        ArcTan[(8.189126509606261 + ArcTan[(208.67572389064014` Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{239., -3.483238259348379}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "386.69395243491755`"}], "+", 
         RowBox[{"257.3847194432957`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.756506038425044`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"176.72792657018135`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-386.69395243491755` + 
       257.3847194432957 
        ArcTan[16.756506038425044` + ArcTan[(176.72792657018135` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[3 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{241., -3.4919110217598193`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "577.1035068107044`"}], "+", 
         RowBox[{"379.72970907667104`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"21", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"845.3143459185612`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"38.04008947444624`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-577.1035068107044 + 
       379.72970907667104` ArcTan[21 + ArcTan[845.3143459185612 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(38.04008947444624 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{269., -3.5010457836365747`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "739.9235338603315`"}], "+", 
         RowBox[{"244.20800717881752`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", 
                    SqrtBox["5"]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-739.9235338603315 + 
       244.20800717881752` (ArcTan[24.59388935870163 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[5^Rational[-1, 2] - E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.5107255700153277`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "362.53892454040584`"}], "+", 
         RowBox[{"241.94098322752535`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.704794415548982`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-362.53892454040584` + 
       241.94098322752535` 
        ArcTan[14.704794415548982` + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Sin[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{275., -3.5401570809203937`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "348.7295565094533`"}], "+", 
         RowBox[{"233.09522823574613`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.199134013005816`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"389.8696996191449`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"378.90980295353506`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-348.7295565094533 + 
       233.09522823574613` 
        ArcTan[12.199134013005816` + ArcTan[(389.8696996191449 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(378.90980295353506` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Style[
                 TraditionalForm[
                  Subscript["x", "15"]], 
                 Hue[
                  Rational[15, 16], 1, 
                  Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{276., -3.56478535296979}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.846457231766909`"}], "+", 
         RowBox[{"1.5943661374339824`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", "\[ExponentialE]", "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.846457231766909 + 1.5943661374339824` (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + E + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + (Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{278., -3.581515307066763}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.026488460713625`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8627542875402779`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 SqrtBox[
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.026488460713625 + 0.8627542875402779 (ArcTan[(6 + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]])^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{310., -3.582587252610189}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "427.1851075012458`"}], "+", 
         RowBox[{"283.49804547437947`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.54816398174844`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"162", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", "6", "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-427.1851075012458 + 
       283.49804547437947` ArcTan[17.54816398174844 + ArcTan[(162 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[6]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{314., -3.5911565509053385`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.4678701093025515`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19874383197191242`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"8", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.4678701093025515` - 0.19874383197191242` (-(E^(E^(-ArcTan[8 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{317., -3.5978434866640354`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.771123803280172`"}], "+", 
         RowBox[{"1.697317587989864`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", "\[ExponentialE]", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.771123803280172 + 1.697317587989864 (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + E + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{329., -3.600997156485809}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "363.63147295026135`"}], "+", 
         RowBox[{"242.91659682132791`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"5", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-363.63147295026135` + 
       242.91659682132791` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` - ArcTan[
             Cos[5 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{330., -3.6112186578635344`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.087935628278349`"}], "+", 
         RowBox[{"1.9141851488822845`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1.6654238281788025`*^-6", "+", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.087935628278349 + 
       1.9141851488822845` (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Sin[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + Log[1.6654238281788025`*^-6 + 4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{334., -3.657802581423661}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.584473645815642`", "\[VeryThinSpace]"}], "-", 
         FractionBox["320.37804524983045`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "7", "]"}], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.584473645815642` - 320.37804524983045`/(22.258641845677218` + 
       Cos[7 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[
            Cos[7]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{352., -3.664738408242671}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.269240503765517`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19895525420947166`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                 "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.269240503765517 - 0.19895525420947166` (-(E^(E^(-ArcTan[6 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{367., -3.6654028000137324`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "334.8031357380791`"}], "+", 
         RowBox[{"224.10156882562623`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", "8"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-334.8031357380791 + 224.10156882562623` ArcTan[13 + Cos[
            Rational[1, 8]] + Cos[
            Rational[1, 2]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{385., -3.6956583791948434`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "308.3352249681475`"}], "+", 
         RowBox[{"207.12673127380825`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-308.3352249681475 + 207.12673127380825` ArcTan[13 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.6980542138001895`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "337.82229373446734`"}], "+", 
         RowBox[{"226.06124230173984`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.98822900605531`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.499126084842551`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-337.82229373446734` + 
       226.06124230173984` ArcTan[13.98822900605531 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.499126084842551 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{422., -3.7336956649061377`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "308.0626829898644`"}], "+", 
         RowBox[{"206.9135122713311`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-308.0626829898644 + 206.9135122713311 ArcTan[13 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{440., -3.7392367656175303`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "543.2010415722799`"}], "+", 
         RowBox[{"255.90517157185886`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"17.465283176327702`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.494691062541248`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    FractionBox["4.189126509606261`", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-543.2010415722799 + 
       255.90517157185886` (E^
          ArcTan[17.465283176327702` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.494691062541248` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + 4.189126509606261/(4 + Style[
                  TraditionalForm[
                   Subscript["x", "15"]], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]]]^2) + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{458., -3.8016298746482455`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.626229831638433`", "\[VeryThinSpace]"}], "-", 
         FractionBox["501.15067295130126`", 
          RowBox[{
            RowBox[{"31.05496990829101`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.626229831638433` - 501.15067295130126`/(31.05496990829101 + 
       Cos[7 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{503., -3.815965377759859}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.963255272855616`", "\[VeryThinSpace]"}], "-", 
         FractionBox["528.1466309995243`", 
          RowBox[{
            RowBox[{"32.01389418295415`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", "7", "]"}]}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
            "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.963255272855616` - 528.1466309995243/(32.01389418295415 + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[2 Cos[7] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{548., -3.8263890349608163`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "284.28162579368967`"}], "+", 
         RowBox[{"191.63131120322146`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"10.999996081310284`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-284.28162579368967` + 
       191.63131120322146` ArcTan[10.999996081310284` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Sin[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{619., -3.8557523188347917`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1074.903921403236`"}], "+", 
         RowBox[{"696.3855463889639`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"44.25376257487277`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                   "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1074.903921403236 + 
       696.3855463889639 ArcTan[44.25376257487277 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Sin[Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] (1 + Tan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{145., -3.2197997515570442`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "300.6672481835313`"}], "+", 
         RowBox[{"202.1760636442167`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"1446.9163555798934`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-300.6672481835313 + 
       202.1760636442167 ArcTan[9 + ArcTan[((1446.9163555798934` Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{147., -3.329378706521758}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "310.2231293006596`"}], "+", 
         RowBox[{"208.29552069211056`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.22844972669056`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-310.2231293006596 + 
       208.29552069211056` ArcTan[14.22844972669056 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{160., -3.3303245583924377`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "380.35939536107395`"}], "+", 
         RowBox[{"253.44984899120365`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"17", "+", 
               FractionBox["\[Pi]", "4"], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-380.35939536107395` + 
       253.44984899120365` ArcTan[17 + Rational[1, 4] Pi + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{171., -3.34926131389768}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "316.00881857969915`"}], "+", 
         RowBox[{"212.04589731719759`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               FractionBox["\[Pi]", "4"], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", "1", "]"}]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-316.00881857969915` + 
       212.04589731719759` ArcTan[13 + Rational[1, 4] Pi + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[1]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{175., -3.3887570840438435`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "323.69832632545985`"}], "+", 
         RowBox[{"217.00056431962932`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.928261061276817`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"5.9938267690997264`", "\[VeryThinSpace]"}], "-", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-323.69832632545985` + 
       217.00056431962932` ArcTan[15.928261061276817` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Log[5.9938267690997264` - Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{205., -3.430928297714432}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "376.0573558487514`"}], "+", 
         RowBox[{"250.64958361989227`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.7605492945042`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-376.0573558487514 + 
       250.64958361989227` 
        ArcTan[15.7605492945042 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.43618797440371}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "419.3369338356075`"}], "+", 
         RowBox[{"278.44414559623215`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-419.3369338356075 + 278.44414559623215` ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{223., -3.456495209818577}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "373.59570639835005`"}], "+", 
         RowBox[{"249.05845683973635`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.946918986900421`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-373.59570639835005` + 
       249.05845683973635` 
        ArcTan[14.946918986900421` + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{243., -3.4751616256837217`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "452.6134971075878`"}], "+", 
         RowBox[{"299.8921426590022`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "-", "\[ExponentialE]", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                  "]"}]], "+", "\[Pi]", "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-452.6134971075878 + 299.8921426590022 ArcTan[18 - E + E^ArcTan[
             Cos[
              Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Pi - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{253., -3.4850002749811844`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "367.8761791468047`"}], "+", 
         RowBox[{"245.2917742066122`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.082814430529336`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-367.8761791468047 + 
       245.2917742066122 
        ArcTan[16.082814430529336` + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{276., -3.5557537437673425`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.7950272769504003`"}], "+", 
         RowBox[{"1.5907355063861897`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", "\[ExponentialE]", "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.7950272769504003` + 1.5907355063861897` (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[2.2010988964402785` + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + E + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + (Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{297., -3.5743293721584513`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "429.6260587846889`"}], "+", 
         RowBox[{"285.06213582882896`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"19", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", "3", "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-429.6260587846889 + 
       285.06213582882896` ArcTan[19 + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[3] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{316., -3.5765416166774493`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.315231313486457`", "\[VeryThinSpace]"}], "-", 
         FractionBox["307.7320199137037`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"15.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
                   "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.315231313486457` - 307.7320199137037/(22.258641845677218` + 
       Cos[15.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[7.419547281892406 + Cos[Tan[
             Cos[13.222006034561666` - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{317., -3.5968780148867596`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "413.3517777890341`"}], "+", 
         RowBox[{"274.6203196397014`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.621450523904594`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"226.21283151873808`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"403.57546805050436`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"3.1666199982033474`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-413.3517777890341 + 
       274.6203196397014 
        ArcTan[14.621450523904594` + ArcTan[(226.21283151873808` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(403.57546805050436` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[3.1666199982033474` + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{334., -3.6088136082465514`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"2.094202846726532`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7642566925702926`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[2.094202846726532 + 0.7642566925702926 (-ArcTan[ArcTan[Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]^4] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{338., -3.6300993559151564`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.769279223977315`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1944393915962661`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.769279223977315 - 0.1944393915962661 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{347., -3.6369980726834736`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.70024768556551`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19546944172483158`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[13, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.70024768556551 - 0.19546944172483158` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "13"]], 
           Hue[
            Rational[13, 16], 1, 
            Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{364., -3.6547196024672317`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.300904262066446`", "\[VeryThinSpace]"}], "-", 
         FractionBox["556.139141253404`", 
          RowBox[{
            RowBox[{"33.35460251799542`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.300904262066446` - 556.139141253404/(33.35460251799542 + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{365., -3.662394107967658}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.377857826996283`"}], "+", 
         RowBox[{"1.927853381036534`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.377857826996283 + 
       1.927853381036534 (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Log[2.2010988964402785` + 4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{377., -3.6651191784536237`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "629.9652626481769`"}], "+", 
         RowBox[{"295.75916466421637`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"19.708499536878648`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.904011197164452`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-629.9652626481769 + 
       295.75916466421637` (E^
          ArcTan[19.708499536878648` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.904011197164452` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.6968963033479447`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "338.08879033690727`"}], "+", 
         RowBox[{"226.23299913846998`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.999996081310284`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-338.08879033690727` + 
       226.23299913846998` ArcTan[13.999996081310284` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{412., -3.697846336710907}}]},
      StyleBox[
       RowBox[{
         RowBox[{"24.923229430857983`", "\[VeryThinSpace]"}], "-", 
         FractionBox["942.7201722734546`", 
          RowBox[{
            RowBox[{"46.269077957266035`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      24.923229430857983` - 942.7201722734546/(46.269077957266035` + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{426., -3.7311762856718684`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "443.4057486612418`"}], "+", 
         RowBox[{"293.9254366638837`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"219.15557116407143`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"18", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"828.1505913759556`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-443.4057486612418 + 
       293.9254366638837 
        ArcTan[15.79037150445428 + ArcTan[(219.15557116407143` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + 
          ArcTan[((18 ArcTan[828.1505913759556 Style[
                   TraditionalForm[
                    Subscript["x", "13"]], 
                   Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]]]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{466., -3.766618317675511}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "441.50917905954515`"}], "+", 
         RowBox[{"292.69476561211565`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.79037150445428`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"]}], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"15.600350833134332`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-441.50917905954515` + 
       292.69476561211565` 
        ArcTan[15.79037150445428 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "12"]], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]]]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (
              Log[4.189126509606261 + Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[15.600350833134332` + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{474., -3.778964787232989}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "143.52421818610526`"}], "+", 
         RowBox[{"65.04056443064854`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{"12", "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                "+", 
                RowBox[{"Csc", "[", 
                  RowBox[{"Sec", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
                "+", 
                FractionBox["1", 
                 RowBox[{"Log", "[", 
                   RowBox[{
                    RowBox[{"6.388694565552804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                FractionBox["1", 
                 RowBox[{"1", "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.4999960813102842`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-143.52421818610526` + 65.04056443064854 ArcTan[12 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[(Cos[
                Rational[1, 8]] + Cos[Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)] + Cos[Cos[
                Rational[1, 2]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Csc[
             Sec[(Sin[2] + Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]])^(-1)]] + 
           Log[6.388694565552804 + Log[6.488694565552803 + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^(-1) + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[1.4999960813102842` + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{491., -3.8007643182325688`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "291.30126531011314`"}], "+", 
         RowBox[{"196.16610662854478`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"11", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.888694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-291.30126531011314` + 196.16610662854478` ArcTan[11 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.888694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{510., -3.811126187261599}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "292.6486284352256`"}], "+", 
         RowBox[{"197.03032456272615`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"11", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-292.6486284352256 + 197.03032456272615` ArcTan[11 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{544., -3.81343049110969}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.471417840759686`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7944766456641752`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                    "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.471417840759686 + 0.7944766456641752 (-ArcTan[ArcTan[Cos[Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]] + Style[
                  TraditionalForm[
                   Subscript["x", "8"]], 
                  Hue[
                   Rational[1, 2], 1, 
                   Rational[1, 2]]]] + Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]] + Tan[
                Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "12"]], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]]]]]] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[(-1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{145., -3.2196954106368803`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "300.54670588289605`"}], "+", 
         RowBox[{"202.09807102849476`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"1000", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-300.54670588289605` + 
       202.09807102849476` ArcTan[9 + ArcTan[((1000 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{147., -3.2862185407539717`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "339.6315885210906`"}], "+", 
         RowBox[{"227.21696335697405`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.285132645727876`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-339.6315885210906 + 
       227.21696335697405` ArcTan[15.285132645727876` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{149., -3.309175329100723}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "317.26048285404113`"}], "+", 
         RowBox[{"212.8347688681384`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.928261061276817`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"2", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-317.26048285404113` + 
       212.8347688681384 ArcTan[15.928261061276817` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{171., -3.3479332406692768`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "275.65963062000486`"}], "+", 
         RowBox[{"186.0717490190652`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.9324732268360348`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-275.65963062000486` + 186.0717490190652 ArcTan[13 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[0.9324732268360348 + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{180., -3.3846385391636646`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.635707594446767`"}], "+", 
         RowBox[{"4.780447933851653`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.429142337261685`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.635707594446767 + 
       4.780447933851653 Log[1 + Log[2.429142337261685 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{205., -3.411658407898014}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "419.56785157472797`"}], "+", 
         RowBox[{"278.62323428469415`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.33842330586289`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-419.56785157472797` + 
       278.62323428469415` 
        ArcTan[17.33842330586289 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.4205346472558906`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.1440269533778929`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.016688951039743112`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"12.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.9999953893457124`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.4570580048577`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.1440269533778929 + 
       0.016688951039743112` (12.122264710056605` + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.9999953893457124 + (0.4570580048577 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{218., -3.4280560684984374`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.465430863260664`", "\[VeryThinSpace]"}], "-", 
         FractionBox["385.37215246827884`", 
          RowBox[{
            RowBox[{"25.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.465430863260664` - 385.37215246827884`/(25.258641845677218` + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{225., -3.4511995099635056`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "496.5340604943996`"}], "+", 
         RowBox[{"327.97727439683604`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.18912650960626`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"89.89430809482145`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-496.5340604943996 + 
       327.97727439683604` 
        ArcTan[20.18912650960626 + ArcTan[(89.89430809482145 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{227., -3.4536337501626955`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "469.97294779173455`"}], "+", 
         RowBox[{"310.96943494244096`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"19.599725492723756`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"15.603884208136735`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-469.97294779173455` + 
       310.96943494244096` 
        ArcTan[19.599725492723756` + ArcTan[(15.603884208136735` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[7 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{243., -3.4574176357116517`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "509.39809423172636`"}], "+", 
         RowBox[{"336.31491045708253`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"22", "-", 
               FractionBox["9", 
                SqrtBox["82"]], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-509.39809423172636` + 
       336.31491045708253` ArcTan[22 - 9 82^Rational[-1, 2] + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{254., -3.47053266890955}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "379.9254013660829`"}], "+", 
         RowBox[{"253.07451710169465`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "-", 
               FractionBox["9", 
                SqrtBox["82"]], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-379.9254013660829 + 
       253.07451710169465` ArcTan[18 - 9 82^Rational[-1, 2] + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.474737253676862}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "362.4522129922705`"}], "+", 
         RowBox[{"242.1452589353563`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"10", "+", 
                   RowBox[{"ArcTan", "[", "5", "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-362.4522129922705 + 
       242.1452589353563 ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10 + ArcTan[5] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{278., -3.4833675507777913`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.165502579614131`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2632931723794328`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"3.6252252761254273`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.165502579614131` - 0.2632931723794328 (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3.6252252761254273` + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{282., -3.537731449235009}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "286.2163616347292`"}], "+", 
         RowBox[{"192.82529824331655`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Csc", "[", "2", "]"}], "2"], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-286.2163616347292 + 192.82529824331655` ArcTan[12 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Csc[2]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{286., -3.537800573147904}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.781475473475536`"}], "+", 
         RowBox[{"5.015648447756598`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.300115778126962`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"0.26225254021994265`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.781475473475536 + 
       5.015648447756598 Log[1 + Log[2.300115778126962 + Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]^2 + (4 + Style[
                 TraditionalForm[
                  Subscript["x", "11"]], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + (0.26225254021994265` Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{297., -3.538834218674088}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.734153465400378`"}], "+", 
         RowBox[{"5.003314607539592`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.300115778126962`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"0.26225254021994265`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.734153465400378 + 
       5.003314607539592 Log[1 + Log[2.300115778126962 + Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]^2 + (4 + Style[
                 TraditionalForm[
                  Subscript["x", "11"]], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + (0.26225254021994265` Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.551050509209986}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.38380518249006`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.20260978641055233`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.38380518249006 - 
       0.20260978641055233` (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.56052564205673}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.736214174837077`"}], "+", 
         RowBox[{"4.998992633416128`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.300115778126962`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"0.26225254021994265`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.736214174837077 + 
       4.998992633416128 Log[1 + Log[2.300115778126962 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (4 + Style[
                 TraditionalForm[
                  Subscript["x", "11"]], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + (0.26225254021994265` Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{312., -3.56169224332093}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "202.43209278238808`"}], "+", 
         RowBox[{"45.64852582756373`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"14.130249108405627`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Csc", "[", 
                  RowBox[{"Sec", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
                "+", 
                FractionBox["1", 
                 RowBox[{"Log", "[", 
                   RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                FractionBox["1", 
                 RowBox[{"1", "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-202.43209278238808` + 
       45.64852582756373 E^ArcTan[14.130249108405627` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Csc[
             Sec[(Sin[2] + Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]])^(-1)]] + Log[6.488694565552803 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^(-1) + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                 Rational[1, 8]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{315., -3.5712553644221265`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "289.39839589580356`"}], "+", 
         RowBox[{"194.92766724388613`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.799058500570624`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-289.39839589580356` + 
       194.92766724388613` ArcTan[12.799058500570624` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{324., -3.5867027213183236`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"2.6250307161366377`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7251377401553132`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"2", "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[2.6250307161366377` + 0.7251377401553132 (-ArcTan[2 - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{350., -3.6068995471001863`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.064972964641763`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.20418958043653695`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.064972964641763 - 0.20418958043653695` (-(E^(E^(-ArcTan[6 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[6 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{352., -3.6300993559151564`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.769279223977315`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1944393915962661`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.769279223977315 - 0.1944393915962661 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{358., -3.6363340639255965`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "686.3774226634307`"}], "+", 
         RowBox[{"447.9688292900184`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"30.516111544687227`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.147695761381096`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-686.3774226634307 + 
       447.9688292900184 ArcTan[30.516111544687227` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[1.147695761381096 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[7 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{378., -3.6439450949680863`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"21.727049945739488`", "\[VeryThinSpace]"}], "-", 
         FractionBox["589.8910008428988`", 
          RowBox[{
            RowBox[{"33.75418502449384`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"10", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      21.727049945739488` - 589.8910008428988/(33.75418502449384 + 
       Cos[10 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{428., -3.7172888052276174`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "626.6665041424028`"}], "+", 
         RowBox[{"294.2408833250984`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"19.708499536878648`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.494691062541248`", "\[VeryThinSpace]"}], "+", 
                    
                    FractionBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "33"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-626.6665041424028 + 
       294.2408833250984 (E^
          ArcTan[19.708499536878648` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + 
            Cos[15.494691062541248` + Rational[1, 33] Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{447., -3.723696183057301}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.51976722562808`", "\[VeryThinSpace]"}], "-", 
         FractionBox["401.5546669763337`", 
          RowBox[{
            RowBox[{"26.688957490446313`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"0.13477911279580704`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.51976722562808 - 401.5546669763337/(26.688957490446313` + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[
           Cos[0.13477911279580704` + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{464., -3.7272893600602375`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "291.263576430144`"}], "+", 
         RowBox[{"196.10946849906315`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"8.388694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-291.263576430144 + 196.10946849906315` ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[(1 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]])^(-1)] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[8.388694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{477., -3.770069553122558}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "283.2302113059935`"}], "+", 
         RowBox[{"190.94458179946693`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.992193748539613`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"7.126622684847211`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-283.2302113059935 + 
       190.94458179946693` ArcTan[11.992193748539613` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[7.126622684847211 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Sin[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{489., -3.7789170783012334`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "295.8920946842516`"}], "+", 
         RowBox[{"199.10610512987222`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"7.888694565552804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-295.8920946842516 + 199.10610512987222` ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + 
          Log[7.888694565552804 + Cos[1 + Cos[
                 Rational[1, 2]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{548., -3.7979700289119305`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "283.2169271361321`"}], "+", 
         RowBox[{"190.95264081294928`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"10.999996081310284`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"7.126622684847211`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-283.2169271361321 + 
       190.95264081294928` ArcTan[10.999996081310284` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[7.126622684847211 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Sin[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{564., -3.8072252480890825`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1035.316577201529`"}], "+", 
         RowBox[{"671.0641277263994`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.63594641207696`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                   "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1035.316577201529 + 
       671.0641277263994 ArcTan[43.63594641207696 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Sin[Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] (1 + Tan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{643., -3.8116076971774597`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1034.443224233389`"}], "+", 
         RowBox[{"670.543156650894`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.14185438768466`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.6073934555129563`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                  "2"]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1034.443224233389 + 
       670.543156650894 ArcTan[43.14185438768466 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + 2 ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[0.6073934555129563 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + 2 Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]] (1 + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "7"]], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]]]]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{145., -3.219653627278085}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "300.85602130442805`"}], "+", 
         RowBox[{"202.29818527509195`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"5040", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-300.85602130442805` + 
       202.29818527509195` ArcTan[9 + ArcTan[((5040 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{147., -3.235522362857954}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "246.37296152100262`"}], "+", 
         RowBox[{"167.1527356460689`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.51960834365007`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-246.37296152100262` + 
       167.1527356460689 ArcTan[11.51960834365007 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{148., -3.2414517542139674`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "246.34018076599074`"}], "+", 
         RowBox[{"167.1951189247422`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.913588932593228`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                   "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-246.34018076599074` + 
       167.1951189247422 ArcTan[11.913588932593228` + 2 ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{151., -3.246959505636596}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "342.351142915594`"}], "+", 
         RowBox[{"228.96090264960864`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", "2", "]"}], "+", 
               RowBox[{"Cos", "[", "6", "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", "1", "]"}]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-342.351142915594 + 
       228.96090264960864` ArcTan[13 + ArcTan[2] + Cos[6] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[1]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{152., -3.2594902888410764`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.145309351129079`"}], "+", 
         RowBox[{"2.3278622650046787`", " ", 
           RowBox[{"Log", "[", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"5.477063115095553`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                  "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
              "2"], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.145309351129079 + 
       2.3278622650046787` Log[(5.477063115095553 + ArcTan[
             Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]]] + Cos[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{153., -3.2738986970718478`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.14352175477093554`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"1.7951422957134562`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"6.988615073697536`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.14352175477093554` + 
       1.7951422957134562` Log[6.988615073697536 + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]] + (ArcTan[
              Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{161., -3.293529869169105}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "313.2926188204239`"}], "+", 
         RowBox[{"210.28826956889165`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-313.2926188204239 + 
       210.28826956889165` ArcTan[14.085903183616281` + 2 ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{165., -3.295657252135866}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "389.1146384791172`"}], "+", 
         RowBox[{"259.0099138111031`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.501804311467012`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-389.1146384791172 + 
       259.0099138111031 
        ArcTan[18.501804311467012` + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{172., -3.2994366875942167`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "400.7949239576357`"}], "+", 
         RowBox[{"266.60289702596634`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.011024089573652`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-400.7949239576357 + 
       266.60289702596634` ArcTan[18.011024089573652` + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.3073590117114975`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "312.80455730641614`"}], "+", 
         RowBox[{"209.97159822563412`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-312.80455730641614` + 
       209.97159822563412` ArcTan[14.085903183616281` + ArcTan[
            ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{174., -3.3259272136911266`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.6877779552668364`"}], "+", 
         RowBox[{"4.252841008573285`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.8216396508809565`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.6877779552668364` + 
       4.252841008573285 
        Log[4.8216396508809565` + ArcTan[(Rational[50, 7] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{180., -3.3799358191297317`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.656066497337587`"}], "+", 
         RowBox[{"4.785462146022956`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"3.382894990021157`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.656066497337587 + 
       4.785462146022956 Log[1 + Log[3.382894990021157 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.4119343168073772`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.1455241328914685`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.01667986072640418`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"12.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.926038969708321`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.9999953893457124`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.4570580048577`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.1455241328914685 + 
       0.01667986072640418 (12.122264710056605` + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.926038969708321 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.9999953893457124 + (0.4570580048577 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{212., -3.4125691963449203`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.369571066718407`"}], "+", 
         RowBox[{"0.8864356623855245`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.357083250063511`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.912103860432534`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.165090189044747`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", "5", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.369571066718407 + 
       0.8864356623855245 (ArcTan[7.1182925689352174` + Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[6.357083250063511 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.912103860432534 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[6.165090189044747 + ((Log[5] + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2 - Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]])^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{219., -3.414929943140457}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "307.65974106372204`"}], "+", 
         RowBox[{"206.5943402307215`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.657476320898844`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-307.65974106372204` + 
       206.5943402307215 ArcTan[15.657476320898844` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{220., -3.426179861259909}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "267.3111056480167`"}], "+", 
         RowBox[{"180.65033035788153`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"0.7863225731137681`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-267.3111056480167 + 180.65033035788153` ArcTan[13 + ArcTan[
            ArcTan[0.7863225731137681 + E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{226., -3.4438983278069397`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "305.28738801939414`"}], "+", 
         RowBox[{"205.04320487881276`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"14", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", "1", "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-305.28738801939414` + 205.04320487881276` ArcTan[14 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[(2 Cos[
                Rational[1, 8]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[1] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{245., -3.4515080011381523`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "461.3081272701752`"}], "+", 
         RowBox[{"305.4059012245209`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox["\[ExponentialE]", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "-", 
               RowBox[{"Sin", "[", "81", "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-461.3081272701752 + 305.4059012245209 ArcTan[18 + E^Cos[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + ArcTan[
            Cos[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] - Sin[81] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{248., -3.451781559111509}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "459.2764658071285`"}], "+", 
         RowBox[{"304.115027047397`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "+", 
               RowBox[{"ArcTan", "[", "9", "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "-", 
               RowBox[{"Sin", "[", 
                 FractionBox["1", "10"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-459.2764658071285 + 304.115027047397 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] + ArcTan[9] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] - Sin[
           Rational[1, 10]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{257., -3.4558087009269025`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "73.3378862178846`"}], "+", 
         RowBox[{"60.64225217257874`", " ", 
           RowBox[{"ArcTan", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"8.189126509606261`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"60", " ", 
                    RowBox[{"Log", "[", "7", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Sin", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-73.3378862178846 + 
       60.64225217257874 ArcTan[(8.189126509606261 + ArcTan[((60 Log[7]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{262., -3.4664475159363057`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "358.032791199273`"}], "+", 
         RowBox[{"239.09966290253973`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.374549769929878`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"4.740857876994031`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-358.032791199273 + 
       239.09966290253973` ArcTan[17.374549769929878` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Sin[E^Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4] - Sin[4.740857876994031 - Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{265., -3.466464488153587}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "307.11071734996597`"}], "+", 
         RowBox[{"206.50913916738352`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"12", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-307.11071734996597` + 
       206.50913916738352` ArcTan[12.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[12 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.471753009330987}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.84110684816265`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.02093520788707214`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"6.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"7.575350573792917`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.4570580048577`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.84110684816265 + 
       0.02093520788707214 (6.122264710056605 + 
          ArcTan[7.1182925689352174` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + 
          ArcTan[(7.575350573792917 + ArcTan[7.1182925689352174` + Style[
                 TraditionalForm[
                  Subscript["x", "6"]], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.16509018904474715` + (0.4570580048577 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{281., -3.4734213604157165`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "357.6707652503442`"}], "+", 
         RowBox[{"238.8637233988472`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.374549769929878`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], 
                   "]"}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"4.740857876994031`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-357.6707652503442 + 
       238.8637233988472 ArcTan[17.374549769929878` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Sin[E^Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]]] + Sin[
            Sin[
             Sin[Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]]] - Sin[4.740857876994031 - Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{287., -3.502260477802119}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "707.1201347945179`"}], "+", 
         RowBox[{"461.19829104984177`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"32.819852996050756`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-707.1201347945179 + 
       461.19829104984177` ArcTan[32.819852996050756` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{292., -3.511100197965447}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "665.3791460351955`"}], "+", 
         RowBox[{"434.4642641742678`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"31.198923069796628`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-665.3791460351955 + 
       434.4642641742678 ArcTan[31.198923069796628` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.5206541171730525`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.351021259677713`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.20371716260109518`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.351021259677713 - 0.20371716260109518` (-(E^(E^(-ArcTan[6 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{303., -3.521055481275357}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.36753286552386`", "\[VeryThinSpace]"}], "+", 
         FractionBox["385.03205928136947`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.5463521874072836`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.36753286552386 + 
       385.03205928136947`/(-24.060521364609343` - Cos[
        1.5463521874072836` + Cos[6 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{304., -3.5336081452831176`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.179057982531468`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2659557248274772`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"3.6252252761254273`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.179057982531468` - 0.2659557248274772 (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3.6252252761254273` + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]] - Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.5517397293569886`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "139.31645426324948`"}], "+", 
         RowBox[{"63.27517391943544`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"13.099152445907018`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Csc", "[", 
                  RowBox[{"Sec", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
                "+", 
                FractionBox["1", 
                 RowBox[{"Log", "[", 
                   RowBox[{
                    RowBox[{"6.388694565552804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                FractionBox["1", 
                 RowBox[{"1", "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.4999960813102842`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-139.31645426324948` + 
       63.27517391943544 ArcTan[13.099152445907018` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Csc[
             Sec[(Sin[2] + Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]])^(-1)]] + 
           Log[6.388694565552804 + Log[6.488694565552803 + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^(-1) + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[1.4999960813102842` + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{314., -3.561490085158599}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7439601152858788`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8695491777919349`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]]], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7439601152858788 + 0.8695491777919349 (ArcTan[E^(E^Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]) + E^Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{315., -3.5712372283708036`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "288.36106970319247`"}], "+", 
         RowBox[{"194.2595753247306`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.756758216220327`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-288.36106970319247` + 
       194.2595753247306 ArcTan[12.756758216220327` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{340., -3.580377398265011}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "607.0497657149905`"}], "+", 
         RowBox[{"201.26394035246872`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   RowBox[{"0.09263271280039957`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-607.0497657149905 + 
       201.26394035246872` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + 0.09263271280039957 Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{356., -3.5930697627226627`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "615.0344363728666`"}], "+", 
         RowBox[{"203.8643187622885`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.5284320043644632`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"8.79360244649667`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-615.0344363728666 + 
       203.8643187622885 (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.5284320043644632` - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (8.79360244649667 + Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]])^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{365., -3.614629120665493}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.3661966156145695`"}], "+", 
         RowBox[{"1.9301350200656782`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"3.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.3661966156145695` + 
       1.9301350200656782` (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Log[3.2010988964402785` + 3 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{367., -3.6262141864205457`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "952.1813736621507`"}], "+", 
         RowBox[{"617.9843995504305`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.87073864162443`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-952.1813736621507 + 
       617.9843995504305 ArcTan[39.87073864162443 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{389., -3.6356970452273427`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.545252221794286`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1932775748463637`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.545252221794286 - 0.1932775748463637 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "13"]], 
           Hue[
            Rational[13, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.6391046320221254`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9436331808181793`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19080842768040582`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"0.16939734954746669`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]]}], "]"}], 
               "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9436331808181793` - 0.19080842768040582` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[(0.16939734954746669` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]) (Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4)^Rational[1, 2]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{428., -3.7167946837611936`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "626.4487653719938`"}], "+", 
         RowBox[{"294.1402927612141`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"19.708499536878648`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.494691062541248`", "\[VeryThinSpace]"}], "+", 
                    
                    FractionBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "40"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-626.4487653719938 + 
       294.1402927612141 (E^
          ArcTan[19.708499536878648` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + 
            Cos[15.494691062541248` + Rational[1, 40] Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{451., -3.7169954297305963`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7261303340485935`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.860163210145761`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7261303340485935 + 0.860163210145761 (-ArcTan[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] - (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 + 2 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{489., -3.7460768804795697`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "754.8876274927078`"}], "+", 
         RowBox[{"491.7649819416011`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"33.32648470563434`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                   "2"]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-754.8876274927078 + 
       491.7649819416011 ArcTan[33.32648470563434 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + (ArcTan[E^Style[
                  TraditionalForm[
                   Subscript["x", "6"]], 
                  Hue[
                   Rational[3, 8], 1, 
                   Rational[1, 2]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{498., -3.7494939509816287`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "283.7231022479501`"}], "+", 
         RowBox[{"191.23744038818378`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-283.7231022479501 + 191.23744038818378` ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + Cos[
               Cos[(Cos[
                   Rational[1, 9]] + Cos[1] + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]])^(-1)]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{510., -3.760235830765749}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "279.7152443587485`"}], "+", 
         RowBox[{"188.6778602284911`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"11", "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Csc", "[", 
                   RowBox[{"Sec", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.888694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-279.7152443587485 + 188.6778602284911 ArcTan[11 + Cos[
            Csc[
             Sec[(Cos[
                 Rational[1, 8]] + Sin[2] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]])^(-1)]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.888694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{547., -3.7736280839569614`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "902.6303813699709`"}], "+", 
         RowBox[{"586.2222361244694`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"38.85451220928411`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-902.6303813699709 + 
       586.2222361244694 ArcTan[38.85451220928411 + ArcTan[
            Cos[ArcTan[E^Style[
                 TraditionalForm[
                  Subscript["x", "6"]], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]^2 + Sin[
            Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{555., -3.7819820723762607`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1044.7672158444955`"}], "+", 
         RowBox[{"677.120051944511`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.63594641207696`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                   "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1044.7672158444955` + 
       677.120051944511 ArcTan[43.63594641207696 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Sin[Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] (1 + Tan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{599., -3.8032609814646667`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.016054879038913`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18797497043668304`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                    "2"]}]]], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.016054879038913 - 0.18797497043668304` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[(1 + ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]]^2)^Rational[-1, 2]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{148., -3.2219164428653957`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "284.07449457736215`"}], "+", 
         RowBox[{"191.4826370803498`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"9.577945895085527`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"80", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"338.79335103547356`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-284.07449457736215` + 
       191.4826370803498 ArcTan[9.577945895085527 + ArcTan[(80 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(338.79335103547356` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{151., -3.2391813435930805`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "246.59374784707157`"}], "+", 
         RowBox[{"167.36011425543296`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.913588932593228`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-246.59374784707157` + 
       167.36011425543296` ArcTan[11.913588932593228` + ArcTan[
            ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{153., -3.2535728652749545`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "356.6430990567226`"}], "+", 
         RowBox[{"238.13072466299138`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.873759219243595`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.7863225731137681`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-356.6430990567226 + 
       238.13072466299138` ArcTan[16.873759219243595` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[0.7863225731137681 + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{163., -3.289994346807315}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "352.0072032323624`"}], "+", 
         RowBox[{"235.1636750889502`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.320664636050154`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-352.0072032323624 + 
       235.1636750889502 ArcTan[17.320664636050154` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{172., -3.2966649487702435`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "370.7669746327721`"}], "+", 
         RowBox[{"247.29547370954984`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.627092335543374`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"ArcTan", "[", "2", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-370.7669746327721 + 
       247.29547370954984` ArcTan[16.627092335543374` + ArcTan[E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + ArcTan[2] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{174., -3.309557383287002}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "314.00102723311556`"}], "+", 
         RowBox[{"210.72522779498567`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-314.00102723311556` + 
       210.72522779498567` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[6.95204228255524 - 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{178., -3.324086351774902}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.498182354646826`", "\[VeryThinSpace]"}], "-", 
         FractionBox["314.5225674048797`", 
          RowBox[{
            RowBox[{"21.816682971832254`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.071748728398591`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.498182354646826` - 314.5225674048797/(21.816682971832254` + 
       Cos[7.071748728398591 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{180., -3.3416625770101875`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.730056994646655`"}], "+", 
         RowBox[{"4.8006451710753355`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"12.382894990021157`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.730056994646655 + 
       4.8006451710753355` Log[1 + Log[12.382894990021157` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{186., -3.3541501641135256`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "368.0349998478511`"}], "-", 
         RowBox[{"246.39551602540502`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"18.49551502819849`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}], 
               "+", 
               FractionBox["1", 
                RowBox[{"20", " ", 
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.285984840096106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], 
                    ")"}]}]]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-368.0349998478511 - 
       246.39551602540502` (-ArcTan[18.49551502819849 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[
               Rational[1, 2]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
        Rational[1, 20]/(8.285984840096106 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "15"]], 
            Hue[
             Rational[15, 16], 1, 
             Rational[5, 6]]]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "4"]], 
            Hue[
             Rational[1, 4], 1, 
             Rational[1, 2]]]])), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{187., -3.365425589976119}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "395.43612168834073`"}], "+", 
         RowBox[{"263.0492520567886`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.02133123212667`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"216", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-395.43612168834073` + 
       263.0492520567886 ArcTan[17.02133123212667 + ArcTan[(216 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{191., -3.369127075693861}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.1546462221224283`"}], "+", 
         RowBox[{"0.8882805402807872`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.357083250063511`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.912103860432534`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.165090189044747`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", "5", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.1546462221224283` + 
       0.8882805402807872 (ArcTan[6.357083250063511 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.912103860432534 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[6.165090189044747 + ((Log[5] + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2 - Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]])^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.3939884287164857`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "357.35084706533826`"}], "+", 
         RowBox[{"238.83321905637928`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.285132645727876`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-357.35084706533826` + 
       238.83321905637928` ArcTan[15.285132645727876` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{212., -3.3971278733549752`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.22871108983172`", "\[VeryThinSpace]"}], "-", 
         FractionBox["301.7387446262071`", 
          RowBox[{
            RowBox[{"21.839094563784812`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"8.978283250791709`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"6.834818864258004`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"7", "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.840444646718434`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.22871108983172 - 301.7387446262071/(21.839094563784812` + 
       Cos[8.978283250791709 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[6.834818864258004 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.840444646718434 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{219., -3.412280675075094}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "153.0996615306932`"}], "+", 
         RowBox[{"68.97591404339116`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{"10", "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"54", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                   "]"}], "4"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-153.0996615306932 + 
       68.97591404339116 ArcTan[10 + ArcTan[(((54 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "13"]], 
                  Hue[
                   Rational[13, 16], 1, 
                   Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])) (6 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])]^4 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{225., -3.4185457989967927`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "310.7175946785522`"}], "+", 
         RowBox[{"208.5795823281128`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", "6", "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "4"], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-310.7175946785522 + 
       208.5795823281128 
        ArcTan[10 + 
          ArcTan[((((72 ArcTan[6]) ArcTan[2.0096060494165187` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]) ArcTan[6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{233., -3.4326679251169985`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.289699856318525`"}], "+", 
         RowBox[{"1.712392651778814`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"\[ExponentialE]", "+", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.289699856318525 + 1.712392651778814 (ArcTan[E + ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]]] + ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2] + (E - ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{245., -3.4407202204507903`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "170.17420028830978`"}], "+", 
         RowBox[{"76.19229654247917`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"14.99790950762732`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"2.0131650035986226`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-170.17420028830978` + 
       76.19229654247917 ArcTan[14.99790950762732 + ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + ArcTan[10.544750992301736` - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{252., -3.450327858731454}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "739.5282222031184`"}], "+", 
         RowBox[{"244.0797947348637`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", 
                    SqrtBox["5"]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-739.5282222031184 + 
       244.0797947348637 (
         ArcTan[24.59388935870163 + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[5^Rational[-1, 2] - E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{262., -3.454728230139373}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "363.0529901370362`"}], "+", 
         RowBox[{"242.27003265327363`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.704794415548982`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-363.0529901370362 + 
       242.27003265327363` 
        ArcTan[14.704794415548982` + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{274., -3.4678350644988023`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "965.6373513312184`"}], "+", 
         RowBox[{"626.5363556813832`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"42.591881212979686`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-965.6373513312184 + 
       626.5363556813832 ArcTan[42.591881212979686` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + ArcTan[
            Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]]] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]]^2] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{292., -3.468133334343495}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.032932440197994`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8644805761751699`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                   RowBox[{"Cos", "[", "6", "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.032932440197994 + 0.8644805761751699 (ArcTan[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]^2 + Cos[6]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{294., -3.469669710083731}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.3344780916662788`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8216173264272485`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.3344780916662788` + 0.8216173264272485 (ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.516446966716338}}]},
      StyleBox[
       RowBox[{
         RowBox[{"2.5741819380136204`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7312848063246423`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"2", "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[2.5741819380136204` + 0.7312848063246423 (-ArcTan[2 - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{303., -3.52073153713429}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.371517780887352`", "\[VeryThinSpace]"}], "+", 
         FractionBox["385.33721630090974`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.5278232293217513`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.371517780887352` + 
       385.33721630090974`/(-24.060521364609343` - Cos[
        1.5278232293217513` + Cos[6 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.5297835364422814`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.9237483576409873`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"331.1519220913266`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"7.528667279685674`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[7, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                 "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "4"], "]"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "4"], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"16", "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"2.273572568916576`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"]}], 
              ")"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.9237483576409873 + ((331.1519220913266/(10.651382597834791` + 
          Cos[(2.4405983039138768` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^4]^2 + 
          Cos[(18.424973303913877` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^4]^2))/(16 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]]^2 + Cos[2.273572568916576 - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) Log[7.528667279685674 + Style[
            TraditionalForm[
             Subscript["x", "14"]], 
            Hue[
             Rational[7, 8], 1, 
             Rational[1, 2]]] + (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{312., -3.539695947433725}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "230.70580039277098`"}], "+", 
         RowBox[{"51.62372080549098`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"15.838322526679198`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Csc", "[", 
                  RowBox[{"Sec", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
                "+", 
                FractionBox["1", 
                 RowBox[{"Log", "[", 
                   RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                FractionBox["1", 
                 RowBox[{"1", "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-230.70580039277098` + 
       51.62372080549098 E^ArcTan[15.838322526679198` + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Csc[
             Sec[(Sin[2] + Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]])^(-1)]] + Log[6.488694565552803 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^(-1) + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                 Rational[1, 8]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{314., -3.5555884903901256`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "682.7637194152277`"}], "+", 
         RowBox[{"319.94533965665346`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"21.654409685933963`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.599419225281405`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-682.7637194152277 + 
       319.94533965665346` (E^
          ArcTan[21.654409685933963` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.599419225281405` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{315., -3.569073222055913}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "305.3215332208118`"}], "+", 
         RowBox[{"205.18118864598307`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.442168159159072`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-305.3215332208118 + 
       205.18118864598307` ArcTan[13.442168159159072` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{325., -3.570438856920757}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.8836793515163577`"}], "+", 
         RowBox[{"1.6007541259505902`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]]], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", "\[ExponentialE]", "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.8836793515163577` + 1.6007541259505902` (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E^(E^Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]) + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + E + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + (Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{357., -3.5899134196427696`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "931.3394078417781`"}], "+", 
         RowBox[{"604.6090729156479`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"40.27703715194244`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-931.3394078417781 + 
       604.6090729156479 ArcTan[40.27703715194244 + ArcTan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + 2 Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{370., -3.6024082229768157`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.750597808508207`"}], "+", 
         RowBox[{"1.9882619665854482`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                   "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", "1", "]"}]], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.750597808508207 + 1.9882619665854482` (Log[7 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E^Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + E^Cos[1] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 3 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{372., -3.618917292540436}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7212526988757796`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8623081830033634`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"2", "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7212526988757796 + 0.8623081830033634 (ArcTan[2 + (-1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-E^2 + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{390., -3.634654939951678}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.933874600581994`"}], "+", 
         RowBox[{"4.763639113385772`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"3", "+", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"0.27701956375123454`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.933874600581994 + 4.763639113385772 Log[1 + Log[3 + ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "11"]], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "11"]], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + ((0.27701956375123454` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[(1 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{428., -3.708641034252562}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "542.6871956556951`"}], "+", 
         RowBox[{"255.67059185997837`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"17.465283176327702`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.494691062541248`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    FractionBox["4.189126509606261`", 
                    RowBox[{"36", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-542.6871956556951 + 
       255.67059185997837` (E^
          ArcTan[17.465283176327702` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.494691062541248` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + 4.189126509606261/(36 - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]) + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{451., -3.7095916789685752`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.0770248809152759`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8205228513984024`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.0770248809152759 + 0.8205228513984024 (ArcTan[1 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] - Style[
            TraditionalForm[
             Subscript["x", "5"]], 
            Hue[
             Rational[5, 16], 1, 
             Rational[5, 6]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{548., -3.7193493833056066`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1042.757666627528`"}], "+", 
         RowBox[{"675.848269374728`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.63594641207696`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "49", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                   "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1042.757666627528 + 
       675.848269374728 ArcTan[43.63594641207696 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[Cos[49] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]^2 + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Sin[Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] (1 + Tan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{574., -3.7203494815834244`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.547835387147455`"}], "+", 
         RowBox[{"2.124952972653469`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"3.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.0354798789655568`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
                    "]"}], "2"], "+", 
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.547835387147455 + 
       2.124952972653469 (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + 
         Log[3.2010988964402785` + Log[1.0354798789655568` + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + (1 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2 + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]])^2]^2 + 3 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{586., -3.7462467368242924`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "457.876171779233`"}], "+", 
         RowBox[{"303.2598448611598`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"9", "-", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                    "4"], "]"}]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-457.876171779233 + 303.2598448611598 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + ArcTan[9 - Cos[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]] - Tan[ArcTan[
               Tan[E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{634., -3.7631001095392564`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "452.9572744435451`"}], "+", 
         RowBox[{"300.109183431764`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"9", "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                    "2"], "]"}], "]"}], "+", 
                   RowBox[{"Cos", "[", "9", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-452.9572744435451 + 300.109183431764 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + ArcTan[9 - ArcTan[
             Tan[ArcTan[
                Tan[E^Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]]^2]] + Cos[9] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] + 2 Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]] - Tan[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{151., -3.23886018867746}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "246.7783863378953`"}], "+", 
         RowBox[{"167.4802562312145`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.913588932593228`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-246.7783863378953 + 
       167.4802562312145 ArcTan[11.913588932593228` + ArcTan[
            Sin[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{163., -3.2666256678594094`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "430.57985337760397`"}], "+", 
         RowBox[{"285.6841181043538`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.18912650960626`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-430.57985337760397` + 
       285.6841181043538 ArcTan[20.18912650960626 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{164., -3.27748608624657}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "390.3358231458716`"}], "+", 
         RowBox[{"259.83742203835203`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.603930673266888`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"2", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-390.3358231458716 + 
       259.83742203835203` ArcTan[18.603930673266888` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[E^(-Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{172., -3.2957198828471252`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "414.6533218543974`"}], "+", 
         RowBox[{"275.5129595489969`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.501804311467012`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-414.6533218543974 + 
       275.5129595489969 ArcTan[18.501804311467012` + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{177., -3.2985312325520617`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.777694932802038`"}], "+", 
         RowBox[{"4.81498065384731`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"14", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", "1", "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.777694932802038 + 4.81498065384731 Log[Log[14 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + (2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[1] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{183., -3.319909326678657}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "394.21231099594314`"}], "+", 
         RowBox[{"262.36589192442494`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.011024089573652`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-394.21231099594314` + 
       262.36589192442494` ArcTan[18.011024089573652` + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{184., -3.3260671821608834`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.08234716621176`", "\[VeryThinSpace]"}], "-", 
         FractionBox["225.84194809813684`", 
          RowBox[{
            RowBox[{"16.882772161420597`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.835636492419482`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.08234716621176 - 225.84194809813684`/(16.882772161420597` + 
       Cos[13.222006034561666` - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[13.835636492419482` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{187., -3.3424506631794304`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "497.36953943252735`"}], "+", 
         RowBox[{"328.54793612040305`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.553471143014143`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"216", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-497.36953943252735` + 
       328.54793612040305` ArcTan[20.553471143014143` + ArcTan[(216 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{195., -3.348582256278249}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.733689247536216`"}], "+", 
         RowBox[{"4.798150066905011`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.733689247536216 + 4.798150066905011 Log[1 + Log[7 + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{206., -3.351853085338023}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.3713776423454656`"}], "+", 
         RowBox[{"4.693306924134677`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.382894990021157`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.3713776423454656` + 
       4.693306924134677 Log[1 + Log[2.382894990021157 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{209., -3.359415432046264}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.89482186498991`"}], "+", 
         RowBox[{"5.0961998001192335`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", "7", "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.89482186498991 + 
       5.0961998001192335` Log[Log[7] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{216., -3.371822188508738}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "338.11684552175103`"}], "+", 
         RowBox[{"226.17916874897193`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.946918986900421`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[13, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-338.11684552175103` + 
       226.17916874897193` 
        ArcTan[14.946918986900421` + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "13"]], 
             Hue[
              Rational[13, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{221., -3.404006423328064}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "363.53625489411706`"}], "+", 
         RowBox[{"242.82398533404302`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"7.085903183616281`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"9.57359898311001`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-363.53625489411706` + 
       242.82398533404302` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[7.085903183616281 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + ArcTan[9.57359898311001 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{226., -3.4157944016731268`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.436684949034663`"}], "+", 
         RowBox[{"4.744357204302722`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"11.191447495010578`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", "10", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.436684949034663 + 
       4.744357204302722 Log[Log[11.191447495010578` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (Log[10] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[E^Tan[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{237., -3.4297548933624284`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "361.02213998084636`"}], "+", 
         RowBox[{"240.9777094699453`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.516882663367497`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.140710995683652`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.423903158924036`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-361.02213998084636` + 
       240.9777094699453 ArcTan[17.516882663367497` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[2.140710995683652 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[9.423903158924036 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{253., -3.432901384201413}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.574116241744548`", "\[VeryThinSpace]"}], "-", 
         FractionBox["485.50562842841964`", 
          RowBox[{
            RowBox[{"29.330410744256014`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.574116241744548` - 485.50562842841964`/(29.330410744256014` + Cos[
         Cos[7.419547281892406 + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4] - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]] + Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{257., -3.445348975651722}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "153.1106699187735`"}], "+", 
         RowBox[{"68.97875496668424`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{"10", "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", "81", "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], "2"], 
                    "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                   "]"}], "4"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-153.1106699187735 + 
       68.97875496668424 
        ArcTan[10 + ArcTan[((((72 ArcTan[81]) ArcTan[(6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])]^4 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{258., -3.446678023347625}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "362.1969079014203`"}], "+", 
         RowBox[{"241.98461530163385`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-362.1969079014203 + 
       241.98461530163385` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{272., -3.4503770166655072`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.2833633123080783`"}], "+", 
         RowBox[{"1.7104987846135313`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"\[ExponentialE]", "+", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", "8", "]"}], "]"}]], "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.2833633123080783` + 1.7104987846135313` (ArcTan[E + ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]]] + ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2] + (E^ArcTan[
                ArcTan[8]] - ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{278., -3.4563560316574664`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.93915715600626`", "\[VeryThinSpace]"}], "-", 
         FractionBox["341.79692322576017`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "+", 
                  RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[18.93915715600626 - 341.79692322576017`/(22.258641845677218` + Cos[
         Cos[7 + 2 Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{284., -3.4583393250495074`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.2171813479489277`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8195481062680658`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.2171813479489277` + 0.8195481062680658 (ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{296., -3.4598184057716894`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "618.2158108368858`"}], "+", 
         RowBox[{"406.1468334513881`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"27", "-", 
               FractionBox[
                SuperscriptBox["\[ExponentialE]", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False]], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}]]], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-618.2158108368858 + 406.1468334513881 ArcTan[27 - E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] (1 + E^(2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]))^Rational[-1, 2] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.4847468307725364`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.373273980214177`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2026153110197049`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"276.6154854526354`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.373273980214177 - 0.2026153110197049 (-(E^(E^(-ArcTan[6 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[276.6154854526354 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{303., -3.499556795659452}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.476992879626543`", "\[VeryThinSpace]"}], "+", 
         FractionBox["393.0420555109058`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"24.060521364609343`", "\[VeryThinSpace]"}], "-", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.476992879626543` + 
       393.0420555109058/(-24.060521364609343` - Cos[
        24.060521364609343` - Cos[6 Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.5057109227708785`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.9320764623744412`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"304.1502497113435`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"7.528667279685674`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[7, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                 "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"9.71404298447733`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "4"], "]"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "4"], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"16", "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"2.273572568916576`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"]}], 
              ")"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.9320764623744412 + ((304.1502497113435/(9.71404298447733 + 
          Cos[(2.4405983039138768` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^4]^2 + 
          Cos[(18.424973303913877` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^4]^2))/(16 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]]^2 + Cos[2.273572568916576 - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) Log[7.528667279685674 + Style[
            TraditionalForm[
             Subscript["x", "14"]], 
            Hue[
             Rational[7, 8], 1, 
             Rational[1, 2]]] + (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{310., -3.5247065931152304`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "769.1750559897988`"}], "+", 
         RowBox[{"500.9053344302075`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"33.64746557913435`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-769.1750559897988 + 
       500.9053344302075 ArcTan[33.64746557913435 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + ArcTan[
            Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]]^2] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{317., -3.5575803511951527`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"25.19942090359684`", "\[VeryThinSpace]"}], "-", 
         FractionBox["967.5034653663608`", 
          RowBox[{
            RowBox[{"47.24916310059122`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      25.19942090359684 - 967.5034653663608/(47.24916310059122 + 
       Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{324., -3.5655226474858868`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"2.412296859847917`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7401844857977499`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"1", "-", "\[ExponentialE]", "+", 
                   SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], "]"}],
                "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[2.412296859847917 + 0.7401844857977499 (ArcTan[1 - E + (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{340., -3.5668264367079567`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "617.5075776389787`"}], "+", 
         RowBox[{"204.65872466397622`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   RowBox[{"0.1008584909940365`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-617.5075776389787 + 
       204.65872466397622` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.795322405754767` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + 0.1008584909940365 Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{358., -3.5889765642394496`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "596.199719479462`"}], "+", 
         RowBox[{"391.9531594747699`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"23.897626046484913`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"405.46338487699046`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"5", "+", 
                   RowBox[{"Log", "[", "7", "]"}], "+", 
                   RowBox[{"Log", "[", "9", "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "4"], 
                   "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-596.199719479462 + 
       391.9531594747699 
        ArcTan[23.897626046484913` + ArcTan[(405.46338487699046` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[5 + Log[7] + Log[9] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[ArcTan[(187.84763242634693` Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + 2 Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{374., -3.616821524719807}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "981.4244760217532`"}], "+", 
         RowBox[{"636.6775307202549`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"40.27703715194244`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-981.4244760217532 + 
       636.6775307202549 ArcTan[40.27703715194244 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{401., -3.624227564402825}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "455.2040996913907`"}], "+", 
         RowBox[{"301.44678080471715`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.668093674645245`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", "4", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-455.2040996913907 + 
       301.44678080471715` 
        ArcTan[16.668093674645245` + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[4]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "15"]], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]^4]^2 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{427., -3.632618220397518}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.5496076711616147`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"77.82932326532017`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"7.528667279685674`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.7363544006993052`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], ")"}], "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "4"], "]"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "4"], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"16", "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"2.273572568916576`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"]}], 
              ")"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.5496076711616147` + ((77.82932326532017/(10.651382597834791` + 
          Cos[(2.4405983039138768` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^4]^2 + 
          Cos[(18.424973303913877` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^4]^2))/(16 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]]^2 + Cos[2.273572568916576 - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) Log[7.528667279685674 + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + (Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (3.7363544006993052` + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]] + (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{439., -3.6516553482396863`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "661.0403403200444`"}], "+", 
         RowBox[{"431.7328770821902`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"29.898295381891415`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.147695761381096`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-661.0403403200444 + 
       431.7328770821902 ArcTan[29.898295381891415` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[1.147695761381096 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]] (1 + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "7"]], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]]]]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{440., -3.656899507539296}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "457.20740046163354`"}], "+", 
         RowBox[{"302.8572968372241`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"9", "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "-", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-457.20740046163354` + 302.8572968372241 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + ArcTan[9 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] - Tan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^2]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{443., -3.665090664482655}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "337.77506096795224`"}], "+", 
         RowBox[{"226.01356230134544`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.98822900605531`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"10", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-337.77506096795224` + 
       226.01356230134544` ArcTan[13.98822900605531 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(10 + Cos[
               Rational[1, 9]] + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{445., -3.6701829285188383`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.397045422979607`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.13729999955485522`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"3", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "3"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.397045422979607` - 0.13729999955485522` (3 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - 2 Cos[
          Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[Rational[1, 3] Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 2 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Rational[-1, 3] Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{455., -3.674465831257195}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "6.320403181367885`"}], "+", 
         RowBox[{"5.0189606283707935`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"8", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-6.320403181367885 + 
       5.0189606283707935` Log[Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[8 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{473., -3.708740179097754}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.00472403300724`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.3353608194016162`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"10", "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "-", 
                    RowBox[{"Sin", "[", "7", "]"}]}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.00012804895597598695`"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.00472403300724 - 0.3353608194016162 (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[10 + ArcTan[
            Tan[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] + Cos[3 + Cos[1] - Sin[7]] + 
          Sin[6.989024623684227 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] - Sin[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]]] + (
          1.4005764990867249` + (-0.00012804895597598695` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{555., -3.7172669945504673`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.553588458785328`"}], "+", 
         RowBox[{"2.1256154490575874`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"3.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.035479878965557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
                    "]"}], "2"], "+", 
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.553588458785328 + 
       2.1256154490575874` (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + 
         Log[3.2010988964402785` + Log[2.035479878965557 + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + (1 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2 + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]])^2]^2 + 3 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{606., -3.7205596128419236`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.703520448317448`"}], "+", 
         RowBox[{"5.387463043234125`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "9"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]], "]"}], 
                    "]"}], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0839686468203915`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.703520448317448 + 5.387463043234125 Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Rational[1, 9] Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (3 + Cos[9] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Sin[
                Sin[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (2.0839686468203915` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{620., -3.742768535696473}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.088224630519851`"}], "+", 
         RowBox[{"4.837454691973262`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               FractionBox["50", "7"], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{"7", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["1", "7"], "+", 
                    FractionBox["1", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", "7"], "]"}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["7", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", "3", "]"}], "]"}]}], "]"}], "]"}], 
                  "14"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{"7", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}], "+", 
                   
                   RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}]}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.088224630519851 + 
       4.837454691973262 Log[Rational[50, 7] + ArcTan[(7 + 2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^(-1)] + ArcTan[(Rational[1, 7] + ArcTan[
                Rational[1, 7]]^(-1) + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Sin[7^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[ArcTan[
              Log[9 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Tan[
                 Cos[3]]]]^14] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[ArcTan[(7 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "6"]], 
                  Hue[
                   Rational[3, 8], 1, 
                   Rational[1, 2]]])^(-1)] + ArcTan[(Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "6"]], 
                  Hue[
                   Rational[3, 8], 1, 
                   Rational[1, 2]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{632., -3.7432473650312574`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.076162549567413`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1796103968896518`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"5", "/", "2"}]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]], "]"}], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[4.076162549567413 - 0.1796103968896518 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[E^Rational[5, 2] - (-ArcTan[
                 Cos[(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^4)^Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - (-Sin[4] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2)^2 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{152., -3.2299987053891246`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.5994184271987777`"}], "+", 
         RowBox[{"2.124154192562474`", " ", 
           RowBox[{"Log", "[", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4.2261474686723375`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                  "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
              "2"], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.5994184271987777` + 
       2.124154192562474 Log[(4.2261474686723375` + ArcTan[
             Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]]] + Cos[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{163., -3.2581128781549813`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "296.59942577279344`"}], "+", 
         RowBox[{"199.5468013043002`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"450.0791119127379`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-296.59942577279344` + 
       199.5468013043002 ArcTan[9 + ArcTan[(((450.0791119127379 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (6 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])) Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{166., -3.2582181854202266`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.476749865690405`", "\[VeryThinSpace]"}], "-", 
         FractionBox["482.64316472058476`", 
          RowBox[{
            RowBox[{"30.527951991586754`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.476749865690405` - 482.64316472058476`/(30.527951991586754` + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "8"]], 
          Hue[
           Rational[1, 2], 1, 
           Rational[1, 2]]]] + Cos[13.222006034561666` - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[0.42089736482602796` + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{172., -3.2760450328840536`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "325.1240526645654`"}], "+", 
         RowBox[{"217.9350943613014`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"14", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-325.1240526645654 + 217.9350943613014 ArcTan[14 + ArcTan[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "10"]], 
                Hue[
                 Rational[5, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{174., -3.28058342351741}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "379.364784490947`"}], "+", 
         RowBox[{"252.71941911140547`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-379.364784490947 + 252.71941911140547` ArcTan[18 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Sin[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{182., -3.2879895965204256`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "373.51981418617623`"}], "+", 
         RowBox[{"249.03067815853942`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-373.51981418617623` + 249.03067815853942` ArcTan[18 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[E^(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Sin[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{183., -3.3178536974422372`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7527221433848896`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7696388492387055`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.912103860432534`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.1622658946312185`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7527221433848896 + 0.7696388492387055 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.912103860432534 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + Log[6.1622658946312185` + (Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{187., -3.33961397257035}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "504.4864379041549`"}], "+", 
         RowBox[{"333.11844555075095`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.789141872274616`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"216", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-504.4864379041549 + 
       333.11844555075095` ArcTan[20.789141872274616` + ArcTan[(216 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{209., -3.3463629495102696`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "323.20123244839345`"}], "+", 
         RowBox[{"216.67190171326283`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"360", " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], "2"], 
                    "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-323.20123244839345` + 
       216.67190171326283` ArcTan[10 + ArcTan[(((360 ArcTan[(6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{210., -3.348718600242116}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.433856449258403`", "\[VeryThinSpace]"}], "-", 
         FractionBox["318.11910007048925`", 
          RowBox[{
            RowBox[{"22.679539210503247`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.433856449258403` - 318.11910007048925`/(22.679539210503247` + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{214., -3.34971911938222}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "326.633437186007`"}], "+", 
         RowBox[{"218.83930646665056`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", "2", "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", "1", "]"}]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-326.633437186007 + 
       218.83930646665056` ArcTan[13 + ArcTan[2] + ArcTan[E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Cos[
              Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + Tan[1]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{216., -3.362796427496401}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.859563317878335`"}], "+", 
         RowBox[{"5.085385861053921`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", "7", "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.859563317878335 + 
       5.085385861053921 Log[Log[7] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{223., -3.3900221577325462`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.654150994774276`"}], "+", 
         RowBox[{"4.7854654712438975`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"3.382894990021157`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                   "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.654150994774276 + 
       4.7854654712438975` Log[1 + Log[3.382894990021157 + Sin[4 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{224., -3.4013363913235506`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "494.8745856247607`"}], "+", 
         RowBox[{"326.91142085019544`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.18912650960626`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"67.26257800841739`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-494.8745856247607 + 
       326.91142085019544` 
        ArcTan[20.18912650960626 + ArcTan[((67.26257800841739 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{237., -3.413969296441961}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "281.81660484527856`"}], "+", 
         RowBox[{"190.02471997232635`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.8926435134864008`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
                "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-281.81660484527856` + 190.02471997232635` ArcTan[13 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[1.8926435134864008` + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] + 2 Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{245., -3.4212043938435026`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.14777516860498188`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.016679808155079134`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"12.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.9999953893457124`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.4540213429303286`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.14777516860498188` + 
       0.016679808155079134` (12.122264710056605` + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.9999953893457124 + (-0.4540213429303286 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] - (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{252., -3.4222550461881904`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "633.1388081855987`"}], "+", 
         RowBox[{"415.7285618634597`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"26.7711460234138`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.140710995683652`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-633.1388081855987 + 
       415.7285618634597 ArcTan[26.7711460234138 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[2.140710995683652 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{255., -3.4259851762821927`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.6469707173782797`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"9.27234610741163`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"12.71404298447733`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"8", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"9.71404298447733`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{
                 RowBox[{"Log", "[", "7", "]"}], "-", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False]}], "]"}], 
             "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.6469707173782797 + (9.27234610741163/(9.71404298447733 + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[Log[7] - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) Log[12.71404298447733 + (8 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{268., -3.428918999560821}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "598.5673252765646`"}], "+", 
         RowBox[{"391.7162975292222`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"25.998606318918796`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-598.5673252765646 + 
       391.7162975292222 ArcTan[25.998606318918796` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[E^(-Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{269., -3.4432269800425312`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.820706938717585`", "\[VeryThinSpace]"}], "-", 
         FractionBox["337.5592101599122`", 
          RowBox[{
            RowBox[{"23.012544100020524`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"Sin", "[", "4", "]"}], "]"}], "2"], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.820706938717585` - 337.5592101599122/(23.012544100020524` + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[
             Sin[4]]^2 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{272., -3.4436450719099123`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "315.56766717496856`"}], "+", 
         RowBox[{"211.72212772596498`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", "81", "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"327.1198343819689`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], 
                    "2"]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-315.56766717496856` + 
       211.72212772596498` 
        ArcTan[10 + 
          ArcTan[((((72 ArcTan[81]) ArcTan[(327.1198343819689 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2) (6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{281., -3.4497485443947062`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.990804779605432`"}], "+", 
         RowBox[{"5.144881413288353`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"0.9729816085866787`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.990804779605432 + 
       5.144881413288353 
        Log[0.9729816085866787 + Log[1.1914474950105785` + E^Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (1 + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{284., -3.4507460934561065`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1289.512651671636`"}], "+", 
         RowBox[{"1661.5626146587147`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"18.911661864745632`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], "-", 
                 
                 FractionBox["1", 
                  RowBox[{"20", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.285984840096106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], 
                    ")"}]}]]}], "]"}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1289.512651671636 + 1661.5626146587147` ArcTan[
          ArcTan[ArcTan[18.911661864745632` + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]] + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + (1 + Cos[
                 Rational[1, 2]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]])^(-1)] + 
           Rational[-1, 20]/(8.285984840096106 + Cos[
              Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]])]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{297., -3.4591296124683004`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "73.40211778293252`"}], "+", 
         RowBox[{"60.68781160267431`", " ", 
           RowBox[{"ArcTan", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"8.189126509606261`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"10", " ", 
                    RowBox[{"Log", "[", "7", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.857617352803711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], ")"}], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Sin", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-73.40211778293252 + 
       60.68781160267431 
        ArcTan[(8.189126509606261 + 
           ArcTan[(((10 Log[7]) (9.857617352803711 + Sin[
                   Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]])) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.4837301118702926`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.16493439970924`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2663323651164929`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.1430814818724813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.16493439970924 - 0.2663323651164929 (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.1430814818724813 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{303., -3.494629326454708}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.24918612745901`", "\[VeryThinSpace]"}], "+", 
         FractionBox["375.08104329031505`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{"4", "-", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.24918612745901 + 
       375.08104329031505`/(-24.060521364609343` - Cos[4 - Cos[6 Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.5055054513355968`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.419670350697853`", "\[VeryThinSpace]"}], "-", 
         FractionBox["383.1537035994364`", 
          RowBox[{
            RowBox[{"25.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.839094563784812`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                   "2"], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.419670350697853` - 383.1537035994364/(25.258641845677218` + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.839094563784812` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[
             Cos[14.419547281892406` + Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]^2 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{315., -3.5175568310984127`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.414644405165607`", "\[VeryThinSpace]"}], "+", 
         FractionBox["388.6374942051871`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.3696850295348935`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "4"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.414644405165607` + 
       388.6374942051871/(-24.060521364609343` - Cos[
        1.3696850295348935` + Cos[6 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^4] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{319., -3.552596949271373}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "393.14303798724933`"}], "+", 
         RowBox[{"261.6548207448798`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.501804311467012`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"18.501804311467012`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "2"], 
                   "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"8.933122937030676`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-393.14303798724933` + 
       261.6548207448798 ArcTan[18.501804311467012` + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[ArcTan[18.501804311467012` + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[8.933122937030676 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{328., -3.5604640760027557`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "765.0598866812384`"}], "+", 
         RowBox[{"498.2545154257752`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"33.64746557913435`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-765.0598866812384 + 
       498.2545154257752 ArcTan[33.64746557913435 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + ArcTan[
            Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49]^2] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{360., -3.5717497874121253`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.791844368095462`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1940241733334284`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.791844368095462 - 0.1940241733334284 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[7.683763484795428 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{371., -3.5849353811375755`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"2.254825978706055`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7528417246575358`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[2.254825978706055 + 0.7528417246575358 (-ArcTan[E - ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{374., -3.586750755154378}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.3315041809918642`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7908599217018505`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.3315041809918642 + 0.7908599217018505 (ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[1 + (E - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{376., -3.6075844846936884`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8968827668223405`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.188034984782076`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8968827668223405` - 0.188034984782076 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{389., -3.613286014385113}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "674.8564839089514`"}], "+", 
         RowBox[{"440.5547653970583`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"30.60518643595306`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.147695761381096`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-674.8564839089514 + 
       440.5547653970583 ArcTan[30.60518643595306 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[1.147695761381096 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]] (1 + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "7"]], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]]]]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{407., -3.623769846077535}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "677.7098034328644`"}], "+", 
         RowBox[{"442.3856345999857`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"29.898295381891415`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.147695761381096`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-677.7098034328644 + 
       442.3856345999857 ArcTan[29.898295381891415` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[1.147695761381096 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]] (1 + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "7"]], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]]]]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{440., -3.6349944810287997`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.3832262212969193`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.5840829646373025`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"3", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.3832262212969193` + 0.5840829646373025 (ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2 - Tan[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 3 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{458., -3.651157170738337}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.365309445902987`", "\[VeryThinSpace]"}], "-", 
         FractionBox["473.646114281913`", 
          RowBox[{
            RowBox[{"29.70371032461711`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.9460399306011027`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.365309445902987` - 473.646114281913/(29.70371032461711 + 
       Cos[7 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[0.9460399306011027 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{479., -3.7029390283548858`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "626.1681468384011`"}], "+", 
         RowBox[{"294.009955436709`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"19.708499536878648`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.494691062541248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    FractionBox["1", "29"], " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"15.701990185956962`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"]}], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-626.1681468384011 + 
       294.009955436709 (E^
          ArcTan[19.708499536878648` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + 
            Cos[15.494691062541248` + 
              Rational[1, 29] ArcTan[(15.701990185956962` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]) Style[
                    TraditionalForm[
                    Subscript["x", "13"]], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{576., -3.7169501760963106`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "334.8715701207111`"}], "+", 
         RowBox[{"224.131915002857`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.98822900605531`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "2", "]"}], "2"], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-334.8715701207111 + 
       224.131915002857 ArcTan[13.98822900605531 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]] + Log[6.488694565552803 + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + (9 + Cos[2]^2 + Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "15"]], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]]]] + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^(-1) + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{153., -3.219805757121199}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "300.6692276616063`"}], "+", 
         RowBox[{"202.17841576791125`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"576", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-300.6692276616063 + 
       202.17841576791125` ArcTan[9 + ArcTan[(((576 Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "8"]], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]]]]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{157., -3.2281817409012072`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "284.00868407529805`"}], "+", 
         RowBox[{"191.44185406398637`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"9.577945895085527`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"338.79335103547356`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"80", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-284.00868407529805` + 
       191.44185406398637` 
        ArcTan[9.577945895085527 + ArcTan[(338.79335103547356` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(80 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{163., -3.248681637614328}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "324.2925250332336`"}], "+", 
         RowBox[{"217.3822529790065`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"1000", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-324.2925250332336 + 
       217.3822529790065 ArcTan[10 + ArcTan[(((1000 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (6 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])) Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{169., -3.2566937423995004`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.56591097335319`", "\[VeryThinSpace]"}], "-", 
         FractionBox["306.2944036851015`", 
          RowBox[{
            RowBox[{"20.222006034561666`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"4.383595390844114`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.720139825636043`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Sin", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.56591097335319 - 306.2944036851015/(20.222006034561666` + 
       Cos[4.383595390844114 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] - Style[
          TraditionalForm[
           Subscript["x", "8"]], 
          Hue[
           Rational[1, 2], 1, 
           Rational[1, 2]]]] + Cos[7.720139825636043 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.641553316454072` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.260411355144557}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.1870264255443614`"}], "+", 
         RowBox[{"2.1844056815334376`", " ", 
           RowBox[{"Log", "[", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4.071415465715283`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                  "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
              "2"], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.1870264255443614` + 
       2.1844056815334376` Log[(4.071415465715283 + ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2] + ArcTan[
             Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]]] + Cos[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{174., -3.2794961654438}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "419.2245983819378`"}], "+", 
         RowBox[{"278.35296393225957`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.18912650960626`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-419.2245983819378 + 
       278.35296393225957` ArcTan[20.18912650960626 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{184., -3.3019694318055492`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "347.6436001340092`"}], "+", 
         RowBox[{"232.35439872890225`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-347.6436001340092 + 
       232.35439872890225` ArcTan[14.092284613091337` + ArcTan[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{191., -3.303434757015103}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "410.915752874832`"}], "+", 
         RowBox[{"273.0964075470411`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.501804311467012`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.929213553016766`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-410.915752874832 + 
       273.0964075470411 ArcTan[18.501804311467012` + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[9.929213553016766 - Sin[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{192., -3.3219062794501752`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.470068465030915`"}], "+", 
         RowBox[{"4.973344317012622`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"7", "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", "7"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.470068465030915 + 4.973344317012622 Log[7 + ArcTan[
            Rational[1, 7]] + ArcTan[(Rational[50, 7] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{194., -3.3229632623451604`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "393.35452092686273`"}], "+", 
         RowBox[{"261.692180708747`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.183578656176614`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"15.603884208136735`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-393.35452092686273` + 
       261.692180708747 
        ArcTan[17.183578656176614` + ArcTan[(15.603884208136735` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{202., -3.3373635149852343`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "344.3318315860914`"}], "+", 
         RowBox[{"230.2499290237047`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-344.3318315860914 + 
       230.2499290237047 ArcTan[13.092284613091337` + ArcTan[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + 3 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{215., -3.337942621693451}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7557559298788844`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7690654514079414`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21774355635380405`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7557559298788844 + 0.7690654514079414 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[7.1182925689352174` + (-0.21774355635380405` + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{224., -3.3382127233944385`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.951858255308682`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8704855497554086`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.951858255308682 + 0.8704855497554086 (ArcTan[Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{225., -3.3566484846785865`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.49998038864017`", "\[VeryThinSpace]"}], "-", 
         FractionBox["323.88983470909085`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[18.49998038864017 - 323.88983470909085`/(22.258641845677218` + Cos[
         Cos[
          Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]]] + Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{226., -3.3838283012760404`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.58528315922347`", "\[VeryThinSpace]"}], "-", 
         FractionBox["318.8758563133422`", 
          RowBox[{
            RowBox[{"21.839094563784812`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.5587359688993025`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"2", " ", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"6.834818864258004`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.58528315922347 - 318.8758563133422/(21.839094563784812` + 
       Cos[1.5587359688993025` + 2 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[6.834818864258004 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{234., -3.3877774333347332`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.1503635551913005`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"1.7015968218584407`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"7.274147285544032`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      3.1503635551913005` + 
       1.7015968218584407` (-ArcTan[7.274147285544032 - Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2] + (E - ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{235., -3.3896089872273985`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.654009216639265`"}], "+", 
         RowBox[{"4.785299683182738`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"3.382894990021157`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.654009216639265 + 
       4.785299683182738 Log[1 + Log[3.382894990021157 + Sin[(Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])^2] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{238., -3.396546911878782}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "677.6243464369306`"}], "+", 
         RowBox[{"442.3373809021315`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"30.986591227186132`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-677.6243464369306 + 
       442.3373809021315 ArcTan[30.986591227186132` + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{245., -3.4191351049732575`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "570.706677125842`"}], "+", 
         RowBox[{"375.65083364121324`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-570.706677125842 + 375.65083364121324` ArcTan[25 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] (1 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)^Rational[-1, 2] + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{246., -3.4207334744818048`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "286.98857034639474`"}], "+", 
         RowBox[{"193.40082769493452`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.374549769929878`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"4.740857876994031`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-286.98857034639474` + 
       193.40082769493452` ArcTan[14.374549769929878` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4] - Sin[4.740857876994031 - Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^4] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{258., -3.421640628110974}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.518392175295862`", "\[VeryThinSpace]"}], "-", 
         FractionBox["472.20010483607166`", 
          RowBox[{
            RowBox[{"29.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", "7", "]"}], "2"], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.518392175295862` - 472.20010483607166`/(29.258641845677218` + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[7]^2 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{269., -3.4224395065380118`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.51068699546394`", "\[VeryThinSpace]"}], "-", 
         FractionBox["471.74176790848287`", 
          RowBox[{
            RowBox[{"29.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"Sin", "[", "4", "]"}], "]"}], "2"], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.51068699546394 - 471.74176790848287`/(29.258641845677218` + 
       Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[Cos[
             Sin[4]]^2 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{273., -3.4307193995802514`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.396040187278021`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2007067666082232`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.396040187278021 - 
       0.2007067666082232 (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{276., -3.4390625020466348`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "761.127878951979`"}], "+", 
         RowBox[{"285.2336973092768`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"ArcTan", "[", 
                RowBox[{
                  RowBox[{"14.530013371407822`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox[
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                  "+", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
              "]"}]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-761.127878951979 + 285.2336973092768 E^ArcTan[
           ArcTan[14.530013371407822` + ArcTan[(187.84763242634693` Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{294., -3.4406290930740036`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "632.2524066717364`"}], "+", 
         RowBox[{"413.280934631877`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"27", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"10", "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-632.2524066717364 + 413.280934631877 ArcTan[27 + ArcTan[
            Sin[2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{299., -3.4816705069520655`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.170689477226789`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2627929173809959`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.170689477226789` - 0.2627929173809959 (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{320., -3.544905178692546}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "747.8490426295292`"}], "+", 
         RowBox[{"246.92312535699324`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-747.8490426295292 + 
       246.92312535699324` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{330., -3.5513018086227066`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "747.8436153097226`"}], "+", 
         RowBox[{"246.9212540916221`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-747.8436153097226 + 
       246.9212540916221 (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{335., -3.5578775078432723`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.67913688606399`"}], "+", 
         RowBox[{"4.988603046770903`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.300115778126962`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                   "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"0.26225254021994265`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.67913688606399 + 
       4.988603046770903 Log[1 + Log[2.300115778126962 + Sin[4 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + (4 + Style[
                 TraditionalForm[
                  Subscript["x", "11"]], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + (0.26225254021994265` Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{360., -3.5657730129571283`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "597.7128856504755`"}], "+", 
         RowBox[{"392.9300958486734`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"23.897626046484913`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"405.46338487699046`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"5", "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Log", "[", "7", "]"}]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "4"], 
                   "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-597.7128856504755 + 
       392.9300958486734 
        ArcTan[23.897626046484913` + ArcTan[(405.46338487699046` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[5 + 2 Log[7] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[ArcTan[(187.84763242634693` Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + 2 Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{373., -3.572493304760205}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "609.1307398961181`"}], "+", 
         RowBox[{"201.94218172870626`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-609.1307398961181 + 
       201.94218172870626` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]])^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{377., -3.5981853666346235`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.252032240179592`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.26677496705004894`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"4.989844082816676`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                   "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.252032240179592` - 0.26677496705004894` (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[4.989844082816676 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{391., -3.604854164381823}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "363.6499680116371`"}], "+", 
         RowBox[{"242.93902225714984`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"11.089501984603473`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    FractionBox["1", "5"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-363.6499680116371 + 
       242.93902225714984` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + 
          ArcTan[11.089501984603473` - ArcTan[Rational[1, 5] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{398., -3.6106022424732958`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.170635905647819`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2633054048979173`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"5.989434353250451`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                   "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.170635905647819` - 0.2633054048979173 (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[5.989434353250451 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{399., -3.611742872830326}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.936226148644703`", "\[VeryThinSpace]"}], "-", 
         FractionBox["242.5878081362131`", 
          RowBox[{
            RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"0.36307581826373736`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"4.953779542217687`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                  "]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"2.0131650035986226`", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], " ", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.936226148644703` - 242.5878081362131/(14.085903183616281` + ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + ArcTan[10.544750992301736` - ArcTan[
          Cos[((0.36307581826373736` ArcTan[4.953779542217687 - Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2]) Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "11"]], 
          Hue[
           Rational[11, 16], 1, 
           Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "6"]], 
           Hue[
            Rational[3, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]^2] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{442., -3.6178295530969837`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.260214318285616`"}], "+", 
         RowBox[{"5.402056939938167`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               FractionBox["50", "7"], "+", 
               RowBox[{"ArcTan", "[", "7", "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["1", "7"], "+", 
                    FractionBox["1", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", "7"], "]"}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["7", 
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", "3", "]"}], "]"}]}], "]"}], "]"}], 
                  "14"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    ")"}], 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "7"], "]"}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.260214318285616 + 
       5.402056939938167 
        Log[Rational[50, 7] + ArcTan[7] + ArcTan[(Rational[1, 7] + ArcTan[
                Rational[1, 7]]^(-1) + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Sin[7^ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]] + Sin[ArcTan[
              Log[9 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Tan[
                 Cos[3]]]]^14] + Sin[(ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2)^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[Sin[Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^7] + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{445., -3.6326526296241854`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.419347869332821`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.13858556700101854`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "3"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.419347869332821` - 0.13858556700101854` (2 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - 2 Cos[
          Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[Rational[1, 3] Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 2 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Rational[-1, 3] Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{479., -3.640277879154903}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.04913673843604126`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8136198683412846`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", "2"], "]"}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.04913673843604126 + 0.8136198683412846 (ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]] - Style[
            TraditionalForm[
             Subscript["x", "5"]], 
            Hue[
             Rational[5, 16], 1, 
             Rational[5, 6]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2] + ArcTan[Cos[Cos[
               Sin[E^2]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{480., -3.644220095701306}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.36485096061271`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.13766796747530846`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"3", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.36485096061271 - 0.13766796747530846` (3 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Rational[-1, 3] Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "3"]], 
          Hue[
           Rational[3, 16], 1, 
           Rational[5, 6]]]] - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 3 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{486., -3.6877516902786955`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1103.8260154468012`"}], "+", 
         RowBox[{"714.8993731754797`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"46.38635417534749`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                   "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1103.8260154468012` + 
       714.8993731754797 ArcTan[46.38635417534749 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Sin[Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]] (1 + Tan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{492., -3.697310899058543}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.418908248627385`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.138644239834068`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"3", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
                  "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "3"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.418908248627385` - 0.138644239834068 (3 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Sin[
            Sin[6.989024623684227 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]]]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - 2 Cos[
          Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[Rational[1, 3] Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 2 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Rational[-1, 3] Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{506., -3.6992231663314086`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.448526973707855`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.1387931186503981`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"3", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"3.0281029277773017`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "3"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.448526973707855` - 0.1387931186503981 (3 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[3.0281029277773017` - ArcTan[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Sin[6.989024623684227 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]] - Style[
            TraditionalForm[
             Subscript["x", "4"]], 
            Hue[
             Rational[1, 4], 1, 
             Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - 2 Cos[
          Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[Rational[1, 3] Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 2 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Rational[-1, 3] Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{525., -3.700283028414027}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "296.2564266050387`"}], "+", 
         RowBox[{"199.3330392280545`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"11", "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", "8"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.388694565552804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-296.2564266050387 + 199.3330392280545 ArcTan[11 + Cos[
            Rational[1, 8]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + 
          Cos[(Cos[Log[6.388694565552804 + Log[6.488694565552803 + Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^(-1)] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{593., -3.7026396934601804`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.74591425286757`"}], "+", 
         RowBox[{"5.397489102984541`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "9"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", "3"], "]"}], "]"}], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0839686468203915`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.74591425286757 + 5.397489102984541 Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Rational[1, 9] Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (3 + Cos[9] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Sin[
                Sin[E^3]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (2.0839686468203915` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{648., -3.7039435500039977`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "461.4037546213779`"}], "+", 
         RowBox[{"305.5709888179271`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"9", "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}]], "]"}], 
                   "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                    "4"], "]"}]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-461.4037546213779 + 305.5709888179271 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + ArcTan[9 + Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] - Sin[E^Cos[E^Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]] + 2 Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]] - Tan[ArcTan[
               Tan[E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{153., -3.219180371237739}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "300.7084686229462`"}], "+", 
         RowBox[{"202.2029231965159`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"1000", " ", 
                    RowBox[{"Sin", "[", "10", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-300.7084686229462 + 
       202.2029231965159 ArcTan[9 + ArcTan[(((1000 Sin[10]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (6 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{157., -3.2267986275464744`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "294.7347998957743`"}], "+", 
         RowBox[{"198.34976385598733`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"294", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"162", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-294.7347998957743 + 
       198.34976385598733` ArcTan[10 + ArcTan[(294 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(162 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{163., -3.229034499923515}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.770710113020044`"}], "+", 
         RowBox[{"4.03859993276184`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"8.358815390669289`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.770710113020044 + 
       4.03859993276184 Log[Log[8.358815390669289 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{165., -3.233728836745661}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "408.33898860545474`"}], "+", 
         RowBox[{"271.3969204963361`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.979999540340643`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-408.33898860545474` + 
       271.3969204963361 ArcTan[18.979999540340643` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{170., -3.243240241320817}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8092652856289146`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7652957408649226`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.8092652856289146 + 0.7652957408649226 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + Log[7.1182925689352174` + ((Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2 + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]])^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{175., -3.265271395865696}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "9.165098698329336`"}], "-", 
         RowBox[{"241.13063112524728`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"ArcTan", "[", "9", "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"18", "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-9.165098698329336 - 241.13063112524728` 
       ArcTan[ArcTan[9] - ArcTan[18 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{179., -3.2712130850510928`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "396.12276913060157`"}], "+", 
         RowBox[{"263.48377281857046`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.02133123212667`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"1944", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-396.12276913060157` + 
       263.48377281857046` ArcTan[17.02133123212667 + ArcTan[1944 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{180., -3.2763918614710765`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.600849170640429`"}], "+", 
         RowBox[{"0.9368239469740741`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"5", "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"2", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.600849170640429 + 0.9368239469740741 Log[5 + (2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (2 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^4], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{184., -3.293946414035204}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "319.18657111402115`"}], "+", 
         RowBox[{"214.030395797777`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-319.18657111402115` + 
       214.030395797777 ArcTan[13.092284613091337` + ArcTan[Cos[9] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{188., -3.2964150231049407`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "423.38207778525674`"}], "+", 
         RowBox[{"280.94804343950216`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.567379528818783`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-423.38207778525674` + 
       280.94804343950216` ArcTan[20.567379528818783` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[3 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{194., -3.3114221277017966`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "481.2749053049812`"}], "+", 
         RowBox[{"318.19068351395697`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"20.25996863382131`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"15.603884208136735`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-481.2749053049812 + 
       318.19068351395697` 
        ArcTan[20.25996863382131 + ArcTan[(15.603884208136735` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{204., -3.3322755126958232`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.36066741673192954`"}], "+", 
         RowBox[{"0.7712232427091017`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.357083250063511`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.912103860432534`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.1622658946312185`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.36066741673192954` + 
       0.7712232427091017 (ArcTan[6.357083250063511 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[7.1182925689352174` + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.912103860432534 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + Log[6.1622658946312185` + (Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{209., -3.334212885611674}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.4932903413161474`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7889220626106536`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"0.95206790723147`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.4932903413161474 + 0.7889220626106536 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + Log[0.95206790723147 + (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.335295602682962}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "336.4450820849378`"}], "+", 
         RowBox[{"225.17752286175312`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"0.735603459595815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "-", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-336.4450820849378 + 
       225.17752286175312` 
        ArcTan[13.092284613091337` + ArcTan[0.735603459595815 - 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] - 2 Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{226., -3.363370235225917}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.518552866624176`"}], "+", 
         RowBox[{"4.767501314770029`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"11.191447495010578`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", "10", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.518552866624176 + 
       4.767501314770029 Log[Log[11.191447495010578` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]]^2 + (Log[10] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[E^Tan[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{227., -3.3646860085350676`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.978528723156372`"}], "+", 
         RowBox[{"1.95912458709746`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.000993656438439`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.978528723156372 + 
       1.95912458709746 (Log[6.000993656438439 + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[3 + (1 + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{229., -3.377121251741108}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.802725027142481`"}], "+", 
         RowBox[{"4.8235067842115535`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.802725027142481 + 
       4.8235067842115535` Log[1 + Log[2.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{238., -3.394101020499013}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "757.5172923647924`"}], "+", 
         RowBox[{"493.46825014231086`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"33.98659122718613`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-757.5172923647924 + 
       493.46825014231086` ArcTan[33.98659122718613 + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{245., -3.4068621964709855`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.139201675864095`"}], "+", 
         RowBox[{"0.017129011234176067`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"12.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.6612345640775175`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.4540213429303286`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.139201675864095 + 
       0.017129011234176067` (12.122264710056605` + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[6.6612345640775175` + (-0.4540213429303286 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] - (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{249., -3.4179058946707084`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"2.016377436029845`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8620268596568242`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[2.016377436029845 + 0.8620268596568242 (ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{276., -3.439041626582642}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "744.7404245751328`"}], "+", 
         RowBox[{"279.1990625918289`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"ArcTan", "[", 
                RowBox[{
                  RowBox[{"14.2439824256213`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox[
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                  "+", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
              "]"}]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-744.7404245751328 + 279.1990625918289 E^ArcTan[
           ArcTan[14.2439824256213 + ArcTan[(187.84763242634693` Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{301., -3.461338226767416}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "427.27188827928615`"}], "+", 
         RowBox[{"283.5592794854797`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.501804311467012`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"8.463773165437535`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-427.27188827928615` + 
       283.5592794854797 
        ArcTan[18.501804311467012` + ArcTan[8.463773165437535 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{317., -3.4751587184135273`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.248198250865281`"}], "+", 
         RowBox[{"1.908895202213581`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"3.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.248198250865281 + 
       1.908895202213581 (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2] + ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Log[3.2010988964402785` + 3 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{320., -3.5335691041070008`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "612.2604784568758`"}], "+", 
         RowBox[{"202.94779569579592`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.80344710999942`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-612.2604784568758 + 
       202.94779569579592` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.80344710999942 - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{330., -3.5478292983637782`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8400044635249353`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19273504479735082`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8400044635249353` - 0.19273504479735082` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{336., -3.5555335286873913`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "703.9578030006172`"}], "+", 
         RowBox[{"459.14181950083406`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"32.35775246868566`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-703.9578030006172 + 
       459.14181950083406` ArcTan[32.35775246868566 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49]^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{377., -3.5571577479846894`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "871.0628174528504`"}], "+", 
         RowBox[{"566.0640285341988`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"38.35775246868566`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "7", "]"}], "2"], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-871.0628174528504 + 
       566.0640285341988 ArcTan[38.35775246868566 + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Sin[Cos[7]^2] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49]^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{384., -3.5762871112690866`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "608.1441815142067`"}], "+", 
         RowBox[{"201.6204343142743`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-608.1441815142067 + 
       201.6204343142743 (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + 2 Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]])^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{386., -3.5825843752963342`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "306.36230629611816`"}], "+", 
         RowBox[{"205.84481899649134`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"13", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-306.36230629611816` + 205.84481899649134` ArcTan[13 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{391., -3.5843187382106816`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "364.0648042249813`"}], "+", 
         RowBox[{"243.20584237535678`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"11.089501984603473`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    FractionBox["1", "5"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-364.0648042249813 + 
       243.20584237535678` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + 
          ArcTan[11.089501984603473` - ArcTan[Rational[1, 5] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{404., -3.611344503621218}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.642529472805602`", "\[VeryThinSpace]"}], "-", 
         FractionBox["409.20540238749214`", 
          RowBox[{
            RowBox[{"26.925986272411212`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.642529472805602` - 409.20540238749214`/(26.925986272411212` + 
       Cos[7.419547281892406 + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[7.419547281892406 + Cos[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[Cos[7] + Cos[Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{465., -3.631238667745436}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "284.7075533607413`"}], "+", 
         RowBox[{"191.87519092108585`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"11.992193748539613`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"7.126622684847211`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["5", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-284.7075533607413 + 
       191.87519092108585` ArcTan[11.992193748539613` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[7.126622684847211 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Sin[
            Sec[(Sin[2] + Sin[Rational[5, 2] + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{496., -3.638621795812358}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "538.9576885134455`"}], "+", 
         RowBox[{"253.95498233723106`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"17.465283176327702`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"54", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], ")"}]}], 
                    "]"}], "2"], "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.494691062541248`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    FractionBox["4.189126509606261`", 
                    RowBox[{"36", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-538.9576885134455 + 
       253.95498233723106` (E^ArcTan[17.465283176327702` + ArcTan[((54 Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]) Style[
                  TraditionalForm[
                   Subscript["x", "13"]], 
                  Hue[
                   Rational[13, 16], 1, 
                   Rational[5, 6]]]) (Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^4)]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.494691062541248` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + 4.189126509606261/(36 - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]) + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{501., -3.6474530982567903`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.616166103754501`"}], "+", 
         RowBox[{"4.994973985892452`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               FractionBox["50", "7"], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{"7", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["1", "7"], "+", 
                    FractionBox["1", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", "7"], "]"}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["7", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", "3", "]"}], "]"}]}], "]"}], "]"}], 
                  "14"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    ")"}], 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "7"], "]"}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.616166103754501 + 
       4.994973985892452 Log[Rational[50, 7] + ArcTan[(7 + 2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^(-1)] + ArcTan[(Rational[1, 7] + ArcTan[
                Rational[1, 7]]^(-1) + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Sin[7^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[ArcTan[
              Log[9 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Tan[
                 Cos[3]]]]^14] + Sin[(ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2)^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[Sin[Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^7] + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{523., -3.659756474984829}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1031.17365626138`"}], "+", 
         RowBox[{"668.394502394035`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"43.75967055048048`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.6073934555129563`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1031.17365626138 + 
       668.394502394035 ArcTan[43.75967055048048 + ArcTan[
            ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[ArcTan[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[0.6073934555129563 + Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[7 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]^2 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{542., -3.667963721059696}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.63706710121088`"}], "+", 
         RowBox[{"5.361954168820477`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"8", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.63706710121088 + 
       5.361954168820477 Log[Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[8 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2 + (Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{560., -3.693666091807499}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.304301485047743`"}], "+", 
         RowBox[{"5.272354833940474`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "9"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", "4", "]"}], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0839686468203915`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.304301485047743 + 5.272354833940474 Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Rational[1, 9] Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (3 + Cos[9] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + 
              Sin[4] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + 2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + (2.0839686468203915` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{569., -3.697083818054789}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.568858361237957`"}], "+", 
         RowBox[{"5.349211538299183`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "9"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0839686468203915`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.568858361237957 + 5.349211538299183 Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Rational[1, 9] Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (3 + Cos[9] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "10"]], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]]]]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (2.0839686468203915` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{589., -3.70020090051657}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.722958099551567`"}], "+", 
         RowBox[{"5.391042898708623`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]], "]"}], 
                    "]"}], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0839686468203915`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.722958099551567 + 5.391042898708623 Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (3 + Cos[9] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Sin[
                Sin[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (2.0839686468203915` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{165., -3.2286087868476945`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "376.3609161797266`"}], "+", 
         RowBox[{"250.81527172408332`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.011024089573652`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"8.760121933840146`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-376.3609161797266 + 
       250.81527172408332` ArcTan[18.011024089573652` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[8.760121933840146 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{166., -3.228632264519483}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "294.5663503716615`"}], "+", 
         RowBox[{"198.24167601827193`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"120", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"312.9966825951751`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-294.5663503716615 + 
       198.24167601827193` ArcTan[10 + ArcTan[(120 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + ArcTan[(312.9966825951751 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{172., -3.2325501436650477`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.7871568414576366`"}], "+", 
         RowBox[{"4.064110294523466`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"8.358815390669289`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.7871568414576366` + 
       4.064110294523466 Log[Log[8.358815390669289 + Sin[Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.235982055710884}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "115.20308792855303`"}], "+", 
         RowBox[{"53.25308450259745`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"11.20272054114536`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"2.0131650035986226`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-115.20308792855303` + 
       53.25308450259745 ArcTan[11.20272054114536 + ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{177., -3.2575394732108993`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.619576976332695`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8663502299481124`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"8.963141609437418`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.619576976332695 + 
       0.8663502299481124 Log[8.963141609437418 + (6 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{184., -3.2838816551776966`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8795592115064195`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7598089689850342`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.16509018904474715`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.8795592115064195 + 0.7598089689850342 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[7.1182925689352174` + (-0.16509018904474715` + Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{185., -3.2871003309092157`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "6.8432593794847705`"}], "+", 
         RowBox[{"5.316581328272186`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"7", "+", 
               RowBox[{"ArcTan", "[", "4", "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-6.8432593794847705` + 
       5.316581328272186 Log[7 + ArcTan[4] + ArcTan[(Rational[50, 7] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{188., -3.288108010702832}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "281.7346669244098`"}], "+", 
         RowBox[{"189.94303588475856`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.786322573113768`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.5313243816460839`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-281.7346669244098 + 
       189.94303588475856` ArcTan[13.786322573113768` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[0.5313243816460839 + E^Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + 2 Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{193., -3.2926052532940258`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.033874431936797`"}], "+", 
         RowBox[{"4.626827724650649`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"6.361711417213267`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", "9", "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"14.876304387141033`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]}], "]"}],
                "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.033874431936797 + 
       4.626827724650649 
        Log[6.361711417213267 + 
          ArcTan[Cos[9] + Cos[14.876304387141033` + Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]] + ArcTan[
            Tan[9.39812942667831 + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{197., -3.2954302486843576`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.0748837470151713`"}], "+", 
         RowBox[{"1.5986433133753788`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"8.201098896440278`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"5", "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.0748837470151713` + 
       1.5986433133753788` (Log[8.201098896440278 + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[5 + (Sin[
               Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "15"]], 
                 Hue[
                  Rational[15, 16], 1, 
                  Rational[5, 6]]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{198., -3.296770071304977}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "6.4767220437522575`"}], "+", 
         RowBox[{"2.617591254456977`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"7", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["7.702941275878956`", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-6.4767220437522575` + 2.617591254456977 Log[Style[
            TraditionalForm[
             Subscript["x", "14"]], 
            Hue[
             Rational[7, 8], 1, 
             Rational[1, 2]]] + (7 + ArcTan[
              Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[7.702941275878956^(Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] + 3 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]])] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2 + Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]] + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{204., -3.301204184321451}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "6.4620575338119215`"}], "+", 
         RowBox[{"2.6103027999807833`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"7", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["7.702941275878956`", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-6.4620575338119215` + 2.6103027999807833` Log[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "14"]], 
            Hue[
             Rational[7, 8], 1, 
             Rational[1, 2]]] + (7 + ArcTan[
              Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[7.702941275878956^(Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] + 3 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]])] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{206., -3.3160179817182143`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.9024546084064581`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7582165225573285`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.912103860432534`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.9024546084064581 + 0.7582165225573285 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.912103860432534 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[ArcTan[7.1182925689352174` + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]]] + (Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{209., -3.3321374724222843`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7868149924361365`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7666899808131746`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.6612345640775175`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21774355635380405`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7868149924361365 + 0.7666899808131746 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[6.6612345640775175` + (-0.21774355635380405` + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{216., -3.332944143636608}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.864833929145406`"}], "+", 
         RowBox[{"5.087543769749814`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", "7", "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.864833929145406 + 
       5.087543769749814 Log[Log[7] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{226., -3.33900119540029}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7338862536877906`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7708397305603467`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.980998223173188`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.1622658946312185`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.003036661927371398`", "\[VeryThinSpace]"}], 
                    "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7338862536877906 + 0.7708397305603467 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.980998223173188 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[6.1622658946312185` + (0.003036661927371398 + ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{228., -3.343779118252697}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.4186743610288657`"}], "+", 
         RowBox[{"2.242872809173165`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"4.171288691203903`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.4186743610288657` + 2.242872809173165 Log[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + (4.171288691203903 + ArcTan[
              Tan[
               Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]]]] + ArcTan[
              Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{231., -3.3746431858204313`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "717.7378112014475`"}], "+", 
         RowBox[{"468.0040673779309`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"30", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"10.993826769099726`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-717.7378112014475 + 468.0040673779309 ArcTan[30 + ArcTan[
            Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.993826769099726` + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{241., -3.384265341148877}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "658.7355262003367`"}], "+", 
         RowBox[{"432.1598384606752`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"27.26192624530716`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"8.760121933840146`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-658.7355262003367 + 
       432.1598384606752 
        ArcTan[27.26192624530716 + Cos[8.760121933840146 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{246., -3.404928935256343}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "580.3538949846053`"}], "+", 
         RowBox[{"381.8286327518781`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"22.4978454547364`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-580.3538949846053 + 
       381.8286327518781 
        ArcTan[22.4978454547364 + ArcTan[(469.4950238927627 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[1 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{252., -3.4144388644191848`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "366.8451643197309`"}], "+", 
         RowBox[{"244.67669755973404`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.011024089573652`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"8.760121933840146`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-366.8451643197309 + 
       244.67669755973404` ArcTan[18.011024089573652` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[8.760121933840146 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{288., -3.4349618392873795`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.766543626513945`"}], "+", 
         RowBox[{"4.67176460681319`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"9.419547133366983`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"8", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   RowBox[{"0.0008490912944668228`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "8"]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.766543626513945 + 
       4.67176460681319 Log[Log[9.419547133366983 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[8 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + ((0.0008490912944668228 ArcTan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^4) Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^4) Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^8 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{301., -3.4388830496004283`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "314.25341863756495`"}], "+", 
         RowBox[{"210.86981581814493`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], "2"], 
                    "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], "]"}], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-314.25341863756495` + 
       210.86981581814493` ArcTan[10 + ArcTan[((((72 ArcTan[(6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) ArcTan[E^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{302., -3.4429332311206653`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.561691506221822`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2001469568432893`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.561691506221822 - 
       0.2001469568432893 (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Sin[
           Style[
            TraditionalForm[
             Subscript["x", "14"]], 
            Hue[
             Rational[7, 8], 1, 
             Rational[1, 2]]]]] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.4558736550336806`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.31906051661229035`"}], "+", 
         RowBox[{"0.017257623145115013`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"12.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.9999953893457124`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.4570580048577`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.31906051661229035` + 
       0.017257623145115013` (12.122264710056605` + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.9999953893457124 + (-0.4570580048577 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] - Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 - (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{313., -3.457813765956075}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.5638010271910169`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"10.152533937802174`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"7.849991770513654`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"7", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], ")"}], 
                 "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.5638010271910169 + (10.152533937802174`/(10.651382597834791` + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[(18.424973303913877` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2)) Log[7.849991770513654 + Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]^2 + (7 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{317., -3.4719577785879814`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.5724842579879883`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.019243028690651472`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"6.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"1.431226576898648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
                 "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.5724842579879883` + 
       0.019243028690651472` (6.122264710056605 + 
          ArcTan[1.431226576898648 + Log[6 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]]] + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.16509018904474715` + (3 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] - 2 (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{322., -3.489900079037185}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8153878908447142`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.581506396858616`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 SqrtBox[
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"3", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.8153878908447142 + 0.581506396858616 (ArcTan[(6 + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]])^Rational[1, 2]] + ArcTan[1 + (Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]])^2] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 3 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{323., -3.503665085537587}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "611.0772975612497`"}], "+", 
         RowBox[{"287.0743107829361`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"21.684344851086927`", "\[VeryThinSpace]"}], "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"15.904011197164452`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-611.0772975612497 + 
       287.0743107829361 (E^ArcTan[21.684344851086927` + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[15.904011197164452` + Style[
                TraditionalForm[
                 Subscript["x", "12"]], 
                Hue[
                 Rational[3, 4], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{329., -3.5201211301841426`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.371154954337026`", "\[VeryThinSpace]"}], "+", 
         FractionBox["385.31436318953865`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"24.060521364609343`", "\[VeryThinSpace]"}], "-", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.371154954337026` + 
       385.31436318953865`/(-24.060521364609343` - Cos[
        ArcTan[24.060521364609343` - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[6 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{339., -3.5551775760228868`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.0173078580872654`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8336546354626286`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.0173078580872654` + 0.8336546354626286 (ArcTan[(E - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "8"]], 
             Hue[
              Rational[1, 2], 1, 
              Rational[1, 2]]]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{385., -3.5699273243367005`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "617.1707913915086`"}], "+", 
         RowBox[{"204.54889175371142`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"10.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{"3", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-617.1707913915086 + 
       204.54889175371142` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.795322405754767` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.795322405754767` + Sin[3 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]])^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.58211907871711}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "618.4087649464917`"}], "+", 
         RowBox[{"204.95108284731`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"3", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-618.4087649464917 + 
       204.95108284731 (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.795322405754767` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + Sin[3 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{405., -3.5987751651116673`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "606.5163507233204`"}], "+", 
         RowBox[{"201.1905698764841`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"22.795322405754767`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-606.5163507233204 + 
       201.1905698764841 (ArcTan[22.795322405754767` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^4)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + Sin[Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{407., -3.6037981384950415`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "609.4449382401941`"}], "+", 
         RowBox[{"202.03191580781174`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"10.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "]"}]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"10.078869601108746`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-609.4449382401941 + 
       202.03191580781174` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Cos[
             Cos[10.795322405754767` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.078869601108746` + (Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2)^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{428., -3.6074399378165527`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "458.28023984024327`"}], "+", 
         RowBox[{"303.51377990205435`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"9", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-458.28023984024327` + 303.51377990205435` ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] + ArcTan[9 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{465., -3.607615830523193}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.5251864248561969`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7914510512725371`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"]}], ")"}], "2"]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.5251864248561969 + 0.7914510512725371 (-ArcTan[ArcTan[Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]^2] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + (-1 + E^Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - (Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]])^2)^2)^2] + ArcTan[(E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{478., -3.61887253694514}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.652639917130406`"}], "+", 
         RowBox[{"5.356907806858478`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.7990405932174554`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"0.025552233900370046`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.652639917130406 + 5.356907806858478 Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (2.7990405932174554` + Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + ((0.025552233900370046` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + Log[2.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{480., -3.6190485871766045`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.388096222787983`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.13900570010949184`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.388096222787983` - 0.13900570010949184` (2 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Rational[-1, 3] Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "3"]], 
          Hue[
           Rational[3, 16], 1, 
           Rational[5, 6]]]] - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 3 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{555., -3.633131834977006}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.750041978796236`"}], "+", 
         RowBox[{"5.387621603115254`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"5\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0839686468203915`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.750041978796236 + 5.387621603115254 Log[Log[7 + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^4 + (3 + Cos[9] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "10"]], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]]]]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "5"]], 
                Hue[
                 Rational[5, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^2] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (2.0839686468203915` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{560., -3.6734747186769137`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.186560785869651`"}], "+", 
         RowBox[{"4.862731729076287`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               FractionBox["50", "7"], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", "7"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["1", "7"], "+", 
                    FractionBox["1", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", "7"], "]"}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["7", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", "3", "]"}], "]"}]}], "]"}], "]"}], 
                  "14"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{"7", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}], "+", 
                   
                   RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}]}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.186560785869651 + 
       4.862731729076287 Log[Rational[50, 7] + ArcTan[
            Rational[1, 7]] + ArcTan[(Rational[1, 7] + ArcTan[
                Rational[1, 7]]^(-1) + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Sin[7^Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[ArcTan[
              Log[9 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Tan[
                 Cos[3]]]]^14] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[ArcTan[(7 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "6"]], 
                  Hue[
                   Rational[3, 8], 1, 
                   Rational[1, 2]]])^(-1)] + ArcTan[(Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "6"]], 
                  Hue[
                   Rational[3, 8], 1, 
                   Rational[1, 2]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{579., -3.6826123336034473`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "292.97300896366517`"}], "+", 
         RowBox[{"197.23366150725622`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"11", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"10", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-292.97300896366517` + 197.23366150725622` ArcTan[11 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[(Cos[
               Rational[1, 9]] + Cos[(10 + Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "15"]], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{601., -3.6986324604368703`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "936.5771394232942`"}], "+", 
         RowBox[{"607.9493621986173`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.28119298697581`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"7", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], ")"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                "2"], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-936.5771394232942 + 
       607.9493621986173 ArcTan[39.28119298697581 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Cos[(7 + Cos[Cos[Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "3"]], 
                 Hue[
                  Rational[3, 16], 1, 
                  Rational[5, 6]]]^49] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]])^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]^2 + Sin[Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]^2] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{165., -3.2231675210357755`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "381.142351979804`"}], "+", 
         RowBox[{"253.90749758276948`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.011024089573652`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-381.142351979804 + 
       253.90749758276948` ArcTan[18.011024089573652` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{172., -3.225825165699762}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.412935847322016`"}], "+", 
         RowBox[{"1.0524413573325304`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"11.520856280944137`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.412935847322016 + 
       1.0524413573325304` Log[11.520856280944137` + (2 Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (4 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{174., -3.2284005413080346`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "376.1510621213408`"}], "+", 
         RowBox[{"250.68075600743887`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.011024089573652`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"8.760121933840146`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                   "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-376.1510621213408 + 
       250.68075600743887` ArcTan[18.011024089573652` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[8.760121933840146 + Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{177., -3.2518637423106354`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.77113569049238`"}], "+", 
         RowBox[{"5.046956949035845`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.858691932816067`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.77113569049238 + 
       5.046956949035845 
        Log[2.1914474950105785` + Log[1.858691932816067 + Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{182., -3.2573651255687954`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.995220674175601`"}], "+", 
         RowBox[{"1.5223234232217708`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"3", "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.995220674175601 + 1.5223234232217708` (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[3 + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + (Sin[
               Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "15"]], 
                 Hue[
                  Rational[15, 16], 1, 
                  Rational[5, 6]]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{184., -3.2729994366172788`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "348.64756958749444`"}], "+", 
         RowBox[{"233.0041775645884`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-348.64756958749444` + 
       233.0041775645884 ArcTan[14.092284613091337` + ArcTan[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{188., -3.2794217935278764`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.49850158849896276`"}], "+", 
         RowBox[{"0.9260766920421835`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.963141609437418`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.49850158849896276` + 
       0.9260766920421835 Log[4.963141609437418 + (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (2 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^4], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{197., -3.279443573301957}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7827651728394084`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8497005275951397`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7827651728394084 + 0.8497005275951397 Log[9 + (4 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{199., -3.2932527177932567`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "311.64225479381963`"}], "+", 
         RowBox[{"209.20099378846672`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"15", "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               FractionBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}]]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-311.64225479381963` + 209.20099378846672` ArcTan[15 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^4)^Rational[-1, 2] + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{203., -3.2945402769393404`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "341.5298514022355`"}], "+", 
         RowBox[{"228.45460137902404`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-341.5298514022355 + 
       228.45460137902404` ArcTan[13.092284613091337` + ArcTan[2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + 3 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{209., -3.3320509619643337`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7861511422368369`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7664979679809341`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.980998223173188`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.1622658946312185`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.4540213429303286`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.7861511422368369 + 0.7664979679809341 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.980998223173188 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[6.1622658946312185` + (-0.4540213429303286 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{230., -3.33481347055454}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "335.4392748253033`"}], "+", 
         RowBox[{"224.5251766763156`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", "5", "]"}], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-335.4392748253033 + 
       224.5251766763156 ArcTan[13.092284613091337` + ArcTan[Cos[
               Tan[5]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{231., -3.371208574798473}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "639.5801038509733`"}], "+", 
         RowBox[{"417.97635283560913`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"27", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"10.993826769099726`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-639.5801038509733 + 417.97635283560913` ArcTan[27 + ArcTan[
            Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.993826769099726` + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{236., -3.3729333007057525`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "66.50849791391944`"}], "+", 
         RowBox[{"55.80309716322548`", " ", 
           RowBox[{"ArcTan", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"7.65683301240092`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"60", " ", 
                    RowBox[{"Log", "[", "7", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Sin", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-66.50849791391944 + 
       55.80309716322548 
        ArcTan[(7.65683301240092 + ArcTan[((60 Log[7]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^2 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{249., -3.4006027584855625`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.698177260381236`", "\[VeryThinSpace]"}], "-", 
         FractionBox["331.7856156150927`", 
          RowBox[{
            RowBox[{"22.258641845677218`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "+", 
                  RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.491296010290997`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.255183774311888`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[18.698177260381236` - 331.7856156150927/(22.258641845677218` + Cos[
         Cos[7 + 2 Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]] + Cos[7.491296010290997 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.255183774311888` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{268., -3.4026947020871012`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "720.1172015728716`"}], "+", 
         RowBox[{"469.5052823744516`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"30.998606318918796`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-720.1172015728716 + 
       469.5052823744516 ArcTan[30.998606318918796` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[E^(-Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{269., -3.4079531505662266`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "882.0533145110152`"}], "+", 
         RowBox[{"573.0837529217315`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.819852996050756`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-882.0533145110152 + 
       573.0837529217315 ArcTan[39.819852996050756` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{281., -3.4140410090639906`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.194589328587499`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.265614237745707`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.194589328587499` - 0.265614237745707 (-ArcTan[
           Cos[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{288., -3.4275748277877707`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.5885233424943487`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"9.325719152344252`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{"4", "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"8", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                RowBox[{"0.00014675073072075627`", " ", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}]}], 
          RowBox[{
            RowBox[{"9.71404298447733`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{
                 RowBox[{"Log", "[", "7", "]"}], "-", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False]}], "]"}], 
             "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.5885233424943487 + (9.325719152344252/(9.71404298447733 + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[Log[7] - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) Log[4 + (8 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]^2 + 0.00014675073072075627` Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{289., -3.4307611139158523`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7442321679893615`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"9.184266022724405`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                FractionBox["257", "64"], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"8", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                RowBox[{"0.00014675073072075627`", " ", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}]}], 
          RowBox[{
            RowBox[{"9.71404298447733`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{
                 RowBox[{"Log", "[", "7", "]"}], "-", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False]}], "]"}], 
             "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.7442321679893615 + (9.184266022724405/(9.71404298447733 + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[Log[7] - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) Log[Rational[257, 64] + (8 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + 0.00014675073072075627` Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{293., -3.431843823168905}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.689247046060627`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"9.234163076758954`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"8.71404298447733`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Log", "[", "8", "]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"8", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"9.71404298447733`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{
                 RowBox[{"Log", "[", "7", "]"}], "-", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False]}], "]"}], 
             "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.689247046060627 + (9.234163076758954/(9.71404298447733 + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[Log[7] - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) 
        Log[8.71404298447733 + Cos[Log[8] - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]] + (8 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{301., -3.4343057652202296`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "365.6689548662536`"}], "+", 
         RowBox[{"244.28436635920045`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-365.6689548662536 + 
       244.28436635920045` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[10.544750992301736` - ArcTan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{307., -3.446450114924386}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "153.3958254251393`"}], "+", 
         RowBox[{"69.09853382481653`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{"10", "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", "81", "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"327.1198343819689`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], 
                    "2"]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                   "]"}], "4"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-153.3958254251393 + 
       69.09853382481653 
        ArcTan[10 + 
           ArcTan[((((72 ArcTan[81]) ArcTan[(327.1198343819689 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2) (6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])]^4 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{309., -3.447994692882773}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.1775470517922`", "\[VeryThinSpace]"}], "-", 
         FractionBox["444.34327089430116`", 
          RowBox[{
            RowBox[{"27.700224955094946`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.1775470517922 - 444.34327089430116`/(27.700224955094946` + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{313., -3.4530610492078697`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "8.494685274088335`"}], "+", 
         RowBox[{"5.667309240146453`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"10", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-8.494685274088335 + 5.667309240146453 Log[Log[10 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[2.1914474950105785` + E^Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{324., -3.5002962093377894`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.8753422970792082`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.780272260484164`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"1", "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.8753422970792082` + 0.780272260484164 (-ArcTan[1 - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{333., -3.5179282959923417`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "750.5789880808215`"}], "+", 
         RowBox[{"247.66567240723361`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"8", "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-750.5789880808215 + 
       247.66567240723361` (ArcTan[24.59388935870163 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[8 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{340., -3.554665744320725}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "606.2294351832454`"}], "+", 
         RowBox[{"200.9865243331212`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"8", "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   RowBox[{"0.09263271280039957`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-606.2294351832454 + 
       200.9865243331212 (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[8 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + 0.09263271280039957 Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{389., -3.5682056673741096`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "645.1148118659711`"}], "+", 
         RowBox[{"421.4999973603623`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"29.898295381891415`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.147695761381096`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-645.1148118659711 + 
       421.4999973603623 ArcTan[29.898295381891415` + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[1.147695761381096 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + 3 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]] (1 + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "7"]], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]]]]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.5757568614711386`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "617.7243312866891`"}], "+", 
         RowBox[{"204.72821127245564`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-617.7243312866891 + 
       204.72821127245564` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.795322405754767` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + 
              Sin[7.795322405754767 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{407., -3.60137346613116}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "609.7827357686716`"}], "+", 
         RowBox[{"202.1210463937823`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.769293441864576`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"10.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "]"}]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"10.078869601108746`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-609.7827357686716 + 
       202.1210463937823 (ArcTan[23.769293441864576` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Cos[
             Cos[10.795322405754767` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.078869601108746` + (Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2)^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{423., -3.6034829803789297`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "605.4730637606028`"}], "+", 
         RowBox[{"200.84584779642492`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"22.795322405754767`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.743079410605866`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"8.79360244649667`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-605.4730637606028 + 
       200.84584779642492` (ArcTan[22.795322405754767` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[8.743079410605866 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2]]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (8.79360244649667 + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{473., -3.6055998983821365`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "606.4697022585052`"}], "+", 
         RowBox[{"201.17059383527462`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"22.795322405754767`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    FractionBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-606.4697022585052 + 
       201.17059383527462` (ArcTan[22.795322405754767` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]] (1 + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{481., -3.611751760198487}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "610.6363193563973`"}], "+", 
         RowBox[{"202.41976469885964`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"10.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "]"}]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-610.6363193563973 + 
       202.41976469885964` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Cos[
             Cos[10.795322405754767` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 - Sin[
              7.795322405754767 - Cos[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]]] + (Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2)^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{505., -3.61339691282766}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "610.0444830261797`"}], "+", 
         RowBox[{"202.22595475190948`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.5284320043644632`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"10.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "]"}]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-610.0444830261797 + 
       202.22595475190948` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.5284320043644632` - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Cos[
             Cos[10.795322405754767` + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 - Sin[E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]] - Cos[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]]] + (Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2)^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{521., -3.6157368048773524`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.14227630481815973`"}], "+", 
         RowBox[{"0.2224950078344008`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "8.676350914851405`"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"64", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"5", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], ")"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.14227630481815973` + 0.2224950078344008 (ArcTan[
           Cos[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2] + Log[Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + (-8.676350914851405 + (64 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + (5 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]] + (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + ArcTan[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "7"]], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "4"]], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]]]] + Sin[
                    Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]] + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2)^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{573., -3.6430383961914026`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.18938424773462512`"}], "+", 
         RowBox[{"0.22303396001772738`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5.587879631050326`"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"64", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"5", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "]"}]}], ")"}], "2"]}], ")"}], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.18938424773462512` + 0.22303396001772738` (ArcTan[
           Cos[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2]] + ArcTan[ArcTan[
             Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2] + Log[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + (-5.587879631050326 + (64 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + (5 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]] + (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + ArcTan[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "7"]], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "4"]], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]]]] + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2 + Tan[
                    Sin[
                    Sin[
                    Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]]]])^2)^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{579., -3.670999458203269}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "464.5943495952959`"}], "+", 
         RowBox[{"307.585541044963`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"9", "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", "9", "]"}], "]"}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "-", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                    "4"], "]"}]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-464.5943495952959 + 307.585541044963 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[9 + Cos[
              Tan[9]] + 2 Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]] - Tan[E^(4 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])] - Tan[ArcTan[
               Tan[E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])] (1 + Tan[E^(4 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]])]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{171., -3.221799344189317}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.568975191762625`"}], "+", 
         RowBox[{"4.228405295648344`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"8", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.568975191762625 + 4.228405295648344 Log[Log[8 + Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{177., -3.226675916643255}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.3872597180286568`"}], "+", 
         RowBox[{"8.427293297497554`", " ", 
           RowBox[{"Log", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], "]"}], 
                  "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                SqrtBox[
                 RowBox[{
                   RowBox[{"16.93617477220362`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]]}]], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.3872597180286568` + 8.427293297497554 Log[(ArcTan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]] + ArcTan[
             Tan[9.39812942667831 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (16.93617477220362 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]])^Rational[1, 2])^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{180., -3.2379582415782986`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "6.340407524725745`"}], "+", 
         RowBox[{"2.6076031826332513`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Sin", "[", 
                 RowBox[{"Tan", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"7", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-6.340407524725745 + 2.6076031826332513` Log[Sin[
            Tan[
             Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "14"]], 
            Hue[
             Rational[7, 8], 1, 
             Rational[1, 2]]] + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]] + (7 + ArcTan[
              Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{182., -3.23917751667636}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.486570358349745`"}], "+", 
         RowBox[{"1.6107044056719775`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.021553924681339`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.486570358349745 + 
       1.6107044056719775` (Log[6.021553924681339 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + E^ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]^2 + (Sin[
               Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "15"]], 
                 Hue[
                  Rational[15, 16], 1, 
                  Rational[5, 6]]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{183., -3.248063675920646}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "409.3862456679091`"}], "+", 
         RowBox[{"272.0706161882574`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.501804311467012`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-409.3862456679091 + 
       272.0706161882574 ArcTan[18.501804311467012` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{188., -3.258509723370793}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.6689148923006941`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.862174751603956`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.963141609437418`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.6689148923006941 + 0.862174751603956 Log[4.963141609437418 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (6 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{190., -3.2792844856309027`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "649.644189685632`"}], "+", 
         RowBox[{"426.25437294514876`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"19.441340542305888`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"9", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               SqrtBox[
                RowBox[{"81", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-649.644189685632 + 
       426.25437294514876` ArcTan[19.441340542305888` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[9 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (81 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]])^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{199., -3.287053225370586}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.13541254441488842`"}], "+", 
         RowBox[{"0.7564520157058048`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.16509018904474715`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.13541254441488842` + 
       0.7564520157058048 (ArcTan[7.1182925689352174` + Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[7.1182925689352174` + (-0.16509018904474715` + Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{209., -3.3292927135725687`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.5190810919917983`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7869391764303004`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                   
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.5190810919917983 + 0.7869391764303004 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + Log[0.16509018904474715` + (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{231., -3.3533047630233743`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "764.4214684654532`"}], "+", 
         RowBox[{"497.85939882704696`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"32", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"10.993826769099726`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-764.4214684654532 + 497.85939882704696` ArcTan[32 + ArcTan[
            Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.993826769099726` + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{235., -3.360607318035791}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "735.9154431640771`"}], "+", 
         RowBox[{"479.6325816759431`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"31.39444038852711`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-735.9154431640771 + 
       479.6325816759431 ArcTan[31.39444038852711 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{240., -3.36784229927362}}]},
      StyleBox[
       RowBox[{
         RowBox[{"2.0584113349531283`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8556092855274455`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[2.0584113349531283` + 0.8556092855274455 (ArcTan[Cos[6 + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{249., -3.3789151839842115`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "638.8391828210479`"}], "+", 
         RowBox[{"417.50008076688584`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"27", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"10.993826769099726`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-638.8391828210479 + 417.50008076688584` ArcTan[27 + ArcTan[
            Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.993826769099726` + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{252., -3.3968276428922337`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "639.5944132926293`"}], "+", 
         RowBox[{"419.89178099240223`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"26.7711460234138`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-639.5944132926293 + 
       419.89178099240223` ArcTan[26.7711460234138 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[9.250902155733506 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{282., -3.405295166124422}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.220710520038235`"}], "+", 
         RowBox[{"1.9382331012383338`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1.6654238281788025`*^-6", "+", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.220710520038235 + 
       1.9382331012383338` (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E^Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1.6654238281788025`*^-6 + 4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{287., -3.409974891538795}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.404091531127221`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.20026336432324202`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"276.6154854526354`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.404091531127221 - 
       0.20026336432324202` (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[276.6154854526354 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{288., -3.4275742117509145`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.5885240611751352`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"9.325718492097247`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{"4", "+", 
                RowBox[{"0.00014675073072075627`", " ", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"8", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"9.71404298447733`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{
                 RowBox[{"Log", "[", "7", "]"}], "-", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False]}], "]"}], 
             "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.5885240611751352 + (9.325718492097247/(9.71404298447733 + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[Log[7] - Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]]^2)) Log[4 + 0.00014675073072075627` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + (8 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{308., -3.4455433907341786`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "314.9981111896849`"}], "+", 
         RowBox[{"211.3554519604566`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", "81", "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"3600", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "9", "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], 
                    "4"]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "4"], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-314.9981111896849 + 
       211.3554519604566 
        ArcTan[10 + 
          ArcTan[((((72 ArcTan[81]) ArcTan[2.0096060494165187` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]) 
               ArcTan[(3600 ArcTan[9]^2) (6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^4]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{309., -3.445887158919874}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "616.2315134248487`"}], "+", 
         RowBox[{"403.0276871287229`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"27", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-616.2315134248487 + 403.0276871287229 ArcTan[27 + ArcTan[
            Sin[2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{314., -3.453052518063902}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "337.6647324699356`"}], "+", 
         RowBox[{"225.9132378193196`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"15", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"7.740857876994031`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"9", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"5.000324575710058`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-337.6647324699356 + 225.9132378193196 ArcTan[15 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[Cos[7.740857876994031 - Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[9 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (5.000324575710058 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]])^Rational[1, 2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{324., -3.4898751645169357`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "633.3763675387892`"}], "+", 
         RowBox[{"414.0049795400269`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"27", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"10", "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-633.3763675387892 + 414.0049795400269 ArcTan[27 + ArcTan[
            Sin[2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{326., -3.492907489509}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "346.2699732005107`"}], "+", 
         RowBox[{"231.4940873743351`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"15", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"7.740857876994031`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"9", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"5.000324575710058`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-346.2699732005107 + 231.4940873743351 ArcTan[15 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[Cos[7.740857876994031 - Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]]]^2 - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[9 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (5.000324575710058 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]])^Rational[1, 2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{333., -3.499968985287744}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "597.2714114610422`"}], "+", 
         RowBox[{"390.96180134552424`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"12", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-597.2714114610422 + 390.96180134552424` ArcTan[25 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4] + Sin[12 + 5^Rational[1, 2] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{334., -3.5081882255831713`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.503296946119542`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.26306398437257494`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.5994235009132751`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      13.503296946119542` - 
       0.26306398437257494` (ArcTan[1.5994235009132751` + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{335., -3.510962918528921}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "583.3497940349488`"}], "+", 
         RowBox[{"382.0107435332183`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-583.3497940349488 + 382.0107435332183 ArcTan[25 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{336., -3.511435439881127}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.664096347023029`"}], "+", 
         RowBox[{"1.8884108396534034`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                   "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.664096347023029 + 1.8884108396534034` (Log[7 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E^Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[7 + Sin[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{352., -3.5493825903472684`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.9044724720404145`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7818489744456365`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                   "]"}]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[1.9044724720404145` + 0.7818489744456365 (-ArcTan[ArcTan[Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] - (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[1, 2]] + ArcTan[Cos[Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] + Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]] + (E - ArcTan[
               ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + 2 (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{391., -3.5503150981243907`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "751.7741371939007`"}], "+", 
         RowBox[{"248.06627381819885`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}]}],
                     "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-751.7741371939007 + 
       248.06627381819885` (ArcTan[24.59388935870163 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[15.795322405754767` + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]]]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{402., -3.5727347375474516`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"24.732419207669025`", "\[VeryThinSpace]"}], "-", 
         FractionBox["932.1302842792851`", 
          RowBox[{
            RowBox[{"46.269077957266035`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               RowBox[{"7", "+", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      24.732419207669025` - 932.1302842792851/(46.269077957266035` + 
       Cos[7 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[
            Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2 + Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{408., -3.594272066664861}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.044202512386413`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.3334721330846107`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"8.400576499086725`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.00012804895597598695`"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.044202512386413` - 0.3334721330846107 (ArcTan[
          Tan[E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[3 - E^Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[8.400576499086725 + ArcTan[
            Tan[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] + Sin[6.989024623684227 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] - Sin[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]]] + (
          1.4005764990867249` + (-0.00012804895597598695` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{414., -3.594543930951302}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "614.7424738418481`"}], "+", 
         RowBox[{"203.76909043921447`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"8.79360244649667`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-614.7424738418481 + 
       203.76909043921447` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[15.795322405754767` + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2]]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (8.79360244649667 + Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]])^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{459., -3.6000637725279434`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "774.5993748371313`"}], "+", 
         RowBox[{"504.34314139494904`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"35.35957453335216`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 FractionBox[
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                  SqrtBox[
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-774.5993748371313 + 
       504.34314139494904` ArcTan[35.35957453335216 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[ArcTan[E^Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]] (1 + Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{531., -3.6100187370238164`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "605.8776094024548`"}], "+", 
         RowBox[{"200.9776229139373`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"22.795322405754767`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.743079410605866`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    FractionBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-605.8776094024548 + 
       200.9776229139373 (ArcTan[22.795322405754767` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[8.743079410605866 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2]]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]] (1 + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2)^Rational[-1, 2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{576., -3.6164014095708215`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.14433136605384925`"}], "+", 
         RowBox[{"0.22253811065182746`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", "5", "]"}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "8.676350914851405`"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"64", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"5", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], ")"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.14433136605384925` + 0.22253811065182746` (ArcTan[
           Cos[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2]] + ArcTan[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2] + Log[ArcTan[
             Cos[5]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + (-8.676350914851405 + (64 + ArcTan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "7"]], 
                   Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]^2 + (5 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]] + (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + ArcTan[
                    Tan[
                    Sin[
                    Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]]]] + ArcTan[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "7"]], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "4"]], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]]]] + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2)^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{592., -3.6565826560334793`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.15421781972326506`"}], "+", 
         RowBox[{"0.22231300765869802`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5.587879631050326`"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"64", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"5", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], ")"}], "2"]}], ")"}], "2"]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.15421781972326506` + 0.22231300765869802` (ArcTan[
           Cos[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2]] + ArcTan[ArcTan[
             Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2] + Log[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + (-5.587879631050326 + (64 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + (5 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]] + (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + ArcTan[
                    Tan[
                    Sin[
                    Sin[
                    Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]]]]] + ArcTan[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "7"]], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]]]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "4"]], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]]]] + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{648., -3.6651805057761173`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "337.7618251358407`"}], "+", 
         RowBox[{"226.00499518636187`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.98822900605531`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"9", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    FractionBox["1", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-337.7618251358407 + 
       226.00499518636187` ArcTan[13.98822900605531 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(9 + Cos[
               Rational[1, 9]] + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + (9 + Cos[2 + Cos[
                    Rational[1, 2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2]^2 + Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "15"]], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]]]] + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^(-1) + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.512729284775987 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{176., -3.2204272777490703`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.7208123499508572`"}], "+", 
         RowBox[{"8.065668182695077`", " ", 
           RowBox[{"Log", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"2", " ", 
                  SqrtBox["3"]}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"18.93617477220362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], "]"}], 
                  "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.7208123499508572` + 
       8.065668182695077 Log[(2 3^Rational[1, 2] + ArcTan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]] + ArcTan[
             Tan[18.93617477220362 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{177., -3.2266426587867763`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.408306014938939`"}], "+", 
         RowBox[{"1.0520821670065053`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"7", "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.408306014938939 + 1.0520821670065053` Log[7 + Style[
            TraditionalForm[
             Subscript["x", "7"]], 
            Hue[
             Rational[7, 16], 1, 
             Rational[5, 6]]] + (2 Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (4 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{183., -3.2299974414087114`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.4168661712510215`"}], "+", 
         RowBox[{"1.0527646606938341`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"1.917068008407039`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[7, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.4168661712510215` + 
       1.0527646606938341` Log[1.917068008407039 + Style[
             TraditionalForm[
              Subscript["x", "7"]], 
             Hue[
              Rational[7, 16], 1, 
              Rational[5, 6]]]^2 + (2 Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (4 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{185., -3.241341038704005}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "655.7243252206908`"}], "+", 
         RowBox[{"430.18297850564437`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"26.860713902365628`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}]], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-655.7243252206908 + 
       430.18297850564437` ArcTan[26.860713902365628` + ArcTan[
            Sin[E^(-Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]])]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[E^Sin[Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]^2]] + Sin[E^Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{189., -3.2438388240097216`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.5530215875015894`"}], "+", 
         RowBox[{"1.0635033688950297`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"9", "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.5530215875015894` + 1.0635033688950297` Log[9 + (2 Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (4 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]])^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^4], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{190., -3.264529525386229}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.196077093482253`"}], "+", 
         RowBox[{"2.3329962886739657`", " ", 
           RowBox[{"Log", "[", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4.071415465715283`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.30664579395777`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                  "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                  "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
              "2"], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.196077093482253 + 
       2.3329962886739657` 
        Log[(4.071415465715283 + ArcTan[7.30664579395777 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2] + ArcTan[
             Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]]] + Cos[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{191., -3.2768143075886633`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.595558592713345`"}], "+", 
         RowBox[{"0.9363933998304474`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"4", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"2", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.595558592713345 + 0.9363933998304474 Log[4 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + (2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (2 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^4], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{197., -3.2779206639487555`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.984688401203495`"}], "+", 
         RowBox[{"2.001907025878144`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"4.402197792880557`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.984688401203495 + 
       2.001907025878144 (Log[4.402197792880557 + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] + (3.2010988964402785` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{210., -3.323956935118909}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.0729373770544814`"}], "+", 
         RowBox[{"5.386719129500355`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"3", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.0729373770544814` + 5.386719129500355 Log[3 + Log[7 + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{238., -3.342178848916559}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "2.632798163041573`"}], "+", 
         RowBox[{"2.12785625180366`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.273622330215009`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"4.376082579465595`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                    "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-2.632798163041573 + 
       2.12785625180366 
        Log[4.273622330215009 + (4.376082579465595 + 
            ArcTan[(Rational[50, 7] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "6"]], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Sin[ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^7] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{240., -3.344085935591842}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "348.6713126053175`"}], "+", 
         RowBox[{"233.05171903620786`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"30.74426356663109`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-348.6713126053175 + 
       233.05171903620786` 
        ArcTan[14.085903183616281` + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + ArcTan[5.544750992301736 - ArcTan[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + (30.74426356663109 Style[
                 TraditionalForm[
                  Subscript["x", "11"]], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]]]^2) Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]^4] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{244., -3.3516066808648346`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "366.7897898436281`"}], "+", 
         RowBox[{"244.63744925116745`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.26208343404685`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-366.7897898436281 + 
       244.63744925116745` ArcTan[18.26208343404685 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{250., -3.3745660642092528`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.917901917465341`"}], "+", 
         RowBox[{"5.099933758085713`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", "7", "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.917901917465341 + 
       5.099933758085713 Log[Log[7] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{264., -3.387350099341861}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.330398741789349`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.20463585506703005`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.330398741789349 - 
       0.20463585506703005` (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{283., -3.392860232475254}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "327.750173821921`"}], "+", 
         RowBox[{"219.5412544260481`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.880671251425152`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "-", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"40.85670134447199`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"1", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-327.750173821921 + 
       219.5412544260481 ArcTan[15.880671251425152` - Cos[3 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[40.85670134447199 + Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[1 - E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] - Sin[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] - (1 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{289., -3.3949741859758276`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.32007623565496823`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"10.374017702283084`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"21.62531054629088`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"9", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.32007623565496823` + (10.374017702283084`/(10.651382597834791` + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[(18.424973303913877` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2)) Log[21.62531054629088 + (9 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{291., -3.4268875666624687`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "167.31745457534296`"}], "+", 
         RowBox[{"75.13000544523331`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"12.630654175918018`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-167.31745457534296` + 
       75.13000544523331 ArcTan[12.630654175918018` + ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + ArcTan[10.544750992301736` - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Cos[Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{310., -3.441721295612838}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "177.36317769585816`"}], "+", 
         RowBox[{"79.17377281842899`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"2.0131650035986226`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-177.36317769585816` + 
       79.17377281842899 ArcTan[14.085903183616281` + ArcTan[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + ArcTan[10.544750992301736` - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]^2] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{316., -3.4500197313495353`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1794.7114502732543`"}], "-", 
         RowBox[{"1820.460995206334`", " ", 
           RowBox[{"Sin", "[", 
             RowBox[{
               RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.5284320043644632`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "]"}], 
                   "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1794.7114502732543` - 1820.460995206334 
       Sin[7.795322405754767 + ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.5284320043644632` - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Cos[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{317., -3.4506215817899117`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "151.73369694195563`"}], "-", 
         FractionBox[
          RowBox[{"490.222201373636`", " ", 
            SuperscriptBox[
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                    "]"}], "2"], "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"]}], 
          RowBox[{
            RowBox[{"-", "8.713937467700774`"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"16", "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], 
              "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-151.73369694195563` - 
       490.222201373636 (ArcTan[13.092284613091337` + ArcTan[Cos[9] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]^2] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "10"]], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]]]]^2]^2 + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2/(-8.713937467700774 + ArcTan[16 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]] + Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]] + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^2])), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{325., -3.4511717567326174`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "397.7648130435003`"}], "+", 
         RowBox[{"264.6213607971663`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-397.7648130435003 + 264.6213607971663 ArcTan[18 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])] (1 + Tan[E^(4 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]])]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{326., -3.4632621650135613`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.2324800611185308`"}], "+", 
         RowBox[{"0.01713149187698537`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"12.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.9999953893457124`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", "6"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.2324800611185308 + 
       0.01713149187698537 (12.122264710056605` + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Log[0.9999953893457124 + (ArcTan[
                Rational[1, 6]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] - Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] - Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 - (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{329., -3.4719452207757584`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.4008132248693`", "\[VeryThinSpace]"}], "+", 
         FractionBox["388.3629886208334`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"ArcTan", "[", 
                  RowBox[{"5", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.4008132248693 + 
       388.3629886208334/(-24.060521364609343` - Cos[ArcTan[5 - Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]] + Cos[6 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{331., -3.47729784520143}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "8.678071651088857`"}], "+", 
         RowBox[{"5.708896126134323`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"10", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-8.678071651088857 + 5.708896126134323 Log[Log[10 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[1.1914474950105785` + 2 E^Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (1 + Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{332., -3.4783320218657297`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "622.7189021697495`"}], "+", 
         RowBox[{"407.24812971001705`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"25.998606318918796`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-622.7189021697495 + 
       407.24812971001705` ArcTan[25.998606318918796` + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{333., -3.499912361224323}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "591.7866409936821`"}], "+", 
         RowBox[{"387.44107513316015`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"6", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-591.7866409936821 + 387.44107513316015` ArcTan[25 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4] + Sin[6 + 5^Rational[1, 2] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{346., -3.507055354364556}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "600.2472928179852`"}], "+", 
         RowBox[{"392.8154546329957`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", "2", "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-600.2472928179852 + 392.8154546329957 ArcTan[25 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[2] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{353., -3.5185377028310607`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "582.6210737198104`"}], "+", 
         RowBox[{"381.5421041481193`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-582.6210737198104 + 381.5421041481193 ArcTan[25 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{357., -3.5322549224971684`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "603.2531924529917`"}], "+", 
         RowBox[{"394.8040490210669`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-603.2531924529917 + 394.8040490210669 ArcTan[25 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{358., -3.532938149840522}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.881400358757936`", "\[VeryThinSpace]"}], "-", 
         FractionBox["242.00597619098207`", 
          RowBox[{
            RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"12.630654175918018`", "\[VeryThinSpace]"}], "-", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"5", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                  "]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"2.0131650035986226`", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], " ", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.881400358757936` - 242.00597619098207`/(14.085903183616281` + 
       ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + ArcTan[12.630654175918018` - ArcTan[
          Cos[((ArcTan[5 - Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]]) Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "11"]], 
          Hue[
           Rational[11, 16], 1, 
           Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "6"]], 
           Hue[
            Rational[3, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]^2] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{368., -3.5337934404192395`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "535.6967178214145`"}], "+", 
         RowBox[{"351.53882539357505`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"20", "+", 
               SqrtBox["5"], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-535.6967178214145 + 
       351.53882539357505` ArcTan[20 + 5^Rational[1, 2] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^4] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{375., -3.5373147435964394`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.5587031489078567`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.019211615327367124`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"6.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.8257038361230722`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    "]"}]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.980998223173188`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.5587031489078567` + 
       0.019211615327367124` (6.122264710056605 + ArcTan[ArcTan[6 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Log[1.8257038361230722` + (-Style[
                   TraditionalForm[
                    Subscript["x", "14"]], 
                   Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]]] + Style[
                  TraditionalForm[
                   Subscript["x", "4"]], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]]])^2]] + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.980998223173188 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.16509018904474715` + (3 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] - 2 (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{389., -3.5464750929608915`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "765.0657861780212`"}], "+", 
         RowBox[{"498.2369157581137`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"35.35957453335216`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 FractionBox[
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], 
                  SqrtBox[
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"]}]]], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-765.0657861780212 + 
       498.2369157581137 ArcTan[35.35957453335216 + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]]^49]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]] (1 + Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]^2)^Rational[-1, 2]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{403., -3.5597368280519577`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.186391563455653`"}], "+", 
         RowBox[{"5.235897851239935`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"8", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.186391563455653 + 5.235897851239935 Log[Log[8 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (4 + 
              Cos[9] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^2] + Log[2.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + Style[
                TraditionalForm[
                 Subscript["x", "10"]], 
                Hue[
                 Rational[5, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{408., -3.5745455599130063`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.7590602060183196`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19409394524217205`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", "5"], " ", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.7590602060183196` - 0.19409394524217205` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6.871489524120378 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[(E^5 Cos[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2]) Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{420., -3.5879349948958543`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.45907811352271`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.13678274064008192`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"3", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "3"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.45907811352271 - 0.13678274064008192` (3 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "3"]], 
          Hue[
           Rational[3, 16], 1, 
           Rational[5, 6]]]] - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[Rational[1, 3] Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 2 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Rational[-1, 3] Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{443., -3.5906462777022683`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.276103697669949`"}], "+", 
         RowBox[{"5.261945830232147`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"8", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "9", "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.276103697669949 + 5.261945830232147 Log[Log[8 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (3 + Cos[9] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^2] + Log[2.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + Cos[9]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{472., -3.5918667244704623`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.5257373673723493`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19351741652061494`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], "2"], 
                    "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.5257373673723493` - 0.19351741652061494` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + 25.140795789942956` Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]])^2] - (E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{489., -3.5989411314786355`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "606.5504074959028`"}], "+", 
         RowBox[{"201.20184656633737`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"22.795322405754767`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}]}], 
                    "]"}]}], "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-606.5504074959028 + 
       201.20184656633737` (ArcTan[22.795322405754767` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[
            15.795322405754767` + Sin[E^Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]]]]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^4)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.795322405754767 + Sin[Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{606., -3.6014082828458984`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.787622109049287`"}], "+", 
         RowBox[{"5.015724467898965`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               FractionBox["50", "7"], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{"7", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["1", "7"], "+", 
                    FractionBox["1", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", "7"], "]"}]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Sin", "[", "7", "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", "3", "]"}], "]"}]}], "]"}], "]"}], 
                  "14"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{"7", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}], "+", 
                   
                   RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}]], "]"}]}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.787622109049287 + 
       5.015724467898965 Log[Rational[50, 7] + ArcTan[(7 + 2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]])^(-1)] + ArcTan[(Rational[1, 7] + ArcTan[
                Rational[1, 7]]^(-1) + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Sin[7] + Sin[ArcTan[
              Log[9 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2 + Tan[
                 Cos[3]]]]^14] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[ArcTan[(7 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "6"]], 
                  Hue[
                   Rational[3, 8], 1, 
                   Rational[1, 2]]])^(-1)] + ArcTan[(Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "6"]], 
                  Hue[
                   Rational[3, 8], 1, 
                   Rational[1, 2]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{611., -3.631112936317794}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "456.222208026126`"}], "+", 
         RowBox[{"302.1983564985421`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"9", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "-", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-456.222208026126 + 302.1983564985421 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + ArcTan[9 + E^ArcTan[
               Cos[E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]] + Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] - Sin[
             Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] - Tan[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]^4]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{179., -3.2204898767494097`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.9103506457661505`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.83831695085236`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                   
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.9103506457661505 + 0.83831695085236 (ArcTan[(8.997137324829144 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[0.16509018904474715` + (-6 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{186., -3.2228492083114233`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.1049371165600606`"}], "+", 
         RowBox[{"7.747129519159642`", " ", 
           RowBox[{"Log", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], "]"}], 
                  "]"}], "+", 
                SqrtBox[
                 RowBox[{"9", "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}]], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.1049371165600606` + 7.747129519159642 Log[(ArcTan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]] + ArcTan[
             Tan[9.39812942667831 + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4]] + (9 + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^Rational[1, 2] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{190., -3.2519577986964743`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "318.91571441827784`"}], "+", 
         RowBox[{"213.8109013419176`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.037945466171522`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"0.36307581826373736`", "\[VeryThinSpace]"}], "-", 
                   
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-318.91571441827784` + 
       213.8109013419176 ArcTan[14.037945466171522` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[0.36307581826373736` - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{192., -3.2718471052344893`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.725438575885954`"}], "+", 
         RowBox[{"4.7556002834847515`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"7", "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", "7"], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.725438575885954 + 4.7556002834847515` Log[7 + ArcTan[
            Rational[1, 7]] + ArcTan[(Rational[50, 7] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.277385622003605}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.8979285959073354`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.7584020888692435`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"7.575350573792917`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.16509018904474715`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.8979285959073354 + 0.7584020888692435 (ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "6"]], 
             Hue[
              Rational[3, 8], 1, 
              Rational[1, 2]]]] + 
         ArcTan[(7.575350573792917 + ArcTan[7.1182925689352174` + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[7.1182925689352174` + (-0.16509018904474715` + Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{212., -3.2934299349882052`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "384.88424810726667`"}], "+", 
         RowBox[{"256.205531084115`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"20", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{
                  RowBox[{"-", "8"}], "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-384.88424810726667` + 256.205531084115 ArcTan[20 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + (-8 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]])^(-1) + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{219., -3.3139282628907925`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "318.37014334432814`"}], "+", 
         RowBox[{"213.4840183328173`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.880671251425152`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "-", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"40.85670134447199`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"0.05862559386771415`", "\[VeryThinSpace]"}], "-", 
                   
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"1", "-", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-318.37014334432814` + 
       213.4840183328173 ArcTan[15.880671251425152` - Cos[3 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[40.85670134447199 + Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[0.05862559386771415 - E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Sin[1 - E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{220., -3.3146551647108873`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "748.7939943916125`"}], "+", 
         RowBox[{"487.8698353199552`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"31.197275649713855`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"10", "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-748.7939943916125 + 
       487.8698353199552 ArcTan[31.197275649713855` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{225., -3.3155698367265845`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.0132642560031249`"}], "+", 
         RowBox[{"1.5107055207491102`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.2010988964402785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", "\[ExponentialE]", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.9999983345761718`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.0132642560031249` + 1.5107055207491102` (Log[6 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[2.2010988964402785` + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Log[1 + E + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (-0.9999983345761718 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{238., -3.3363387242736624`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.4323090575621933`"}], "+", 
         RowBox[{"2.2472261457267577`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"12.130765187357866`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"4.376082579465595`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                    "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.4323090575621933` + 
       2.2472261457267577` 
        Log[12.130765187357866` + (4.376082579465595 + 
            ArcTan[(Rational[50, 7] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "6"]], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Sin[ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^7] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{243., -3.337082106330455}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "615.8446535567982`"}], "+", 
         RowBox[{"402.8173706574053`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"27", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", "5", "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-615.8446535567982 + 402.8173706574053 ArcTan[27 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[5] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "10"]], 
              Hue[
               Rational[5, 8], 1, 
               Rational[1, 2]]]] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{249., -3.3494578568502114`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.401811568366718`", "\[VeryThinSpace]"}], "+", 
         FractionBox["385.43929527405504`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.3696850295348935`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.401811568366718` + 
       385.43929527405504`/(-24.060521364609343` - Cos[
        1.3696850295348935` + Cos[6 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{251., -3.3682738581000873`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "728.125500643435`"}], "+", 
         RowBox[{"474.6088793152918`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"33.98659122718613`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-728.125500643435 + 
       474.6088793152918 ArcTan[33.98659122718613 + ArcTan[3 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{253., -3.372512261940932}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "738.7051343144971`"}], "+", 
         RowBox[{"481.39809021287067`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"30.998606318918796`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"10", "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-738.7051343144971 + 
       481.39809021287067` ArcTan[30.998606318918796` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[E^(-Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{266., -3.3837224613751538`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.06800018963804028`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8894282186850389`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"5", "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.06800018963804028 + 0.8894282186850389 Log[ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + (5 + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (ArcTan[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]]] + 2 Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{278., -3.387350099341861}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.330398741789349`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.20463585506703005`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.330398741789349 - 
       0.20463585506703005` (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{286., -3.3900473746686575`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.7780537778317873`"}], "+", 
         RowBox[{"1.1457189311328593`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"15.260349000533859`", "\[VeryThinSpace]"}], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"5.347549219628953`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["7.702941275878956`", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.7780537778317873` + 
       1.1457189311328593` Log[15.260349000533859` + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]] + Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]] + (5.347549219628953 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (4 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Cos[7.702941275878956^(Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]] + 3 Style[
                    TraditionalForm[
                    Subscript["x", "7"]], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]])] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{295., -3.3919148975313487`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.146663902648468`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.2602042644222206`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.146663902648468` - 0.2602042644222206 (-ArcTan[
           Cos[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + 2 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + (
          1.4005764990867249` + (0.15261977892104736` + 
            Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{296., -3.4250682369875336`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.487113331793898`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19574929147072756`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"276.6154854526354`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.487113331793898 - 
       0.19574929147072756` (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]] + Cos[276.6154854526354 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.4259359728095244`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.02100135928902416`"}], "+", 
         RowBox[{"2.517681592345335`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], "]"}], 
                    "]"}], "+", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    RowBox[{"Cos", "[", "9", "]"}]}]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"0.5080960709285205`", "\[VeryThinSpace]"}], "+", 
                    
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
                    "]"}]}], "]"}], "]"}]}], "+", 
               SqrtBox[
                RowBox[{"4", "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.02100135928902416 + 2.517681592345335 (-Cos[
            Log[ArcTan[
               Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^4]] + (9 + Cos[9])^Rational[1, 2] - Cos[
             0.5080960709285205 + (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^Rational[1, 2]]]] + (4 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{320., -3.445323892587586}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.179547646975776`"}], "+", 
         RowBox[{"4.764452862467299`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"8", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   RowBox[{"0.0008490912944668228`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "8"]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.179547646975776 + 4.764452862467299 Log[Log[8 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + ((0.0008490912944668228 ArcTan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^4) Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^4) Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^8 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{321., -3.4482742094310135`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "153.1096639696195`"}], "+", 
         RowBox[{"68.97993328878437`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{"10", "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", "81", "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"3600", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], 
                    "2"]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "4"], 
                "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-153.1096639696195 + 
       68.97993328878437 
        ArcTan[
          10 + ArcTan[((((72 ArcTan[81]) 
                 ArcTan[2.0096060494165187` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]) ArcTan[(3600 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2) (6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]]^4 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{326., -3.456760938551061}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "612.8145978328292`"}], "+", 
         RowBox[{"402.6218638171008`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"24.887495582112116`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-612.8145978328292 + 
       402.6218638171008 ArcTan[24.887495582112116` + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] (1 + Tan[Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{327., -3.4600805644141652`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "73.3816234496174`"}], "+", 
         RowBox[{"60.67462044932586`", " ", 
           RowBox[{"ArcTan", "[", 
             SqrtBox[
              RowBox[{
                RowBox[{"8.189126509606261`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{
                    RowBox[{"Log", "[", "7", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.857617352803711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], ")"}], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"7", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}]}], "]"}],
                  "2"], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                "+", 
                RowBox[{"Sin", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-73.3816234496174 + 
       60.67462044932586 
        ArcTan[(8.189126509606261 + 
           ArcTan[(((Log[7] (9.857617352803711 + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]])) Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (7 + Style[
                 TraditionalForm[
                  Subscript["x", "15"]], 
                 Hue[
                  Rational[15, 16], 1, 
                  Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "6"]], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]]])]^2 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{334., -3.480821601913769}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.43192487991395556`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"10.23424398861637`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"17.564034754990985`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"7", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], ")"}], 
                 "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.43192487991395556` + (10.23424398861637/(10.651382597834791` + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[(18.424973303913877` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2)) 
        Log[17.564034754990985` + (7 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{337., -3.4944956068053283`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"4.420919704490945`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.20174627246471485`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SqrtBox[
                  SuperscriptBox["\[ExponentialE]", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.42358941220425095`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]]}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      4.420919704490945 - 
       0.20174627246471485` (-(
           E^(E^(-ArcTan[6 - (-0.42358941220425095` + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2)^2 - Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{355., -3.514274258675528}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "8.518839561034081`"}], "+", 
         RowBox[{"5.643070014534143`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"10", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-8.518839561034081 + 5.643070014534143 Log[Log[10 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[1.1914474950105785` + E^Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (1 + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{371., -3.5245752391869734`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.382015540417687`", "\[VeryThinSpace]"}], "+", 
         FractionBox["386.48302464435307`", 
          RowBox[{
            RowBox[{"-", "24.060521364609343`"}], "-", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    RowBox[{"0.34997021580682713`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"24.060521364609343`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}]}], 
                  "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
             "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"6", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "-", 
            SqrtBox[
             RowBox[{
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}]]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.382015540417687` + 
       386.48302464435307`/(-24.060521364609343` - Cos[ArcTan[Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + 
           0.34997021580682713` (24.060521364609343` + Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]])] + Cos[6 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]] + Cos[6 Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] - (Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 + (ArcTan[Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (-Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2] - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2)^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{388., -3.5288723566265263`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "437.6528426031607`"}], "+", 
         RowBox[{"290.2327745884564`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox["\[ExponentialE]", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-437.6528426031607 + 290.2327745884564 ArcTan[18 + E^Cos[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + ArcTan[
            Cos[
             Sin[
              Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]]] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{409., -3.5561568384613538`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "310.6778692617901`"}], "+", 
         RowBox[{"208.58802118402988`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.507330659092322`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{"10", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-310.6778692617901 + 
       208.58802118402988` ArcTan[13.507330659092322` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(10 + Cos[
               Rational[1, 9]] + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{410., -3.5659647192890827`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.90057051242465`", "\[VeryThinSpace]"}], "-", 
         FractionBox["242.51857112445984`", 
          RowBox[{
            RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"12.630654175918018`", "\[VeryThinSpace]"}], "-", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"4.953779542217687`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                    " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                  "]"}], "+", 
                RowBox[{"Cos", "[", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"2.0131650035986226`", " ", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[11, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], " ", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.90057051242465 - 242.51857112445984`/(14.085903183616281` + ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + ArcTan[12.630654175918018` - ArcTan[
          Cos[((ArcTan[4.953779542217687 - Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] - Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2] Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]]) Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2]] + Cos[
           Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]] - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "11"]], 
          Hue[
           Rational[11, 16], 1, 
           Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + ArcTan[6.95204228255524 - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "6"]], 
           Hue[
            Rational[3, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
            TraditionalForm[
             Subscript["x", "11"]], 
            Hue[
             Rational[11, 16], 1, 
             Rational[5, 6]]]) Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]]^2] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{412., -3.5693688449057728`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1797.0044258970722`"}], "-", 
         RowBox[{"1822.7500392821457`", " ", 
           RowBox[{"Sin", "[", 
             RowBox[{
               RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1797.0044258970722` - 1822.7500392821457` 
       Sin[7.795322405754767 + ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + 4 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^4)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{425., -3.5798367261285824`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "607.077514550728`"}], "+", 
         RowBox[{"201.27317517032907`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}]}], "]"}]}], "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   RowBox[{"0.09263271280039957`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-607.077514550728 + 
       201.27317517032907` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[15.795322405754767` + Sin[
               Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]]]]]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + 0.09263271280039957 Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{500., -3.5893089080264486`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1795.5249716339908`"}], "-", 
         RowBox[{"1821.3399135962384`", " ", 
           RowBox[{"Sin", "[", 
             RowBox[{
               RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.3859672172643`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1795.5249716339908` - 1821.3399135962384` 
       Sin[7.795322405754767 + ArcTan[23.3859672172643 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + (Sin[ArcTan[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]] - Sin[
                  Style[
                   TraditionalForm[
                    Subscript["x", "15"]], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2)^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{501., -3.59043926880069}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1795.7640386419248`"}], "-", 
         RowBox[{"1821.580201762338`", " ", 
           RowBox[{"Sin", "[", 
             RowBox[{
               RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.3859672172643`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"5.510522207940621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1795.7640386419248` - 1821.580201762338 
       Sin[7.795322405754767 + ArcTan[23.3859672172643 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (
             1 + (Sin[5.510522207940621 + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2]] + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2)^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{553., -3.5914965148695304`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.232502669291862`"}], "+", 
         RowBox[{"5.25320781007138`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]], "]"}], 
                    "]"}], "+", 
                    RowBox[{"0.029139171135549185`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0839686468203915`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.232502669291862 + 5.25320781007138 Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]])^2 + (3 + Cos[9] + Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]] + Sin[
                Sin[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)]] + ((0.029139171135549185` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2] + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (2.0839686468203915` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{620., -3.6006554126991155`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "292.62158364767475`"}], "+", 
         RowBox[{"197.0128145263917`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"11", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "9"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.388694565552804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.488694565552803`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6.512729284775987`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.513694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", "1", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-292.62158364767475` + 197.0128145263917 ArcTan[11 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 9]] + Cos[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Cos[(Cos[Log[6.388694565552804 + Log[6.488694565552803 + Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]] + Style[
                   TraditionalForm[
                    Subscript["x", "9"]], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]^(-1)] + Cos[(6.512729284775987 + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]])^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[Cos[
               Rational[1, 2]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.513694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Cos[
                Rational[1, 8]] + Cos[1] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{625., -3.6119306352747222`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "192.45870742258163`"}], "+", 
         RowBox[{"0.0038844975036497935`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
              RowBox[{"ArcTan", "[", 
                RowBox[{
                  RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                  RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                "]"}], "+", 
              RowBox[{"ArcTan", "[", 
                RowBox[{
                  RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                  RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                  FractionBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                   RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", 
                    SqrtBox["10"]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"]}], ")"}], 
                    "2"]}]]}], "]"}]}]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-192.45870742258163` + 
       0.0038844975036497935` 
        E^(7.795322405754767 + ArcTan[23.590644811509534` + ArcTan[
              Sin[
               Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]])]] + 
          ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] - Sin[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] - (1 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (7.795322405754767 + 
               Sin[10^Rational[-1, 2] - E^Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]] + (Sin[7.795322405754767 - E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^4)^2)^(-1) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{638., -3.6290404584680003`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "580.8357755695893`"}], "+", 
         RowBox[{"192.9280348574111`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.322706310002932`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "7.795322405754767`"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
                    RowBox[{
                    RowBox[{"7.649822371946153`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], 
                    RowBox[{"3", "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]]}], 
                 "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-580.8357755695893 + 
       192.9280348574111 (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.322706310002932 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.795322405754767` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (7.649822371946153 + 
              Sin[7.795322405754767 - E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]] + (3 + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]])^(-1) ((-2) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])])^(-1) (-7.795322405754767 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{179., -3.2192016279362567`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.9103124883160223`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.8382381665260408`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"8.980998223173188`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                   
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.9103124883160223 + 
       0.8382381665260408 (ArcTan[(8.980998223173188 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)] + 
         Log[0.16509018904474715` + (-6 + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]] - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{188., -3.222828124926636}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.15084503079336395`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.9038593159243599`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.963141609437418`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"9", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.15084503079336395` + 0.9038593159243599 Log[4.963141609437418 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (9 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{191., -3.2493458571537652`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.048633133700605`"}], "+", 
         RowBox[{"1.0991148115172769`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"3", "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.048633133700605 + 1.0991148115172769` Log[3 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^2 + (2 Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] + (4 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{195., -3.2563079984124275`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.97869772900475`", "\[VeryThinSpace]"}], "-", 
         FractionBox["277.75909026857056`", 
          RowBox[{
            RowBox[{"19.573081961453298`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"Cos", "[", "7", "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{"7", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                  RowBox[{"0.22722309525110254`", " ", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], "]"}],
               "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      17.97869772900475 - 277.75909026857056`/(19.573081961453298` + 
       Cos[Cos[7] + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[7 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]] + 0.22722309525110254` Tan[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{207., -3.2662489185564425`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.2245434275124865`"}], "+", 
         RowBox[{"2.3374022525403335`", " ", 
           RowBox[{"Log", "[", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4.071415465715283`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"3.2261474686723375`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                  "+", 
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                  "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], "]"}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
              "2"], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.2245434275124865` + 
       2.3374022525403335` 
        Log[(4.071415465715283 + ArcTan[3.2261474686723375` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]^2] + ArcTan[
             Tan[
              Style[
               TraditionalForm[
                Subscript["x", "7"]], 
               Hue[
                Rational[7, 16], 1, 
                Rational[5, 6]]]]] + Cos[ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{213., -3.2737420736092537`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "706.0230367682957`"}], "+", 
         RowBox[{"233.22739300843267`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"17.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", 
                    SqrtBox["5"]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-706.0230367682957 + 
       233.22739300843267` (
         ArcTan[24.59388935870163 + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])] + Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + 
         ArcTan[17.590644811509534` + Sin[5^Rational[-1, 2] - E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{214., -3.2778389839285977`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "0.6413964441352419`"}], "+", 
         RowBox[{"0.9401277808605222`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"12.986603461342183`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"2", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], ")"}], "2"], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "4"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-0.6413964441352419 + 
       0.9401277808605222 Log[12.986603461342183` - Sin[
           Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (2 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2)^2 + Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]] + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]^4], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{215., -3.287711030213683}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.6685003061527184`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"1.7262545074719204`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[ExponentialE]", "-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], 
                    "]"}], "2"], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                    ")"}], "2"], "+", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                 "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.6685003061527184 + 
       1.7262545074719204` (ArcTan[1 + (E - ArcTan[ArcTan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2]^2 - (Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]] - Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]])^2)^2 + Tan[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{222., -3.290786251855545}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "329.44144998083925`"}], "+", 
         RowBox[{"220.89207568910967`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"10.544750992301736`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-329.44144998083925` + 
       220.89207568910967` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[10.544750992301736` + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{227., -3.302262325123562}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "352.710976699579`"}], "+", 
         RowBox[{"235.76316674357153`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"7.085903183616281`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"5", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-352.710976699579 + 
       235.76316674357153` ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[7.085903183616281 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] + ArcTan[5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "11"]], 
             Hue[
              Rational[11, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{228., -3.307542571225995}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "296.2651740103949`"}], "+", 
         RowBox[{"199.32276394254805`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"36.94349302874269`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"5.544750992301736`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-296.2651740103949 + 
       199.32276394254805` ArcTan[12.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[36.94349302874269 - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + ArcTan[5.544750992301736 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{238., -3.3194583289803363`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.4652151834244074`"}], "+", 
         RowBox[{"1.9730020898482643`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"4.273622330215009`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"3.3567561299312785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    FractionBox["50", "7"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"Tan", "[", "8", "]"}]}]], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                    "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.4652151834244074` + 
       1.9730020898482643` 
        Log[4.273622330215009 + (3.3567561299312785` + 
            ArcTan[(Rational[50, 7] + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "6"]], 
                 Hue[
                  Rational[3, 8], 1, 
                  Rational[1, 2]]] + Tan[8])^(-1)] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]] + Sin[ArcTan[
                Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^7] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{240., -3.3354967235674033`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "335.9133097931463`"}], "+", 
         RowBox[{"224.8326743472885`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", "14"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-335.9133097931463 + 
       224.8326743472885 
        ArcTan[13.092284613091337` + ArcTan[Cos[E^14] + 2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{244., -3.3366913610527207`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "587.989769631798`"}], "+", 
         RowBox[{"384.93942303769927`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"25", "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"10.993826769099726`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-587.989769631798 + 384.93942303769927` ArcTan[25 + ArcTan[
            Sin[
             Cos[
              Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "10"]], 
              Hue[
               Rational[5, 8], 1, 
               Rational[1, 2]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (10.993826769099726` + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{252., -3.358490540581736}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "367.3444954832296`"}], "+", 
         RowBox[{"245.3220315970116`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.085903183616281`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"6.95204228255524`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"16.089501984603473`", "\[VeryThinSpace]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"2.0131650035986226`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-367.3444954832296 + 
       245.3220315970116 ArcTan[14.085903183616281` + ArcTan[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] + ArcTan[6.95204228255524 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + ArcTan[16.089501984603473` - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] - 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Cos[(2.0131650035986226` Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{256., -3.358744685458908}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "381.7347353058913`"}], "+", 
         RowBox[{"254.18460243465054`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.756506038425044`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"58.909308856727115`", " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
                "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-381.7347353058913 + 
       254.18460243465054` 
        ArcTan[16.756506038425044` + ArcTan[((58.909308856727115` Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "15"]], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]]]]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]^2]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[3 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{258., -3.368012056415399}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.16358191385995544`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"1.8412483616685`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], "]"}], 
                    "]"}]}], "]"}], "]"}]}], "-", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Log", "[", 
                   RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "]"}], "+", 
               SqrtBox[
                RowBox[{"9", "+", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[0.16358191385995544` + 1.8412483616685 (-Cos[
            Log[3 + ArcTan[
               Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^4]]]] - Cos[
          Log[2 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]] + (9 + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{280., -3.3796216214133903`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "6.936236369810384`"}], "+", 
         RowBox[{"5.345911267432694`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{"3", "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "]"}], "]"}], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-6.936236369810384 + 5.345911267432694 Log[3 + Log[1 + Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[
             Sin[
              Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{298., -3.4109129250800505`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "148.89470726034693`"}], "-", 
         FractionBox[
          RowBox[{"482.0944210823446`", " ", 
            SuperscriptBox[
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                    "]"}], "2"], "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"]}], 
          RowBox[{
            RowBox[{"-", "8.713937467700774`"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"16", "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-148.89470726034693` - (482.0944210823446/(-8.713937467700774 + 
        ArcTan[16 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]])) 
       ArcTan[13.092284613091337` + ArcTan[Cos[9] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{301., -3.4231231031286247`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "866.4174652692598`"}], "+", 
         RowBox[{"563.1207785905543`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"39.19072549889149`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"3.1406996321259637`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Tan", "[", 
                   RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-866.4174652692598 + 
       563.1207785905543 ArcTan[39.19072549889149 + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[3.1406996321259637` - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 - Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + 2 Cos[9.250902155733506 + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + Cos[
            Tan[85.57919069495483 Style[
               TraditionalForm[
                Subscript["x", "8"]], 
               Hue[
                Rational[1, 2], 1, 
                Rational[1, 2]]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{320., -3.4243562909769008`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "3.4254130257490667`"}], "+", 
         RowBox[{"1.117403646653829`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"63.33530429963972`", "\[VeryThinSpace]"}], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "+", 
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["7.702941275878956`", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                "2"]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-3.4254130257490667` + 
       1.117403646653829 Log[63.33530429963972 + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]] + Style[
            TraditionalForm[
             Subscript["x", "7"]], 
            Hue[
             Rational[7, 16], 1, 
             Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "9"]], 
            Hue[
             Rational[9, 16], 1, 
             Rational[5, 6]]] + (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + 2 Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + (4 + ArcTan[
                Tan[
                 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]]]] + Cos[7.702941275878956^(Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]] + 3 Style[
                    TraditionalForm[
                    Subscript["x", "7"]], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]]])] + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Style[
              TraditionalForm[
               Subscript["x", "7"]], 
              Hue[
               Rational[7, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{322., -3.437833150664169}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "691.848695444678`"}], "+", 
         RowBox[{"451.3926552046293`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"32.35775246868566`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-691.848695444678 + 
       451.3926552046293 ArcTan[32.35775246868566 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49]^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]^2] + Sin[Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{323., -3.43931117168096}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "157.1104314698161`"}], "-", 
         FractionBox[
          RowBox[{"507.02098051678456`", " ", 
            SuperscriptBox[
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", "14"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                    "]"}], "2"], "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
             "2"]}], 
          RowBox[{
            RowBox[{"-", "8.713937467700774`"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{
                RowBox[{"23.712206455060006`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                RowBox[{"2", " ", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-157.1104314698161 - (507.02098051678456`/(-8.713937467700774 + 
        ArcTan[23.712206455060006` + Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]^2 + 2 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]])) 
       ArcTan[13.092284613091337` + ArcTan[Cos[E^14] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{329., -3.4506414395735097`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.643517622675774`"}], "+", 
         RowBox[{"4.638875120795278`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"8.191447495010578`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   RowBox[{"0.0008490912944668228`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "8"]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.643517622675774 + 
       4.638875120795278 Log[Log[8.191447495010578 + Sin[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]^2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + ((0.0008490912944668228 ArcTan[
                  Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^4) Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^4) Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^8 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{332., -3.4592440604808923`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "715.61562618932`"}], "+", 
         RowBox[{"466.62740431584143`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"32.35775246868566`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "49"], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}]}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-715.61562618932 + 
       466.62740431584143` ArcTan[32.35775246868566 + ArcTan[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Style[
              TraditionalForm[
               Subscript["x", "3"]], 
              Hue[
               Rational[3, 16], 1, 
               Rational[5, 6]]]^49] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[Cos[Style[
                TraditionalForm[
                 Subscript["x", "3"]], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]]]^49]^2] + 2 Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2] + 2 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{335., -3.4746707398413137`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.6518542354709487`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"10.066751777835272`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"14.849991770513654`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"7", "-", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], ")"}], 
                 "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.6518542354709487 + (10.066751777835272`/(10.651382597834791` + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[(18.424973303913877` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2)) Log[14.849991770513654` + (7 - Sin[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{343., -3.4809950943494146`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.572280465717795`", "\[VeryThinSpace]"}], "+", 
         RowBox[{"0.019250376830969293`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"6.122264710056605`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.1182925689352174`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "]"}],
                 "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                RowBox[{"ArcTan", "[", 
                  FractionBox["1", 
                   RowBox[{
                    RowBox[{"8.997137324829144`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]}], ")"}], "2"]}], "]"}]}], ")"}], "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.572280465717795 + 
       0.019250376830969293` (6.122264710056605 + 
          ArcTan[ArcTan[7.1182925689352174` + Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] + Log[6 + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]]]] + ArcTan[6 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + ArcTan[(8.997137324829144 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + 
          Log[0.16509018904474715` + (3 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] - Style[
               TraditionalForm[
                Subscript["x", "14"]], 
               Hue[
                Rational[7, 8], 1, 
                Rational[1, 2]]] - 2 (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^2)^2])^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{347., -3.492999232854589}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8642178042456203`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.190970761040318`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[11, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8642178042456203` - 0.190970761040318 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[
          Style[
           TraditionalForm[
            Subscript["x", "11"]], 
           Hue[
            Rational[11, 16], 1, 
            Rational[5, 6]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{373., -3.5128298583447193`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "461.540555387424`"}], "+", 
         RowBox[{"305.5825860930951`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"Cos", "[", 
                  SuperscriptBox["\[ExponentialE]", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}]], "+", 
               RowBox[{"ArcTan", "[", "9", "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-461.540555387424 + 305.5825860930951 ArcTan[18 + E^Cos[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + ArcTan[9] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{397., -3.5161887925314805`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "8.512403503950162`"}], "+", 
         RowBox[{"5.641713668671502`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"10", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-8.512403503950162 + 5.641713668671502 Log[Log[10 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2] + Log[1.1914474950105785` + E^Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]] + Sin[
              Sin[4 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (1 + Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{404., -3.52470625367716}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.459149771606802`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.13894860232387077`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"]}], "]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.459149771606802` - 0.13894860232387077` (2 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Rational[-1, 3] Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "3"]], 
          Hue[
           Rational[3, 16], 1, 
           Rational[5, 6]]]] - Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 2 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{410., -3.542988160735351}}]},
      StyleBox[
       RowBox[{
         RowBox[{"13.467622754945925`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.13750964707980148`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"3", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   RowBox[{"Sin", "[", "4", "]"}]}], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "3"], "]"}]}], 
                    ")"}], "2"]}], ")"}], "2"], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   RowBox[{"6.989024623684227`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "3"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
               FractionBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "3"]}], ")"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[13.467622754945925` - 0.13750964707980148` (3 ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[3 + E^Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] - Sin[4]] + (
          1.4005764990867249` + (0.6252252761254272 + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]] + Cos[Rational[1, 3] Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]])^2)^2 - 2 Cos[
          Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] + Sin[6.989024623684227 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] - Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - Sin[Rational[1, 3] Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "4"]], 
           Hue[
            Rational[1, 4], 1, 
            Rational[1, 2]]]] - 2 Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Rational[-1, 3] Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{431., -3.5608697781465954`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1799.6864579952526`"}], "-", 
         RowBox[{"1825.4404905635156`", " ", 
           RowBox[{"Sin", "[", 
             RowBox[{
               RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1799.6864579952526` - 1825.4404905635156` 
       Sin[7.795322405754767 + ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[3 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2]]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{444., -3.57112237434996}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.6103119525601737`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.191871793244516`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                    "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[3.6103119525601737` - 0.191871793244516 (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]])^2] - (
         E^(E^(-ArcTan[7.683763484795428 - (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]])^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[6 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{457., -3.5747839200534686`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.770288066907519`"}], "+", 
         RowBox[{"5.3855855408685995`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.7990405932174554`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"0.025552233900370046`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"8.191447495010578`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.770288066907519 + 5.3855855408685995` Log[Log[7 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (2.7990405932174554` + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + ((0.025552233900370046` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + Log[8.191447495010578 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{466., -3.577142749621919}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "7.731363329309867`"}], "+", 
         RowBox[{"5.375542759679189`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"7", "+", 
                   SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.7990405932174554`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"0.025552233900370046`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]}], ")"}], 
                    "2"], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"8.191447495010578`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-7.731363329309867 + 5.375542759679189 Log[Log[7 + ArcTan[
               Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (2.7990405932174554` + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + ((0.025552233900370046` ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]^2) Style[
                   TraditionalForm[
                    Subscript["x", "10"]], 
                   Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]]]^2) Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^4)^2 + Style[
              TraditionalForm[
               Subscript["x", "6"]], 
              Hue[
               Rational[3, 8], 1, 
               Rational[1, 2]]]] + Log[8.191447495010578 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2 + (Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{192., -3.242921365604727}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.809124799153621`"}], "+", 
         RowBox[{"4.800868616997389`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"1.3666164453021894`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.809124799153621 + 
       4.800868616997389 
        Log[1.3666164453021894` + Log[1.1914474950105785` + Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{201., -3.2525701566361}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.77905599340848`"}], "+", 
         RowBox[{"5.049527942738226`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.77905599340848 + 
       5.049527942738226 
        Log[2.1914474950105785` + Log[1.1914474950105785` + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "10"]], 
               Hue[
                Rational[5, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + (Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{211., -3.2661128832310826`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "338.40771449845084`"}], "+", 
         RowBox[{"226.44493484858057`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"13.092284613091337`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"0.3708235451785795`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-338.40771449845084` + 
       226.44493484858057` 
        ArcTan[13.092284613091337` + ArcTan[0.3708235451785795 + 2 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + ArcTan[Cos[Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]] + Tan[
                Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]]^2]^2 + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{215., -3.286651045136243}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1247.2061446589366`"}], "+", 
         RowBox[{"1606.0485915825202`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"ArcTan", "[", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"16.733958777897442`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox["1", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["3", "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}], 
               "]"}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1247.2061446589366` + 1606.0485915825202` ArcTan[
          ArcTan[
           ArcTan[16.733958777897442` + Cos[
              Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (1 + Cos[Rational[3, 2] + Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{230., -3.2985834845099316`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "753.1647686153808`"}], "+", 
         RowBox[{"248.50519256218698`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.53201921764182`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", 
                    SqrtBox["5"]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-753.1647686153808 + 
       248.50519256218698` (ArcTan[24.59388935870163 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[7.795322405754767 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.53201921764182 + Sin[5^Rational[-1, 2] - E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{234., -3.2995472509770916`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "6.939253318177961`"}], "+", 
         RowBox[{"2.6768872167837947`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"-", "0.03685839056258189`"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               RowBox[{"2", " ", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"7", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["7.702941275878956`", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "2"], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-6.939253318177961 + 
       2.6768872167837947` Log[-0.03685839056258189 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + 2 Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]] + (7 + ArcTan[
              Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[7.702941275878956^(Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]] + 3 Style[
                  TraditionalForm[
                   Subscript["x", "7"]], 
                  Hue[
                   Rational[7, 16], 1, 
                   Rational[5, 6]]])] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{242., -3.3202559395099276`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "77.60116488571578`"}], "+", 
         RowBox[{"63.6309911501978`", " ", 
           RowBox[{"ArcTan", "[", 
             SqrtBox[
              RowBox[{"9", "+", 
                RowBox[{"ArcTan", "[", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "]"}], 
                "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"4", "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "-", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], "]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}]], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-77.60116488571578 + 63.6309911501978 ArcTan[(9 + ArcTan[E^Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]] + ArcTan[4 + E^Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]] + 2 Sin[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] - 4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "10"]], 
                Hue[
                 Rational[5, 8], 1, 
                 Rational[1, 2]]]^2 + 2 Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{244., -3.332749978916232}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.7742254675478993`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"19.901881704250044`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"6.450397385176636`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                 "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.7742254675478993 + (19.901881704250044`/(10.651382597834791` + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[(18.424973303913877` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2)) Log[6.450397385176636 + Cos[
            Tan[
             Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]]]] + (Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{253., -3.3575553033188825`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "570.3241947546986`"}], "+", 
         RowBox[{"268.3414214058062`", " ", 
           SqrtBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ArcTan", "[", 
               RowBox[{
                 RowBox[{"18.519373027272387`", "\[VeryThinSpace]"}], "+", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    RowBox[{"469.4950238927627`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
                 "+", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                 "+", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], 
               "]"}]]]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-570.3241947546986 + 
       268.3414214058062 (E^
          ArcTan[18.519373027272387` + ArcTan[(469.4950238927627 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]]^2 + Cos[
              Style[
               TraditionalForm[
                Subscript["x", "15"]], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]]]] + Cos[Log[4.189126509606261 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2])^Rational[1, 2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{286., -3.3733256327631325`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "629.8144522499862`"}], "+", 
         RowBox[{"208.65511074219853`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.5284320043644632`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"15.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"8.79360244649667`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-629.8144522499862 + 
       208.65511074219853` (ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.5284320043644632` - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[15.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[7.795322405754767 - E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (8.79360244649667 + Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]])^(-1) Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{294., -3.3764031157020775`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "397.8217342008951`"}], "+", 
         RowBox[{"264.6197550307058`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"Cos", "[", 
                 RowBox[{"3", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "-", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"7", "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "-", 
               RowBox[{"Sin", "[", 
                 RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                   FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-397.8217342008951 + 
       264.6197550307058 ArcTan[18.590644811509534` - Cos[3 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] - Cos[21.795322405754767` + Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Sin[7 - E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]] + Sin[
            Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]]] - Sin[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] - (1 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2)^Rational[-1, 2]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{298., -3.387926036832162}}]},
      StyleBox[
       RowBox[{
         RowBox[{"1.0611645604588613`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"9.669687639219807`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"21.71404298447733`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}], "2"]}], 
              "]"}]}], 
          RowBox[{
            RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      1.0611645604588613` + (9.669687639219807/(10.651382597834791` + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[(18.424973303913877` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2)) Log[21.71404298447733 + (Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 - Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{306., -3.389358142850112}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "615.2092029531556`"}], "+", 
         RowBox[{"402.43465619523096`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"25.86664063115359`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-615.2092029531556 + 
       402.43465619523096` ArcTan[25.86664063115359 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{307., -3.4017574384646925`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "509.0081337922872`"}], "+", 
         RowBox[{"336.05693662371885`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"22.23047721891991`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox["\[ExponentialE]", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], 
                    "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-509.0081337922872 + 
       336.05693662371885` ArcTan[22.23047721891991 - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] + Cos[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])] (1 + Tan[E^(4 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]])]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{310., -3.420869617459676}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "341.85843392756`"}], "+", 
         RowBox[{"228.62919763611254`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"15", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                  "2"], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"9", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  RowBox[{"5.000324575710058`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-341.85843392756 + 228.62919763611254` ArcTan[15 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Sin[Cos[2 + Cos[
                 Style[
                  TraditionalForm[
                   Subscript["x", "4"]], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^4 + Style[
                 TraditionalForm[
                  Subscript["x", "4"]], 
                 Hue[
                  Rational[1, 4], 1, 
                  Rational[1, 2]]]^2]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Sin[9 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (5.000324575710058 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]])^Rational[1, 2] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{323., -3.42384767370963}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "8.171481621002577`"}], "+", 
         RowBox[{"5.567445548541632`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{"10", "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"1.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[5, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
                 "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-8.171481621002577 + 5.567445548541632 Log[Log[10 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "11"]], 
               Hue[
                Rational[11, 16], 1, 
                Rational[5, 6]]]^4 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + Log[1.1914474950105785` + 2 E^Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (1 + Style[
                 TraditionalForm[
                  Subscript["x", "10"]], 
                 Hue[
                  Rational[5, 8], 1, 
                  Rational[1, 2]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "14"]], 
                Hue[
                 Rational[7, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] + Style[
                TraditionalForm[
                 Subscript["x", "6"]], 
                Hue[
                 Rational[3, 8], 1, 
                 Rational[1, 2]]] + Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]^2)^2] + Sin[
            Sin[4 Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{324., -3.438232492984121}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "154.72157354199697`"}], "+", 
         RowBox[{"69.6562981861738`", " ", 
           SuperscriptBox[
            RowBox[{"ArcTan", "[", 
              RowBox[{"10", "+", 
                SuperscriptBox[
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"144.69163555798934`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"64", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "10", "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], 
                    "2"]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                   "]"}], "4"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "2"]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-154.72157354199697` + 
       69.6562981861738 
        ArcTan[10 + 
           ArcTan[(((144.69163555798934` ArcTan[((64 ArcTan[10]^2) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2) (6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]) Style[
                 TraditionalForm[
                  Subscript["x", "13"]], 
                 Hue[
                  Rational[13, 16], 1, 
                  Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]])]^4 + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]^2, 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{330., -3.4448524480433322`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "315.0803942164798`"}], "+", 
         RowBox[{"211.40673327077195`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"10", "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"72", " ", 
                    RowBox[{"ArcTan", "[", "36", "]"}], " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"81", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "9", "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], 
                    "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}], 
                    "2"]}], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0096060494165187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]}], ")"}]}], 
                  "]"}], "4"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-315.0803942164798 + 
       211.40673327077195` 
        ArcTan[10 + 
          ArcTan[((((72 ArcTan[36]) ArcTan[((81 ArcTan[9]^2) ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2]^2) (6 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]])^2]) Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]) Style[
                TraditionalForm[
                 Subscript["x", "13"]], 
                Hue[
                 Rational[13, 16], 1, 
                 Rational[5, 6]]]) (2.0096060494165187` + 2 Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]])]^4 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{332., -3.4560957982795935`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "726.7435825895262`"}], "+", 
         RowBox[{"473.83512102423265`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"30", "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"Sin", "[", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"10\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[5, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 RowBox[{"5", "+", 
                   SqrtBox["5"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], "]"}], 
               "+", 
               RowBox[{"3", " ", 
                 RowBox[{"Sin", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "+", 
               SqrtBox[
                RowBox[{"5", "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}]]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-726.7435825895262 + 473.83512102423265` ArcTan[30 + 2 Cos[
             Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] + Sin[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Sin[
            Sin[Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]]^2]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "10"]], 
             Hue[
              Rational[5, 8], 1, 
              Rational[1, 2]]]] + Sin[5 + 5^Rational[1, 2] + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4] + 3 Sin[
             Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]] + Sin[Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]]^2] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2 + (5 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{340., -3.4660239442796907`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "305.92396756098157`"}], "+", 
         RowBox[{"205.5372505745498`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"12.82681789174209`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}]], "]"}], "+", 
               
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.5130495600995655`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-305.92396756098157` + 
       205.5372505745498 ArcTan[12.82681789174209 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)] + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.5130495600995655` + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[Rational[1, 2] + Cos[
                Rational[1, 8]] + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{343., -3.4688270755551582`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "747.5579746871686`"}], "+", 
         RowBox[{"487.08138390140704`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"34.542985104841634`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.140710995683652`", "\[VeryThinSpace]"}], "-", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"11\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[11, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
               "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"Tan", "[", 
                    RowBox[{"85.57919069495483`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
                "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
               RowBox[{"2", " ", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-747.5579746871686 + 
       487.08138390140704` ArcTan[34.542985104841634` + Cos[Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "12"]], 
             Hue[
              Rational[3, 4], 1, 
              Rational[1, 2]]]] + Cos[2.140710995683652 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
              TraditionalForm[
               Subscript["x", "11"]], 
              Hue[
               Rational[11, 16], 1, 
               Rational[5, 6]]] + 2 Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 - Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + 2 Cos[9.250902155733506 + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]] - Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]] + Style[
                TraditionalForm[
                 Subscript["x", "11"]], 
                Hue[
                 Rational[11, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2] + 2 Cos[
             Tan[85.57919069495483 Style[
                TraditionalForm[
                 Subscript["x", "8"]], 
                Hue[
                 Rational[1, 2], 1, 
                 Rational[1, 2]]]]] + 2 Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + 2 Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{347., -3.485782867143772}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "5.050301630139578`"}], "+", 
         RowBox[{"1.8857830525378811`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"6.390596357258282`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
                    "]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"\[ExponentialE]", "+", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"7\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
                   "+", 
                   RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]}], "]"}], 
               "+", 
               RowBox[{"Log", "[", 
                 RowBox[{
                   RowBox[{"2.000001665423828`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]], 
                    "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}], "]"}]}], ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-5.050301630139578 + 
       1.8857830525378811` (Log[6.390596357258282 + E^Cos[
              Style[
               TraditionalForm[
                Subscript["x", "12"]], 
               Hue[
                Rational[3, 4], 1, 
                Rational[1, 2]]]] + ArcTan[E + Tan[2 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]] + ArcTan[E + Tan[
               Style[
                TraditionalForm[
                 Subscript["x", "7"]], 
                Hue[
                 Rational[7, 16], 1, 
                 Rational[5, 6]]]]] + Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Log[2.000001665423828 + 3 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + (E^Cos[Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2] + E^Cos[
                Style[
                 TraditionalForm[
                  Subscript["x", "9"]], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]]]] + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{364., -3.492786822010447}}]},
      StyleBox[
       RowBox[{
         RowBox[{"0.22067020371346638`", "\[VeryThinSpace]"}], "+", 
         FractionBox[
          RowBox[{"10.39317899406938`", " ", 
            RowBox[{"Log", "[", 
              RowBox[{
                RowBox[{"7.849991770513654`", "\[VeryThinSpace]"}], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[3, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{"7", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"14\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[7, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "+", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]}], ")"}], 
                 "2"]}], "]"}]}], 
          RowBox[{
            RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                "4"], "]"}], "2"]}]]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[
      0.22067020371346638` + (10.39317899406938/(10.651382597834791` + 
         Cos[(2.4405983039138768` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2 + Cos[(18.424973303913877` + Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^4]^2)) Log[7.849991770513654 + Style[
             TraditionalForm[
              Subscript["x", "3"]], 
             Hue[
              Rational[3, 16], 1, 
              Rational[5, 6]]]^2 + (7 - Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]] + Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "14"]], 
              Hue[
               Rational[7, 8], 1, 
               Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2 + (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)^2 + Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "4"]], 
                Hue[
                 Rational[1, 4], 1, 
                 Rational[1, 2]]]] Style[
               TraditionalForm[
                Subscript["x", "3"]], 
               Hue[
                Rational[3, 16], 1, 
                Rational[5, 6]]])^2], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{383., -3.5075820882912097`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "456.7418775792224`"}], "+", 
         RowBox[{"302.5133360450461`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"18", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}]], 
               "+", 
               RowBox[{"ArcTan", "[", "9", "]"}], "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "]"}], "]"}], 
               "-", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Tan", "[", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "-", 
               FractionBox[
                RowBox[{"Tan", "[", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                  "]"}], 
                SqrtBox[
                 RowBox[{"1", "+", 
                   SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "4"], 
                    "]"}], "2"]}]]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-456.7418775792224 + 302.5133360450461 ArcTan[18 + E^ArcTan[
             Cos[E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]]] + ArcTan[9] - ArcTan[
           Tan[E^Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[
           Tan[E^(4 Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]])]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 - Tan[Sin[
              Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^4] (1 + Tan[Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "9"]], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]]]]^4]^2)^Rational[-1, 2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{413., -3.5331585791171607`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "297.0225610488899`"}], "+", 
         RowBox[{"199.83010251732193`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"12", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox["1", "8"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                  RowBox[{"10", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Csc", "[", 
                 RowBox[{"Sec", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"Sin", "[", "2", "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]], "]"}], "]"}], 
               "+", 
               FractionBox["1", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"6.888694565552804`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}]], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"1.4999960813102842`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-297.0225610488899 + 199.83010251732193` ArcTan[12 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[(Cos[
               Rational[1, 8]] + Cos[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2] + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]])^(-1)] + Cos[10 + Cos[
               Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]]] + 2 Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^2 + Csc[
            Sec[(Sin[2] + Sin[
                 Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]])^(-1)]] + Log[6.888694565552804 + Style[
               TraditionalForm[
                Subscript["x", "9"]], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]]]]^(-1) + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[1.4999960813102842` + Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{475., -3.550589899517681}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "751.839692602999`"}], "+", 
         RowBox[{"248.08751549567745`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                    "]"}]}], "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-751.839692602999 + 
       248.08751549567745` (ArcTan[24.59388935870163 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[
            15.795322405754767` + Sin[7.795322405754767 - E^(E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]])]]]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{476., -3.5512502191258988`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "751.9015767655432`"}], "+", 
         RowBox[{"248.1077559906971`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"24.59388935870163`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]]}], 
                    "]"}]}], "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}]]]}], 
                    "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             ")"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-751.9015767655432 + 
       248.1077559906971 (ArcTan[24.59388935870163 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[15.795322405754767` + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]] (1 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]^2)^Rational[-1, 2]]]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^4)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]), 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{482., -3.5721693493977087`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1794.8479513303148`"}], "-", 
         RowBox[{"1820.6540751986884`", " ", 
           RowBox[{"Sin", "[", 
             RowBox[{
               RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.3859672172643`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"1.511141024310431`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]]}], "]"}]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"5.510522207940621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}]}], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1794.8479513303148` - 1820.6540751986884` 
       Sin[7.795322405754767 + ArcTan[23.3859672172643 + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] + Sin[1.511141024310431 - E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]])]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + (Sin[5.510522207940621 + ArcTan[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]] + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2)^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{586., -3.5735502711373925`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1800.1290520689533`"}], "-", 
         RowBox[{"1825.895102504952`", " ", 
           RowBox[{"Sin", "[", 
             RowBox[{
               RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"23.590644811509534`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]]], "]"}]}], 
                    "]"}]}], "]"}]}], "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"21.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"]}]]]}], "]"}], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}], 
             "]"}]}]}], 
       RGBColor[0, 0, 1], StripOnInput -> False]],
     Annotation[#, 
      Style[-1800.1290520689533` - 1825.895102504952 
       Sin[7.795322405754767 + ArcTan[23.590644811509534` + ArcTan[
             Sin[
              Sin[
               Style[
                TraditionalForm[
                 Subscript["x", "9"]], 
                Hue[
                 Rational[9, 16], 1, 
                 Rational[5, 6]]]]]] - Sin[E^(E^Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) - ArcTan[
            15.795322405754767` + Sin[E^(E^Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]])]]]] + 
         ArcTan[18.590644811509534` - Cos[21.795322405754767` + Style[
              TraditionalForm[
               Subscript["x", "4"]], 
              Hue[
               Rational[1, 4], 1, 
               Rational[1, 2]]]] - Sin[E^Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]] - (1 + (ArcTan[
                  Sin[
                   Style[
                    TraditionalForm[
                    Subscript["x", "9"]], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]]]]]^2 + Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]]]^2)^2)^Rational[-1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2]], 
       RGBColor[0, 0, 1]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{111., -3.2541704153375512`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"18.759985507522625`", "\[VeryThinSpace]"}], "-", 
         FractionBox["321.2839933641992`", 
          RowBox[{
            RowBox[{"21.50655541560061`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "49"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Sin", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[
      18.759985507522625` - 321.2839933641992/(21.50655541560061 + ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "15"]], 
          Hue[
           Rational[15, 16], 1, 
           Rational[5, 6]]]] + Cos[Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + Cos[Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]]^49] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{115., -3.2976119906061623`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "327.7676755295721`"}], "+", 
         RowBox[{"219.51836128295156`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{"17", "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Sin", "[", "2", "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-327.7676755295721 + 219.51836128295156` ArcTan[17 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Sin[2] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{120., -3.3182589629173718`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"17.964627732210918`", "\[VeryThinSpace]"}], "-", 
         FractionBox["266.7665124303018`", 
          RowBox[{"17", "+", 
            RowBox[{"ArcTan", "[", 
              RowBox[{"Sin", "[", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], "+", 
            
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[15, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              SuperscriptBox[
               StyleBox[
                TagBox[
                 FormBox[
                  SubscriptBox["\"x\"", "\"3\""], TraditionalForm], 
                 TraditionalForm, Editable -> True], 
                Hue[
                 Rational[3, 16], 1, 
                 Rational[5, 6]], StripOnInput -> False], "49"], "]"}], "+", 
            RowBox[{"Cos", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
            RowBox[{"Sin", "[", 
              StyleBox[
               TagBox[
                FormBox[
                 SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                TraditionalForm, Editable -> True], 
               Hue[
                Rational[9, 16], 1, 
                Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", "1", "]"}]}]]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[17.964627732210918` - 266.7665124303018/(17 + ArcTan[
         Sin[
          Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]]] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "15"]], 
          Hue[
           Rational[15, 16], 1, 
           Rational[5, 6]]]] + Cos[Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2] + Cos[Style[
           TraditionalForm[
            Subscript["x", "3"]], 
           Hue[
            Rational[3, 16], 1, 
            Rational[5, 6]]]^49] + Cos[
         Style[
          TraditionalForm[
           Subscript["x", "4"]], 
          Hue[
           Rational[1, 4], 1, 
           Rational[1, 2]]]] + Sin[
         Style[
          TraditionalForm[
           Subscript["x", "9"]], 
          Hue[
           Rational[9, 16], 1, 
           Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[1]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{124., -3.4308247702556898`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "310.69438568620933`"}], "+", 
         RowBox[{"208.52383342064797`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.225597132501772`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-310.69438568620933` + 
       208.52383342064797` ArcTan[16.225597132501772` + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{142., -3.4495230837108193`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "316.8592169070334`"}], "+", 
         RowBox[{"212.4831479836076`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"15.7610364928194`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               FractionBox["1", 
                RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                    FractionBox["1", "2"], "]"}], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}]]}], "]"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-316.8592169070334 + 
       212.4831479836076 ArcTan[15.7610364928194 + Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2 + (1 + Cos[
              Rational[1, 2]] + Style[
              TraditionalForm[
               Subscript["x", "9"]], 
              Hue[
               Rational[9, 16], 1, 
               Rational[5, 6]]])^(-1)], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{150., -3.4954676223906143`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "4.1766131444263115`"}], "+", 
         RowBox[{"4.635549217341963`", " ", 
           RowBox[{"Log", "[", 
             RowBox[{
               RowBox[{"6.361011137933576`", "\[VeryThinSpace]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 FractionBox["1", 
                  RowBox[{
                    RowBox[{"0.30384906247115673`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"6\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}]], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 4], 1, 
                   Rational[1, 2]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Sin", "[", 
                 SuperscriptBox[
                  RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "7"], 
                 "]"}], "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-4.1766131444263115` + 
       4.635549217341963 
        Log[6.361011137933576 + ArcTan[(0.30384906247115673` + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]] + Style[
               TraditionalForm[
                Subscript["x", "6"]], 
               Hue[
                Rational[3, 8], 1, 
                Rational[1, 2]]])^(-1)] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "4"]], 
             Hue[
              Rational[1, 4], 1, 
              Rational[1, 2]]]] + Sin[ArcTan[
              Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^7] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{155., -3.5539874375581175`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "1.6406815067580778`"}], "+", 
         RowBox[{"1.7066159248785278`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"1.8047949685514126`", "\[VeryThinSpace]"}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.883770826008501`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"]}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"4\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], ")"}], "2"], 
                   "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[9, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}]]}], 
             ")"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-1.6406815067580778` + 
       1.7066159248785278` (
         ArcTan[1.8047949685514126` + (3.883770826008501 + Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]])^2] + ArcTan[(Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^2)^Rational[1, 2] + (Style[
               TraditionalForm[
                Subscript["x", "4"]], 
               Hue[
                Rational[1, 4], 1, 
                Rational[1, 2]]] - Style[
              TraditionalForm[
               Subscript["x", "8"]], 
              Hue[
               Rational[1, 2], 1, 
               Rational[1, 2]]])^2 + Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + (Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2 + Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2)^Rational[1, 2]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{173., -3.5907829778232085`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.91930896255793`", "\[VeryThinSpace]"}], "-", 
         FractionBox["422.880907229359`", 
          RowBox[{
            RowBox[{"26.845493341154025`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"13.641553316454072`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.840444646718434`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.91930896255793 - 422.880907229359/(26.845493341154025` + 
       Cos[13.641553316454072` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.840444646718434 - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{194., -3.599408836869338}}]},
      StyleBox[
       RowBox[{
         RowBox[{"19.839760622270273`", "\[VeryThinSpace]"}], "-", 
         FractionBox["414.4935191381362`", 
          RowBox[{
            RowBox[{"26.354895765283672`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.0359518910482919`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[
      19.839760622270273` - 414.4935191381362/(26.354895765283672` + 
       Cos[1.0359518910482919` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{203., -3.6214428863729884`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.62042181670319`", "\[VeryThinSpace]"}], "-", 
         FractionBox["480.56864025483645`", 
          RowBox[{
            RowBox[{"29.271011306981283`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"14", "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}]}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"14.419547281892406`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"13.222006034561666`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.62042181670319 - 480.56864025483645`/(29.271011306981283` + 
       Cos[14 + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[2 Cos[
            Cos[
             Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[14.419547281892406` + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[13.222006034561666` - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{241., -3.692680669588057}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.042777414541497`", "\[VeryThinSpace]"}], "-", 
         FractionBox["441.8865514977323`", 
          RowBox[{
            RowBox[{"28.182535564890905`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Sin", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"6.9704156052152895`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"1.3655872124935087`", "\[VeryThinSpace]"}], "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"8.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"0.9460399306011027`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.042777414541497` - 441.8865514977323/(28.182535564890905` + 
       Cos[0.42089736482602796` + Sin[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[6.9704156052152895` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[1.3655872124935087` - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[8.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[0.9460399306011027 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{271., -3.7104128423130494`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "437.3378853185767`"}], "+", 
         RowBox[{"290.0294830104925`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"17.89254821129124`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.6003508331343324`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-437.3378853185767 + 
       290.0294830104925 
        ArcTan[17.89254821129124 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.6003508331343324` + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{292., -3.7307632621587015`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"20.077089680156202`", "\[VeryThinSpace]"}], "-", 
         FractionBox["442.6592733816677`", 
          RowBox[{
            RowBox[{"27.4286333105476`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"0.42089736482602796`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Sin", "[", 
                  SuperscriptBox[
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
            "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"6.9704156052152895`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"7.419547281892406`", "\[VeryThinSpace]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "-", 
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "2"], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{
                RowBox[{"8.17344953623571`", "\[VeryThinSpace]"}], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 2], 1, 
                  Rational[1, 2]], StripOnInput -> False], "+", 
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[9, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
              RowBox[{"Tan", "[", 
                RowBox[{"Sin", "[", 
                  RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "]"}], 
                "]"}], "]"}], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]], StripOnInput -> False], "2"], "+", 
            SuperscriptBox[
             StyleBox[
              TagBox[
               FormBox[
                SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
               TraditionalForm, Editable -> True], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]], StripOnInput -> False], "2"], "+", 
            RowBox[{"Tan", "[", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  RowBox[{"0.9460399306011027`", "\[VeryThinSpace]"}], "-", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "+", 
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"8\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 2], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], 
              "]"}]}]]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[
      20.077089680156202` - 442.6592733816677/(27.4286333105476 + 
       Cos[0.42089736482602796` + Sin[Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2] + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2 + Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[6.9704156052152895` + Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[7.419547281892406 + Cos[
           Cos[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] - Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^2 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]]] + Cos[8.17344953623571 + Style[
           TraditionalForm[
            Subscript["x", "8"]], 
           Hue[
            Rational[1, 2], 1, 
            Rational[1, 2]]] + Style[
           TraditionalForm[
            Subscript["x", "9"]], 
           Hue[
            Rational[9, 16], 1, 
            Rational[5, 6]]]] + Cos[
         Tan[
          Sin[
           Tan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]]]] + Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 + Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
         Cos[0.9460399306011027 - Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]] + Style[
            TraditionalForm[
             Subscript["x", "8"]], 
            Hue[
             Rational[1, 2], 1, 
             Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{305., -3.8163242647597357`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "459.64554281762685`"}], "+", 
         RowBox[{"304.37719141320065`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"16.14783074519155`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"1583.4898206311666`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-459.64554281762685` + 
       304.37719141320065` 
        ArcTan[16.14783074519155 + ArcTan[1583.4898206311666` Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{348., -3.821688821746963}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "413.9804627902741`"}], "+", 
         RowBox[{"275.0255183326565`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.601244994848019`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"187.84763242634693`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"54", " ", 
                    RowBox[{"Cos", "[", "4", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.167257443853776`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], ")"}]}], "]"}],
                 "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-413.9804627902741 + 
       275.0255183326565 
        ArcTan[14.601244994848019` + ArcTan[(187.84763242634693` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[((54 Cos[4]) Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (7.167257443853776 + Style[
                TraditionalForm[
                 Subscript["x", "15"]], 
                Hue[
                 Rational[15, 16], 1, 
                 Rational[5, 6]]])]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{351., -3.8232244347543083`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"-", "415.1332080614732`"}], "+", 
         RowBox[{"275.76785272805296`", " ", 
           RowBox[{"ArcTan", "[", 
             RowBox[{
               RowBox[{"14.621450523904594`", "\[VeryThinSpace]"}], "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"226.21283151873808`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"13\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[13, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"ArcTan", "[", 
                  RowBox[{"403.57546805050436`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}]}], 
                  "]"}], "2"], "+", 
               RowBox[{"Cos", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[15, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   RowBox[{"2.754501512961591`", "\[VeryThinSpace]"}], "+", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], 
                    "]"}], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"12\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[3, 4], 1, 
                    Rational[1, 2]], StripOnInput -> False], "+", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"15\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[15, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
                    "2"], "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Sin", "[", 
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"9\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[9, 16], 1, 
                   Rational[5, 6]], StripOnInput -> False], "]"}], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "+", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}]}]}], 
       
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[-415.1332080614732 + 
       275.76785272805296` 
        ArcTan[14.621450523904594` + ArcTan[(226.21283151873808` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) Style[
               TraditionalForm[
                Subscript["x", "13"]], 
               Hue[
                Rational[13, 16], 1, 
                Rational[5, 6]]]]^2 + ArcTan[(403.57546805050436` Style[
                TraditionalForm[
                 Subscript["x", "1"]], 
                Hue[
                 Rational[1, 16], 1, 
                 Rational[5, 6]]]) (Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2)]^2 + Cos[
            Style[
             TraditionalForm[
              Subscript["x", "15"]], 
             Hue[
              Rational[15, 16], 1, 
              Rational[5, 6]]]] + Cos[2.754501512961591 + Sin[
              Tan[Style[
                 TraditionalForm[
                  Subscript["x", "2"]], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]]]^2]] + Style[
              TraditionalForm[
               Subscript["x", "12"]], 
              Hue[
               Rational[3, 4], 1, 
               Rational[1, 2]]] + Style[
              TraditionalForm[
               Subscript["x", "15"]], 
              Hue[
               Rational[15, 16], 1, 
               Rational[5, 6]]]] + Cos[Style[
              TraditionalForm[
               Subscript["x", "2"]], 
              Hue[
               Rational[1, 8], 1, 
               Rational[1, 2]]]^2] + Cos[Log[4.189126509606261 + Style[
                  TraditionalForm[
                   Subscript["x", "2"]], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]]]^2]^2 + Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^2] + Sin[
            Style[
             TraditionalForm[
              Subscript["x", "9"]], 
             Hue[
              Rational[9, 16], 1, 
              Rational[5, 6]]]] + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 + Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]^2], 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{359., -3.8381143031273424`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.904830046344218`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19082962107576024`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[3.904830046344218 - 0.19082962107576024` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 
        Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{372., -3.941332358784651}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8885022818520762`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19126612394207465`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}]}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}]}]}], 
       
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8885022818520762` - 0.19126612394207465` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + 2 Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{388., -4.023458603755575}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9162755175839314`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.19047997994393376`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "4"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.020730394225662`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9162755175839314` - 0.19047997994393376` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[9 - Style[
               TraditionalForm[
                Subscript["x", "1"]], 
               Hue[
                Rational[1, 16], 1, 
                Rational[5, 6]]]^4 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + Cos[25.020730394225662` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{462., -4.044633679187256}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.8735761014385757`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18561737438919954`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                "-", 
               RowBox[{"ArcTan", "[", 
                 SuperscriptBox[
                  StyleBox[
                   TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[3.8735761014385757` - 0.18561737438919954` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + 2 ArcTan[
           Cos[25.020730394225662` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]] - ArcTan[Style[
           TraditionalForm[
            Subscript["x", "1"]], 
           Hue[
            Rational[1, 16], 1, 
            Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{485., -4.0906288739497265`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.820737010009064`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18673601085163793`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "]"}], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 8], 1, 
                  Rational[1, 2]], StripOnInput -> False], "2"], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[3.820737010009064 - 0.18673601085163793` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[
                 Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - Style[
          TraditionalForm[
           Subscript["x", "2"]], 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]]]^2 + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{517., -4.1357492264613915`}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.919638964727381`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18436443329168598`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "]"}]}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"ArcTan", "[", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
                 "]"}], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{
                   RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "]"}], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[3.919638964727381 - 0.18436443329168598` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (E^(E^(-ArcTan[6 - (-ArcTan[Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]^2] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          ArcTan[
           Cos[25.140795789942956` Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]]]] + ArcTan[ArcTan[
            Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]] - Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "1"]], 
            Hue[
             Rational[1, 16], 1, 
             Rational[5, 6]]]] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{613., -4.250460271455656}}]},
      StyleBox[
       RowBox[{
         RowBox[{"3.9991219611506588`", "\[VeryThinSpace]"}], "-", 
         RowBox[{"0.18098829743981493`", " ", 
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "]"}]]}], "-", 
               SqrtBox[
                SuperscriptBox["\[ExponentialE]", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "4"]}], 
                    "]"}]}]]]], "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False]}], "]"}], "]"}], 
               "+", 
               RowBox[{"ArcTan", "[", 
                 RowBox[{"6", "+", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"], "-", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], StripOnInput -> False], "2"]}], ")"}], 
                    "2"], "-", 
                   SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False], "2"]}], "]"}], 
               "+", 
               RowBox[{"Cos", "[", 
                 RowBox[{"25.140795789942956`", " ", 
                   StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "-", 
               SuperscriptBox[
                StyleBox[
                 TagBox[
                  FormBox[
                   SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                  TraditionalForm, Editable -> True], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]], StripOnInput -> False], "2"], "-", 
               SqrtBox[
                SuperscriptBox[
                 StyleBox[
                  TagBox[
                   FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                   TraditionalForm, Editable -> True], 
                  Hue[
                   Rational[1, 8], 1, 
                   Rational[1, 2]], StripOnInput -> False], "4"]], "+", 
               RowBox[{"Tan", "[", 
                 RowBox[{"Cos", "[", 
                   RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], StripOnInput -> False]}], "]"}], "]"}]}],
              ")"}]}]}], 
       RGBColor[1, 0, 0], StripOnInput -> False]],
     Annotation[#, 
      Style[3.9991219611506588` - 0.18098829743981493` (-E^ArcTan[(-Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2 + Style[
                TraditionalForm[
                 Subscript["x", "2"]], 
                Hue[
                 Rational[1, 8], 1, 
                 Rational[1, 2]]]^2)^2] - (
         E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]]]]] + Style[
                 TraditionalForm[
                  Subscript["x", "1"]], 
                 Hue[
                  Rational[1, 16], 1, 
                  Rational[5, 6]]]^2)^2 - Style[
               TraditionalForm[
                Subscript["x", "2"]], 
               Hue[
                Rational[1, 8], 1, 
                Rational[1, 2]]]^4])))^Rational[1, 2] + ArcTan[
          Cos[25.020730394225662` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]]] + ArcTan[6 + Style[
             TraditionalForm[
              Subscript["x", "1"]], 
             Hue[
              Rational[1, 16], 1, 
              Rational[5, 6]]]^2 - (-Sin[5] + Style[
              TraditionalForm[
               Subscript["x", "1"]], 
              Hue[
               Rational[1, 16], 1, 
               Rational[5, 6]]]^2)^2 - Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]^2] + Cos[25.140795789942956` Style[
            TraditionalForm[
             Subscript["x", "2"]], 
            Hue[
             Rational[1, 8], 1, 
             Rational[1, 2]]]] - Style[
          TraditionalForm[
           Subscript["x", "1"]], 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]]]^2 - (Style[
           TraditionalForm[
            Subscript["x", "2"]], 
           Hue[
            Rational[1, 8], 1, 
            Rational[1, 2]]]^4)^Rational[1, 2] + Tan[
          Cos[25.140795789942956` Style[
             TraditionalForm[
              Subscript["x", "2"]], 
             Hue[
              Rational[1, 8], 1, 
              Rational[1, 2]]]]]), 
       RGBColor[1, 0, 0]], "Tooltip"]& ]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->None,
  AxesOrigin->{111., -4.250460271455656},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->True,
  FrameLabel->{
    FormBox["\"Complexity\"", TraditionalForm], 
    FormBox["\"1-\\!\\(R\\^2\\)\"", TraditionalForm]},
  FrameTicks->{{{{-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.020\"", 0.02, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.200\"", 0.2, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-3.506557897319982, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.030\"", 0.03, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-1.203972804325936, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.300\"", 0.30000000000000004`, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.199705077879927, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.015\"", 0.015, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-1.897119984885881, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.150\"", 0.15000000000000002`, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.659260036932778, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.070\"", 0.07, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-0.3566749439387323, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.700\"", 0.7000000000000001, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.487387150331708, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.382026634673882, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.286716454869556, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.135166556742356, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.074541934925921, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.017383521085972, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.9633162998156966`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.2072749131897207`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.120263536200091, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.040220828526554, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.9661128563728327`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.8170772772123447`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.7429693050586228`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6739764335716714`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm]}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm]}, {-4.199705077879927, 
       FormBox["\"\"", TraditionalForm]}, {-1.897119984885881, 
       FormBox["\"\"", TraditionalForm]}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm]}, {-0.3566749439387323, 
       FormBox["\"\"", TraditionalForm]}, {-4.487387150331708, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.382026634673882, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.286716454869556, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.135166556742356, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.074541934925921, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.017383521085972, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.9633162998156966`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.2072749131897207`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.120263536200091, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.040220828526554, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.9661128563728327`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.8170772772123447`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.7429693050586228`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6739764335716714`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{
   Automatic, {-4.605170185988091, -2.3025850929940455`, -2.995732273553991, \
-0.6931471805599453, -3.912023005428146, -1.6094379124341003`, \
-3.506557897319982, -1.203972804325936, -4.199705077879927, \
-1.897119984885881, -2.659260036932778, -0.3566749439387323, \
-4.487387150331708, -4.382026634673882, -4.286716454869556, \
-4.135166556742356, -4.074541934925921, -4.017383521085972, \
-3.9633162998156966`, -3.2188758248682006`, -2.8134107167600364`, \
-2.5257286443082556`, -2.4079456086518722`, -2.2072749131897207`, \
-2.120263536200091, -2.040220828526554, -1.9661128563728327`, \
-1.8170772772123447`, -1.7429693050586228`, -1.6739764335716714`, \
-0.916290731874155, -0.5108256237659907}},
  ImageSize->400,
  Method->{},
  PlotLabel->FormBox[
    StyleBox[
    "\"RUN1 High Accuracy Models\"", {
     FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, FontColor -> 
      GrayLevel[0], FontSlant -> "Plain", Background -> None}, StripOnInput -> 
     False], TraditionalForm],
  PlotRange->{{111., 648.}, {-4.250460271455656, -3.219180371237739}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{-4.605170185988091, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.3025850929940455`, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-3.912023005428146, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.020\"", 0.02, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.200\"", 0.2, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-3.506557897319982, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.030\"", 0.03, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-1.203972804325936, 
      FormBox[
       TagBox[
        InterpretationBox[
        "\"0.300\"", 0.30000000000000004`, AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.199705077879927, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.015\"", 0.015, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-1.897119984885881, 
      FormBox[
       TagBox[
        InterpretationBox[
        "\"0.150\"", 0.15000000000000002`, AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.659260036932778, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.070\"", 0.07, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-0.3566749439387323, 
      FormBox[
       TagBox[
        InterpretationBox[
        "\"0.700\"", 0.7000000000000001, AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.487387150331708, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.382026634673882, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.286716454869556, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.135166556742356, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.074541934925921, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.017383521085972, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.9633162998156966`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.2072749131897207`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.120263536200091, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.040220828526554, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.9661128563728327`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.8170772772123447`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.7429693050586228`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6739764335716714`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659907, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.599301297296043*^9, 3.599558780987891*^9, {3.599560916897863*^9, 
   3.599560928568419*^9}, 3.59986608007327*^9, 3.599904872382523*^9, 
   3.600032873506689*^9, 3.6001753422060843`*^9, 3.600588360713276*^9, 
   3.600770151498968*^9, 3.6008684095176363`*^9, 3.600876439059558*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["", "PageBreak",
 PageBreakBelow->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Feature Selection", "Subsection",
 CellChangeTimes->{{3.532853939269116*^9, 3.532853945860551*^9}, 
   3.561457205031646*^9, {3.6001709777393713`*^9, 3.600170979841782*^9}}],

Cell[TextData[{
 "Variable importance is related to variable presence in the high quality \
model ensemble. \nIn this example, only variables ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "2"], " "}], TraditionalForm]]],
 "seem important. This is in accordance with the setup of our toy simulator. \
"
}], "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6009696792527037`*^9, 
   3.6009698124606667`*^9}, 3.6009729227279243`*^9, {3.6009730524413013`*^9, 
   3.600973126313175*^9}, 3.600973429118082*^9, {3.600973704497159*^9, 
   3.600973731621529*^9}, {3.600973773366457*^9, 3.600973786679249*^9}, 
   3.601017404336278*^9},
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VariableCombinationTable", "[", 
  RowBox[{"modelSet1", ",", " ", 
   RowBox[{"SignificanceLevel", "\[Rule]", "0.1"}]}], "]"}]], "Code",
 CellChangeTimes->{
  3.599301547596033*^9, 3.59990493881329*^9, {3.600868547190721*^9, 
   3.600868590673946*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 TagBox[
  TemplateBox[{FrameBox[
     GridBox[{{" ", 
        StyleBox[
        "\"num \[DoubleLongRightArrow] %\"", StripOnInput -> False, 
         FontFamily -> "Helvetica", FontSize -> 10, FontWeight -> "Bold", 
         FontSlant -> "Plain", FontColor -> GrayLevel[0], Background -> None], 
        StyleBox[
        "\"Variables Used\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 10, FontWeight -> "Bold", FontSlant -> 
         "Plain", FontColor -> GrayLevel[0], Background -> None], 
        StyleBox[
        "\"ParetoFrontPlot\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 10, FontWeight -> "Bold", FontSlant -> 
         "Plain", FontColor -> GrayLevel[0], Background -> None]}, {
        StyleBox[
        "\"1\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 
         10, FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
         GrayLevel[0], Background -> None], 
        StyleBox[
         StyleBox[
         "\"749 \[DoubleLongRightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"13.2\\\\\\\"\\\
\", 13.193588162762024`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[4, 1], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\) %\"", StripOnInput -> False, FontFamily -> "Helvetica", 
          FontSize -> 10, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], Background -> None], StripOnInput -> 
         False, FontFamily -> "Helvetica", FontSize -> 10, FontWeight -> 
         "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0], 
         DataModeler`UtilityFunctions`NumberFormatting -> {4, 1}], 
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox[
             "\"\\!\\(TraditionalForm\\`\\*StyleBox[\\\"x1\\\", \
Hue[Rational[1, 16], 1, Rational[5, 6]], Rule[StripOnInput, False]]\\)\"", 
              StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 
              10, FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
              GrayLevel[0], Background -> None]}, {
             StyleBox[
             "\"\\!\\(TraditionalForm\\`\\*StyleBox[\\\"x2\\\", \
Hue[Rational[1, 8], 1, Rational[1, 2]], Rule[StripOnInput, False]]\\)\"", 
              StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 
              10, FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
              GrayLevel[0], Background -> None]}}, 
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
         StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 10, 
         FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
         GrayLevel[0], 
         DataModeler`UtilityFunctions`NumberFormatting -> {4, 1}], 
        StyleBox[
         GraphicsBox[{{{}, {
             RGBColor[
             0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
             PointSize[0.02], 
             PointBox[CompressedData["
1:eJxc3Xk8FlH7MHBLaJG0KO1IpVKUUKQulC37kn1fs+/7cttKUihZypZ930uh
3EiJFhFRikiplEK78nqe35xzPG//9Pl+Zu6ZM2fOzFznnGsGr4WLpjUTAwPD
7tUMDP/5///+iYCUQpHS9Z6JI8hNq6LXnppGFgOxgqyNAzKvKR8A53qv7P30
N9h1s8HvHj4jfje454+X7Si2TsqjKeWnbykfhCDeNw2zy8awDf/7A7Q/Cbj0
Msxw99sRyocg0I/x+5Md77DTchsnA8TeU5YCywdMF3Su07EzFoi9G1o7jH3D
fqyC/Q+xovzBZBXaCPa+E1dmddOIa6wXv7MSeYPdLTUjF/mHOPpU79OWq6PY
jgKcT2QVPlE+DC0PRnpeKb+ifASiJll28w9Rx08DqHH0iIgqrsDOcv+9JmGe
7U0VMvmfEHv3vS+p31SJLeh+eNfmA8STXyMze2Krse9/7s/tfnEdO3RRfUlV
xE3sxJAou8f0e9gxZlHSLIIdVHmlQUtNuDRJ+C12orn4vVWnx7CHtiksv51K
rHBqg+HjznFqe9L/ez7mzLFno0e6G1W/NBmQ1/4QzXC0ElulyYtHbqQTW6xr
4TjPaBf2qGpG97DMc2yP61vXLNxOtvfxyF1xF59R7LvHZrlkZT9Q5ZOFevVy
pT6nZmzpZNoC+9572EV8ocWv5cn6Jzr1l+g9o0yTBbavA71uz0awT4kxrOfk
HcWW3W/abq2A2udRUFgtHGrocx/7gxzHvcKYh9hfDvy5qZv6GFuPVZieMkVc
ZjASZPP8KXZCR5znGvcR7LB9+5xy4lF5jsK9xOh99CI69nAyfaHXOFr/GAhw
JiUfzivHXrLhl4b8PCfoDubPN/fixEmPed71NuDqi3neMC74b3CeLXjvlvrn
E5cVNjnXFhDfP6u99+c8b95nvqSkkNh0F61UspiYt24Vl9882yXK3QmY53HV
E3Gx8/zt5ob8x/O8vMDccXCeGxVYrv6b58dbXFRNy4i5fssH+s+zzO21LovL
iUUzYrRjKonP0GQLNKvnHf+3DvWiWuKJFFrdQD3xorgXHPEtxO13YjyFWol3
+GSMZM/ztBK8T2onTnSWZJpcUIFdt/wba9Qa4ltHH+jGbiCe9rs1LLeReOYR
a0f6VuLTf9fxMB8hZqlkPH5Om9i3W1Wx1IJYZW2NLWMmcYGZ7LbHxcQvWwt2
PJnnUHcaS888B7ufODQwz1psq1e+nGdH35eP380zX2qo7vg8nwiWuPx7ns19
TT3/zvO50q7s9hLig4cctEVKiSs+bZdxLidWXB5IK5lnZ++Dph3zrNXSNnC3
Yl55nooKPK0itttdv3pknlMiJ7mWXSN+c8lnDc8N4n/Lnlj13iJe+OVT26Zm
Ygkpzh6HUWL25SxOGh+IjcV+tvdMEie/rs9J/Ua8Wy1BRmBhJfbTLVyD1XzE
0VPy4VeFiJX+XLxOFycWHRVxzjlOzNSVrTqqT/zuWv4mBQviRovxhZ0RxNc2
Pj7cdJbY/+KzvcfPEzdViOVC7DyvDHO+cJHY6YzVa9VEYi02cd67j4gT+PKY
vn8gjnj8at/i78RbuX6qt4hUYXu/zmlINiFeryuSZmlO/FAuzeX3SWJ9Rw3n
6QTiAcV8vu5CYm3J0Bt3pom3D+yaOmFcTdqv5RmDAR/i779und5JIy7KZ14j
8oJYcHPP5J9RYra24Gqe3hpSXluuPRdWXiPtv0Wn038t8SW+xozE78QDutUL
cxSuY690T3AvLanF5he9M2JXTswhenR6YssNcv90PRQ8teQmOX+h2Xsstelk
/b/OXJt/38dWLCsJvr75IfZ0bu2RNUsfYd+d9V28iv0J2R79kFW7PHkeGWr3
cAXFUvEUba793U1m4S/uwW59smT3Vbc+7C8lF9+fGniFnXw32otFbAg7YFet
vrnpW+wZJ7W4PmcUH8pBw8xUf97GRmyVO8sNWp8Q/zZbu76un/jlD5N9RxfQ
sXfsWFLHbUJsWpfT6hlIrDzivqZBtgl7LbuV4JksYs9NdcdYpogFvZ5bped1
Yt8d1Lj953AfdkZ2Rh3zqWHsyJjxieWrUX3J/X/xizwUv5311vEpx87QHn52
xaACO0ni/a+ie8QSV6xDDw1UYn/f0LIjgbEK++PEzwMdK4m3J+a+2/62Bjvn
ufLOxko6doH3a4vMu93YDtqJzxgMh7Clh8Q9T+57jS2/3HJkidUw9kmH995X
Uok3RWxtSWxB8ZU8dDa9XynE0oBdPjsY9NvzFjbPKiWugE0t2PZPx/zl9xF3
mP/Y2GL5EJumccBNAMdTCtCsGJrFUlSOzWxy+u1yjkrs04x5tj0yVdhJ6vzs
TX7Ej41rS7vC2rGNeNlokdsfYHup/n3Yk9mPPZs014Ajn2P/WVOq8DURxXMK
IJnDzfNkQTO2rejKZn2GTuxIuSW7XM+h/ofi/9e+FUF8O5joVxN3FGo9VfuM
4mlF0GLW4An1K8fOaC92uBJC7Dzc4po+z1s/7274O8/yQj0XymnE33OdqmbK
iRUkQj5EDxLXxlUt2T5K3NY4prNcsIJs/98yFcF9xEYeHeKu0sRfZN5N6dcS
K8n3Ol1YU4m9c6F4YIg08UjE4x+Pi4jb9I3YqxdXYVfskFM+klSNfXitqumX
UeKpv3qV56pqsEvMRYLfs17HdjtpayJ0/wa25umOoVcfG7B/FEmoK4fTsY9s
jF1bEEP8v/0jRQjUyhKrnyX2SWH9cPDRMPZq6dJqhxh0vpUgYPbK5/yYMuyF
ipPpf/QrsP8Gca7cFExc/XJVU2sxcazj44LOed5lORYUVUXMVblV/EEb8Z6B
zIt7aVXYF+6zt23oJj79kW3XAoFq7HsSp38WSBLvH/u5TWea2JtNLjlUtQab
We7JMOdl4sgsIQ/XDOKUCwecbv+sxa5areN1bPAm9pWnp/yO5dGxC+R+XZSx
R9eTEowvSo9oR/2VObOytWYaP67ADjmXuXCVTxX2Kr/qsOtsNdhhcsY7ukOv
Y4d3f6qiRRJ/W2YlerQKPU+Pw0nHWm8WtXLsDvb11n/fUv052nG4pNJlamRX
iU331nCN2lKFPdjL2sBqVI196ubnHz02jdhGWzliqzOIx0SfyBjPEr9e3rEh
dA8du6pnNIGWTHw0d7nIn0NN2P1vLsXV0Juxv6974KrS0YJ9Ysn43vgu4n33
Jsv86W3Yh6rvn3r+AsUDyqB0527YSFkF9meuk/wSVcQyV3x+GCbWYO87rWj8
7GkztmJjX2/RT/R8V4bVB2L9ukcascNz1IrHltGx//17VeugRez6KYOp3qsL
O15ZqqlmE7rfq0CC1lfRuoO3sHOGDRTWZ1H3Z5oKLN4vcn48F11vqpCmq/ys
H/f/VKFB8O/1T6kV2Ov9FPf6q1Rix0Rann9AJxaXPjk884S41Gl7WrRyFfYR
eb0VBWtQe1MF2SxJ1cmMcuwoveoIhxzioON7P2fnEQ/7dO+WvEPMtuB2x/Mh
4hhxR4lTX4iPNnMv/bKsAnvh86rrCzmJ+w3ZV4uKEuu/1vboMiFeWXXC/Gs2
cQBz2MT463rsviwz3keb0PlTAxdOh1+XFSqxtx/g2BxZSAwbl7xmRvHHnGUU
HmTZ/EPxgzp8MYxIsMbjBepQm3952e23xIZ7RdIfiVViP5UPGg1PJFao9+ZY
PEEcxuA5NXa1EXt43VHOGIEm7As2w+w1X6n7L6iD92PXmxX8FdhlW8+07wqs
xL6mpBOyo4COLX+StuHVrbvU8ajDL11mTXuFQuzDP76VsdUUYbd9qW3yYy3G
rr2UWWv6ogRbaMll7UPy5dh5grIbPg5XYKcMb1rEPEacmb5A99v9a9gvNpa2
MtVRx0dXB643tlueqRRih0/Kze4ZKsb2+mLNImJVgr2h/nX7er1SbIk8f8/1
9cQ8UU1iTfMsdUdvUfTLMuzAV3lZW1WqsGOa38wwX7mFXZLK1jTNRsqn/9fx
iGdqC/bsra1KMeXEt4o4VnUPdWJfFw164jc2gn1SIOejLxMar9UAkdur42uM
y7F5R09+5bQk/nH76L/4TuKNpteWd+P7lwZ84gzwZWwgzk+NLn/ykPhevkSL
3mNiu/xlkzUviFnNn/Duwf1zDcgKsr8z+oJY1PAvY47rNWy/PWk8f+yp+xFo
gPgwv0B/ay+2hqMZ6+2/L6jzqwFHrf4uKZRvxG5aXR90IoU4yctgxR/TNmxP
9W5fkf3U84iuAb420BodVIa9rCP2nL9tFXZiRcqXRa/R/VoTnr+bKDV/X4a9
JHVRf714BbZuT6jFukO3sXm+rK/b309c8FRsmdutO9hHRppD40qeYmfs2PlE
QWKAOl5NeFAzsFFmZwV29qvbT78UEq+PWcT9u5o4kJuTMwyNL895obNArihU
Yefs7GOPV6vBvjPByPW+/w726cECV1M+1N/SBKMKkUVs+P6oCb6S7D9ejBFX
XnwiEr62EjvjzqPKZWi8YM4NsqN1EenV2K0WCuyLU69hGxwW7y/eT51vuibo
H/vA/EGxALt/+8wOulQl9l9hGd8aN+p6YNCCrcIxRVxGBdhMrYfeK08VY2f3
Me1QRfH0nB95vj8c8Zo4MSXu1ZmGa9ix5cmOSfFUfANasLphbJdCNdX/pmuB
fAZ/0quwcuy6iy8OGDQQl4a39hvaVmIX5fNv3fCP+NBNx0sDB6qwBbvVN+vR
iTtTagrr5G9j3/t5dr9y2x1s/W83n0cH9WIP/nAxSb2B+o/awGHtPLj5bgF2
tXiuv4RrOXbCRm+Jj/j61oYeQ5vIITox++pk0zWxtdg72V+YTao3Yu+quM49
eZu6nkAbNrx11ZQ6XInNZzJmKMz0jDq/2nAov0Zf3aMS215x6XmOzdexDYyi
/G0+38EeDMqodzakjoeuDWyL3B+cKSjEdstq40neXI49cZiP8V8Eur50oCqD
hz2pohH7LduiEp+VVHwFOqCf0DYtkVyBnV4tn1mwqApbopYvwaGtGvtomsmj
5Sboea4DfXvv6fSL5mP36I2MMZpcx96+P2f0Shv1PKTrQG1TqE9sI6rPEyCZ
cS5dy6cC+7sCT+VmAxT/nIBP/Zwug1fKsduXfu0p/0L8K5v/jyZLBXbtI9nE
yz7EUlxnHBOqif8s9+qZvFmJvSQoNpi/DrXHE3AtfWHICnw96ILXbwE687FK
7CHmyLPbeFF/TBcGV/1xFdUtw+5+OiPTn1uObacs6uYvXIHNWiNhoIGPTxd+
Zcy8lLSn2g9dF87Idd0vzWnALvob0+S3HcWneiD3lG7zEc+36MFdJaFXKo0V
2FPtF2JeXa3GvvGwXLqumhpPAj3YzenzdINiMXZVG/14nQ86Hj0IGfM/o4rG
i+fcF8tsvYgXXY96cL13zSKng2i8SR+O1tgOxTcXYXMOPA1bxl6MfThd+UKa
E7oe9GGjmQWz9r8C7BtL/a/KyRRiJ9xIHF76sgjblE/aum6wBDtqVJZjbUE1
dti625FeltTzgaYPf9Z4pNmi/hRdHyTjnt5lPFOBvSixv5fFHc3HGoCpoNwh
Y1ZUPgNYsVJvR5c4Op8GMLp4b+wIP7U/ugHcUmEWaussw2bqFH4kg8Y75iwl
25AetLkS2/zsy8PFD1B8bwiGC79H2fSVY+fFvk8vP1CBveyMZulxdD+iGcLo
7JalKsYo/jKECvW9E5+cqOuHZgRLO3d+jdqSh/2fx6egGbp+jcG4Zl/+uCt6
/hjDpQLhtZIZKL4zhtXf/bl7rfKwna4XsIw6UmYwgYcpCnOPxGJsd/10+6t8
JdhjZw0+ZR9H58cE+LNWRRg/R/GrCTiItC+u0CnEzoi9xH4bHS+Ywpdnx7/0
B6L7hSncCS28z8BBHR/dFNy0J59LuBdiPzVZLFwgh65HM2hzO/9s2RQVb/KY
wQbmFIn1+4uwg17QX5wNJX5ml/r7X08JtkRJfL+wF7U/MAOmg+6f6e0onjQD
MZnL7HylddT+zEGoOm2Hlvp17EOfLTcZlVH9fTAH7jDRvU9eFWG/8atb8LWj
DJvVZTP/k3HUvsyh1vhMQ4NDAXbP73OH9tpS7S3THKRWfNrHdawEe0FJ/1S7
UBn2Phf/BlGdOuwgE+XziSbU/QMsYNo/J0TjSi724Uc6Lm/GKTNYQkEHd0/f
Kup5wWMJS3eo96i+ourTzBKmY4Lu3w2nzmemJchcaHgXfKIIW3WJ1FvBUOJ/
vn397TtRe7WEq6kdoQMqudiSQhtjJDWJ0579Ern4HJXHChS/1pqoHUf1YwU3
4OUViQ/U+A7dCuLZFn2+OJrzfx6ygiZ3y3+/r1P3UzNrOG127IUDD7r/2cDQ
Jokp8xJ0v7OB+3wFXt7nqP4p3QbYON5U2Oyklg/ZwMVnmvo+mej82UJK7k+t
w6YF2HIrZ4cHo6j2Z2YLBX3DVoJvcrFfBv+yanUtxI6bCDh5pxjdL+zAmMUh
4IgJ9bxkOAnxP7YZW4ug9nkSHtwZbNCfRdfTSZhVZXMNi6LWp5+E01vVo31m
UDxjDxbbs21Z0e/N7EH0gEQguyhxy7tkqXXJlOn2kPDFoekVK1VeHgfofbHE
TaMLxZcO8FE0U3OklKpfHke4qLli8c8udD9zhBG1WjPbFej6dwLRf50cFVLU
9ZzpBBO3L1XtDsmm6tMJfL/JPn6+i/jVGMMqa1sqvjRzhmfnpjj4BrOwNeWt
ipfKUceb6QyxiVJjxqNZ2AxGTRuP7cjGbvf7UfZqP/HuBa+cP2sTP7m8hoNX
Ah2PC9idshJR+YXOrwuI2A/qbU9B/W8XKCxekVRon4ddnvFdJr0C3R9dYPjW
d47yLqo86q7QXnjbRcuZWm7mCoa9lw/aPEHbc4UPE7w3ZlSuYosdeXnn5np0
PbuC//lThrpCVHm/uM61j4UaEd+o9sjpBrlnC978iM/8Pwu7QdCy2OI9Imh/
bv+7/Tg3gNQnmVXFqL7cIGzn8D7vF8TK7Emx4YlF2HtYP9/pmWePvsaR5k3U
86LCDVij4C/Nnvo93Q06YlaoPRlH59MNpnsXv9niQS3/4gbJuYExwx8yseP4
eGnRKdnYV9rUD3etQ/dfd+DPMy43Ru1T2B223WBZpC+Enn/ukNcXu4GpKBN7
aIHW2bjuLOxWJtMnpc+o7VW4Q/TX6mkuizRsk93P46SU0rGlt166W2+dgV3n
ZOhgMJGHbceT+HDDBXQ9zO0/MUEvV4xqj53uMNJn/v4xndrfkDukmd7a/HUx
uh484ERUS6G0CVU+Tg+I0732SjUPnT8P4C+Srcj6RG1P3QMWnt8zYvUhF9vN
w1G0a4Laf5wHPNkX4Pyil7r+Mj2gds2xh6YSqVT5PICZo+6d0050P/AEFZXN
S9+PUe2HxxP0Gt40cShR5zPTE9i+/n1j4E/VD6cX9E9VXmhaQ9UHjxdIB1w+
YLLtCtW+vCCVIbSXC7UPVy9gUVfivLcxiSqfF7j4aZjlXUDtxwtqpd4WKOyk
jr/CCzQFtaNNC1Oo+vICB919y2n3qe0zeMP5XkWrhoOXsf9n/67eIMmSWL50
aSJ1vr1hndVlppl7qdg3p7+lvTBE9eUNJeoljmEbqO11esN3evrriy7U78EH
ss72P3UbuUjVtw8MnBPzqv9AHY+ZD0i8fV04bnaJ2r8PjAXoqsZ4F2C7c3ME
Tt1A8YwPKOyUELp65wr2mgy6rL0Udb/J9IELZxbeYkX11+kDT7riRUJWJFP1
4QONDm3bEt9R9Q++AJL/GSG8gP0z5qjdgvXU9a3uC2vPOi5cfJHaXoUv8LkO
V59fSpWXxw96pEM2Lhujjl/YD5InlbYr/0DH7wffxzf4LPyYgK0ynLNG8wlV
Xpof7Cg6+vtkNVW/FX5QeejO6k+1VP0M+cFlzft3cySp65nHH9T+HJTnKknE
7llaqeIoloI9YcDAtzqBKm+cPxyxLqy2eHIRWxeuph9moraf6Q9mA7pCnbNU
+XgCgM5p71RbQVk9AELdxA4va6XWpwXAZo8VC2XF0PYC4NLaBXE3r6P6D4Ch
FhqNk58qHz0AHvUFP77ygDo+nkDg5Mn7eh+1X7NAKPBZvCEo+iL2+i7BX07N
CdhBXMd1n1y5hL3WOGBy0pE6P0OBcHCV2IfbE/HU8iDY9raH8/Q+an1aEDx6
JRFwWJTaf1wQPK5oFQwPR8+XILi8/Sdf5TJ0/MFQH7aroCmJan/qwSDXan9T
mzce+6KK1B/TMWp9ejB8z2eUjgqilg8Fg7iLwc+VP9H1HQKCfwNlVtZcxP7S
nKC+coj6vWsI9MtusC1C9UELgdAT2zaaC1D1GRcCgy4Xe9IaqPYpQAOxPXEm
A6ZxVHlo8PJHCOzeTrWPKBo4bJNJ2vOgENuthmbEP0r8/g/N/epKdP+gQbk0
LepNIlWeNhrE8OQe7VtOlZc7FDr3pL16lUyVRy8UXtt7HvzoSd1fzUIhaUQ3
x/U5tf2CUGjYJ3Vlf3wR9ms1vhl7dHzqYdD0+oyiyjdq+65hsORo1bTpBHG0
rNrux9LU8RTMrf+7pTEtmFp+IwwcHh1zPNZDtS+GcPjo3PjT7zZVHwLhQP86
sYJH5Bz2+QDVnmQU70M4HD3OUrVzAbo+wmH6G+8qhqg47Ekmri2RqPz0cHBK
fpH66DB1/2gLB17JqSu65dT57ouAe3uFVp62iqXKGwlnfF1EaV+vYhcsZ1rS
Mk1Z4RTcP72E9ecH6nxyngbfo/dYbwqcp+r7NGx25jdaDFR5x07DLaN/fOML
qOfXz9PgmbZVWVqZOl8HzgBXqIm3bmwm9qbY60FPVlPnK/kMHJM7a8TikIGt
aBhpYb2SWl89GnK8yj9Xb0Xrx8C7DEf2fRVnqfLHwPmaFc0NO2Oo+2kMfPNd
SAu6Tv0ezv3vchpA97ap/SzP7mOHKyYeSLqH8pllwbQ0JLDMsBGb4/XUpmYt
NP9zDBjSw8S4nUuxIe23fqwL8d6plBYeb+LyZVsPvoklvjbmefbUvPzD9qfO
LCY+bdgt3bus1w63Y7uaH9j3QZTKn6EdgwtG/2R/70bllQPG4H0Oj2xI/pCo
4NXVr+gj2CWWef/O7kX5y/Lw99PMePwatL4CpE97Wl1Z3IHN48Ic9SAP5dco
wPlH2iMMOmi+QBE6hM8OcE2i8SAliDvW8uNAVQn2N6UDvmrVxMlN3PECNcSv
V7ncU5jnGo5NfbXz/CeBN/HtTeKWDaJLtzcQH4g4LmvVQizEyX5w7X1i/Ujh
XV0PiG2eWv58MUS8g3Zr4yF0/uZsZiRfYDjPHfERImXz7LLOtVPKhfi71CRP
5jyf6huPXu5K/ClaK8ZnnsPrhBbEzHO/wYiRnhvxlUOnZOXciTVeBi3WnWdv
x6h1684QD0S2CubEEwd9uNx09wLx5R1Kl+yTiBkS+rjHkomjLhb0mLYR33T5
Yb/n6bzy0tlvr5khXu/x+GrhzjLsxIRNv0skiNlvCZuGnCfWqKetfB1PDFsD
d6w3IPkVvz1PTdXFEh9+uKRgEyvJtwh3EV9F8yEO9RTNUkwlln9YFSYBpP1t
ouf94FtVje0oYupS0lOHbezEc2Prw9vY18XLRJVUUD6BCpg4Bbglb0LXgyrY
DNVJH4gtwQ47sGy7cBqxU0J1SG02sfxDrtJvBcTfVsicvWRTip3r03j0ii1x
1cYI20E74nF5t12cIcTBAvd5QxpQ/avCsh9Lt0wMl2HnHMjqjRVA82HqUFzz
Vnb79RJs5yuidQF4f+qgftzg/Mj9Cuz0tW6Nx5ursP3Yj7muOEjNZ4E6CBTs
zwnD7VMddBdyDBxB/b85v4q6mGm1phF7/xrn8noh4v/rn9KxN8kuTz36iPhX
ymb+ilfEmTenTta1UPunq0PyXhaHVBUyX3x/ZcKbynlWsNl0fiyIOHvNK//T
dfPmX+Udnx88W4It5+aVlpJF/NPlpo5DA5rv0IDa1vasWLS9OVurPBHL7qDy
EWkaUL6kfvZ3GRrv0IDx9/0WTjIl2LUb+U5/bCXmmV1dpre0FJvvabJm7Hpi
+YFSbxNPYn5FzjKaTDm2qsPSiLGDFdjHbYpDU9+S+cqXtQbb99yrxfa48KO+
ybyVWl8TJhhfSKn312AHKt52Ypyh8g0YtCCV8UzoIvES7JI3t4WnR1A+jBa4
3wmInsoqwH73VUDraRXxM8nVdYk3iReFB66T9izD3rg3+1OXdTn2UaHt8StQ
Pvp/ts+4iW1VJvW8oWtBlO1O+Khcip0/Hq8/O4japzZcOcLoMoDy40EbLBiS
rjsfLMZOWfUy7LYusg6ccxW4bp5cgC2/nZHn5W00P6kDb+8tuGreW4QdteXK
JyZ2tP0TUJKTsuZbeCW2+HipOM9P1F5PgLrS3h5W1jJsK+mGRWtRfhaDLsze
KgwTlkTjdboQczEu7FRYAbbQiU9/6/D9WxfUDSZ1lS/lYweOcJ9melyEzdR0
YowtvQRbRdyseU8xsY8UcwXfZnS968GAlILdnjf52Oe8W7TWv0Lj/3pw6Gh0
+rv4QuwFEu4Cjk/R+L8ePOUrWsSyljg8+ad5jDmZvzmT0veM6zzKr9WHTTdE
5y4RMp+i5aXTxO+I8t0MQI43llGnGl1fBnAj57vVd7N87Lr/vJ5zjnj/key1
wp/Q/K4BvJdtWHcsIB+70FH8mOvXEuzpvMgjoej+OeettS1VL0zJfMwp7hU5
nJ1o/NcQ9st1LWn3LsJOzL50TXCkGJtJw54jYUEJdgfT3y8396PzaQjFOwUz
wtQKsXfL3eC3yCU+W1SXNaGI5pOMIKeXf2nBanR8RkBXOKIc9bwEW2yX6/gN
a3T/MgZzqdaBgH70fDOG2RMpd8MWlGLbnmTKHH1KzDiryRFSQeZzpuITpoVr
0PycMSilFw6mK5VgmxwOqziH5icZTCBd36vdfJbM76xML39p00jmb6pMpZbZ
J6J8BBO4qVipcEMU5eOYQMDa8BN+1qj9mcKQuta2OKcC7CVOnNyVrqj9m0J8
p2TddSPUvk1hKei/e8RUiH3h94y0cyeaXzGDxXK28U8H0fVpBh+Li5mucVM2
M4M7OeeMQx3R+JwZ/Cn36LZB8QKPOdheXHqtFs2/gjnIrOX6tzsoH9t9RemZ
lqsof8UCdJMubdqvV4atev/Vj1W5VHsHC8iVLdfbhsbzMy1gjb1NnBCaD5hz
4KcZtYYu1N4sQcbexoXXOx97kdPBpOEiNP9jCU/dK6v37ULt2xIELlrZrr9f
in3WyWNQehNV/iFLGDs1tvDe/SJsw9DbtEx0/c7Za3+1pKIpOn4r6DubsosH
0Pi2FTA/2ptTbU4db6YVZH/f17C5j9r/kBXEdQdKtPgVY/tfNLSfWIvGp62h
07q1Y48HKp81OIZsNeVD/WG6DUSr7zNo2UD8tiN2TOR5KXbo3UQhPxV0Puxg
J+f9rpBb+dgVZ+VVO2oKsJlKdwn270bzTXbwW3tkUE41G9siYNXxjdtysM9Z
Mjtd8cnD/p/9DdnBD7OY7axu1PkbOgkLfDas7hlD8wH2sDq77NqPQmr/ZvYg
mDHq5+qTid32ReRMjz/xMYZtpo2ryfyKrln+gFMJmo+zh+ENkve7TDKwi7cV
tv20oMoPDiD1sdEjQSAT2+OWU57MIXR/dwD1Q1snRG1Re3MAZ81JmzcmaLzZ
AW46Smy5K4Pm8xxhhD/8wg3Uvs0cYeXub8xnqq8S9wQuP6qA6s8RZJTFBtQG
0fybI4jIZy7Z/54ar+Vxgk3nd14++CEf23bXp4GH16nyMDgD34KB56b30f6c
YeoEvXJrdQZ2vHXmdTE+6vgynYGz91pJpQTlIWfoTdPvm96A7scu8E70d9P5
g5nYLw5Ib9YZRuVxgRzGNY0R1ii/3gU4HLWOZkxS53vIBc74si9pjcrCnrUT
nt6aT51fTlfg2h/34hN6Hgu7wqPabs79H9B4sxs84r26SqmKWl/YDYxChqx+
F1LL49zgWIWf84IT1O8r3OCHTOPtCVT/Q25wMWHpI205qn5c3UGjf7I5whmN
v3qA+WLpp+kcV7Eb9/+ZvGFCbDi8Ir44C83feMCdEF1d+VNo+x7w6uy3PQa6
aPzXE87cOmm85hBqj55gef+Y0id+ypxe8NBkn/WKehRfeIFaqnhhizVVX3He
EJ+wsWLUE41XekPQND1Pc4C6f3zxBi89plzfe9T5VPcBWOiltu10OvZJxxXC
vplU+b74wKWWBsZjFdRy8IU7vZFhdxdTdvUDL+m+iGU0an8M/vDc/OgZkRWo
/fnD+iB1KGilxs95AsGATWPhnkxqfXogpJUKS15Uo7YnQIN2mTETIRvKnTQY
Mx5NH0uhbBYKm7J0TtgZUPMb3GHQskhkcc8y6nyoh4F4sM64uCA1fsYQDvuZ
hs5ve0jVF3c4eO/VKNXaTJWnMxzqrfkfPbhDjTd/CQedl0cLExah538E/Cjl
zksTp8a79SKg8lL+qyFBynYR8MnollD3Fap8cRFQanbUNdGN2l5BBAxNq437
/qPGDysi4BHj5mWNF6nfM0TCyUmLKyLbqOMxiwT5L7X8OU1o/DsS+EsH3/Ma
UesnR8Lj3WsdY8Op5Z2R0JTmfZsuQI03c58CTk1G6fYUNN9xCjLtfbP5Tajf
u56CkYJN5rNofoLhNOyJXHb4xwWqfY2dBquq/ff431O/9z0DW9U/Xa3VpeqX
fgbO6blXmfFT+7sRDYESRQOHGtB8x1lorrcSpftRv4/KgO13JI8+qKOO7z/v
X0YfGZ3KRfmW8pDHuWWQ4Tx5n4ZeHs+/ULcE+7YeZ6VJMorflODi+L0BBx/0
e2Wo+3V1tww7yg9Sg7GITukkV/R+ojpwnVrhw6pL+nO/quCvqRHKN9GEb46V
YrwLS7GnviReCPuN4l8dGLnl3rtYnsT/Wkq8U17PUP9RF/oYZSrFZFD/Qx+4
V2owabyl+s90Q3jQI7hFvJ66PufiQxn+vBt2nSR+dJXdUcqIfj8XL04oFHMe
E8/Hph8Ivi9zHF3vxnDhR+jqvgiSz/P+bELybv9K4rFgFzU0/z4Xz1U2cCh+
9EH9O1OI9lj9WTYgD5s98XRf1l9UP6bgXr6da8wZxa9mUNXr5svdSq3PYwbn
eWW02/aR+E2B07PnBgeqLzPY6UZbKjdN4rcze18HG/cXY5/yan5ccB7Fe+aw
6d9qz1I8P2IOiT+FNHkuF2DbZD8S/7ufxGtyEksSfMKKsZtM9NWvofd75+K1
qqkUs+91aHsW8F3eozF9McpXsoSb0fbXk/pR/GMJSzT2/Ug2R/uzhHUxjx1d
I9HzxxJW1EyatUZRy3msIaz7wq+l+1F8aw2p4qqLp9D3Oubip2tJRwUCn6H5
NhtQ7vrIoqOPtmcDWwcSzxu8RP0TOwgsfxeTU5OL7T7j5lM6QcxmpaxyRysP
O6t7VRDXcdT/mvO/7VIv0HjqXDwk9Fv5s8nZXOzz9O0TcheJ07YzvqKPEzPo
druxo3yDOVfmz0xUnkHx2klIeNCUfkglD3v8Cv+uX7XU8c/FV5eWvSra7YTi
BXuQe9bYvjUY9RccgDlK6IkAipfNHOCjY2dFQAaa33eAsfu7E95vQfG2A5Qb
TXWrpKLjd4SWavZoRcFC7E20+jOlw+j+7AjnLn6U/NVdgK0kUlxpmY/6I46Q
ULfIsuI0yt9xgg+cGuULG/KxN4zZLonwRPGYExT2SW3KQPk1Q05Q/vHAb5e4
HOznfHe+OKL5fHCG7J2MMc1nsrGZbSNWNKH6nouXDogPdV3bnIO97Xivt8p2
srzTkD59Vpl4hUP50j00En9lHd3JaVNQQLZ3fEnsm1jUnp3hBbOliLdvDnZK
Cm3m5zmynOlz/brTSeh6cQGuD9Yfj8+g9V0gU+l7WsoRFL+5QK32RF2bai72
mlCXrPLwfOxQntEH6x9Qnou/nOqDVgXponwjV/h11Mqve0EWtpRNCD+XYTb2
AdrR/WLHc7A/bnOoFkX3tzlfWvz4yxJt4qcCx/Jvo3wqdVewm9l9T3kT9XtX
V1hyqvRGg0Uu9nmpW0pb+1G+gCvUH/7BoVyQjV1pWHdgqDCPmO+A3Xlh6vx3
uoJxktP7+yPU8/zL3PZs1jt7G1D7n4sfJWak2j+KUtszc4Oe4NyubtcMbO7V
F8KMmVF55uJP21Hm/BFUHjd4Gc1xQa2fqu+5eDPsg//fHFEUD7nBFikfBU1V
kn+z5HZY0rkYajmnO/hrH54ZMUD3I3dY4yFT9q0pG3vs3FkNzwqqftTd567Y
3us99qi87nDdJyW7MZja3lw82ypKK398kDi+8MEry9+UK9yhtLv67ZgTyacp
Ze+OCQmmzOAB6hPPY1zfpmHfjn35RpIXnT8PSLshdWvHGpT/5QHdj+8sOqWJ
xg89QHxB4/RF1F+s8IBbBmz2uY9Q/OgBq+sj772GTOysP4rvziykytfpAVKM
JhXWstTxMnjCy+7vuzzj0rA3fHu39BYqn7An/NvEuiCCB/WfPGHG26ndNSkP
W9gzRW8sFT0fPWGxBXPiukLU3/GE/Sl9a/eZUduje4LK3lZ+L+tM7Ctld2I9
LlL13ekJzwKCJmxNqfY05Amam9XVwoop88zF8woe6/SCqPoR9oIa92q7xxno
fuIFUwrCFyuiUrHVTnIY6I8Tz9Qe6fkiR5VH3Qs2q/5dNulO1V+mFwyY3xiU
c0HjEV4gY5Zdo36Jau+c3vAYdNY5mKDr1xu4LhWBCx9lYW+4HhHYWa2PyuMN
exy/98QKUvs384aH4y5DgPo/c74jvPqQ5GN0f/GGy40SXmHo/pjpDeuOXuu6
BijfzBvab25oe5mAjt8H6ht+HOn/gfbnA53jM93T3ih/ygd23OVbH9aM8it8
4Gwdj2MzG/FVp7icWbT9uf5Lb8v65rso/47BF9w12FddzaPW5/SFceaQMsce
yq6+MNN+KyPdlqpPmi/8/KJD9/FH/SlfELy98YZoOerP+MH279o+vwNSsf9F
q/6KKKIs7Ad22pHFBTbU78EPDpdu8+1D15+6H6xbvFjxNDOqTz8w2vTItYmX
Ku9c/0qoxaQkefAKtp44j8THLygfyQ++twSKj25JxX4VeTC89jN1fcb5wYf+
8IBdIlS8kOkHX6NrGX6no/brB7FZvSox/dTvh/ygX+vl+wle4irGMYuUjAxs
uR85vx1YUL6fH1gsc0stRPl3rv4w2p3r0/eaKl+cP6wQffIuOwZtzx/Ynj01
qzVE58cfGHf8+XmJG9V3AJRvG99zAfWvOwOAhbFMUoGLOPNl7t+cVej4A0Es
9d6VFwtR/koQXH2sFn2TOwV7tPbeCXoXtX5FEMw+ucB3zhodfxBouyx1vISu
Z85gyFlvrrE8H53fYHBinex4cwedz2DYWFt5qCGXKn9cMCx67Zx6ggnl6wWD
zkcOj4sWKB8uGJjXPYuEIvS8C4FIUd4JlTqqvoRD4C6fcXqCPXU9qocAJxeX
eOwRdD5DwOaY31nBw6h/GQKj/jMGzleo8mWGwNHtnoI7TlD7qwiB7nWzXFbx
Gdg563qc/FD75aGBYaXsVtk2avtz/e1IrWU2Kkuo7evR4PcMW4scyh9MpsG2
Co8qvWpqfz9p4KSxpL1/CPW/Q6HviJiNtRTKNwkFuciQ44MT1Pb7QoEz4pf1
sgPU8rFQGFynPblBF+WDhMGWdvuZujpqfbsweHKP9/TuYcrJYZBYl36vhA3l
e4bBRj1lz/LvqP8ZBk7vNtx4/o3ywnBILbEvcZumHBUOSV6pex7mUuVvCwdj
wVVMG3D5wiHUqynyNaqPuf6/z28etfrd6HjD4d8J2o7hn1R55/rzs5PHNKVM
0f0jEjykIw+NHqP6v3P9867yHbYGAlR77YuErDM22o8PUNsTOAXNwqHPDquh
/r88/Pd1+3Hq+zlz/eH/pvc+R/MxilAVfeEjo2oR9uPszJEGC2KBt/Ze4eh7
KzQlYJT985ftL3qfSB3OTRbf8n1agK2lu3WPVg/xHs/mZ2ufEUufv6WY8m3e
+t12Gls2FmL7ly00H1Ypwmb+8Pn6fC81t+38Os9aUikh0/PMQd+u6aZKzF62
4VHdPB9Y2nNrZJ65E80+zc6zf2PSSLwa8eGb6Y83qhPnnc949l6DeNGaJLU/
msQnNF+ucNEiHru+OLxMm1jzb29cxQnixX5xQ4f1iXf2zkjYGRO77n4Yw+RE
XO94zuFLIHGhC9eVptx521dMo21rJqZbyDfL9BJ7Pj+3sW9dMbawxVH5NUDs
ZlfnWOZHvBHWFWpykPwAo1LvpvRg4vbVJaMxwmj+SR1ChJd/tHqB+uMaYC6+
aG+/K5m/TuVf/PGRIJrP0ITsf/9uFYah8Q1NUGYVS9MKIeMnhrtEe/WjiFW5
w6UG7hCn8CR973Emv09VHBVPbCrDHkxZV9XBiMYTtGAH/Zj5d7ES7DsCuVNb
vIl/M5kf3eNfih01UbzMR7wc+x9LcYiSJ3r/Tgvsznp8cl5RiC1V9MlulR/x
/WChsb1RxBKLcoUiUonbFNw742qJGbamCH/D16MWNH5+tvyYOvFEcneboSNx
Itv7He5RxDOfropsvousDRkTdMtx9H7cnAN2LrYbUiPLq5zsmfn1iFds650K
medZ9Qb2H77Er6P1T+6dIS5XtbzW54bGz3Qg3+dr8EAwur/ogOOF0WNZ+YXY
JavTbySj+p7z64yYTq2lldh/8pnOqsmi+UgdMO3MFWRkQP3LE1CiWzX4wSEf
O0GrL3ntHnT/0AXjlnZXnUNkPC3jSeUr5sdkPv3eNsZwNn8yX173cS2N6xdq
L7rAe/TxzY3ofM65Nvx43vlgYkmOEl/jdHQ96YFKiczNLZpkftw+5prs+Gs0
36oHXeqs9ZsbC7D161jz7Daj9qoHJ7+9vHvfDbUvffhifO2nKAcqjz40fnI8
lIjmB+gGoFFy3FNEiLhl9uNqs2x0/IawR7ks4PwhMl/84O4121o0Xs5gDL6K
Px61WKH+uzE0/PIt40Tv7zCYwMA7ywVecuT9O4PoTc8Wt6Dtm0Lcq46+XafR
/cEMNFdFvr+1A41vmMGBZxoaD0pQ+czg/FhjuDfK/xgyg4qz22AY5RPQzEHI
9/5beTX0voEF7Pvrtf4C6m+DBTTHr1mwwRLNT1rCrUb739vQ957olrDfWywr
XB6NX1hBS1151/cV2dgvPrResD+F5het4Mnyr7eM0PcuadZwfjgkQ6gV9b+s
4WFSj6yKLuqv2UDNm8Q/Z1yo39NsgClceuuXEPS+lS2cNZnZ0uyFjscWIscS
XK9PUfEb2MHg1Yerr2WS+caORSG7gn+i8YuT8DvkewY7HdWPPVyzDbJlS8/A
vrLm0wqNLaj8DpCk+6U74zIVT9GcQVMwMW/vBBX/ZDqD4p81E1YtqL/oAk11
RtEP+tD2XGD9ZV+BU/VoPsAVNrI9n+56juIfN/D1X6j7L4IqD6c73P50qf4e
jfT/1yx7tOveLyq+mOv/f9vhWPyv9Cr2wyUq1heniVUlt16Lfknet1kquktX
jRuVzx16376SN3FA/Vl3sK9sl5TKpbbP6QEyDhVi74zSsBtaqrdu/0D69zsK
D6l5r0jDLjzkGvGnFh3PXP9/tK0rsyMVuyYtgr1lns+v2KZZ/4LyXH9eR8Ak
/8xWKr7i9AQ9g5HGMEHKc/3zyMizLWKixPdYVhU81KBc4Qm3ONge5+6nPNd/
drDZzZLzl6r/Ti9IF/Z/0vE2BduSyfpLONreXH+2UeXm1VIPtNwblreNuNm3
52CXdjCEzT6i/MUbdpRffyWHfs/jAx9iErr6mNH8sA8sTR3Sj/6bjC0V7NKd
gTzXn41PH7K/roPiex9oHtcuX+5Dza/M9V+HByvfazqh9zF8IXV998pEX9If
5aAZT745koJ9/D+vkxsTly7dqH3MmvJc/zFabezCX1Hq+p7rPwbpdf1rlUTn
yw9YcosY9+ZR5euc6/9mnql4/R6Nt/jD507nmSxbqnzC/vA+Zfhypwm1vpk/
6N3Tdjbzp1wRAD2qr5abiqP52iC4KJ9lnJdFLecMglI1g/2em1B/Jwj62RqA
zRrNfwVBlq6zUPRl9L5SMKjWtduoo+UVwfBUZ8+K4ZFE7OP5kq5K6lT9z/XH
Yma/rhLgRvNXIcDVNi7on5+Irb6+5z30Utuzo8E4Nxcoofh9rn8U9Plq5/Ri
1D+gge29FLuo5Wg8JRQ2vW/+d1UtEbvn8myd/DR6nyAMXD20kve+ofbPHTYX
H2evfdhMbd8sHLx7YmM5vlPHDxGwVmfXjTtiaP46Ag4U6MU1jSZj/y277ZqG
2yvA4oAQASnfZuyP6iqKvbxvsNUVZe5VC6PvX8nCSaPPYT4FKL9WFibfvQjL
lUD548fgwhFu389St7HzF3aIRAPxQZ4y6QWh6Hs8cvBcRu77j4Uon1Qe3NpY
u1rzUD68IgQdzZdJOo7y2ZXA/f72dQZa6PueSnDDXf/XllW12GUBu1asfNqA
LfTQMlySFeX7qoD8t3fjZX9RvpEa0G/HcAueRfnB6pD8l+scpx8qrzo4910X
qJZG36fRgCHJWwlVUyQe9t770LP8IjW/yKAJz/qinrq7lGP/3/uAKN9IC5Rf
XjIW/om+T6QFCpKnLwXTULyqA/WXtkp0CKLvRZ0A87de2Sv3VWP/vTb69XM+
9f45/QTYCanlOtPI9ycKuwZ2uWxCz1c9aOSXcPV4jL6Ppw924q//OKN877l4
Zbx94zhzCDr/+pDn7Hv2SQT6Xoc+KKxniZsyJ/OXIkIf2ES8kA3gb6LSGWc2
lG9oCGKTHDvVl5H8OfplqfIZPuKbevY8i/lR/GgIRdKZyqzTxGOtLD5d6P3q
OSuY7Fi6OwXlVxlB5g8H3XPtFdgc6WUXM36h9eeWT+98RitF73MYw1O2y2Mn
AouxNcKFnGqmUHmM4eu0kv6pA0XYS2/83CooSZZ3DceYq6LvPYAJMJwT7ZSo
KsTeLrXgECuO/00g3jJqgvU+8brrz0NlUH9xzsuvO2lWoPw8MIWdXasltiyk
7gc0U/h75d+ZjY9JfNYmfVztyDHisryrMxfLqO8TgBkM6Gz25w5A8Z4ZpKWL
yrusJ/lwEjd/Hr7/ohR7qTRrv5pmGbZIEfuIM/qeEd0cHNXvexgtL8Y+GBQS
EJlVhi37/eGRyWson2wuvmPtH9/+jlo+ZAExB64zKj9D8aYlbGqxPHI2F/Xf
LOFku+qRgrNovswSNJgb6iN+oe8NWMGDtrMruLah82sD3Qy98XR3ND5mAyWB
Y6P8migeswEG4Xt0z4PofNhCh4L00GobNL5sCxw+ZndFcb64HaywiooZWIrq
2w7C9o7lvtqJtn8SLgllPYhG70PCSdC3Ytx/14TMP3pNn+NTmkX9Z2fYcS5T
SVgxF3tCZsIqC81P8LjAiZ6Oif0p6Hy4gpqrz4/AHJT/4waRtmnK4m/QfJUb
iHtsN7ohjdrPnK8Y3RVE+ZpxbrDkw21O4WY0H+UGfy5K/HohicbH3UH65QFO
oRdkfkeoMFmzYgeaX3GHwVw9k9No/3PmeKQtt4sTbd8dGDxU7U6i+THwACUe
9v4Hlih+9oC1ZQ8s31pfxV537vqiAGYU33rA3shZQxurHGzbyRIB1XDi/5s/
RvlZnvBtNjSHi4H6vbAnnGIfsEs7moXtH8axYAV6n3ouHkvO2de6YQHavxcM
d/faaoqg+NkLCk42rH2Oxl+HvOB++NUHHIuvYv9jUdCJXUJsfP+9XPVSdD68
4SOUPvXzop7Xrt7gV3VgQpoB5Wd5w6bL23ZukUfzcd4wREssM0Pv587Fb1u6
t7In/0bzdz7wYNjd/+0/NB/lAz3x77/+sEDzqT7AlzYueOUayo/yhdZzDCuN
G9ByXzhzePSmxDPiuo3aTYIviaNvpv5ynyRuk6yojJxF5feDkOX9JRnZxPF0
f3G3h6i/5AfNsRa2+e6U5+I16+NNQ/WKVLz7n/hszeHITrQ9hgDg/brFWsA/
HXtrnrfyv2yU/xUApuzZAu/voO0HwMaPIeymaDyXHgAFzAek71yhts8ZCLUJ
N9fpGKN4KxAaykbGGqVReQJB8lp+Fo0VfU8gEFhPRpxak5+OPeUwxa1wB80v
BIE4V9xFLhZU3mBYfQee3aZRyzmDgUuP13xCGB1fMETkzfSueo/y6YLhT628
3EET1D8LBn7LhI+JVWR8/eqo2+yeRiqezQyBodn06NdLqO0tpIFeyLPCDw9I
vlp4VVrp2WlqfaDBflqfqgMLtb4CDRrPTriX1aDvG9DgTkLxA02UDyUcCkct
v5ldy0Pvo4bCF19FzSgxVL5QUEs0mBDH/b9QOJ9ibBA6iOo7FMTXbTn1ojAd
u7DVaIdYCXGnVeoKzXLKC8NgxX9fCE/DblfRWxKaiMofBs3XjplaFKB8uzBw
bFTy5b2KzlcYHDJm3bvYnHrfOSocJFeNG+Wg/LHMcFgh5m03gM7XWDhcvnz1
6DkJavttEeAX8p1JPICyQiRsePXqz6FmdD2dhhPxh9KU9VD+32k47iV7nAWd
ny+nIU9X9NG9vWnYGU2OW9bVoO8/RIFD9y/H6VTUfpWh+UHUBsc/KF7UhJ70
Yk7m9cXYy3632+t6EututxX47Ev8+VMfg1Y2cVrMkGj67RJs/bfvrJOZUX65
FlRsnGAaQd9nYNCBb6dulrxgRs+vOWcH2/+LQ89fHVgjlkyPKS3AFrrKOlM+
zwfj/h4TaSFenPbzLcdDdP8+AbtYrwQWG6HvG+rCZMnnrF+l+djDIvSssh9o
/lcf6k7ztsrk5mDLOKw0z2ol7h5c1OrihJ53BvByeFcH71QOdqTjZ75dsmT5
soM7v+33Q+NBBnD6o6J8LxoPpxmAilRTjUkzGf+S108/W74kH3s2wdGpbQAd
jxGsbPbnmLyCymME3tuO7rqli+rPGFiOS57IRe8nz3m5is3L+pfEjH8WjQRP
Ej8fliyt4kXjXcawe7NGna4Bih9MQD/N4vueayj/zQSUj9f8Pa9D3nd48Ugp
dekQeb9hkrbna9U4yZ9LVPDj5kH5ynRTqO292NlWSvLl9klIr3mTgr4XZAZ5
PCyuQpCNfcE7LJTThNiHe9ndumCUj2UGX5PfTFeb5WKr/trxdbc9yo8wh6T9
7LD5EIpHLCCl2eBdbjiab7YALVu2xtDTxJaDcpV+BcRxohlKB+qIB2/Ovl5+
Bo0HWcD0+XOby1D7MLME3o1HOl+jfJRMSzhmoPXZ1x09L63gYygzd3oFyl+x
gui/bbyZ7ZnY04FXDiQ/IT4UJ0TzfE48xt1uZyd4FXs4PuX0Fn/ipfoHckok
8rA3i27SWiWJ6tsatr73q1e9gfINrGGfwDjLSqlU7GMH/kjFAbHX9HFW35tp
2CG120elG9DzzgaueXy7rexC1QeDLdypjTXr5s7A1roskJb9ntg1eNO/b9Zk
fDGSYUxx5t8V7FCFXwL5Nmh+1w7Yf988PBuCyn8S9t5opXF5ofo+CTFNRwI7
LNDv7cFl7wC73wyKj+yhbeNhpmE+dP4cwLX+/S/5NPS8dYQMv2vV6/rQckcY
/PS5Mc2YONE9YvdkM9qfIxQFK0m4LEzHTl8VkNVeQ7wp/7jHe1t0P3QCc+de
q+u/qPrjcYYEFiatBhoaX3KB+K29J4pWovK6QMf4nzO7K1H9u4Dq2pLvN6JQ
eV0hIJ/+JP8GGh9zBb7ZBzyHK1C+tis8jyqekkLxxJxhm8yNQ9eIw6RVXSrt
qPPP6QaxNjprGc5Q4yFmbpDQ3HAvZRvavjtUvdjqdy8GjZ+4g0AzXfP1T2p/
nB7w2jZxJIWO8uM9oPFgJ6OGIslHqhMwl23JoY6n0wNST+vU8KDnk5knxL1w
qw9G41+unjA21B1QNojyAzxB7zBLhv3Gy9jSbj/PetuhfHYvWGlUs3axcgp2
jpoQb40eql9vUPQw8lQrIvGq3e4jaqcPp2ArdC9ZwAfEvJunHU8EofFPH+gP
dnRbvpBanukDOZ8qdR/cpZZ/8QE7mxBmNnc0HucLw/IuSaFT1HgY3RfUhCJe
reyizOMHL25+38ZUkox9xyljfT0d5Sv5wfu6L+FThVT90v1AzuHP0vshSdgT
r/UOtNYRS+ruHbs7ThxVu/cDtylV3i9z8Sm/6j/9m9T+MgPBeyh1ee6tS9jl
N2q+XmhNxDYxrcxPmeeXIY1TbzuIgx+HCXW+In7G6v/hzCWUfxIILf07dp+P
o5YLB8EHIfknf0opc4aA+6aPoiFHKbuGgJL16KT/WWQabBfzj/v1giofPQLW
hB9TWZpEOTkSsr4d38xlgOKr07Ah5U13rg/1/Y25eCbnU+Hb8HL09w9UoTM6
k/s7G3p+asDbS+2mSvh5pAkWedGi6Qz52CuPRf/KXEBssPKDk1EC8ZLvKReE
Z4j72fRXK89zO6Oea+g8D2pb5LH+JbZ7nH/qDSP5nvHqI4bSVQuIxUJOrTZm
I25buORK43LiOyzDTjESxL65xiKJh4iTGcRmRTyIk1Q+zszMc3HZWEAVG5l/
NuifuWe4nHiiBK4a8ZH5aIPEPiW+52S+NIJm+GfXrzzsLv9zSSqo/HP+ECmS
99cCWQfOZ7P5VtbkYXccbOdPukWcZLWnjvUeMV/UqpCP34gfOh4+PqKP5mdP
wLcJpsNZ6HuH//l+rrRG7Bb890ROgPNluRKBLhRv6YKFfFSScl0OduDB0C1m
P8nyA++PF+68kYedMGz6YqkdmW9VLT9YwoXnU/VAVMfC6sNO8r3XjlcT2UYr
8rC/dP1e+3Yj2p4+WClWRj9lQ8sNYF3uzq+Fe0l8uPaewveFosRe8RFe7UC8
OXK3c7QVsiG8/vpA7fIV4r5/dyMzvxMf/3Iof9lKNH5iCHuOdKheNkfvFxuC
02zhoSKhXOy9QkmNCyWJNWglnT1xqH6M4MOdT+9VbuZg8zPYC+/B38sygjeH
W6tn8onf1cs0MBYQW4c5sVaUk3iVdbt83tgnFC8Yg+Ah8VOWi1F9GUNss585
w/pc7C6nDl8ZZeKyUE6pd+h7ZGACK8KPMss9IfHqsbAovU/o+ObiU//Df3wj
0fcD58yvvpr3/Tzn3NZxZE0i3rWaUS74MvGFsz8WsFwjLo1ZwPdyXx72ZSdj
nh+WKJ42hWzzhQ47pMl45rM/O5V5o9Dxm4LaJU4B9ykS796I2CebMkPi230s
MUVi9uh9FjMw1wwMlPFG431mwL/31lMJcXT/MoMsudvpX1E8RDOHdQf5uQM+
ZWNbqTKZt6HxwLl4ONq3/fOkTCb2y2/s9OhA1D+1AGXzhBP7rqP8Uwt4HpZw
XiAbxV+WsHcwluuFQAZ20R8JNXoGyme2AsMt22/8TULjqVYwcTCW48AQed92
UcGesd5HqD6tQfRPRWqMLBp/sAb+5bWJS86lY39VUROy7ES2AfttMfyKO6j9
021gf1OR/scalA87F39aXEjh/5WO3ammkCYXkIn95s3+36dHULxsB2tTXnAn
Xk7F3vRtMNXzMXGWZbjRKjS+x3ASupM0dVzjUXlOgpjWjtgnZag+T8Lu39qm
+VnU8Q+dBKb/vuCNzo89bDa5fUGcCc1HO0BNpIeaGivKb3WAdze/KCrwoOvX
Afb/9waHzo8DDGntDXzNi65HR/AxWBy9ZjIN+0f1BVFnA1QeR9CuDud9eQmN
dzjDRK3Klik0HznnNQlCZ4Q+EI9MnjSNRuNvnK5wgG+HyEQYysd2BbuuoUsF
bMRtXMt6U5eh8rpC7IeyDs++y9hy+YEyOp0o/nUDxn3PVhuhfOBMN9iVecHh
6120fze4WXFaf0AKjXe4w8C2N6mS894n/c4/qdOP8lvNPGCH936Ob/VofM8D
tMM+m/17j+a3PaBScMNehf1o/MwDQuW2BCtqoXjXE1Yk7Dlix4/eV/aG15uW
ewq7o/bqB6Uf9B+Vovb2n3hIUqP8XSnqjwXCg+K72pPJ6dgjZiM3DItRewuB
8xIMzLfkUX8GQGDfjumKu9Tfx6XJQPXM4pEbaejvA8rCW6WpoO0byN/nnY3x
GWf/iSwHmcmssbT15O/zDezYWDLrQb5vdbNXQLR1dxk238FptzZz9PfXFCEr
UHrJIm5kFbjcGWK/Zg/avipwmvvOKMqQ7/PwyqzbWMhbhn1ieSxcRN9fZtCA
gXTpxrtmZL5PLLqnpnUV9X4daP7v+nPOZ7nAf1eC+Em2qMJN9Pdb5vwjzCxD
aQ36Po8WuF13yeFbgP7+oTbE5zdEBd4ow956xsV9UTz6+zQ6YDl+t7pqHcnP
ustjM6qyH/39DF04yja5LR39vU+aAXzd+DG5cJZ83/zqX8jsPIyeL4bw/7g6
77ga3//xJxoSpdISJQqJSkIor6aKVGiv09516rTnaadBktHQEk2KkBESkpUo
ympoWslW1u+8P9/zuq/3+/fn83Hf5z7Xfd33/bpe12vW8iz9Ld6O+o8tKAqI
0M9ZEH8cff2zOXlrcDz2EO18RKGvgf08m+3B8NWflN92JD5pAz33pUE9rhcO
MKva8rkD9qttdoB306ePCjqReCU1FXOxLF6st0KD5RWVzW+ofh60/16ftT6I
vB9LVcD6DDJOUPRJ9tNAAvo7nWDjux9zOOeTehAa94UlPBYQZiQOKvxeRDhR
WPhe3DDaf5zg6PWtu1PLsV6hM2jmOYy4hmF9AWe4Uhos1If2OBafnfIfHMLn
xeECDx8Oaf1pQf+bC9iHDq7fuoTUzzbZ7uTijuf3u4CWp5R/PfY34HCFGHoa
5626Cop5ktWX/YmqpJjW2Md/oxPj0Vzhz+bPvZcNiH/tU6vZI/mfuD93Bbcv
c2IOq5P6ED9EWtdl4/+xeGq9/H0xZ8wXdQOfU4M9L/H5sdi6Zu+bMayvwnSH
6uneUVwNeNwd6rbKqt3DfK1mD+Druin5zvwYxVu/j9K4KP3eA45FqywPx34y
4Am3OBZmbNNFfdgTambNCzi+oYJiyVWRzcV78Hl5gdEm92swSvx3UbTV85Ox
nneJFyRXWXy5Nhf1V2+44ivpWD6M74s3pN061PC2EPP7vEG1rCDfshGv5wNd
NzqWZB/E9dYPPCubBtVW4P37w4EEReFD+qjfBYBJmYiLyUfCT38HG+f8ILx1
ifH+JD5cDwOgKHLZ1NzJUoof/rlfu8iA1EPwL5sUFApE+1EAcPoNz/hYjd8r
HXY+/tV38k0ZxSF9NpeWjpN61Rp/3yhdP8yeLzodIvwcH+/HeiDZdHDY1nFa
eRPW36bDzy0HxEw+o75FBx+d2oJeHqzXHAjfFTmC1bhQfw2EVJ0W9flP2UwP
hDG7gm7ZBnw/g0Dx/vcj9GasjxwEeQvUPPtXYTxUEMiJtf+U2VJE8enqz6+O
GhL+qJMZnPOB8NyFflKnRIsp5oysWPwL622w2P5s32G/ZhwPA6YC3eMPHWAf
r2fA5pnHI7Y6oz+BATJXhY5qd+DzCYYcVYcZ3fLs7yc7GPQrXfoctxdRbD8k
GWp0v5hiQ53gYx+NUV8KgaValTIRrez/Vw4BzkNbO9XQ/0YLgXN+Z59xYb51
fQj8fGA1/cRizM8IBePbI572TWjPDIPYFRVhHZhPKBgO37NXP9uH+aus9Vrs
UYqnBI6PGQmfogr+vKPmM5K1/iUufW6P71sM7Glom/qmg/pRLNxoKXzl1Y/v
WzyEvHbMuSOC/rJEsFKRDQrVRn9RKpgMCSytdUV/yiaYey/V4mUeqa8ZKGse
4CnXTPH5uPniSvew36AuJIrr5KY7YT9YfRAy2G3/vIDk/z8Ys/oQ74HrswF8
aCqaHOEl/RwVm1fOWfAR97/GUPmn8OXZvqsUf1pUKXlZ8i7Fjg12azd4sPvX
NJvBDzu7vONX2P1MmneCDr3olfROjE/cBd9X7Ew4cxbjhSzgwtlJjQtXqyhu
Sk6+6d9MeNTBarjv4kmKPb1ThNQw3hEsoLq2UexVGft6zRbAPcDZmIH9xJiW
0MS7M3cr1qdi8RzF3UNCQ6R+2Oo7IVutF5N4Hz1VrkUCqji/1rClYZXekg6M
t2btn+8ctY9ZjPXZbMC++Z8OlBjfYwM8mukun4DEI187MvXN9QyJ7+H3a00/
KFxDMfeK7IdjNYRTR3YqmNNIfa4rVcM236RwvHYg53mjoXQcz7eD00mMeeXR
JyheNG9Hs/9V1J/s4dNtpWXh2H+dtd/1fGFwiPsQjs8BHvmIvrhvW01xz1P+
LS1JqO+w9IPg6dVLLCspTguy6vDGfmQs/eBG2zrmYvyeWTw/QNem+19sLpuf
XnQM+03QQNVR5LOzGPt4vxMECGf4XNFG/50z6N9fsFATn7+MM1xNev1Xzw33
t87Q+KYvv5+aX2d4cbGgYsMQrj8u0OUV+WLyX/WijhZYbRxWJPWddjx9Y7bJ
soLiuLIvMdI1VRQHrHvW9b4a9VVXCAks1kvCeG3Wei/56YCT1eMqitf9KV64
1hfziVzhH+3wjyr2H3KF9IKtVufXo/7iCmlcrcLlKL9Y+9X7RoY3z2Zj/LTb
f68PbuB0Y8FnBQ6M/3eDtS3v6jypehRucH51fQVzGa4H7mAZtrd/xknC12HR
toJLeD13GJ/dfV8d8z363eGLteSDR89x/jxBXkdXxhjnQ8YTTN8zq/y3VFDM
M+d6WQz2E2TpCy/qe955Tcfn7QmZrSIZLli/gMUjcr3JT6yIv2W+g7rgvXqi
X+S3PDk57QfqI17guWln/1Yqv8ALWjOOK9kuwPF6weam7t4Bc6JvPDSuPRJ0
EL9PbwiSt4s9eATn1wfKh5ueCL7C8fvAYgE+n74G1Ed8weqKpfapLxhv7wdr
13RoL96F8+sH2fQdcTaHcT784WOG66fI8eMU39LsWFw1Sbir2IozyRvrWflD
RtU82cZ9OJ4A6B12fTaM98vSNxK4BCy/2+N+NwAYUu9mTaD9jbUfbp09Jlki
jPWU6HA8UGptHh9hhunz11F30R5Dh+7bO9Vu8hN+z7tCszOZff0JOixabZ3v
gvW6WfrEZ+lHAY48GD8WCPtfrzj6DutvTATC2sOLGz3x/mhBYHDpvMIL7AdE
DwLzy8zUdccw3z8YNu7on9uZhfm0IZAZ4LwUNDCeKRTOLs2Z3OfLvr+OUJhS
u6EpK4vxRWFw95GIrF0P6hthwJm5QOfcK/QvRQBtdOw1307UFyNgZ6sOr/0v
9u/bmOC1uX3Wq9voL/UAbx9OkU1j2B/DEwbbY2REL+P74gX3kx2X7Mf4OhaX
j3i17VNB+eoFL7xGZ2UmkPfR80d84L7vhDuS34ltAfI+6uTWKMWEEJZWVq54
rkveT/nwqwP02mqKt1y74pI3hfquN8wvvv0nQhL1a28IqB6RScb9I4v3PNa6
0HaY8PmpZ211f3A83mD5ddbT94EoT3zAq/DpxDuMP2PxnWkRsd7SVRQHd+01
d/ElnNs2zzBenvy+7/xZyW1lOF4fWP3y8zwe3UqKOW/tqo/eRvrdJH5eWaju
QLg9Ofya6iDKVx9oHe68QuWDsVhzy0KPha/x/31hqCs3eUUYzpcv1KxcMf2y
PKk3oidiNn88BeWvLwgY3vHah/XvS3zhkN+KkbPbcD584YeGntcdrEfH+t7f
b93X3cuJ8tEPipwyrLnRf8Hi5hjLwYkgvF8/4D4Wn/AX68uX+MHlQ4/cvnPh
9fygMemA3y43XG/8wVe2x17vLcobf9A4ss3q0yCpL5JTYN/e/YnUH1kZ+0Ca
a95xiveUm20OK0B56A9rpuqdBy6Q/j3SlQrFNe34//7QflpaMBnrB7DY5svb
ZzJYj4Ylb2bfTq18vonIn62J9M1XGfh/AcDr4bq9eO0xijVfu2Xn7EZ7cwBY
hJmrRcURLngzvXJlEeEGM95qj8uE36xx+OXWS1h8QPSaOifp/1O9wyty8xLC
JmpOh4vtCQsMBIwsaCNcIXN9p/0U4YO3aCONV3E+AsCAdrngvPtxiq0Xm65T
ekT4yp1Hasp6uF8OAKk3UpU/XPH504EzzcrUpv4YxRffHtgS6EeOL2sY8T0+
ivk/dMjZONer+eYxiuVMEu7xbif1UvhsacZ+LccpTvn8q+YqPz5/1n6vQUTj
JD5v1v4wdBXDktOH7BcD9xxx9aoj+8XAFEWpHRbHKOZtnd6iJsL+fQcdZnf6
BB5A/w6LhaPuGo5g/ApL3rfUm2gP5LPPFwwEkW1VM6sdyylOeSTwMHmIcO2h
c284qnD9CYTqsX8CFo9SbPgl+HjjC9y/B0LR1vdSahifYxoIaktN4c3AUYpd
9aqjju89RnEMXNPaEUrOf7Dh1+FErDdDC4ThhgHzqJhyikOPfLG9NcXm+kCI
5Upw0flK2HOzytojq49RPP3OyfvLQwhn374Q9+kwzkcgFOh783Og/4PFUvZG
nBHz8fsIAjOxVq87+uUUl0ZnHF4cQnjl2d6AM4MY3xwEn1S5jjzZg/HGQcCb
ecm5ZTP6S4JgRp3Q9L1q6G8JgnPqo3wut3H8QaBkr5b1VR7XxyA4+SdaIjcB
xxsEhrscBoRLMZ6XAaFKhYJ9uL9n7b+Nd7+y3xKH/gAG2O5hFtdkYjyRDoic
3DIQuQvzSbZA252u21c6MB9iK+SekF/bVIv1rs2gyvXYeEAInr8DVAqi07dj
/TYWz3ySsKzKnnDW+qwEySMoP3eCqkFqpaZHHcXahhG5o8aYH7wLnCYiI89Z
kfzb77uNQ4RsCRePhxbK2xF+2m4TW4T51v/4ix+aNdSWoL3UHArpK3IbX5N8
W96MOYFaEycozo/dHf4W8zNY+0NO63DFiS/EP+vIPRqtb3eC4tLLmw5cpPKj
LeFQn+kBbWesN2YF83raL1daE/9t1p6vC8NbMZ/FGmR+ml369Yz00xTK9trG
j/EBHDaQ5xe7qj+F1FO+emWHXxneL4slHn4SVuc7QbGwtndqDDLTFpyeNiTx
RqJ92RaWdWfvNSitolg8bRePUj2J30tXzwz6Q8PrO8Dm3OsJFj/Z+3VwgDsN
NKmNiiS/VWxOK7PTivSDzE7clVCL6z2LNTdnCi5E+Qg08Fwl/25fE17fCcaX
LqK1hpVTHGPPeavjX3z+gENB1gH8fpxBgivu1sxQwi//JDcc+BeLPD7XdP9f
PLunQL0kmvCZoBybkX/xje/fDpRfqaSYp0AivhTjHVn7xUzayrScZ+z3U8YF
HnTqHzSIKKe44n7k8sV3KyhO2JLyqk6P1KuzG1bISUlG+eQK+qc2/5Y7RfJr
a1e+HnnTT/jrwl9/alGesfaDh8wnJa1dUf9xhRULg/YcwHhPFtfOfJGXdQXX
TzdYcNE/aQmVb+8OSm0fixyS8HruIHvriWqSC/qPPKAm/fkq82H0F3mC+JmV
FqL4/yx9tPrqs2ULMD5dxhsyt/DXvbIj7PJmgtecp4zitUW2Ch5PjlKcx2FS
2BWL8swbdutqbpTF+ns0H9g4EjrndT+JhzPr6Ep7d5P4D48uP3hOmEnqpw1I
LG77HoX3HwB+Nsfu3v+N9kw67P2Rd9RuF/p3A0Gue0l1jC1htc3DapyqJF92
2GRFY2QA6Q8X0TDc32KC88EA69vT8jN3oj8yGLqitp6VN8DjwdC7cLR6Hc5P
STBcs1BYQrfAeLdgkPpfAUr0D4ZA7Ykex1C8PjMEJG12CqTi+P6xPwbwFx34
hvmWYaAzPcBUZGsJxcc01G6bG2N9lnDIfPJtfs5fzF+NgLCZIo8OGpVQfKfz
1aJWZFoE3C6Wuu6D8Z/ZEbBu2/waGbyfkggYDK4xenAa46Ei4YZ/RetJJ7zf
KIiI+Ws4oYvPJ/q/3B8Nul/FXy7D+yuJAVGnnMFTuB/tj4EXdXWqWVjPjh4L
H+6vjKbGKxj33+sxE+F/7TgWssdrlQLuOVvkqfM7UuCS+DMfHjy/LQ3Cqnea
ilH3nwG3LrnFpeL/cWT+fywPEjX3/9a0f2DzKpB+WNUxHDRIscLvpAbbjLcU
txZX+lp14vmrYdWM3IHOdXi+KrwVNNRsLh+mWPDbutObJN6zeQ0sMH2+4vCR
QYpvdKYszGQMUzz1eujULJ8xirk6I2c6er2luC3joPEdf8L9UlenhXl/oLil
8i9PQznhh6o8OxjXCUcetTh8pZvwcsbnrLFe5PXg5cZ/WcBskGLNU9sPfMgb
othx2kfHm3uGKeZqDuee/fsNxc0XQt5fs3lLsXCwTPaE8zuKPbk/xi+4Os5m
dTAvKC+q9hikuGq7s89cX8JlC7eI15weoZjD9GaWbeY7ii+JbU8L6H5PsdXW
43WZQXg/G+Ad9/yxtzojFMv6hkceUxyj+MqP3986rHG8GnAvqtCrZe0gxf+9
Xw2YsTtHbW8lYYf2uUUhq8nvWxzXR4dlv6f4zN55v9Ym4Xg0Yb2TR92g6xuK
NXg2en9sR94MvUucNvDOG6RYZKVSnZAs4Th63irpJf/iB9b1Rf/i//VHkCOs
P/VHTGIV4dm8LlMiawlnt/NZjKwj/NFS6I1qIOGEE37DzPNDFO+9Mi6xqpvw
VF7kS9mJYYorW4oH7kuOUVx9vXm5c+prcj3xsWdiHYQfWMZt6JLD+QNoWn9Q
SsqM/XsmwA7e3dZdmYMUX7H1bp81bYTiub0Lk5hN+H9a/9/3qwXFv99bHk8a
pviiIT/nCp73FIt1Nd57vZr9fJha8DT58Rw1GKT4n2o4zg6EjZULfQ5T+dla
sG7flxvtATgf2lArUvHXjAP1YW0Qdxpe8WL2IMXGZQ4TXtsJz3F51Ld1YIhi
OxOJ8mQ6+X0Jx7DR4Rk4Xzqwz0W/c40Onq8DqUkffs+WHKRYZLTy6OAbvF9d
WC6iyu+1cJBi5rr9csulCf9nfpi6/50/Fu9eO3eLpzk5fvhDsn9BO35PesD7
PmPDcu1Bipd+dfOqkMf/14e/QpzTdyiS/mhxWXFTCrsIxzyMGBM9QNh6/pX+
VQcJ75n29O3LYsKyMeWP8rhI/nrZCl+nwJ3IWyBdStZ/u9sgxX5XF01+cCdc
bbJsajXVf84A4jZujhpKxvszAubf7x8HFhP/VuSmtB+v5Ak3n7gUUa1DOGgq
8op7BF5/K6w+XzhtaArZGIKu6piV7GUzmIHGs/3zS0zw9w4Q0LDgx2XqfZUH
4Z2qZ89NkfVo1RGZn95WQxQ3qDPOmCi+odjmZNtk7S88XxVcTwtf2Kg/SnFz
7GBrmvRbij8slfgQ04/ycw04+S5q07pN1iNGk306941RihuWgPHK+WS9MIvJ
dDhtQdaLGX9tb+8xJuvFq7bp+/RsCNsfHQaBs4Tj+pN592uQ9WSxxLI+2eNk
PTlmwl2W4DBGsftVw1U2z8n6Ibf09vIJSp6q/3/zow6vNJxNDoaMUbz7caRk
RjxhFwGDBeGmZP1YmxTcciCGcNqC7g6xTFyfNoCAYZrxVcdhiuN3WF9ochil
OJXm/nrX9dcU++Tx3/r8lLDgJ+WjcwYIP41lfQDVeP2NcDVX3mi0Ev9fA3Ym
pdMebSfry3/nRwNMracbTV4l64tFSMlh7gd4vc3QPj9B8x3tX/L9VktrjTPh
K0GM/gw3wkb2q/fs8yVc8Fv+gqcf4Z1P5PIy/Amv99D1CqATFi2XyDjOIEyb
+TdmURzhSYn7TK9UwvHcBRv2phOGPYUb63MIL1fSWSl2ifCRc2+N6A8I2200
ExJ6TdjpS/zuIUGyHgUI8j7okyasr+/8slOZ8JnBlD7jMMK1YjrqD/3JevV7
xQpjo2lkfZLewnAdPoTzDSDU8kf/oMc7ijXM2pK2x+L7qPXf74m1Pii4uQQw
ggmHP7kdrLOKrB9cJd84EorI+rFc4NrSzELCGVzB87QekfXBMmVptZ86WT+q
DBR+CFHzowMqAwOpufXE/385TGlH4g1cL3XgLecF6a0byHrxxTifW+8z4dod
kccPWZH1xW1G3ccvbsMU330yJVvqR3gB9/a5G8fxe9CFmtNGujv3kfXgLEeb
6731pH8m/+b9VicofU8fvjIj2nL3EuY+pMq04yHy/cCg47wLKkS+60YoM+72
EHk+XPmenqyFxw1AVON4uQa1vhjAj9Bpw8f2ET7FPClrYETOzz/dKfDGGe/X
AIKvc3Q2vBmkuEti+bFTqXi+IfB57+wwwPWIaQiWB8cUGwzw+kbwN/qc160x
sh78933fBjOuO9w/juczjWHT/ErtT0nI28EItrUkb8LzTeFFVYCJ/iy2vGea
wQv5+CAmF8qDHf/nrw9gn/9P/b+6RHVlZI5dsPmirLbfsRHqej6e1/Yr3SX1
Ik/EKGwqW0TqFd7ZadH5Ff1PzWYw/3zlJcsdNdT1GRcV5ddKE77rPc/Klp/U
97s7lK4laoX1W3bBTpGruVv+VQ9PMq3CxPoN6QeXfMf15ZDddfZxO3ALlxfe
qHOc4o4+2+uPBqooFsqbvp0D65uwOGb2BY6H0hj/YAcfr4xNWV7Aei0OIJuX
8PlUF4lfYMrcU4pqPkbxTpmuaw//xZvLVu9/1UJ4/Z9YQePbhGf2356/8A7h
Q/SxlQt7CQd8uLpB1R39O46wXmW6hEIu2tccQflJvk3wRbTP0+CU2fcYAbTv
srixiGPOnX9xdxmXp+19wrQPkTDrAeFlS5jrCzoIf9kgtenQI8KX+3Y//jZA
mE86elxuJvn/uyrr2w9qER4/URM6C+17zTS4+o++fY3ks5585HTyWQDa95xB
SMr/0yIcL4v7VEPu3utC/5IzlAx57dq4sJpi2pKg2+n4ftFcgH4s66lBG7GP
qf/Tfij4GMW2ZxZF5UZjPIkrmPiF79e+j8/fDWoO2arssTxKcZGObesa7BdG
cwfeGdF1vAWEFZzsaHq/8P33gJl7T5uf+UvyR/+vHjT6i70gtPityByVMorr
7x/bNIj5KTQvUNCgL3qI/mQWZ8vZ7N1ejPPpBUEKLlk35uH/e0Pe3ELO0xvK
KL51d2h4Kg3tf76Q3SOwcvdCtB/6Qo/97cWfNqG/2w+UXDoU6nxJ/RPJvSda
rqmT+MTqfGfuufqk/omGGV+pzIzjFJ/7mL7riSbxd4mvaZmnlI/2fzpUxNpI
cawjnOuYw6+ih/VAAuHM8NUz7qpsLgmCfGVT3s6REoqreIc6FLYRf8X/xWOQ
+vLi/n7F9lhPg84AxvVRNWFHUi/+cubNQZom2uOCYfBW2IkTfmjvCoaCDB35
k0ew3n4IFN2Tt0/RwvzVUMj5lsOb/AHPD4MD9o//MDCeH+JBKFoz+2U8+u+S
IOSETKQgxn/yJkNjyQfztjG8n2RIv6nmWIr3dz4F0i6Ue1+aifWsUyE1O7sr
Ce2nY6kwbM4byP0T7U97wUCiYcEGzJ/uOPDf67Hk4a9ehfBiKv7ZAiy3bZjh
9w3lnyX0B9U8CS9m9wvlsIX8ozHOO4+w4+U4WPLxp/iTaVjPTsYJttTdmLXx
A6k3dMrcqfFHFcarOcEvzbCX54xQ3rvA9vOWIycwP431/WgKjNjnWJB6P8pK
xcpmWO+H6Q7PPq4tfWJ+lOLr0ZcWtImhfc8dhh4duTcEhIWlXy84L4Lz7QFm
7xfENfRiPJwHhP1VmvlSn329Eg9Idm7TKJ5kc78HhB936939krDF8c+bhL+S
/iwSf/Kc0w1xvJ5w4XSs0GKUH+AJo6ufmfhsRvu3J2Tv6k77jfHALO74vNhc
/zWe7wVjdk3Ds9B+zfSCb8uPW6S9wO/PC0SjuZTmS6A89IbEr6/Wn8R+EDQf
kP2n/Y4p+ud8YNG4+4LmMbSH+8ElK63SntckflnS9ZLg8Bu0x9Jh7+aMpA2P
MT6WDioSPcHbf5dS7PYouP7lNRw/HWZwJxr1/yX+2KcXTTus8Hh/INCbo9/N
1sb6NkGgahTrlHwE5UUQOPoknTcbw/o6QfCq9s65iyhPWN/vZ95Urdl4fkcQ
XIg71JeO8SsTQaBx9abojfVof2dAbdpmpXgOvD4DHifUDkx7XUpxpeOkw8yb
GA/NgAcyp7m/S5VSvCLy4JMDydjvggGmCcPHxvkJe9V0DQliPwMmA9w43Fu/
jBLWFVi0c9CojGI1zp4FvWdRXjFA0o2rp/phKcVRp2v1zDEet54BKc3hR19R
/RUZsHZVgOnnTUQ+TXLTb5TPJLw954f8IUHM52LA5ulv7ldOon05GL6MaY7O
OkE4t3Dq5S3MtxcMhjcbZXf+GiX+hf2v28JVsP8FS96tb74XNoHn04LBtNik
usgA5zMExoQvndTH4/QQgJ+nlec/wPclBH7FFn47W432+hBYfN6Sp+kovg+h
sHjj4IVW7A8nGArlcnqSd/H8/lA4/L1p1vIIzF8Kg57OhpvPklB+h8NXms37
G9Y4H+HQoWIjv0UBrx8Bj+bN9V5RwD4/Ow7eWW2wNqxjc08CGC2uFNr2CP8v
EbL5L49r43zxpsAd80q9unv4+xSoyno1vacT5XsqdEQLTjGxHpNVFrv/IM63
OUufeZ/zMpCdn8NhAd1JZ1pL9rPrt3FYgpTS+t7wR6ifWYKld22DYCfKXxuw
+9nWblmC+oc90NJGtl7gx3wYB1i5/cSxBekYv+UIoV67z/WdIvmZUWff33SK
JP1Yu7Kmfzw9G+NLHOFDRlZg7TKMZ6LBUKTcs+LH6F+mgUTCI25R7K/BpMGV
mzSznVhPmKWvdRncqjWMIfWBbzy5VXTYFP3bTmAq+8s7x4CsDzlvb5U1Y/0Y
FotIucc/PYXyzwm4tnxSOKbPXi9oTnDCXLRfNBXng6XfXXqcGVCI8t0ZPjy2
q3yO8TgsfU6nUTFP2wf7cbqAeESTRivG28q4wqJ+9eXcS7H+niu4yAdpDFD1
gl3hlhj33kE9og9unVYz/8lHEj9rcu43Z+183E+4Qkdv1nXPANS3XCHefbT4
eCPJ9zQ80qKdew/jw9xg1phvUegGtr+a5gbiA19Pm/aVEz7h9TeOQfypNsxz
j2tVyfo4mKcbdQP9/c1uoN987vwx62MUh7e/cO2g8k3dYRN9VI7xBp+/B3S/
Xu82Kxf1O0/YUS1ULNmA/l1PqG6ZygdffH5esNG2SSlvAv3TXuBy4HCa6kH2
+snSL8uNm0rmnsT1zQsW7HfuzNQg/tsn4RV8ji3s81n6ZnfqV/0TyqQeyfvr
ZkvkHEoo/qQdbWWB+b1MH+DNT1a8hvEwJT6w63DmkQdY/421vjm8SzSWECD6
a43MvTl+3Sj//cEw7eF3nWkkvu2Ll6VEcB/qO/5Ae5Qb/HchiVczFVevv+aB
328AWIVK5c/OwvclAORvjqkZU/ENAbDqpXHyaZR3LPb/8p2RcoHEe20687RM
FOsn9AfA7bKnfF1aGM9Bh8K5y7+5HcX9BB0und1TdnYzfp90GHcQKMtcjPsX
OjQ2dyXPoeP1AgEOyI82Yf1mwSB4/WaX5IlIzO8JgvcLFY85ziT+5t5+4Rmf
8jA+jAF3x/35OmxxP8GAkuS341non2etP/Fn/k57Uo35LMEg/uVJxQWsD2Aa
Av2cRePzMZ+4JBz8qsrv8GA/Idb+l7nW23fbc5x/GlxMy8z/eJKwynETJ9uv
OF80mHprufok1ldi6Ys8PWW0Re1lFI8e3TE7jIvE16cfjUz6vbWM4t+XBi+4
WBD2l11xPEDuKMXn9R0Ldy7B78kZFnd9nsWJ/emanaEhKP/uKnxeLHmyt+p3
+0uq/5grjIuKil6adpRi0T9vae8vE/mxVWqhx+bvhOM7In+sNkN55ArzuTWG
X13A78sNOgpqnKfFVlDMU71dxmQz6ScYxHu7eSbGL5a4wdrBUNqoTinFBZGP
T41eKaP4RYfNpy+YH83hDg9zbnV+wn5jLG7/a+DqhP3jWPr1Qxvh6bOwPgdL
n55btfQnBw/+nzvkzjB32qiC+zUP+JG+9+5eBYw394CGLws69TDejqXviqw7
VE8PJPUy/WX5Dqdwkn57RaoRatw43n5fmK07tKoU87+ZflD79r3sHj+s5+0P
SUd/Bz2bi/tffzgrEmZdfAafrz9saDslOv9OAcV+JmrS0fcJ1whNdcphvyYZ
OnBf7rLVCyugOOmPreIFA3K87OUPvQfbcb2ng47nynzeKcx/poNqIsfqblHc
X9Lh68lxUdNr2O8lEFRU/LzdtxdQ/H/fP2G1YsEsZQ1y/ovYjfGHzhVTrCTK
N20P9rOmBQKf9w/RJ1loPwoE7sbvpRfeYj/jICiy5xBag/2hWKzJz8urVYbj
D4LyFa4Ty6Kxv1EQrNR1P125APP7g2Bto8RT27fYjykYil45BRR+xvkLBfVl
w7373mJ99lD4znX6+F3Un5tDwba+UasG67HJhEG+zMNSxyNHKc64pXc2bRnG
L4aDgV6m7yLsn0SLgNh269DPkvj+RsD4l17GpU+kv1TDVOiulfh+MSPh28Zn
1nRR1I+j4Zb0s2nnMP6nIxr4d2woy+TE/ksxIHTibh9DFPcTscA1Z5/npgnU
D+PgZc/129exvulhJqjeDUmegfqfeCJoS4k4e2I8j2cibPrjfpmRiOvDJtgk
JSxe2k78wd8UXYom/NoonjMtdIkxxg8wteE8T/TTh8Ko/+lAyx3L8wUHSX7c
tMPRv20qkfUgUUaMx36wjmJXwfdH6g3Y/bA5DCDK44y5oWsn+/pGICQcse6S
zQmKc+rS0rldCFcxHFqv/Yt7VXQ9fgUQVjcfHTGPJnzg9vPusnjCBTP4F47l
Ef4Ku+oO1BHevJm3J2KA8MiypudLZ5+keHTdCnnHIsKhcQbT8j/UUVw+eSzU
j7+e4o3lhVYh2YT/jEFU/vorFKev6368m/IHbfv/5tMEBPZbJo131VLMU54T
XPuE8BF1jR0fNXC8JrC15cHtwvBaiiVvjgvxHMTzTaH4a5+6kQjWuzaF7mrz
st3TcXymwOc4Y3X/w8sUB96bPfB5IXu8HGZwp+ZD5+LOWopLncSNL+L8szg5
cor31wA73xHM4KyXbx3XZbb9pdkMZmpZdZ/WJ/Z3oRi5lWNUPeKdkHxrsX3P
Zvb70LwTZjbHX5N6doLi1/qXYuOw/jOLP54LOw00zJ/cBS7V1QO+VP3vXXBr
Z+VDqwu4H7AAPqP6pq4jJB+x9MXqxhNYT5vDCni+XFS8Pgv1JStoHZVTaaf6
v1gBLa8u4tMmjAe1gnzrrdO8/j5nszUcvpUjM/kE8/tt4Ll0eazhBIk3XcmX
L7nvMr4/tiD/i2FsZYzjs4OrpvOVjzaQ/igp2qUfUxRxvA7Qkn+KS5CJ9n8a
FLRaJ2cMnaR4yqtB6uQ3zL+nQY2ZmLYK5gey9iP3V7pMVvVjPqEzNBbONE/c
j9d3gcqq10cXLcD8MheQLPOr0irBeig+4JP1Pc/rFOnvYnZJzsYfSD3w9TpW
Cj8nMJ+GBjNz3S1cbpH9lX0FPW3gPLF/e97oquv2JPmHBmOOESuDUV46w81C
tdN82K+m3wUU+nVWvbyN+oUrqER+evqgkOT7hbxV01i2jOxXdN8NcE1gv2UZ
Dwj/qXXI5BnZT6wTMhGeOYb2fQ/YGHrPdEsW5h8GwPvTcveUMf+AxbJv5sWH
CZN8AvGrRzg9T2D8Ox1WHD+lZXIY96+BUOXtlC/US+L3naI07myn4XgDIaat
b0T2B4l359TyCIhWIvHxNw7+1uTXxv6sDBDuFRVe71ZO8RPxDYccsL44nQGZ
ihcDnSOJ/aZoUz3/ZjzewYC3Hz98nGvEvv4EA+rrOpyTsF8ti2+avxa7iPZn
mWCQrjzZbWKD+lEI1P9zuiweD4Xs7Pyntmh/7wgF5mJ542Wv2e+LaRj49rTy
6dJxfxgGBStr7Wc54fyFw9l5Us+63+F6HA4cH9Y+an2A9rAo+GkaqDYP9eHs
aFi9zuVazjDqj9FglXpP4fgprH8dAxPLODLTevF4DFjQti3+ifV0WOsnx+++
rBeY798RC9N/z21bgPZ10ziw+1r1Y7Kd/fuJONDLFg9ztsHjTLDiNmtPEMXr
M4Fhd84nmgv3c0yw/bH36n70B7Qx4U3GB7OSu2hvioecBxVuT8TZ74tnPIhL
vCvmU8R+kQnQtWLxbwHKvpUIHjNSgq774H4wESY3iWw+hvWX6EmwUiBg+XLs
/zuRBGJ7/zYvwXpG2cmQs3+3LZcKe/6XpYLv6rz+dKw32rwbjMKOrOIxw/23
BWzk2rV/45aHlLyzE9Tcse077udt4PXku8F5+sS+k3c3T2mpCX7PdvD19aCH
7jCpF9bBtz2kTvk4xQIPJltdDAhPXxU78y5V/8IehGXH4j+9xf9zgHZJ6WfJ
48T/qG+t82jTxUqKxz9/cPO0J/5Bz5RpM3OykWnAvUD7gd4tfP+cIX9VgY/D
N9wvOMPfd1z+37zJfuqz2qpshxcoj1xg64y7WZNv8XousGvLpABfaznFD0ZN
dfcgs/ZbPZdeNEy8x/2DC9hUT+cxMyqnOGHj++h4M8KntkreSNTA811hnnP8
xxlVuJ9zhbaskyJTW/D/3KDReIXraj3Ml3MHH2N+xS9xlRRnePl2CB9H+eUB
Jdc32CvVl1IsO1CY5StRRnGDao/oQXlSz1XW8ZxtfjDhk1+XrAmqQf+eF5w0
efLzQQ7up7ygL5Zv3wLsD8zii+c25q7dSzjJokFw3j7CdMl3h/IGUf/0gZ88
9D8m+9H+4ANiHZ+eZmG9cxbrqXQ1abZj/ygfEKh5F8GN9U1pviD3KtfiQUYx
xfrxa2X6VNA/5Ad7UxeNmO7B990POp5VtCyWRHupH3DIXdTsDcR6ZP7w/cFs
xbtYL18mADhnP79Ucx2fVwDMelzb+K0T9W86fDAwGNmN8kKQDgrOYzovl+H4
6DDyImKJxUq0TwfC9/caVwsPYX2zQFC2kwu84F9C8c8J93cP/Mn+pzRZv5Lj
bCHFy97JL5Kfj+P3h1AD9VNvZCqo42dWlEbw/sJ6HEEQ05ARKHaD+BOjfjyQ
v+2D6wsDKmfua6nBeoT9DCiWefRW3gX9c8GwJe7Fppc5uF8Jhh45kz/7XVF+
BsOSw+NFD7F/vHIIXDp2X5qO8fGmIRCpNfXiKtarpYeAUE5E2We0B9aHAr0h
76qEx1GK3zb3enUvx/U2DGhV9F/r7qE+EA6H+Yo4cnB/ZBoBf0eWnfHuQ/kf
CauuPn885zPa8yNha5134V4XXG8iwe5901jKNFwPIyFJQkHlQDHaYyNh4hAt
wRXtMROR0Gby3O8M1keGKBizkxa8pYnvaxSs4eKYZnQL34doKJN/6l8zjvb8
aHCULd8bgvVvWOvR2eEeM57NKM/jYGjAonytEjITCtrv3C/DfrOeTBjc6HPQ
JI59/4LxENDZPGv1GvZ4reJhrh1c/zaO71s8LNx7IGDsM64P8RDx+IIVzzdc
/+LhY7KeFLXejcVDzT/h/mVspifA715ZHktu9vXTEuCzwf7LPh/RH5IA0qWV
rqPYD6otAfZOehxtbUX/RgLYdh1lShfg+pkIDMX2woVV7OtbJcGrTYXNwTbs
4z1JIJku2fEzF/vnJoHTywVXPtqwv4/wFLAesxnZcBLlQQowXy6OPPKb8FSZ
SJ+oMfY3S4HobTK/vm3Efr27YfVq1clU7G9emw3Lxc5VbpmGz8sF5DOkitQo
+6ALqFctlB5E/yvTFfa+DbY5qMruV1TiBoobuGX3Y/49zR0G/jFHVmO+mgeU
dlrkjWaj/cATOr2aftxtwvobXpAsIdu8DfWlEm+YZf/Ouz4c91++IBT3s1tP
GN8XP5ge+uyqpQSuD3So8L6nJupA7KU7+nx3mO9j7z+zGaDCv85V0RPlMwNM
M/deX/gK5UkIWC2w6efcSPxZYkWh0eWoXymHwobggnehKL+yQyGm02R/MDJH
GOx8e0nBC7k+DArvXv8hbYLvZzg7nx3jDyKgaIm96qQ7yucIUFj4+LypHX7/
rOP3huDMT6xfFAHazSprN/Di/0XC/jNrJP2oegyR8K5V9OVj7KcBkdCUkOK0
5nURxcol1nxKDsUU329KnTt4CtefSJj9cp/FonTS72Pmr+anT4ZKKf54TiQt
Ge2fEAOHyo5XPMV8oeYYGN1/+rBkHuqnsQD7Xl5qwnpOynGwOqCphwf9deJM
qLlR0eqrx2YDJlzp8Ot8nY793piQksj4xf3iCMXSCg/O1Kwsp77PTytUFGbc
x3ymBAirUji0IYX9e88EGDNO1Xdg4HqXAJWFINtIZ5+/PhlW6Ap7xw6y1w+D
ZPhfucQ+7B+dDKdy3hwML8D6z8nQZXjuYqEQ7idSYbGmu8Ux/D34gLDevXkM
I7Tf+8JjR7/cOerlFL8xz/ociPsHZhCIjWSLOqJ9jfU+LuXOuVaA8gyCwUo7
oGcn9pfhCIFZi9ppff9aT+7qdh9fmUz2GxVjS2VE/5ZSPDtm+uN1Yiifw0Dh
YrzurEb8PsPgt2ORS2QpyvMw2Ph0/8AXLrQnh8PG1Q78BlT9+3BIOjVxiY/q
fx4Of7/v4ncMx+8xHCSSpvuMPEP7cgRE/RU7N30avg+RMGKklj/pRFisNKS/
dyWOJxJKxxUF+HH8ptHQudBAy9UE92sx8KRYKXEH6svMWPiRWO0uiPPD4vVr
dPPWnmLPB2u/Mp64JP/lSCnFqlca3Cex/yU9DpbpT37zRf9BfRyE06+57BYv
p1iR77fuNnk2hzNhz/jlrW892ONJY8IJEd3HB7vx+4iHE3OXuDBeEg5sH8ww
W80+3yAB9LbtXhIpgfEYCfCM67JouBhhFYuj9BJcv0wTIXoyuGJaOa4PiaC0
6vx+/S6MB0iEC+5PlQ+uYB9fnwTSOSfo15/g/SXBnVW99a/F8ffJEFrpyiuB
55vuhpNmPLSS73g/GVAwsqBiDNfjjgyIOlWe79SE/5cBApsTQ6Ui2Lw+E160
nteb7Yr6xV6Yuy/C0wDr0bP04frQzz1X0R7T7w3SiklmMphvx8HSRzfFikiu
xPfTDxJlIlXEt+Hv/aEz6oC21jGib2ZHtayobUP9LgBm/i1SWpbH/t4m6BD3
96+zwiViX/ixVJdTU76C4t+qf69KYT8W5UC4rD7JTEhEfT8Q5lvLDjsx2d9z
cyBcNews8VyI8jYIYkeDem3icbxB8CPHRdP5Hcpvlv6Y9dTrSR/WdwuCc/st
zo17Y/21IKA9Fa27jvVjgAHbF9K+e5iS759eVpf4XZgt7zoY0DzI5Mxdgetl
MDz/s9rHZxPK72BoMFDMLLUppDjUapMp5zfCcrVz3zRS8j8Ypm168f4P9vNh
6a8ZGTeYv7rZ8rI/GGwH2m4PXyqg5Eu/9nWe+Trs8bD01ReT82EaP1kfYxQW
c8Xb4nyHgnFnQHi5P/Y/CAWXodCIJKznoBwGz9wU0sM9cHxhYGp8f05KMPoL
wiDf95ORAXU/4RAs4RUwNxff13AwXGIfMk89j+Km9LNZEb9QvofDhuPfNoYp
5VGsdiV99Bb2N2mOAN8Dm11MOjC+IwoW9u7YYSqN/USj4ZS+3tm3O9j192mx
UJZzRf2jAPbrjIfKgF+/ZfLZnB0P7UXznDc/zmE/v3hw2d52VnM91vs1h3Dx
ZS626Rg/bAESihnhpQE1FK+uoFd9KCVcZfrHezgbz7cETZ6Di11LutlsBZ9P
xz/wfkHsqby3jHf/nEJ7ni107YwI8fuM8Wt20O0TaWpKxY/YwYKLD0/2FaO/
zg4s1mU8HqcT3h0htXSaFumneOUr94y+p8Teqi5sYnwmkHBm/sGv4w9x/PZQ
Pfz9rtMTUt91yaf5qzLe4fhoEKC9nGFxHuNzaXBv7ZD9748VFJ8YPBAmJoP2
CxosUC7Q7qP6ydOA2yIh8SbeL9MJVlROP8OL55c4QbT+NPk8rHfV7ARiSg22
s+MJ2zXapFthP3umMxj8WXhj9BRhtf81tCT1X5d8qWsSpeKpnWEWR3NYE/Zr
7HcGk4oK83kHSX1Y79yynY51hHn+uBp97if2kbmXOPRCP2A9LlfYJaMUpStE
7LOenJUWC7A/oIwbnLsZ8FpKEeMr3KCEodowraiK4vGCZ0d6baopPice+j1p
Xi3F4cPSss9U2fUVmCy++PkG4xzKYzfwMN8wJ+h+BcXqt1aW3z1D7CWBB+9l
n2xB+5MnHHa0rvFH+w/NC25Pu5S/yQ3tUX4g8Zxxet0x/L09SHofvkPH+rHg
BHt/PlvsFVhFPS+H5acZ8nUkXlj02l+L0y5Yj5IOHsU6EwoqbHlgSodtUl9H
Z1/G/iR0sG3sbfk1O4/iAWEPKXNhwvwefjPr/sVDIysa2iUIc2xIj9KTJLx0
5heTfVdRHgWCwReJ97oZWK+GAZu+vr/tuRv7gzAgY72EIg8QeZ1rpHlIbi72
Xw6GY8ceehZg/xqW/OV6tN9314rDlPxM0jc/n+7Nvt5ECNR+T0lrckJ5Ewpu
4VxcO2QOUfLUQVVVSM4I/emhMIP/+qqlX9D+EQaBqwQG4zblUby9/ubeE5qE
rxRv1GjdQrjbJltkFfZf7giDsdmFPWPYn48lX3drz+42C8L+JhFQdYGWt80E
/esRUDh/3/frq9nHWfuXHftv0dsMCOe1RVyebo79UiLhbIvlmJYhys9IuBF2
k2MLH3t9Yu0/vrgFiiul4/xEgnQ1h9HMV4SNdTbqKg0T1n7sesQOnyczCpgy
XlzNlth/Jga+TXlH1Dw4QHFD/Em7z52E3z1YI+Zfx57fiRjY0fX8kCTOF0cc
VEfNvOj8FvvxsPYnZq+VZsuzx8/cBteuJc5auJVdfxQsoIUzoEGTm/Q3uy/w
0ZD7X/3KrF7oXajXI/kjMZcfuWYqo//OAa60T+3Y0k/6t4YdCrI9if3nWfJp
q+OiJ3tnoT3ZBQZuXdvQdgfjsd1heOe5P9sYKB/dYdS6fEiZwfYvlniBeOqK
7TveYf1Cbwjb/NSGuRrlrw+8Dwx+kLce4/l94f5f08dVh0g8h9j7XX5fy9nX
Z+2/g/4p/7cL7V9+kN0TZKmbivLRD/7XblSG/X8l/nCjV+xpawr7/wTpcLT/
w/prc7C/Ix1eeDM+LK7D74kOs8cvn5y3+CjFm7aKGH3xJbwuae7hZ7mEla+H
Gaq/RXs/Hd4e5mdtqVH+BILqvu1rIn8WUry5foHPHU3UV1j6n9B3qymMR8gO
hObb4ZlPsd+GKQOuPZE48vMG6scMOCR0Zu9aPpRPweCq5WR6/CFePxRMBF+H
7FdBfSUUKtcr3dHBeBfW96tgI/KQD+PRTMMg2L9yR84k2Q8vOiCzYi72M2Xp
F1cyci9sdEF7WAL4r569rqibPb62BDC4sKTQ1IM9n+KJYJMkI3BQBPXbJNCc
+iKkncGe//AkeHVnk7uDKL5P22DNMdPAMBV2Pc3mHZA3csfhyhzS3yeriUcn
XICwSVJZQ40I4SHtey0KaG9lmsPUufhGsemoT1jAy+2+Js+o+rQWwF+nl3pI
iPQr3GpUu6MA1x/W99N80tNnxX7S/2V2uUDKA0HyfcVllfCKhOH/28GU4smQ
R5g/w9JPEs+N9GScRnuFA0Tq9qyeuwCvR4ONidt2MjG+ncV36h53eS5DfzkN
tA9yCceJkPi1/jMzb2ZjfRgOJ3hz82uulg3GI7jAn7u9o6vx/H4XmPdIVeaD
MM6HK2TFvOnyxfh9Fi+n9bz/OoL2AE8oOmU66oTxA6zvdT/nbZ0fkaQe4XDh
waXLhVFe+ILpZLS6VTmp97lgyvpTHtqTaf5Qu1K3xB73n6z1k2P9+pmZaK9m
cb6anJjPQ4zXjYIZM482Tcf+thPRYJz7oe+lPtqzYoDGKSlRJoT7n1hwOlly
Q5sX45vi4MQjL+nFqbhfiIMine6s7CHsz8oEI+kZq562sI97MmHGXItF7w+T
fqRNWv8IdMIWV98e3Lce/TOJIHNJb3NRCu73Aeb1fdWcuttKcU3Y+QWSFpg/
qwMPPoYulxQk8TeLgjvkpKb62KwHkX1HFl2bJPE3nJ01kz1ThHvMxks/ctZT
rJ389GJ6FObH6IPMFc5UbvFmig3O5u2KdUE2gBj/fYbMCLRfGsCGs3u4+qfu
sNkIlp9qPxa6h8TLvKg65SO+j3DOtriXKeWEZfZF6xf9JPE0GkPP5sz7RVhK
MNpDQIDE0yw8IrfHfiHhAjfaqs8ehBN9au+dYBA+wTQ6eXM+xh9tA7ka2Reu
u/B+tsPSNMvhJIxPZnGZ4FXvWMdTFPOJ8Gt3WWG/ClOw1/V47oTzyeLa+So1
DvPZ8TVMU9Dm1D+0LvUqxUd4UxOXBzRTPDFbQdSVjvLCFLxttfZ9s8L4HDPQ
E1LfdWUlxkubgYKU8/qTp+oovm0XPHvP+1MUL1i+s6Fcid3vgGkJ8zsPtUvd
w+tZQ5hnRP5R6n2wZ+2PltWo8jZT8kNT8d7yIu5G9vfiAe9Yb6cqfo9MBvAk
R+l2XMN4GWvQqDpauj3nGMWv1o1dvYncbAv7xzjfCNxEeWAP9TvH11r8RfuI
AyxdOJw/kI72NRr4SddHPsX6+6z90GDkHZmVSXh9J9ht7yjyCOsF05xAqrBl
+fcV5RQLTFvDG6WI8sYJevkiH61tIv7dlEsGz7u5SPx9Cd3cvh7ziVgs93Zf
Quxccvz8mZ6vS9D+zNrfKL9PcJiF9iIOV1hifCbnsxmuP67waPY1pd+uqG+w
9hsfzzAnsR8Ca/9h/pi+tgX7b7P0mZM2pU65WF+S6QFq9l8uvjlO+ktUbJBP
TN9C9I//mR/kiD9zrHha4CqMR6cFAKNWa/t2zE+hsfYDcxJWKGL8J2u9H123
bY3BtWJqvbb5+vObnQ7q16HgN5WfkCaK+4VQiBoaSfHVIvaLtVmB47qJGG8Z
BoK/r9kbrkF7QBh4XH5yolGZrW9yhINBwel3temo70fA2+dmZ0EJ802Y4Or1
kZHVn0sxhGg1hsofoPiukK2hri32+2HCKd+bCW+lyf5k94wNyvz5+LwYYH9D
TX+GPq6fIaz9xdA3z99YPzQEar7ZP+jD+E7W/c549/JPv28Zxf+pl1ofCmHi
96vGMD8LwqEpQytwLvonO8KhUbp7Me0cPt9wMPo0eeaeJPv6yhFgepH5VI0X
rx8BQRwRKc89cLwR4Cu+CuZhfCdLv5/Fb/3yjTr626LhkMcj13a0F9LiYMEP
rRXeArg+xMGPNxdlr6zB8+NgROfer8dV+L7EwYpXcz0/3WQfX8YEbdNri2XR
/85ivsAmP1/Uf1nsMHm7vA3zFSuZwPu7bnQ5xov8YEL4tZ7ln1+xz+eNBy0O
x+b4OPx+42HfSs8T1ej/50iAeQEz3VJWo704Abq7NWefSCP+xLsXDu9Vx3zQ
sQSYMLxn9RTHx+LKW+f4129FfTcBUuxXPsvGfNS0RHgpxql/Hv0rzYmgXr6M
01kV86MS4YjFwLQVlbjeJ4IW/7mZveiPr0yCwRb57gtz8HgycOo9rHQTRP9S
KMzjP5K1dRbKh1DYJFjQbHsZn1c4cH9dybiI8ob1/HlOPvVYpIP+vQio/dXt
UN/M3q9xRIJ13IEs8VTMZ40E/Uf+X1SkD1PP37J+osxvBtono+G1YXjr6OBh
iocPahzXwv1+STS0HjB4of0c968xEF5qscTzBu5fY+A5n9LPXXm4/46BZMba
0249uRRzwsWYn33s7+sff4G2f13+IvbxkjjonroaGhTL/h7FmdB80PJk4/1c
ipd381uWzztAvT+mXjVKRYnY7531vvEU9zJ+s+2HpgnwJUWq+6Av+m8T4NAj
P8/tqezzKxNg38KPHxVG2eefTwA5vaLpJkZsrkyEIdfKmsaXbKYnwaoFO7Lb
+AnzXZPXNhdis3IKO/8e40dSYHRHf1b+633s8aZCy1yemIqHbLZKheO3GZJf
d7C5JBUi3/2aN9eQzZWp4PK17GF4DJuV00CxcGTe2hI2M9NgdM644PfNbDbY
B00joTVX5LC/iDusmbU+2KAc/VleoCLXNWO9DeYzeEPIxZJow2jU733gz63u
nhmFuL74wpc4KyYHxnuzeG4Mf/aWLxi/4QtL1l/fchT1Rxbv47b7JXSQcKx4
a4IH5nvS/CBBqVFrTivKE384vTrktNIakg8/eiN+RiKD+CduCv3V49PF9zsA
vlvc9lXLxuN0aBpdfGQz1gNupsPKB+W3C/NKKJbc5HY4lQ/jI+hgQxd1Mr2F
8SGBMH2qTn0Z+peUg+BL2fnnL9Tw/oPAmONx9WJPzA9nwGe1fRcl9Ej+67PR
HT1SO0ooPuv06raxFcqfYJhjNeJThP6F5mAIbHQ4HZJHWKFeQufEUvw+g6FZ
deXn7e+KKGY0NZ+5hjwRDMEKPz42Y3++khAoVeyr8MR+0oKhoMKjtaUG4xlY
623vzwHe9okj1PqyaOuZhUc0UR8Kg60m12O4htnHlRPg1UCJitm/+pHvTK9a
q4z9oJpdIG8e96aC+SQ/x/xAlvoB9B+zOHTVDkMJA8JeHq88/FwJv719MfVI
JmHujN+6r39i/J4bKPMZSK0yJNxvZO4w/yrac93h8VaOptnoX2Jxm4mlmuAQ
3o8n7G7MPJqB/Sc4vCAy7U7dmVbcb/rBnw7TewIH0T/vD3VXTPZuQ3nLDICn
ctWN3OdKKM6V6bA83E24+vG8japL8PnTwZp/t1b8Z5Ivdv5XPWO2UAnFXzMb
g01Po7xnwOJyY+tQiyPU8+QqS987uxbjYUKAd1qRdeMI+rtCYLxI+EQZrYTi
tiW6IUZYv3QiBGb+Kr77/lo59fyrljzfM+hO8k0cxJ4uP4XxMs3hcOPPL97Z
c0h+yVmrpRfp2H+dHgEmnS3N7diPFWJg60UNRiH6g1j6cP9yeQ8BM7SHO0Pd
xy/HhCZrKBYfXJXmZYv7EWdwdSpVd6xG+5YzZBjEfX0aw7bXybhAmYdp8/lt
5P1a9Cto+r5UwlvXzBG9k0fyUbuifK8L+GD8uiu414vsrQ1H/4IrzMvXUFW7
VUHxpxt/Hf0YJN5x/8WTVRprSf+Vta93SjIeVFA8qzxyUSfGc5a4gfyEhtDw
NdKPJXHRMPctzLdjsdJoJk/fErQnuMOWh3EjvbtJf7fIyOgTc19VUjwuaOMt
nof9SDz+e/80DxgWsQwO8Cf93/4z/n4PcJi4Fy6B/gXW+x5s9Zqn5xLaRzyB
KS2tOUUn8ZK6o9uFFb6hf8EPVhTIpIrokXjysoOG8deFUV8NglT5zYfvYPyk
aRB0vez4YIH5vExbCHnZqlgoQ/xZ1wzlX+dYoX2SBt8/7XrD3VZFzXe/cJqC
5loy/14jer9pGC/a7Ao/AoXV/WwxftQNxFrnzO2Kxvtzh1sPtksPeeH+hjWf
Bhymy86j/80D7kX93R/jSOZr8LaikawDYbmAKvFF80l/mSVpaY//7KiguH+4
R3nSHO1JAfD2itHzrXYY/06HaWPLxud5kfkSpAu2np6N80uHrZNRH7KxnlBH
CISV/vT+GoT+ukh4zWdr9QLfD95kuJCgKsFXxz7fKhmev/+noDab6cmw//zG
5QXoHwlPhi+Fmtv4sT9zRzI43euwFClmH+9JBmHlLx7X07FfWgrQum72PEjE
9TwFdNfr3a0+gtdPhTOTlbuu2xNuVNX9RcN+LW2pEGthOft5BJtZ+kacXoq/
Ndbf51gHYdljdaXDpB5sw8PcH+uuYz0xgAjBbXGggvWvABQyV85QX3af4gxp
CSeQw/ptOlCuOOYcvo/Yk+Lax599yL9JsZDdN7UXD0m9s89yfIP2rqRe5X3X
ccGzR59TrLqpVl7zBKkXli4+31HmPdY/M4Cziee0cmLZ+WRMI/j9vf/s1vnY
H9wU0g2Nv+pMYH6LKZhxX5K+2nGK4paHxVue1Dxjn28G+kdEtL4zsR/bTlB/
ENM7+YbUy6+8dDF6+zhhZXrgxofTaiheP/DT/1c8yUey5112vQLzu2AXzA42
uGnTjfYbC3Y9Vsx3sgbZUdEFGpuI//TQebdP+7E/CIt/lVg+tNYj9tJOzoxV
ai7EXnBcsE1uzya2vYfmCb+iR621LuJ66gUVDo28mV9JvL7odI11A1I4Hw6g
GH7+4gcb7I/qDNJcz+/oZKH9ygVEi+z7pm8l+TN3/USaDmC/FBZvea5dWudN
jptYPrMIPE24OWpL1kwVrNfvBtbP7ty6mUjy+S+o6D16uJDUh1I7IzvitaKS
4tdtjrlxaL9i6bsT6dP2iGC8MkvfPXt4W2dAOH7PvrB9C8e6DDH2fLL0xRaH
x2Jze9nj7QiEqOPC/fJe6I9mwJqu+97ySeivD4aomaU3jRpqKXkwFDNd+eNu
XI9CYcVgtEbpA/Zxlj6WlBaY3sGB/vhQGHANDQxtZR83DQO+w25fDJZhP41w
6PFbGh3twpZ/phHgMfjZ9FcumwWjwWp97YJE7CfP4k633OdnFiEngG1UbKF1
/zGKv8dGFnG1sOfLdx+73y7pR79jNJJ+ivL324N6R/Lu9xlHKY7RmDH1GvUv
1vP6OHVjzILKj3eDeRItT+Yq4vvoBrXXD1UrY/8omg+YSVs132kpprgz04Ee
+Rj1DT+4f1JdAO4fpbiiRjZiQx6Jj2/X2TgwQwHtcYFAEx7Uf66N+4VAsOdm
yKv+LaH40pPCjB60/zUHgnVbT3/dXqK/CbRve/wK+40CAw7ub1jyR5nk+wu4
BJzNDsd4JgbEqiSp2P3C+GMG+K2q8f89m8QX5SXdtlv9EffXweDt/tla8gHp
hylnOLrKhBfHGwwre2PruqvZ53OEwOjQdL45OUS/3zEqpv9NHPc/YbC5dp13
8mv2+fQo2Lly41Lvpezz01JAPfUYbe67IxTn0jcoxuN+hWkGoR/bvPIs2P2d
m83g+94xoXslFRQf/tQ6XuFTTbHDyfrjnWtJvcG2g+mrm6sJt64U8Djfj/E2
O4Dxs4D7pxv2Y2a9T9ODVnkXdrHZHvZpBdlOvKim2J0jzuUAxts0O4GsbYeN
uTTRLzkSeOAS5tew9McBTet2FexfyuLnN9w7d75AeeUCFTcVPnzJRf+SG1wP
897SdZ7EZ5Rds9PanYzyxh2unl2jyof94ZkeINjR80mujnD1w3sCqu74/nlC
1Xt68jWqHpYnTLi+iEhlYryGH4T3NK9MH8L3LQDULPe3XdyL4w+Ei71f1pr0
4PccDBExWu4t6Xg8BE6fTTrSi/VbZEKh0H9KaRT7Q3REQOOAe8VjtD82+8CV
E3dtNwahvhnD7veM9qNYECvrP5uF9eKyY4F7nPuTJ8Zz9cfCqWXzZCXR3izD
hFdfrmtn2pJ8M99bv1/wAZut4sH10QauXZhPQ4uHw5tCxMZj8HuLh/NvF320
FyR8yUCT85oI5qckwKH+fDteQ7QXJsDoYb2Mfg22PFifAFojn6X55+N+NAF+
Pzl1ZfOJYoqVrry7dcke7WsJkKwbVji0uZjicIh9ft6b8I1H8w1fLsf6cAnw
5s+FeDfMT+pPgIcla4diZxVTbDh+fkokGMeXCLHDWpHpUmhPTgSPbT9vTkzD
/VMizF1mNuyN+T6VidB/dsKpYJL9PZ5PZ/dDQHuHOywtiPx2teNf+1cFy07T
P4TlxhoUV9qXUzyb9mtKWxf1u0CYzdlmZ0vH5xcI3otnpnm3sr/37CB4+fF6
bvoVNgsy4P1MyW3y88n+syK322hsFfrrw+G4377xVm6MFw+HmLEbol5xGD/E
Wm8M9mXyLGKfDxEwOaL0/K0y5n9EwJwak/Jre3A+IkGL9/919eXxVLXf24hK
haJQKUMZKpUoDaglUyRjyTzP4zFP4RgiDZIilRAhkbFSGYuECtEgJKEkCk2a
5D3P8ztr38/3/fP67HP23vfe+17zulb73HNdzPWXhMJf+pzZC3emUdhX6+/G
CWq+xCEQa11ZX/PjHIXvXb7ZW5aL9ZWHwO9HdUl+KdYDhcF1nQdrzDIJHvF5
PrLNAd9fGMSuyEl5jvWQE3TYuShkbMVqZvxxTySc3/N2+sNW5v8Z9vWitVGa
ChFYv34END8kvpruwnp5B4hJHOgYxvlADP/hb+jNjUKv0T52A7mUNxKQifrC
DZ57PJUzwPg9iyekqeQY6iI/KHhC2N7jefw/SH7Z6Nu+b7UV6B95wgr9lu2j
soQPcvRV1NJFKM+svaBKe+Cd3Goyjy1t44UcTjrRjzdvuRXt2oD+K0NfpkV2
liNfSb8XDMgMaFuoYPyABk0na1zfxGM+gQbTHWMPB0NIfvvB84qqOdiPa02D
X/ViTdtTsyistFpUfjqcHD/d87dIFuV1CQ1cRs2lHiJfH3hD3j7XrCKs59fz
hsDqABsD3I8M/H1Wlt5QNMbrfMBV9Oem6BjCd7fryrHFLfcwP+YEu+uPGQ7L
EP7BGrs/qxcoob/vDKwrXXea3cf4uTMUn9xSZyyaTeEvX2QfsaK/x7AX3y+f
P+KnmUXhX1MTZ3sRW7uCiNB0sH11JoV1QmJ2OQ8QzH6pgWUM6xP6XSFFeeqV
2Qa0L9zh+DHhHV5rSLxV+A3P+VvYz5bpCVXzDX4cvkPiVbFyudO2P0h/39bE
saU9raReurMwtyUU18fY77k3joakYv9Muy+U1X3VlMH529Z+0PZrXEgc+6v6
/cA3+hL3ul4Sj+o7Hsn7ORr3cyAsO5jyYGULypcgAMnx/Gp25vWaIkH86eAa
b4wv0h1A1LSp2Cac7I/JU32RezHfycB2Y43lZcsI/mnWfoM7CeN/brA//tyy
r8OEn/F9riu3AfIz0t1B6jaHCvtttJ89QOWTwsjkdvR3POGKdugZM6z3Z2Aj
w6PsE1n4PrwgZsuwSgPas3QaxOaXXtuM9UATNOhTjhd7d7SA+h5N8tRr39/K
prCWw2xW+yL0F7whf9sepyEhtGd8oOZbw/AC7DdjfK/Rf1l81aeIfcnTIftc
UgexP1iFXnEw6Mf94A8vNsidyKL6+YPhPleRFz/2O0MosDeG72q5h/IxHPiX
e7Ht5GDeX1AM6NiZCs+cx/i1HRzNKTfhb8Lvyx7E9K/6Nz8j/mDvfG5JAeSD
ZLw/q4fFPPTP2K/iCLOfzAj4DaP/5AiPt+8MvboM/TknSDEz5YoPJfnlP7dP
aVzF/nEGdostnrdRiPCHntd8dP7bDcKXJLbxzJuyEfy/M1wUdYQ5efj9uMDg
hYrfjoWEr9fRQSgjMwLjm65Qs91/T98UygMPGHqlmzwX+eVEPOBCnIW4C8an
GfLW76xkzKOLGB/yhG2LVo4MLsDreYFsRvS5Q09JfIhfMf2nJvLNsdCg29JR
bgDjKQz5tvm2qXA1yj+GvX+ItkDBTYHws+5bI9fqN5JFPT+7pZ5s7NifyMDe
0qH7v3oS/IdNoIKP4uN1BoOUnMalyC9a5wJ7Q3z5FmL/J0M+SUyxuoRi/z+4
wrx/Ce/TKZzXwSU0QvUfuYF2z4NVy6n6AjewMvl4tAj5g/vd4GXMJ++1yEfK
kFcivYZSd59kUri94YEL/TbaZ+6gyRZ5/Ego/t4DjDTthe1N8Hl7AGvQrZ5p
5ONi7MdXfEJqvhP4/XuB9EWZV78xn8TAv9VPuJsZkPi8QbPWq9cfsN+JBnvV
dnjWyKK+8oXnXz+s34j1g3VGsIh7jmFfKjP+I+IC6bxu2oM+GF90hd91bEb8
6Wgvu0J38OZtNdfJfOlbl58ZcSH/MriBciJPlUEY6lM3COphLUphxe/XA3K3
axxs6if6XjeAN1n+A8Gf12qd+KmD5/MEiwKhvjTkM2Q8Dz3rolnj0wQX9Pwz
gBvjcTRwdrT8tkIX6ydpcOLWa3Eb5M9lyC+RcEi9J4L3RwPtpQJJVXNJfuz1
Ekf1IZwf2k+D5hO52aXo3zL8kS/VvEdzsD6T4U/LON1c95XKL/hA3oFzrV+w
344lBC7dTtw1043vB4B3k3jSewes51KBhs8XdZz3kPjemoDN3N8qCV9Tzs8a
Pm7B50ysDkOnrfQmLDE+pwGsLcky8S54XBPmTYkHNEkx6ynpWiBhkVD2cgzj
TXtBOnZ2dVIt8hvtg3MeFiJTg4h14FHQRY4jwhjv04Wdm5V8blgx45MsBrAy
pWpiuyPzOBjAxxV320pmMB5nDCb+iTf9rXHepSk4C/x5KOX/H74cpVwRDhrm
N6zhwaVwgZuOWD9lDQqcO87QhbA/1xquzZt+I+pWTD3fq4pjew9Koz3vA6HD
knOCke+RHgid4ont6UPnqPd1QUTarOMT6nNfaOJaduDNWsx3+8E7z9dVF9De
Z/GHuh28xq0YP9ALAMv+D8MfliEOgu9GJW1nYtA/OARaFzT089E+KAkDkUTD
E3e34vXCIevajeq/mcz7EaTDt0iOQmlFrAePhO71n+ljT1MpHKRbHuL4mLk/
Gf5jX4GRxB8DZv0Owz+sT5VfLF6TQuHww/yrzHkxfxkJ2g1LH3KNMP9/KxI2
q+t0io8y898sRyB+4T8Nc0z7PugI7NhwR/KZFdP+P3IELJeuS3PVOU/t9/TF
oVkt15nyP9EX+tbu/HpahNhDzqOsXsaHmetl+EvfdOprRStIfu7k4Tbfs9gf
XBcAG9X3xVuKZ1D4ZtfG9rQk7C8LBOPJnf6aUvj8gmDHP+oqkPhXe3W+hV3w
If3LWWuWjVegPzoRDMqGDq0jzgTbK/8VH/0P1lx0iF5YTPBEYuiKt9hvVxcC
zYKSLwI/M4+LREDNhQOKkYgT6RBRNMHFifWn/XTIsZ+xWI7+LcN/mmm9/kih
FP/vCA8uh4VOKOVS+IqD76eXw8j35AhKv+nfX1Zg/MYJvvTEbNdcgHxPzjBr
Zd8ZTzGi3yUWhv++eJ7MX++7kJx9sx71txucnbQ7qhxM5pNrfJv7+6wI8t96
gUdwlJ7IEJkH/cu8ffz2csyf0KDBrzFtgRz6bzS4NdA8X3E75se84dP+kSoW
5GtiYHmYHZ7ymoknGPJRPY1dvBLjyz7gIrc4tQXj1Qx/e12rVFPyBeQb9AWP
etfVE6uxPt8fvg5kaxo4oX7ZD9dN9Hz39TLrV+EA3C3mGrN7iPGvAzDadSP0
LtWvYATn87dzf+copPC57P7j3LMJbkp48fj5fJRXJlBfMiYgIVtAYfqHhqO1
SS+Z5zcDZZV3TgHId8XAqtsGMsc3Ezx37uVHwvIYf7eAi19e7C8YQXlmAUXs
pp3C3Jg/sIcDl+lVNC18v/bglaAltMuf5Ge5tW4HDoXg+jxg5/OYC2tYmMdp
3rA2+tlKAX0Sb6xvW2006oLxSSv42q6zLZLik7WGid6+gQxRwjfmovao0ygI
8yE2sEApmq3RAeu/bWFsb4/9TyuSjy70v2vf+Rr7PeygMddv81Y/0l/2oH7q
WVwl3q8dJP7cuTr5OJOf4R8+sNBbzpNT+L3ag73wg+hRE4KP5Kvzbhok+WbX
rEX2ozdJvvi6/CIJU2nM/7pBSWfUd08hzPd6gYBY+4alGP/Q84Gb1VUxcicw
Pr4NnJKmU0Mxv8XAK6euPY8/9onC/0wjOJdC5n9FBYfP+ZaNWAnKTs9/vaBp
gMI7qy7KGedhvg1A69zT9tkibykcEpm9we4MzqdRhtd0hW8f41G/qkLWmYWF
VwUQq8HVrE4dqYwBCh/sbZ7c/595Q9clHrnSnoxS+n6yrVTqVD4e14TrrF30
uThPiKHvzb7sHMmoRLwXaCLN+uLjAxQOOf750UMbzP9ZwDK7codJTaZ8ACs4
nfB4hMuAmT9jsQH3w2/m3c9n1i+DDfjU5oaa3SLfT8HfVoGp7wQv/fVxQZtY
IfV+RbeVLd+bRPL77eVVwv4qJP9/vaOvdjqfYP078trLC7B/xgm05zefXLoa
69GdQPLWrusDFhiPdgaNzs3RhrhfMl1hBZvzwu84n4eBW2d38nia4ffpCn+q
EguGclC+ucE57VOGuZaYzzSBo2uuvmkrQvvQDCo3bZmACfS3Lf73ON0GjtZf
al+yFOWHLZQ2p1S5I5+NNQMvn+gyRP4VBlaWs0q8U4P2vS1oNB91WJWD9qQd
VM69WTNbm6nP++1BfsM/FbaY/3SAP549vrTlOdT63Yppxgqz0b70hD8abfe6
RIl/PGh5Sj1rFfrXgaBGL7t2EucTMPRruGLZ3R6c38HQhwrPWj+lIh89ixy0
358Qswgj+0VgtdilDo8BCseZW3VLHBumsMHX5ZGdRiT/Lbg03l9XBfeTIqT3
5tT/nIfzyJTgDcfN8e84r5CBrXOTct8JkOMPflWlCl3DeX+74frriHbhCOb1
6Ltho2CF9B09Mk9SebDz2vt+vD9VkO37XfeLml+rBmphSQruWZh/3wNB7nf2
m4ngft4Hj+jcOhnbmBj0wMf8UN1nI+Z+YfgvxWfmtU1gP1y/B0hPLxU03kv6
Sd3TLS4OY750oTf8+DyiM2sP8kF5Q8ccjhjTP+gPe8OjlZ2Z8Zj/o/vAuI/h
bzOct1PiA6Y3xkP+fiJ8UWk2z96J2OP+8AUHTafp21cx/+kLYuzT7/eM4fv3
g9kcC9lH+gjuMkvUeYn6kmG/if3rUKM/Hgxdw6EHdY5jPVEUqKoY7FN2QP/e
BN4q+YZ+ymfKB7oZBGpWr9ohz9zvDHt+31z1LzuwHoixHz7cOCDy9iPRF1Z7
2cobcb4SA3ueFBTKHybY5/HXsL9phO+aJerdpo7LZH7SlzBJIZm/KE8cwONO
8WK+tyQekxIZIco/ReIH/axySz1e4v51grtK7v6hyJfe7wSrTZ7IND7B+KUn
rNuzLLgQ8zkiPqB8Zcb1lTCeTwNc+etlKqOY/Kt1htDt+CN+4CVTfrAYAbuv
bplMBpOvtc4UuKYOlnDCFQpvzTyesFWB5PPs3mmvHpgi8jeFZ7t9Zk0ehUfL
OqJnHyP96dKFsUeTFpD5N9qnj4cG7if96D51RRK6qF8Z+veEuP7Tnffyqefx
f/N1sF/EGdbf3pN/sYHwayq4LTuySgD9aR9YmDSkNFWO8RAVUDJVDjK5xeyf
YdGAVv6FpjyvkY94Lzj/Orftrh76m3pwXOLv/dpFaI/og/a0gF3lc2Z9CMN+
mQw0Vd1yCe/HAN4XchTO34Dzcg1g1qJUpdo+5Dc2hICQMyyjkkXU89y+hP2D
lG0ZJZ+j9N5tW7YZ9YMdlO17MF7MT3DPJJdYDtq71o6w5JlszJpR5LengfLz
RSdfUXxNPhAmX+VarIv9R3IM//Uwr9BjlGfy4N9tn56bSeZFi6rXsAp5o35V
hMrCDdp7F2E9jxJs+iedsGOIwqG7l4vvT2b2jzHshyr2vJ2JVcSeaOnODTJf
jPJOBebqnlC8IYz2hSqYjdx4aayJ51OHuw5W9Stuo72gDQbGOsMblw5ReJkA
d4w9zhek64LkibhrJ6cHKLzPRqtZ4OUg9T5SuXe/ZTdg/r7OHy5ukqzXlsd8
QwDcGmsd6LMifHHsc0NmScpj/jUAfj/U/xqOfIUTAbA0z67x3jXCz/GBViPG
uYDwAx3kU3SvnYvyKgiMDF7xehli/2sQcGondIU0YTwsGBzrt2YOa+D+DYEv
czIvs+F+ZfjjQb8E+3yofg46pHaJZl/pwnrnGIjI7Q63Z8mmsJuGHl0f+XHo
3rBFKD2w0Q3rQf3gV8pM6XHkp0r0h+8RR+8oYz9GZij8DrfdK4386ImHIKdj
yYlNcYQPiOc978aHRaS+n9X5huI7T4z3RkDP5chsrgMYb6SDXZmFutEqXC8d
9nK326fxMuMXznQYMzUQCUZ/9AodzB3fzzvkiPzqkbD95NPjRjPM+MOeKBgz
SxveOc6MD1hHA8fc05kPlJnxB4b9JttjFRcaQOqLTl2RtFx3j9jrGl/83BcY
on/pAAXuBReidUg96M5Z+37Y2V6h8P+cr98BjHUNOPa8xHofR1gh9aBtwawr
FF7I+U/HIqlPsnxQ4n3+FKlXTLdWTgIRlG/O8GidbPJLjKcz8LHjH7e/vID2
mTtED7Cqqt0n8yve6Ccf4lLC+KYlaE0mvF6xCPWpFXgMd1+YW4L3Yw3hTWZF
4e74PGxAKShp6WKsH2D4U1wPby0ovETw5M3brby5ZP3h4qMP189F/gtH4Hun
tissiNiz73hAk2Mn/t8FNJTd6wxW4fN0gd9z79xfgvM36K4QovEiZe9XfH5u
sHj3HIt7l3A9nuDRFKlreoDwRxwe2qt2cwu+L3OIyvw4oKFO1iOsqcmjUoD6
xhbUPr8wF6L68+2gKBY4PpeReTSCEn58x2+Q60NofcVJjJdmusOLn8u+b8d6
C/AAxbJZP27RUX97wM3Ac9m1mO9i2E/z0w+ZWA6g/eMJ2zxYlvBS82e84NlW
AaFSY7SfaPA01eDk8uXIv+QDiz/kzVm5m9SXmnUKXIzD/UTXg8sel9oPbkF+
AmO4/c3a96gDfs+mAFKmEe5Uv7klFP3U1o//z/Op6N3gGfWFzAtK1+1cEaJM
+BGC1Iqy63MJjpgR8ebrw+vZAY02yamI/dL9djAj5MpeokDqe9fUO3Qu3UT4
YW1CSt/dlMP94gJxF31Zg9FeY6GBTnz32F/k52TYl9sKOisPbsL6PmkwKlxX
siiJ+LPfhbKWF+C8dwb+Ubtq7f4K1B+KsGBU1D/Fj+ij+3sj+c2VBin8j/Sx
fknw1IPQZy04f5eBXU6vfMNjSvSX8kfz6o2GzPnCdGWw/XMyj2GUU/rL23DW
42Fz4t/+S2fPRnAH/ZjVPVnE6v9Xn7KWxKu5Yl9/nsZ5we2+cCp2onJdOYk3
srhVLXKxIFg5QXDWAuzXZOijV+nbdcI1z1P4tu7+g3eSsJ4sEGJa1sqabcD8
DcMedhOQSBZF+R0GF+Md5s31RX6zSKjTO9AjjXwhDFzx58Cd83UXKay2JiZq
YSr6V5EwXfuh6VQr8/fWMRCU8i6Q/wwTX4mB0uJ1QlNpGE+mAR/Pu/DMXdkU
7rzNUftwMann41+VviFakNTzZXzJtd+E9QYsPjC3olXsSCnBf73XizyTxnow
f9Cyu55wFfmGGfvHtDFj/lnku1wYAB9UbS6ElaO+C4C+Cy9qj3Ay5dncGLCN
O55lO4X8ijHQobWG9QzO09SLgatx9etD2DKp9Rq+c93v38x8Pyxu4HrbPElJ
FP1ZdzALbp4ZGsf6DHdw/zyeMJxA+qmaNp7mK4/A/IoHrN8neu8w1v8w/LM6
FqfWjB7MJ3qCVaXP/b5PuF4vOFU5rFqA9aL93lCstexoVznWW/jAqjlfe3Zg
vwnD/jvZ16npl47PwxdYxA8uXsVJ+DgMyi5/W7YR8xG+MP0l4JDtDtL/7P2n
/HQE1S9lA/sPPNTSlyf4/nyFcV+cn1rnABJBYffTsT+FYZ/mDwlmZnhh/Y4T
5F8aK12B9RgM+z3hNbvfuWC0b5yBv+HvnTG8fp0HRFsMsBXjPBQGPtehGPR0
C8GrUp+xbjqM+UwavFP4ET8L5ycy7P9rvJ9tX+nmUs9n3jp5WyUR4g8o/+Tf
pPGhgXl9VXj8drbKihTkQ1CH0RhFSdubWJ+tCTy801uum7cysRaYREyoHzNm
8o2x6MPxyWzew3IY7zAAh/pdi2QwHsnATrVSIt630F8wBM3Sj3/vKWK/vCGk
HBFzrX9VTuF6tnzLps04L+MgmO8+d0n7L/7+IMQ6pItdSWHGt0p8QfjbDqNh
5BNhkYCLskmpv2dQnm4A/ZYbZQnXxyicWaYnyvXqI4VLk9T0Rgvx93KwT3pi
yauQjxQ+5yqU+SEW8WY4G3QhaU7YGIWnMzcYSO0lx287sX3wGUe8HTYmiM/R
GMLz74IJ19tyfNoof3eDuP1z5cVsiFVgrGL5SGkSYl1QM/X7Y7PkI7U+gY+T
u3cokvW1Fm1Kn/r2icIakwpnv/CT43nln0Ia6gl2/Lmk0fs3WW/iAZbd3dT/
N4OHcg7LnFUE913mPnt3muC1Oz7GfD5H9FXDG+/vvl4k3sRV0NnrcH6cWn+v
5JjGRl30t5RA9ML5O288PlE4VaCyi+fROLVfXBa9+taSTfz9fIEfNuPYP5Lp
CQMGFyVZ+zA/4Qv27/Je7dfMoeSdQ9yhuidN+PsA2NtrOKf8PdobASACTVfH
kX9WJBCWv5PPK8d+cFogqMAh523or8iEwtSExaa6U/j7MKj6sWFYaxTrl8JA
0+jAeVPsp2ung7fOEtFijM9ZO8DRikadJa9zKexjVQ0zaJ8w7OXphRn2IEPs
4a1n+S5IU/aKC8hMs94P5yD9raemOHQPIb+NtStYNx+QDjfE9bqC25MRfi6s
VxdxA5lvi2/M30bk8cQTT3mdSTzuAeHCR19OT5D4l3l52+5YtPf0AqErYPWV
dSOYv7eGRSvXsbxuJ/EL+9VpSdGqWH/mBiEePWnj2oTfVt5/ejY/zutlYL4H
uiuOxuL1PUF3UYrT4khSPxA4vFLbBfkzGfK/Y4r17W7JyxQ+93aFh1ItmS+9
Pi/RY9EMPh8aFCzdbWeN/Hx6NFg1IuG7OjyXwuMTbV9U7ch8g5yGtTc052N+
zxochcO+tyNfCsOenN1zRLLyHJnvEmSy/FCDOZlPMLeUN/DtHmb8hGFv8y4Y
P1YUQfoFguPYRU+jP8rwL85G3OMzGSf+Bt0y43ldKtqfTnB3a0lzVxce9wLe
xyU8d3D+rYwv3F2lMvlC7BKFz3j0cz9dg/UzB6HyXbjQHKwPZOAZ9gt23FUE
c1RUf99Yjes3Bpu1Euxvk9EeNYWKTl/LnHKSL9uhr3Dq/AFSD9C9zPDKgVMY
v7GE+FfrI/wyUf5bQezaBX88e/C4FRzN03h/KbmUep72viHRT5Mw/m4DR36W
vFtqyTzO8C90BgvvqfkUUs+76UPgK1neYgoX2KqcF6/F92MP5k6LGozXYnzJ
ATh271z7PRzje47gXJg1FELH/J0jSIk7PcvRIXiBbhff2XuIneAf9oS1lbhe
ZxALrnmyn4b9oa5Q00/zYbXG427QJqu5+Xwt+ouecKKm6vUY9T3awEK1ypFl
1DxrG3B/E7lMtIRgr/fdz8q3Y77YFr52y7IqcGN81hYaR7of757E/KQ9DIn8
Q/iF81IdwDsrj7f4D6kP/eT+K9gvg9RPRXHnG4+G4P51BdnqjV/zX2P9nBsc
9d36Rxr5Iuk0cN+0YX4vrpehj7Yej+qfXI/xLB3gv97NNbYb43t68En6tGr2
T2b+kOG/RcYIyAXp3KVwEXva+KQh8oUdhECuXx09GXep9VtMKcUdTmN+L5m2
sEGyJ4OnFvNRdqDkkpGy7QDmfz3gUOWgUAKuf2EIdE4tixqUxecZAgPRRcUK
VL35Njhw4XL6VckhCidFfl5vm4D5j+3wWFbm7M9ykr+wth1QW7J5mMLvWQJP
itmMUridt7a6sXmMwmfP8MfbDxL8RcYksnES8U7I2x58ijMI9bkyCN8fN2/t
wfiiGlhYbelXeoLxPE1QFVJPy1+H9ysBjR1PKu9pE/2exnk2w8GJ4CoFWaML
M0SfHz+wPTvNkuhrNSvl86Xvib7edO1z/lwhop+v37qhYHqM2Cvq//SvXSX5
ILOshh8hTURf/+/5d4KVx/O182mId8FQA1eRF+aTGPq2+ExsijbOd6YHwlbb
wIfCWP9HD4UTXQ0H8n6Tfg21Zn6ehThfWiYCPhToae7G+RAidFjX09xVIcP8
vzMd9qQ0gB/Wo9ZFwtddHrzHNhF8b2JHidEj9AdiwKDX49MyrD+mxUCqkhin
12O8P3cosZt85oH1kQz9EtHMsrEC+Sb6vWD7aysvqYv4vfnByU2WiXQ+lNd+
MO+5SX7gKox/BEKV+wP+kALkywmGO9Z3TLdhfaReKMQvpLlFIB8RyyHInRXV
2veDGS8UCf9fPvmuIzAR/F2FM5YZH6xzBvrga3FwzKTwbvaBlPnumA90g6tW
CfUcagQfC5319+YexO4woMd5zh/nhzP8uVh1tec/qfkGHrDyjCbtbCXxz44+
bP9jKs30B+le8LhYc92hw8jfT4PpgDz/X/dxnmYQFE5YzXEbx3irM9Rms8iI
hWC/iyusujOarOFN+DrGx2KbVHMyKRxyKd896e9l6v2wT2549vQh83oMeyLF
0GN6Cc63YPiTE+777qW/xHonD5hVNHnn1xHsTwuHtK61lrduJFPf27HqV+Vr
kd+lKQp0xFfr/DVBfk87iNW1W5g0hP35HiBo8oKLboHyyQuSu+fInF2G9VY+
EDEY4/54MdZn+ICRLWud1160L31h46MdLZZYf6rnB3ostukvKL5pP/CZ7tU2
R35Haz/g/ofeDPmMaH6QIrvih8gKEs+O5uN7FPEW36ciCAW83qR4k8yjvDT/
ZJbvIMZ/VMDy6aeDrDW1FLbXOFd/uQj5f9VhcbzhFK8f5l81IdVP63tNHpm3
qG90r3ksC/MLejCvrP1MzXHU54YAsit2KI3j7w3h+tTixq2JBdT6fX6/Pb2k
HvWdBNS41oVmNRL/hF1QIdadg2ATm4yc9nSCn1VIZotfJZhN22+Sd4rIP5UP
0i6hHz5RWGhuM5vEBJGHegbWrNomBJdofM51zyL+i+aCPO/FakSe/bp05He4
yCfq+7gt99LaYgznk0ZBcZTBaXt15vdOi4ZtZ5u5eIeYx4OiYc5zvU9OePzH
/3dcJAa8twUOvXqI/ToxML3V5ScHHu+PgZGWxB+6/Nj/eBiKzEalTH8z419X
DsPsMs7v9G843/UQcPrtmrf3FxPfioSnL1efv9DC/N4XRsOywutpNxcw8bZo
+Mupa18djXxh0cDFnd1ndjWZuv/wMJYzFfOY/EK3omHRw8zbHWbM43XRsLqo
dcpvkskXJBgDW2j6gcWXmfsJYsBngT///QZmPSPDHh7nMkxOvkrsrzeB8sbf
kb+aYb8Uin1j/ba6kMIneHWfjC0h9pi97foVU8/xe3OBT6tZP2WFET6ETayH
L8z9jParG6zk/sneuwXtXXdY3uSy8+IbjNcy5N+PFv07nWj/2sOdKN75oseZ
/H399rDL6TanFvJJ9DuCTZTYxtbjqL9c4Kj/1UNtOA+hzgWyLy0ejkvGfhMf
6P22eFPnaYyv+4J6e7dDLvKNLPSHlRyXhO9gPezCAPjRdDkhD+Uz430fVk29
+tiWGf9k2INcNJErKoq4Plv4FvFUw/wFsZe03m5NuYv5HAZeM1Aj3HSM5IdO
ixX57mQrpNa3QcSHbWw24f8oV1dSzVYootZbXXiVL+8+6jcnECk87qSdSuoR
G4+71xwKwviLHgyP+H/6wIf2uAFAyqkqtwq0xw2hYwWk0Iown7IftL7H/Emn
+CeN4Lz21Ql11yIKR80KbXJLRPvfGnZ9MymWa0P/gmFfDyqJyDUw7U9rR1gV
2iqpWIb5Jk9QvpOSSr+H8ShNePXbQdnnEMonHVjn9v3CUFYbc702kFi4pP3W
BuQDCADu/haHtycxvhcI/XfHJmNw3k9mEFhwNG4uK8Z6nSDICKm25Mb5FxPB
kBA+fwXrNManQ+HIcWt1cTmmP5pKh+S7cxzaazH/oQEfr+qbWM6qoZ6ngldO
27dl+Dz1wb518qXhM1JPuMJUTJgL6wf7g6CK1ip+ZRXOZw+BE6oPNzzHefKJ
IVDhvvsMt+kV6n6iBVXOHBWtYl7vEKjaRPXzUnwCh2Cc37ttvSHz/8aR8OnU
9VsGi5jyhR4Jd5Y9Wa0TwtSXTZHMeR9M7BwF7dFbQzt0mfhIFDxZvLeHE5Af
MQrWsNnKKT5mxtP1omFD3Nv3+3OZ8u79Mci/YXJ05Qvm9w/HwaPqQc9u5GOe
CAFzGYd0e+RbZgkF+sVtC6TQ3qsLgz2TXe7bsP/EOhymDaYNjBeQeTAsf49H
WGD+ti4cMsTijlwwRHs0AuZx7RlVamO+v7l0OG/4xDu1F+0TOih9fXVN+gm+
/2D4mu5V0htI5kn0nxkICipi4iY6sOlVC/HdwPwCHfjW2fhPU/M4IyGl23aE
E+231Cj4dHHfykicj8l4XjISQyJ+yMckdRh+Zq/+bcCB8afDELSDzqeK/S/g
B5kV7GJVWK/LsC94uP+ZMIt8MCGwdLB+zKEH42ehIMAx3/u7IMbfQkF+lnni
+oe43xn6RD1lTzAe74qEg/s3HpbC/2+LAp7e8y8Ov8LzH4YZjmxuNuwnAmPo
5WdbwFVF+E7L/E7F+LdcprC6ouIPjWH8vTWEW+3ffhT9aboNsPlanbn7GPOX
dlDcckJhbhHG751heLvY6xy03xn64Ub0C91QUYxHeYJvc8N4+gcSLx4e3DLv
shWxJ5ya10/xCRO8Kdy/xESTYPVVGQcVbxB7g6c6VN7GG/FmkF9Tqau6hfhb
orRm/k/KBFssVprYZEz8ryuHty7cqo3xzyAoU7v9xFAC+wODYMilwuHl9ywK
5+Q5TEmEY/4oFD6+sc7n6sD4UAQ4ePhpCTxmfg/b6DDEeU3oDA/z9wx/af/O
nSzrYzOp97k69ZgfvxTWV/iBVMXH0KdW+P36g6/jSo/uMyS/1h3zjmUA+zEg
BCyVs8RK9dMofDhtU8Fv5GdjCQfvaK+nIw3nKbwjOf/ZOV/sX6CDbvc8Pc6d
2O/nDfO/9xSx7UbsC2pvO0V3bWZiGT8QVw54t7UY821+8LH9bOjTS8gv7Q8+
3ckJIrJoP/uDSmTLjsVj+P8AaL9SfLEvFPnogmCT/rjXJPIp1pmC+dO/25Nw
HomIA6jzKc+UYv0Vw37J9kzsu9pC5mnE0ja+GhgheCXIqX/B+lIGlqmYmfwv
lvg7p3dwGcHq13vkc5APgmGvp+xr+cT3BO13ZQiwXDovAet/WFThZHRFoZMH
1gOpQkAKz5QGN6knstT8bP46jvAFDb+df4O1HPOxWkAvtWsyUiT1QvpPppWb
NUm+OPF59Z02I5JfTn8Xf7w8gfAfhXEP3L5mR+qlV7PylDrGk/yxe9Xa2X8l
MJ6h8r/HGfdfMM85THzdW+r+6t9bPlKQw+tLwOa2m7uqOsl+ax5RL+eaIvEO
P7cj/Z7/iXd82jwY/mSc2PuWI40cpdVkP4pYvtjYxUVw5u5algUHCL718fmJ
jjrEsTB/Y+raPuxnnIiFEemN7SLYf7gtDiL1n6l7NKP/FQfbiu+uf3uRiRn+
+XWW9meL25lY8RQ8iqb1nrlFsHDlvpJ3GM9l+IvHfGZ3zEF/SMQX+Lde6W1y
wPoqX3gp5rL1VyrJ/7K2Hds3D/ULzR/ePs4rtkO+VpZg8Kk97OFD2Z+hEFVs
n/4A+6naafCmxuVALs63nPCGFtN0W5lu3M8+4BgU+ejaGYw/+IFKWP26dzgf
r84PXsjZHbiGfBAs/qC1M/wIDeebWAfAlQ/fTNb9RnvVFXg47TbXUfM6XSHW
fJD3oRHBTo2nqs/QUJ67QceBPy8yH6E8d4ezC34Mnr5EcJmvRnXxINZ3BcD7
wcV/7vzB446g/mqmyN2HYCeeZwulg5k4kQaN21ef2a2J81d94P3SVOeOdKb9
FBQF4eNOVvyOORTen1G+UjSQiQVjwWSoLd35Kta72IKIfpDCkRqm/SpiBxyV
R02fzmbaq5kOELBxZsf5s2T+Br2IsyCfD/meHME8Pa3HzgPlixNwFnYrJX1D
/8AXXF9Wx78WwudjA6kv/Eol40soLOPM8uX2FYJbt1pbsU9g/aMdqLiuNtSV
Kaaw4ItFH1J6CI4Zz9rvZIr3Yw9qXO43PU3xuAmEXlba0nwA9bUlvKy/ciMk
Fb9Xa/iWErJR9DTmr21g8odPwMVO0o8tXRZjMKcS/StHUJbexuOijf93guce
5eIuOC+17gCwj15XY8/Pp7C0Yu+jiVsE7zpUdn8Anw8DPxC6czKJq4jCHH+W
aUaVMPnL6MaQE/7u/thLsp7SbaavZr0g/O96sG/BPjbC93MR+s+nryZ40EYn
Yd4N9DcOQppq6wLpU2Se9stF/wwcJfOneFeqXoxA/h+Gv9Tln9pwugr9GQ0w
EG/pM2jF+Ise5HDN7xMvQPlv+L+4zgSO1AQHG369SmH7wKGqamp+izlEl2tl
LFAtoN5Prkre8CtjzLcrgXjCG6N3WA/KkM+nPJO9L7YPUpiz9mnbhRaU97vB
plbyeb4P5mvVwVvZPUM1BOvz98Bh4yxjPhr+Xwu4nvoKxYsS+X1RijP++mMi
vz/vTv72/R6R18YPJlVynhD5q/nzsue9LmIPbat+V2I0l8SbpQ6u6BOU/Eg9
v3bRJW4WbczfS8WC/pqM8l0bmfv5Siwo6SleunkK8wNxIF1Xqn73EMFidyss
JJBff08clHB/5a69zsS3jsCKyl9OVXaY/wwCs+MP2bamXaDwx8rax6sHmPYO
LRjkM8/MRBgwj9eFQELs65OdNcTf+79+kbOUPLbMbpCVSEJ7yAPecD9dc9IT
/TEavBff1MqC8YJMGnRnW5sFX8mhsPXhNez6WD+p5w2zbcP5ig+S/oQbSR0q
Gcj/yOIEi2QuCZ/TI/nF63dcu1pDMb/kDFJcgRLLC7EfxxkMjDuEn2L8RcQF
znl6KMoJYT7IFcIy4z3vCxC+1OBVXomhdPTf7UD0Fj324yuSnyvYUm1SnYXx
HXtQ9jZUG7ldRGEW/4hH23eivPQF1bTATXNESP7s0KBgHFsb9kPagJrI/JMc
6ViP7wCZKm1Cex4XUOtP8Qxb2YDz4vUC4JxW781N6P/JBIIql+z8t+tQ35kA
9+Zf0muVMB5gA+/t2P3V3Yh/0SRerPUzNIe63r4T6+I1lFD+O0B8pcCoxXWs
L/IBkHqu3hSF+nE7jJfqmoWHkv60KSHjhMRIsv/yGdJ0zg6CDVJEE/xLEatC
yQJruhzme+hqwP4znGdW1H/6485GRZixkvq+i9/HD8Qex/26E1ovPH0j+4P0
s4V3csw23YvnV4dhHoGWThU8rge7bM7LjbGS85/c+nP9DhPEikCP0EqWCiXX
6zW/dL23htQTDszXFHK+TuSN8LJHS84Y4/l3g9D96MBZKfh/eQi78XfydtEY
db1OYb2xgxPE/uxOqXjJ/Yecf78a28H6k6Q/SH7MIPyaI9qXe6FGRM5GTeAt
df6JM8Jsxp4kfydo0SdUtITYux/vmrr1ORF8b8TzfWABeR8jK1d90JUm9fiG
FS5iYm74e2lIAAHnDmVif/oH/mh0CybvO1hx/S5a8gj1PobSiz4ZF+J694Br
g+QP1lWD1Pmfb6i4r+5K5Gm48t3Q6f/UM5mWtc3t2UywUUSMTV0Skad8S51W
ZHSPUHhgMrvd+Q2Jd89b/bhhqdQ4df5NL4yD9v0l57OeFRY29zCxt2N6f887
8h97mytbJOiQArnee4WiP+/nEfnN01B//0IsYh+w33frHBsd62V84Uh9i64G
xldY/Jj9MOjv+cGSd0J1eyl/MADW31OyZ6fsWxrMX5b3+sRK5If0hXEeN/P7
s9IpnO/5sPN3DfKL+0JC5jBHwh3m70tCoFtmP8/AYuT394BlPg++34jH83uD
5qyrag7I36XnAxEcwtuPHEf7JRA4pazDNkdjvCYQxviyzTwoPkc3KEyTanu1
lvADLebMPW+yF/tXPMFjZdzdP0swn8awnJduXXzvNOHr8RB0Hk1HfniGf6hy
5flowVuUh45QJnTTyf87U18w7P+6z4KP/nwn/RxZJqse/cV5niKBIMUvK/8D
552BBQjEH960H/mBGPafcw+M8X7HeJc93P019Dj2EvEPBgoGl5ZU4v35wURv
6K0h5AuqMwc/tqHkLb8xPmQNc7ac2KpSSerrR/aMDegi/xeLA1S3aR87gPzC
DP/6ycqk1nDkvwFzuDbPesGrTuTbtgS3keUDLioEO3Dafc72QGwFcTevBTZr
Yv2ANTTsXxWfOonxW2MYb5/fMfy3gLqf/aeX3f4chfkDNyhR0vsVM0T4xiwU
XIvL/Ei8/r5Bc04KzvNg2INmg+bG3vFonxnCphNldbrU/DJjOFkya7f6BbS/
zGGNz/qZRpVO6n5DfKR9Bwswn6EBe92ChMduM/vP6PugYsaj0j+bGY+l60Lt
4w/y86WQH1oPfs5K8jTEehwWI1ijI1LmIop8teqgujNdO8mCaf8y/BPfSfOY
1oX5FDacyyEqo0xwZGHC7Rp95BPwBqOu9eFrX+LzUINW5VjVxNtMeV1nCt7X
BGpZ1mP/MA0GbzfSdXG+aiJDv35syvolSOKVXXMguGAC67W3gcoXrWw+Q6yv
UIR/2Ot+uZF+K+6pscWz6dgPBVC9+1n6HgmU5wcheL3sXu1LRD/92/95i2Cp
noDEE9+Jvnq8zOb7wf/Uc0gdusnNLU/0y5+7db7jl1A/SMBPzgV/V/0g8rCz
dnXymnekXnROWbpp2H/if1O/XcuNTEj+8JtNtf6640S+suY6Pdt9mZwvW2b7
TN078v8i28kL91qIPN0pquBlJ0fw1uYPpUf+MPFEBMy6aLttbxzpL3J6/w8h
MPN5v4+CkEevdiifZvr7xtGwmeP1Z+vLGK/2AtFncdYDWH9k7QNx2QV+gTjP
Ry8EWi6y/1FAexKiQF7tTrhaHtY/uMPlyQAtqZ+IPWDmps2XbzkE6xy8e7s9
F+O5XiAoFePiO4XYHZqPNu2zRj70TE94mVXZDTS0V33gs09Yw/4MzN/7gPpp
/VgJa9x/rrB8jM9m1wWs5wwDgX8bWnF94f+LjSNBWnT2wUdayD/iAovl5z/u
UkX55AanRZa9LduM/ePucO9SRVBQG+b7PGGfzy+TEuRH6neG2VmSDgYqKM9p
sLStW5uzFOMJ3rDkgbXmQAjWc/pAw+W1co2zMH7tBLfaOMWrOi5T2Oloq7t8
N8GTO1MOLhogfIerdYSds8yIvTlpoKY99Irw56+ZduOvrMX6UmcQ8W0fpWE9
J2O9wteUW5bM4HrsYbFLyWC6LNNeL/Fnxj+yKWyXUeNRi/Wq9FCwCrNge9CO
1zeFml9B7yvNcL6gOfzRvvyEhvwnLNZwk91dcxfy5YML/PEou3P6IPo3RrBF
PCT5eGsetZ7BN5ZLIpBvFpyANdn82NYi0u+8OW9ohm0G49EG8MNm4fkDsRjf
MISv9XbnVQWfUPrMOzbuWUMeU56y2MOT5Mat63vw9/Lg9SJ3QSAniWdWejWG
XL9H+jPFJ68Mnz5G+BrWBpx84LSP2GOnJgSDrz8i+/kv7ZKiEp3gpauapkK7
CB78PWCQ/J2Jt8XAwYxsxcQ9yL95GML7TwT37Ef+zlho236q/ini/nBY0Lj+
2AZqvmQcaJ0V3pzkxXw/gkdhJK1uQpQPv7dDcDZAU0TnG87PDYc8lrQ5auuZ
+TXBSDCbVaPLdxj5ifyhR8oqQQLrjxl4warqK69w3rI1HTRqDyfQMd9g7Q8l
F/tCPQ/ifvSHPe8vJc8gXxoEQvP2xWWl2L/A2P8m+w6ZfriP8sQLYseNH2hP
k/muf0/n9uVGYr2sJzh/4Tlx3T+X+n3YMmU/g3wyv+Br5dnUOx6kfvj56q/z
ApDfM5EGvY18MxE3cP6LNywfbT4XfB35Gdzhh2nTvOWTKI8CICjI8E48zodl
2JslBxrelOO8bYa8+jiyWaj/NJFfN6ImymjZBAu1G+ksLMb96gaCLyZ6rt3C
fmoPcOFLStp1ppRan9EhTvm1GqXU71VWh23fmkLin2kvDQWSg1EeeYDQwov+
PzahPnaCpB/O5QNs6O8HgGerUerFZtKPS7dVqZSj5p04wamGelvvYwXU9d3l
LTvfFeLzD4A1jzXTOjcTfsuctvM2FxRwfzqClDPPsWjkt6R7wrEpddG4RHw/
9tB4ySFkiRmpT3VfVMihb0Din9euTf7hN8P4nC1Mvz7Ry7EQ+ZacoHqlR2oQ
8kOBH5hyNhxpRz5hsGXyY+D3aQ+x/uK/7JAvINMFFkVr+yW8R74caxiVnq0/
jvUCdTbwsLlKcQcr6e/z43ed/6IK7TdL8Du6SnM8A+WDFdyxqPw+HUX4cN7u
LriuPI32mhn8S0+45iqFZaveSg/9IPwnq9O2tjzB/lowA5qDxOVAsWJKPxyZ
v2dxNfLjZ/rA3ziu4KATeH5juKO45pl8YRH1f33NmgQetP/BDhppckOTAvh7
I5BolJ3mnUR+AzNwUn68xVsA+egsQfLW9NmFgsh3ZAA8EvcfSNoPUPL8Q/go
f/1jjC9aQcyNM5lh15n9OHV6kN6uE3Kxl/k8GPbv+W+CFxaEMet/+23g7Exi
+O8dyD+jB2G6zzr4b+L1TOHl84eNN5yw3scW9E4ny8dtwniSFkRbbfZ3zhqg
8HOblLiU2Shv9WFuR+jS0Bw8rgrgckV/jyzTv6XvB0HOdSvup6G/YwMVphsz
eFTw+SiD9RM7re5Z6G/vBVWP5erKJXh+XVjy7XToQwni/9+5aZ4lXIZYGaTW
vbEPKCX1uypCowPypqSeWPLF4qaxQmJ/Pp4OWavNTuIjknOmU7Q4iX04ck3i
a8Z5wp9y8s7wPBZh0h/D43va9pQM4SegqRo49v2Hb+Xhu8qcd4fI/e78Gzjy
MBDXJw/Ldr+WNL5G4inLldvmC30j9YDbLzX6upfj/csBbR8tM6AI7dutEMtl
3TO29BO1XudN98QXuTFxFx1i3kxKcnKhv0iH8ct7RS4pYT0jHb7zvrbunia4
Rd03l9WVKa9oYaA0nVrNuQjnQ0ZA25HS9insz9ELhVc0F3U9nCdMOwSTlqbB
nojrAuFF+NI1w49xfwWDH2+jhP017F/xh6UOV1duw3rj9iD4emMF5wct9Gf9
IC/DmWNVFLEfN4l/4xUNI3wrmg/LjQs+k3rMDUv3Rp5H/bDQD9oj4d6xpSjv
GfaJvPvuKaq/xhvY8rzo8jivdcIf+MRyHURyUb94QxxtT0j0N8wvRsN6L/49
5djPCZ4gxNGSPpp6hdLXs8LX/jqsi/aPG7gslGHX2k/6eZ40Lu3droz2mQu8
YYmVHItHfeIPLDQar6A46gcXWNIZNnz9F/YfeYJByfENo8/QfrCD9SWcNkI/
yXyiTpdXs28gX1y/LajZG99fjvOerO0hRoZ3i/QllIe2kK/mUXJVifRjyExd
UTnLgf6pDXBrlj6aeEnyYY2POr/sW0nivSff/mq5vxD9yzDQyTf/HB+L809t
wLV2u3YzxgsY8mdJ6/xZXUFoP1hDyFTb2IoB9P9t4VTvU+G3eijfTUFp1dJj
nH3llPxW6zhw8BRfOXW85dI+ScUlKJ8s4bCQ6Oo4K1yfCej5en7wtMd6K0cY
XeoUZLwP/f2D8G6tnmt5N7M/keYHfLsWura/QX1qBIrPGsP0FAcoLNlTt+LK
aZRvB8A06YnCVxt8ftaQ26Nt76qA8aQDkPTwrv2pesxnGYN29WbHhCrCx3Lq
rTTHHCmMt3tA3GxB7bIG9K/0oeV5hsuG3ibm+S2Av/rmurIcrM/Tg5apVusd
yHcHlpDdTuvYdx+P74Gy/s1yIzm91PeiQRu5zRqA9pAaDH6q5mw7gPJSCxbN
M5sW8xmjjvPUG0+M/WHKH4Y/oDtrtmYGP84bUoE6WTpray/m7/bAnhJJ2iVR
jL8CSH8p5f9FxdNVoD7O493o4wHqeO39p3mOmSgv1WGD1rKPbF6En4V3cFS0
/STBwuZ7eZNfEPmYr8L3+Eofysd9cE0j9u6lXpS3AGljJZ0mFUz9w/BHpE/o
aD9ePEAd9zMqka2NwHiGFjRyt1VcPfWUks+pC9x35NUQ+f7n2o83oaZM+SoT
B4tqZq6U4DxJmZj/rRcWjIEjDnJxl5EfJYgOxnEft518iv53OIwdEZPKQ37N
9nCYu+ZUnoklxmPCYIflypoEGTJPwPBF6aFVPWi/h0FAmm5Pwj3S76iUHfNw
og7z7Ycg/qmP11lr5JM5BBz8b7JcqXqlULjN1tQl9gj5iILB1WVf4IMppr8h
Egy9s0VC+zhRHwTBJ7k797+6pVE4NeJO1sIunC8TBDwZsrPHufH8AXBSddpZ
AOMT9AA4M63zqeMNxjP8QXOGw+bzRoxv+sOwy0jGMm7UV35gxM8qTitFfhE/
6D2zvHuHAPZD+YH96IscK6q/2ge2vonIy+RC/eAD/9J3VJRQeN5Y6MqPzbg/
feDN7xJBEr/whpNKguypGA+29oaLmiFpScqYP6OBrwWL3O4xrM+lQdD7rJpb
6A/0e0GvlZrVZaxvzPSCW7dqvrs451E4c8Nz62LkY6Z7QV1H14DKSoLltIvv
H2BD/9oT4of2szTyYjzRE6xick6xYr0Dw9/QNmTfVo3zthj+S+GPBLkStisU
3jhR3yeA/FwMXFTfPOR9mfR3LjlTKSt0AuWdO3TvyXsvKYLy0x287n9XlsN6
QRF38G+/NPhshvCfOn1zod1cTOLnU6a8qVt0SP/aA01o/4XzTkRcYYrlb47Q
X5zf6QKHzVv81+4tpHBg3v6xXh/UVy7wvuN9dqMd/t8F+v2sfT+ezKWwxNxT
o2upeL4LVFntyv5B+R/O8FDBslzsGIm35BsGp4T24v07Q6q2/Hk5LnxezmBr
UZ9v607685rY73nVGhK++J13eQS35JP6j8QgDRZ+rGdn+EdPfUrLZddhfMUJ
jndoNT7vIvNWPAI/3T3DT/Sta5HzNQ3kf2P4X3r1Px8BG/onDvCpxmzOZT30
L+zhuVBf6JNI1Bd2IDLA89RuB9azMeyBqClFIZw/ysDebqn3ZtajvraDDH7X
D02dWH9iC67d73ZX9aO/awshLfd9F+1Af8AWel6tjtqD8xczbSBhyZH+kuWY
P7aBZMXcOc44v9LaBkx4Zz3R50d7wQZejfiamh/B+JQVlC72TD/5oojCzjJ/
Usbb0D60gAucdSvP2qD+swCtvvHZcfsIn+ZJJ8Wb8zQGKWz878BR3B9moOAW
VtYXgf6RMRTIzxGNxvobhr+mPH5ClGXbfeb1jEH86BbWdWOoz4xBxe3DG9ox
pr8EB+DCtaqhCB88vh/GF4WWFXKgPWAIUYVsCzs+IZ+hPjwqk4x8vJ3J5w16
oBG2p0j/PjPeRdeF8FmfnlZIvqPwdkNZrTdU/GofdNUtOPR7Da5XG2YlT47L
FZF6wIcVg58bBDE/oQllp7ZsLt5M+hFZRKI4jq1sp3DRTExD3Comvy+LJpzo
XHjgxxcSL4u/plbCr4r5zD2gU9T63HHuEIUVnyyTSj5A8s/3Upy7ee4R/pjU
QhgM2kz4ZXJH44vmz3ykcKFVxrjFT8JP03lQ/eWiajJ/sSv27VrvWwQXtRcu
cqxFe0AZjI+UPygpHqf0fX+FaKPbSoJr921x4XQepnCVmUlWuTbBw8Jd2kv5
CP4860/tyZPEfqhQ+9p42ZTYK7an1flDWon9cORvbabC1lEK83Dr9//YQvy/
gERZpardpP4l8cG9xgLbjxQWj5IcbFUg+RPLctawB1Q9oyLonUoPA4URCqvS
KiLqVqI/uh1WLSweFXAn/Z0nQ3beNpfD+9kGwr0/PHXgP3xEKu4ltA7iv/7W
dLtX2Ehw1SxFlzdlBD+SffYqluqn2gq6qstok3tJflxq8jbfWC3Jf/S/2MMb
U0DwjLte5terBP/DDjORSbBW4aYTDy0IDvi+QycglfBj0FxLxb+Nj+/6f+S7
Syg=
              "]]}, {
             GrayLevel[0.5], 
             PointSize[0.02], 
             PointBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQFqDscuXdx9yOedPYSv49DnIJ5xyRHG13OQv7jy
wtOix1C+kYMey5SHl81hfDMHsxWLZO84PYTybR2SzzBNCt12AMJvcHDYklPc
0rF6A1Te1YFhXpOZRN5aqLynw6auSa8Z/VZB5f0cLnQtkPjGvgLCdwh0eDb1
VLzXp2VQ9aEOfYvZKzZugfHDHPJmua3RuLQUqj7cIcm9Y7rPriUQ/oFIh13t
ikedlsL40Q6TXzC94j+6GMqPcWBTd1/24u0iqP1xDupyT2c97ILx4x2q7H5X
tE5cAFWf6NBVcerdJycYP8nh7/3eO6wC8yH8hGSH3Rzb9rH5zIXwF6Q6GGm8
YRW2nQN1X4ZDK8MLzz//ZkPVZzr0HLSvOZ0E5SvkOUxhZQre0zATwv9Q4BC9
/d6hP7xQvkORw6bbqpXHe2ZA+ALFDjZf357M6JwGdU+pQ4tb6I6uLCj/Q6nD
mu9tHXsSofyCMgdr1mnreXmhfIdyh0XdN68UPp4M5Vc4OFj/DGcOmgThP6hx
sBQxe7Xv/UQIP6DOwe1o1s4QRShfo8HBTG9C3J34CVB+s8OBj++FFIx7IfwZ
PQ7P5+fwGG3otgcAUJ/BWA==
              "]]}, {}}, {{{}, {
              RGBColor[0, 0, 1], 
              PointSize[0.03], 
              PointBox[CompressedData["
1:eJxd2Xk8Vk/7OHCRJWRJUp9U+Cgt2oiK6LJkKYSULVspZd/X1I3KkqJIZE3o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               "]]}, {
              RGBColor[1, 0, 0], 
              PointSize[0.03], 
              PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQHGDrYeq7y2XX1vD+GbOZitWCR7x+khlG/rkHyG
aVLotgMQfoODw5ac4paO1Rug8q4OGgLTZ9gtWw/luzusfva/LLQcxvdyqP4/
+93ynnVQ/QEOP8OZg7I8VkL4B4IcIl1fMb/yXAGVD3W4YXg89Kbpcig/xoH3
gtbHDuVlEL5DksOXqiX1gbOXQvUnOyycc7rxji+Mn+IwkZ3z3eSnS6D8bIfX
pguCHq+F8hfkOrzfN3WTbv1iCP9BrkPFV+fzt7Sh/IQ8h+u9n/mU7i+C6s93
eLT3G9/6S1B+Q4HDq/eKO/74LoTwBQodlnavePJ94gIIf0ORQ9fHzV9Ek+ZC
7St22C7uejbeag6Er1Dq4Fg9yyJObTaEX1DqwBrgJXBcdjqUX+ZgzTptPS/v
NKh/yx0Wdd+8Uvh4MpRf4eBgDQrBSVD31zhYipi92vd+IoQfUOfgdjRrZ4gi
lK/R4GCmNyHuTvwEKL/Z4cDH90IKxr0Q/oweh+fzc3iMNnTbAwDWWadi
               
               "]]}, {}}, {
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{19., 0.9948378999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.738645862755826`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.04299638487230791`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.738645862755826 - 0.04299638487230791 (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"] + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{19., 0.9985991}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.747245139730287`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.023025936394638666`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.747245139730287 + 0.023025936394638666` (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{22., 0.5394116}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.514962423423125`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.01978322299289958`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.514962423423125 + (0.01978322299289958 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{24., 0.6484626}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.20080149435454`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18322792006821625`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.20080149435454 - 0.18322792006821625` (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{24., 0.6513433}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.207150782177594`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.18247563478112483`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.207150782177594 + 0.18247563478112483` (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{24., 0.6688795}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.279842306811224`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.17808286807270174`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.279842306811224 + 0.17808286807270174` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{24., 0.7134155999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.382088121374512`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.16567439543152582`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.382088121374512 + 0.16567439543152582` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{25., 0.751953}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.659442875011024`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.0671482879456336`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.659442875011024 + 0.0671482879456336 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{25., 0.9831519999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.70343663000309`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.48696889289699635`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.70343663000309 + 0.48696889289699635` Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{26., 0.6218478}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.864049237264135`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.0010042431928539305`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.864049237264135 + (0.0010042431928539305` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{28., 0.7238549999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.476509672720232`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.15611000823219356`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.476509672720232 + 0.15611000823219356` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{28., 0.7879009}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"13.28503441933014`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["79.75971457338929`", 
                   RowBox[{
                    RowBox[{"16.74308309413165`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               13.28503441933014 - 79.75971457338929/(16.74308309413165 + 
                Style[
                  TraditionalForm[
                   Subscript["x", "1"]], 
                  Hue[
                   Rational[1, 16], 1, 
                   Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                  FontFamily -> "Helvetica"] + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.1305644}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.837482792373918`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23439822226357157`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.837482792373918 + 0.23439822226357157` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.565659}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.897164127036377`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.21686197821547992`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.897164127036377 + 0.21686197821547992` (-Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.5931457}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.939308821533777`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.21192188004827314`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.939308821533777 + 0.21192188004827314` (-Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.609412}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.023583366140095`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2061999006937678`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.023583366140095 + 0.2061999006937678 (Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.612957}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.040896399798978`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20392653271016992`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.040896399798978 - 0.20392653271016992` (ArcTan[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.6312736999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.082367716194815`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19897027637076012`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.082367716194815 - 0.19897027637076012` (ArcTan[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.6557031999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.145990486691307`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.19263139750845323`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.145990486691307 + 0.19263139750845323` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.6759967}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.693013866904746`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.008404717414912099`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.693013866904746 - 0.008404717414912099 (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.9150714}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.556790742576798`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.0011834349246475117`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]]}]}], 
                
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.556790742576798 + 0.0011834349246475117` E^(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{30., 0.47344179999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"10.883449093860085`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"2.7476166909544526`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.16939734954746669`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               10.883449093860085` - 2.7476166909544526` 
                Cos[(0.16939734954746669` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{31., 0.714861}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.376539035003582`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.1564039369788761`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.376539035003582 + 0.1564039369788761 (-Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.06511739}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.194850027250133`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["226.3630943116557`", 
                   RowBox[{
                    RowBox[{"16.74308309413165`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               17.194850027250133` - 226.3630943116557/(16.74308309413165 + 
                Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.06511808}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.26588841184679`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["230.65163877999316`", 
                   RowBox[{"17", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[17.26588841184679 - 230.65163877999316`/(17 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.06569127}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"16.563469096493666`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["190.11509623659617`", 
                   RowBox[{
                    RowBox[{"14.494312008733898`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               16.563469096493666` - 190.11509623659617`/(14.494312008733898` + 
                Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.0668752}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"16.132577183786886`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["167.3003866330978`", 
                   RowBox[{"13", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[16.132577183786886` - 167.3003866330978/(13 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.0672626}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"18.905885959025294`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["341.52124089895955`", 
                   RowBox[{
                    RowBox[{"23.105255909803248`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               18.905885959025294` - 341.52124089895955`/(23.105255909803248` + 
                Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.07641349}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.913281625192152`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["111.13338595178794`", 
                   RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[14.913281625192152` - 111.13338595178794`/(9 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.08929179}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.214063715539647`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["84.45313885626945`", 
                   RowBox[{
                    RowBox[{"6.90436117202762`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.214063715539647` - 84.45313885626945/(6.90436117202762 + 
                Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.09968106}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"36.68251205989504`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["3013.116306767144`", 
                   RowBox[{
                    RowBox[{"96.04123718135776`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               36.68251205989504 - 3013.116306767144/(96.04123718135776 + 
                Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.1855716}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.077507443940682`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22133520481240077`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.077507443940682 + 0.22133520481240077` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.2122809}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.138183908943427`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.21767558689908686`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.138183908943427 + 0.21767558689908686` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{34., 0.6934317}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.647018160968441`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.00823071730387591`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.647018160968441 + 0.00823071730387591 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{34., 0.7664894}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.78276169976886`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.044352194864900336`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.78276169976886 + 0.044352194864900336` (E^Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{34., 0.7691336}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.720192234258427`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.12617357561079395`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.720192234258427 + 0.12617357561079395` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{34., 0.9004894999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.355099262266208`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.029191678220741802`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.355099262266208 + 0.029191678220741802` (E^Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - ArcTan[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{35., 0.1305644}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.837482792373918`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.23439822226357157`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.837482792373918 - 0.23439822226357157` (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{35., 0.6076195}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.014937040384924`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.003000006236300486`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"69.2248000914563`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               8.014937040384924 + 
                0.003000006236300486 (69.2248000914563 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{37., 0.06744388}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.9888054294279587`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7553307692884275`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.9888054294279587` + 1.7553307692884275` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{37., 0.2638717}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.367242004066994`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.20509727764947155`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.367242004066994 + 0.20509727764947155` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{37., 0.29523489999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.5515019165205635`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.005851490415677429`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.5515019165205635` + 0.005851490415677429 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{37., 0.4103324}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4.465987614915912`"}], "+", 
                  RowBox[{"9.870244785196611`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-4.465987614915912 + 9.870244785196611 ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{37., 0.5985146}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.962911436007828`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.0500923849341417`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.962911436007828 + 3.0500923849341417` ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{37., 0.6708294}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.857851095864044`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.004675003587191744`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.857851095864044 + (0.004675003587191744 ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{37., 0.8207107}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.919630249903841`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.006563787908654653`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.919630249903841 + 0.006563787908654653 (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{38., 0.1439772}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.821386451232821`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23809165179370817`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.821386451232821 + 0.23809165179370817` (Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{38., 0.1862309}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.153503067342647`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.21416818071440089`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.153503067342647 + 0.21416818071440089` (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{38., 0.8212746}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.970982138565558`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.035861706901595236`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.970982138565558 + 0.035861706901595236` (E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{38., 0.8387871}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.063777096308218`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.03157477634903761`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.063777096308218 + 0.03157477634903761 (E^Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{39., 0.6200494}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.881265627601631`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.19725692133214376`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.881265627601631 + 0.19725692133214376` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{39., 0.6602859999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.136341499943489`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.17029227302961872`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.136341499943489 + 0.17029227302961872` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{39., 0.7275876}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.415792841736412`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.15920221230562318`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.415792841736412 + 0.15920221230562318` (Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{40., 0.198955}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.191884406895172`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2706461764392667`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "8"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.191884406895172 + 0.2706461764392667 (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{40., 0.23085519999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.309708331360302`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.1373915590875292`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.309708331360302 + 0.1373915590875292 (2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{40., 0.24695869999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.340138753431778`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.13709066460015207`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"1.9799691086980715`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.340138753431778 + 0.13709066460015207` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 1.9799691086980715` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{40., 0.2496216}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.351903555085848`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.13570509930633248`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.351903555085848 + 0.13570509930633248` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{40., 0.3258301}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.689849470849154`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2665399152943348`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.37538201172230395`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               6.689849470849154 + 
                0.2665399152943348 (0.37538201172230395` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{40., 0.6076771999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.015514529130344`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.10370154508524584`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.015514529130344 + 0.10370154508524584` (Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{40., 0.6115286}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.030847300925952`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.10307128311690601`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.030847300925952 + 0.10307128311690601` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{41., 0.1302109}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.8387193015819125`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23426115019999902`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.02033930759711211`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.8387193015819125` + 
                0.23426115019999902` ((0.02033930759711211 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{41., 0.6226144}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.629334126103692`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.20212929678505057`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SqrtBox[
                    RowBox[{"5", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.629334126103692 + 0.20212929678505057` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (5 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061815220000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.56809988607475`"}], "+", 
                  RowBox[{"3.979397261764212`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.3700707745176537`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.56809988607475 + 
                3.979397261764212 Log[3.3700707745176537` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06181548}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.530825671635838`"}], "+", 
                  RowBox[{"3.969320189168842`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.3397037272743395`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.530825671635838 + 
                3.969320189168842 Log[3.3397037272743395` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06181549}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.5838273277648345`"}], "+", 
                  RowBox[{"3.983646499402944`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.382894990021157`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.5838273277648345` + 
                3.983646499402944 Log[3.382894990021157 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06181681}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.6173473229215105`"}], "+", 
                  RowBox[{"3.992697662453229`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.410249236385539`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.6173473229215105` + 
                3.992697662453229 Log[3.410249236385539 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061819900000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.4564337724707934`"}], "+", 
                  RowBox[{"3.9491815394778103`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.279210174370462`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.4564337724707934` + 
                3.9491815394778103` Log[3.279210174370462 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06182003}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.6609606025263395`"}], "+", 
                  RowBox[{"4.004463573250782`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.445884373894451`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.6609606025263395` + 
                4.004463573250782 Log[3.445884373894451 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06182464}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.4153190491219236`"}], "+", 
                  RowBox[{"3.938035889686039`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2458425056912787`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.4153190491219236` + 
                3.938035889686039 Log[3.2458425056912787` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06183408}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.3578642974830655`"}], "+", 
                  RowBox[{"3.9224420354290097`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.1992936671566525`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.3578642974830655` + 
                3.9224420354290097` Log[3.1992936671566525` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061836010000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.3481683560871915`"}], "+", 
                  RowBox[{"3.919808292694121`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.3481683560871915` + 
                3.919808292694121 Log[3.1914474950105785` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06184137}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8014216413074406`"}], "+", 
                  RowBox[{"4.042275913052396`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.560982330336749`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8014216413074406` + 
                4.042275913052396 Log[3.560982330336749 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061853280000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.276577574533427`"}], "+", 
                  RowBox[{"3.900342394296467`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.1335991965799153`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.276577574533427 + 
                3.900342394296467 Log[3.1335991965799153` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06185511}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.270122386313016`"}], "+", 
                  RowBox[{"3.8985855035943646`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.1283905338788216`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.270122386313016 + 
                3.8985855035943646` Log[3.1283905338788216` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061855190000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.2698416994496127`"}], "+", 
                  RowBox[{"3.8985091034475725`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.1281640768997443`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.2698416994496127` + 
                3.8985091034475725` Log[3.1281640768997443` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06185578}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8629843935983257`"}], "+", 
                  RowBox[{"4.0588102925698735`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.611583681348158`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8629843935983257` + 
                4.0588102925698735` Log[3.611583681348158 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06185769}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8703055922614529`"}], "+", 
                  RowBox[{"4.060775063649017`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.617607459388868`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8703055922614529` + 
                4.060775063649017 Log[3.617607459388868 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06185816}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8720837034154276`"}], "+", 
                  RowBox[{"4.061252201535225`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.6190706592532322`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8720837034154276` + 
                4.061252201535225 Log[3.6190706592532322` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06185909}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8755698081352576`"}], "+", 
                  RowBox[{"4.06218760622008`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.6219395807504036`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8755698081352576` + 
                4.06218760622008 Log[3.6219395807504036` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06187723}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.9378598852493618`"}], "+", 
                  RowBox[{"4.07888911268573`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.673250780112337`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.9378598852493618` + 
                4.07888911268573 Log[3.673250780112337 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06187804}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.9404027676477325`"}], "+", 
                  RowBox[{"4.079570425118434`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.675347426316243`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.9404027676477325` + 
                4.079570425118434 Log[3.675347426316243 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06188233}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.9537500335183804`"}], "+", 
                  RowBox[{"4.083145910613163`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.686354950804809`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.9537500335183804` + 
                4.083145910613163 Log[3.686354950804809 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06190146}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.0089716094868773`"}], "+", 
                  RowBox[{"4.097927426228855`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.7319405248033775`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.0089716094868773` + 
                4.097927426228855 Log[3.7319405248033775` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061915000000000005`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.1105100445301368`"}], "+", 
                  RowBox[{"3.8550539234150687`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.1105100445301368` + 
                3.8550539234150687` Log[3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061948130000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.0450734482278252`"}], "+", 
                  RowBox[{"3.837156283283189`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.9475917431434393`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.0450734482278252` + 
                3.837156283283189 Log[2.9475917431434393` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061980150000000005`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.1922950726830646`"}], "+", 
                  RowBox[{"4.146869822371305`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.883770826008501`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.1922950726830646` + 
                4.146869822371305 Log[3.883770826008501 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06203893}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.9023745751618992`"}], "+", 
                  RowBox[{"3.7980214789119073`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.8337845671473616`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.9023745751618992 + 
                3.7980214789119073` Log[2.8337845671473616` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06205128}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.3260057369146567`"}], "+", 
                  RowBox[{"4.182444409508369`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.9949726888061714`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.3260057369146567` + 
                4.182444409508369 Log[3.9949726888061714` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06205475}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.332040004592165`"}], "+", 
                  RowBox[{"4.184047469709537`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.332040004592165 + 4.184047469709537 Log[4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06209254}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.3955639488588503`"}], "+", 
                  RowBox[{"4.200910785915102`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.052968839749823`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.3955639488588503` + 
                4.200910785915102 Log[4.052968839749823 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06257546}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.4106919794344949`"}], "+", 
                  RowBox[{"3.662023842754042`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.4471368694705475`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.4106919794344949 + 
                3.662023842754042 Log[2.4471368694705475` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06285906}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.313151451823843`"}], "+", 
                  RowBox[{"4.442089445828308`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.826387957886766`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.313151451823843 + 
                4.442089445828308 Log[4.826387957886766 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06293579}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.387348010781921`"}], "+", 
                  RowBox[{"4.461404429455812`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.889530436268422`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.387348010781921 + 
                4.461404429455812 Log[4.889530436268422 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06294673}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.397785320743897`"}], "+", 
                  RowBox[{"4.4641193520216795`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.8984192228841685`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.397785320743897 + 
                4.4641193520216795` Log[4.8984192228841685` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06307404}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.5169328147849823`"}], "+", 
                  RowBox[{"4.495074647247325`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"5", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-3.5169328147849823` + 4.495074647247325 Log[5 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06346149}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.046814601158116094`", "\[VeryThinSpace]"}], "+", 
                  
                  RowBox[{"3.5337470128378623`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.096076952886976`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.046814601158116094` + 
                3.5337470128378623` Log[2.096076952886976 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06379016}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.1742413625565841`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.497697956765828`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.1742413625565841 + 3.497697956765828 Log[2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06400569}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4.301222306029708`"}], "+", 
                  RowBox[{"4.697207674146118`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"5.673250780112337`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-4.301222306029708 + 
                4.697207674146118 Log[5.673250780112337 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06494149}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.0046857648761724`"}], "+", 
                  RowBox[{"4.876260894585884`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.282813881468968`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.0046857648761724` + 
                4.876260894585884 Log[6.282813881468968 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.0651216}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "340.22600892958513`"}], "+", 
                  RowBox[{"227.55485177030658`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-340.22600892958513` + 
                227.55485177030658` ArcTan[16.795322405754767` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512172000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "339.723399024463`"}], "+", 
                  RowBox[{"227.23146243985317`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.775894865320844`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-339.723399024463 + 
                227.23146243985317` ArcTan[16.775894865320844` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512195}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "342.713590358407`"}], "+", 
                  RowBox[{"229.15537366759096`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.89132037170802`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-342.713590358407 + 
                229.15537366759096` ArcTan[16.89132037170802 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512238000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "338.3344463358828`"}], "+", 
                  RowBox[{"226.33776878623942`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.722152125402594`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-338.3344463358828 + 
                226.33776878623942` ArcTan[16.722152125402594` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512243}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "343.57700292346635`"}], "+", 
                  RowBox[{"229.71088275594624`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.924580058769152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-343.57700292346635` + 
                229.71088275594624` ArcTan[16.924580058769152` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512307}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "337.4479283322655`"}], "+", 
                  RowBox[{"225.76734618377597`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.687807650416097`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-337.4479283322655 + 
                225.76734618377597` ArcTan[16.687807650416097` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512334}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "337.1577326070966`"}], "+", 
                  RowBox[{"225.5806203958098`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.676558013425712`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-337.1577326070966 + 
                225.5806203958098 ArcTan[16.676558013425712` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512419}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "345.53785743946776`"}], "+", 
                  RowBox[{"230.97244461759922`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"17", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-345.53785743946776` + 
                230.97244461759922` ArcTan[17 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06512436}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "336.21423974951784`"}], "+", 
                  RowBox[{"224.9735259708279`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.63995825466416`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-336.21423974951784` + 
                224.9735259708279 ArcTan[16.63995825466416 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06513659000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "352.09080622481093`"}], "+", 
                  RowBox[{"235.18816046596706`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"17.250902155733506`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-352.09080622481093` + 
                235.18816046596706` ArcTan[17.250902155733506` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06514283}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "328.24348544953295`"}], "+", 
                  RowBox[{"219.84433542638544`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.32924156369337`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-328.24348544953295` + 
                219.84433542638544` ArcTan[16.32924156369337 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06517686}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "320.8143740541714`"}], "+", 
                  RowBox[{"215.06307301884513`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.037153368106495`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-320.8143740541714 + 
                215.06307301884513` ArcTan[16.037153368106495` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06518057000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "363.5601797500078`"}], "+", 
                  RowBox[{"242.56576510800483`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"17.685899447422514`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-363.5601797500078 + 
                242.56576510800483` ArcTan[17.685899447422514` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06518241}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "319.8738252922242`"}], "+", 
                  RowBox[{"214.45770649104256`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"16", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-319.8738252922242 + 
                214.45770649104256` ArcTan[16 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.0651974}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.189020188913894`"}], "+", 
                  RowBox[{"4.922851499811421`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.44327910898523`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.189020188913894 + 
                4.922851499811421 Log[6.44327910898523 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06522871}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "371.92739884969257`"}], "+", 
                  RowBox[{"247.947154127638`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"18", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-371.92739884969257` + 247.947154127638 ArcTan[18 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.0652296}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "372.06420802163274`"}], "+", 
                  RowBox[{"248.03513786963723`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"18.00511346649258`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-372.06420802163274` + 
                248.03513786963723` ArcTan[18.00511346649258 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06526274}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "309.5887779113377`"}], "+", 
                  RowBox[{"207.83726835054162`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.59111615887916`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-309.5887779113377 + 
                207.83726835054162` ArcTan[15.59111615887916 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06530953}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "382.8449607439669`"}], "+", 
                  RowBox[{"254.96785918341874`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"18.40585134142499`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-382.8449607439669 + 
                254.96785918341874` ArcTan[18.40585134142499 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06539669000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.6471651854306611`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.3625835096585917`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.650818417830967`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.6471651854306611 + 
                3.3625835096585917` Log[1.650818417830967 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06546204}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "399.043962457531`"}], "+", 
                  RowBox[{"265.38300324638374`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"19", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-399.043962457531 + 265.38300324638374` ArcTan[19 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06600069}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.753753135453919`"}], "+", 
                  RowBox[{"5.064786039918`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.93649747605928`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.753753135453919 + 
                5.064786039918 Log[6.93649747605928 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06607541}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "446.42153197925194`"}], "+", 
                  RowBox[{"295.8327130742271`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"20.68632910055974`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-446.42153197925194` + 
                295.8327130742271 ArcTan[20.68632910055974 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06620537}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "454.939464537988`"}], "+", 
                  RowBox[{"301.305521882091`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"20.981905584437925`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-454.939464537988 + 
                301.305521882091 ArcTan[20.981905584437925` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06624774}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.924330265846996`"}], "+", 
                  RowBox[{"5.107427470854274`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"7.085903183616281`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.924330265846996 + 
                5.107427470854274 Log[7.085903183616281 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06653072}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "475.1288138854019`"}], "+", 
                  RowBox[{"314.27537973422903`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"21.67382811082654`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-475.1288138854019 + 
                314.27537973422903` ArcTan[21.67382811082654 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06693577}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "245.06473849695823`"}], "+", 
                  RowBox[{"166.27190175187468`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"12.906981120648215`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-245.06473849695823` + 
                166.27190175187468` ArcTan[12.906981120648215` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06713304}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "509.81303292669867`"}], "+", 
                  RowBox[{"336.55110941704254`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"22.83554511405802`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-509.81303292669867` + 
                336.55110941704254` ArcTan[22.83554511405802 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06725697}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "238.7156406752825`"}], "+", 
                  RowBox[{"162.1785044662108`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"12.630654175918018`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-238.7156406752825 + 
                162.1785044662108 ArcTan[12.630654175918018` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06756046}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.0850531545966327`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.2354547782502387`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.339367386753635`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.0850531545966327` + 
                3.2354547782502387` Log[1.339367386753635 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06777795}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "6.963970376130401`"}], "+", 
                  RowBox[{"5.365155658653785`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"8", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-6.963970376130401 + 5.365155658653785 Log[8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06790591}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.917312717768418`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7664784446590842`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.10055620476267689`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.917312717768418 + 
                1.7664784446590842` (0.10055620476267689` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06843281}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "220.2049427742017`"}], "+", 
                  RowBox[{"150.24011447607825`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"11.811091487287605`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-220.2049427742017 + 
                150.24011447607825` ArcTan[11.811091487287605` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06853874}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.242764020291899`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.189146031199778`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.2303969605075538`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.242764020291899 + 
                3.189146031199778 Log[1.2303969605075538` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06857748}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "7.502757311737428`"}], "+", 
                  RowBox[{"5.49734248712689`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.475624501166081`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-7.502757311737428 + 
                5.49734248712689 Log[8.475624501166081 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06859211}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "7.512621766687115`"}], "+", 
                  RowBox[{"5.499754317452651`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.484342267399942`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-7.512621766687115 + 
                5.499754317452651 Log[8.484342267399942 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06865802}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "217.25498882013835`"}], "+", 
                  RowBox[{"148.33694814859885`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"11.678494428458452`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-217.25498882013835` + 
                148.33694814859885` ArcTan[11.678494428458452` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06869977000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.8008330042839598`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7842725869449496`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.27003536747451196`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.8008330042839598` + 
                1.7842725869449496` (0.27003536747451196` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06956137}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.167784180216763`"}], "+", 
                  RowBox[{"5.659293629101737`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.064005479118531`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-8.167784180216763 + 
                5.659293629101737 Log[9.064005479118531 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.06999147}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "660.0331138261109`"}], "+", 
                  RowBox[{"432.959446216994`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"27.529969316345454`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-660.0331138261109 + 
                432.959446216994 ArcTan[27.529969316345454` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07016052}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.575599860052995`"}], "+", 
                  RowBox[{"5.757978978426875`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.42538368594352`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-8.575599860052995 + 
                5.757978978426875 Log[9.42538368594352 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07110234}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "9.223311374120703`"}], "+", 
                  RowBox[{"5.913782035698247`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-9.223311374120703 + 5.913782035698247 Log[10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07175593}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.3725091212705367`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8466672685745`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.9372431736389757`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.3725091212705367` + 
                1.8466672685745 (0.9372431736389757 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07179854000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.366523533543424`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8475111859217572`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.94695099526836`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.366523533543424 + 
                1.8475111859217572` (0.94695099526836 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.0719296}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "185.6957978715431`"}], "+", 
                  RowBox[{"127.96466897427901`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"10.223238810813292`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-185.6957978715431 + 
                127.96466897427901` ArcTan[10.223238810813292` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07258537}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "180.98626193129132`"}], "+", 
                  RowBox[{"124.92249490216587`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-180.98626193129132` + 
                124.92249490216587` ArcTan[10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07290382000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "10.493595196659633`"}], "+", 
                  RowBox[{"6.216220941270243`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"11.128390533878822`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-10.493595196659633` + 
                6.216220941270243 Log[11.128390533878822` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07404737}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "171.67021465551608`"}], "+", 
                  RowBox[{"118.90293390955324`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"9.55346010782047`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-171.67021465551608` + 
                118.90293390955324` ArcTan[9.55346010782047 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.075643}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.8048270357090022`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.9240236817566676`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"1.8915504247229356`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.8048270357090022` + 
                1.9240236817566676` (1.8915504247229356` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07604768}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.7423848557941273`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.932239628422614`", " ", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.7423848557941273` + 1.932239628422614 (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07617441}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "160.31560360608714`"}], "+", 
                  RowBox[{"111.56275126442385`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-160.31560360608714` + 
                111.56275126442385` ArcTan[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07756347}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.5013310851830401`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.9634877865574605`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2.423839036684562`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.5013310851830401` + 
                1.9634877865574605` (2.423839036684562 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.07772803}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "153.23710772449073`"}], "+", 
                  RowBox[{"106.98480613277653`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.649648857300427`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-153.23710772449073` + 
                106.98480613277653` ArcTan[8.649648857300427 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.08139233}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.626206618053084`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["94.22609086942724`", 
                   RowBox[{
                    RowBox[{"7.1052559098032475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.626206618053084` - 94.22609086942724/(7.1052559098032475` + 
                Cos[
                  Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.08232988000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "136.33232513226824`"}], "+", 
                  RowBox[{"96.04466329550273`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.79555807943958`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-136.33232513226824` + 
                96.04466329550273 ArcTan[7.79555807943958 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.08242004}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.6354287606678147`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.07045922607197`", " ", 
                    SqrtBox[
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.6354287606678147 + 2.07045922607197 (4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.08579389}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "22.028821253246285`"}], "+", 
                  RowBox[{"8.821224931692964`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"21.30910535792294`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-22.028821253246285` + 
                8.821224931692964 Log[21.30910535792294 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.08704591}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "23.506194619989632`"}], "+", 
                  RowBox[{"9.140840893392584`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"22.594977851031253`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-23.506194619989632` + 
                9.140840893392584 Log[22.594977851031253` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.09247860000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.0215359199814333`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.6426272865242084`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.0215359199814333` + 
                2.6426272865242084` Log[0.16509018904474715` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.09252029}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8683774648656655`"}], "+", 
                  RowBox[{"2.3466827048098486`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"8.83092525575033`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8683774648656655` + 
                2.3466827048098486` (8.83092525575033 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.09429836}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.456291151835639`"}], "+", 
                  RowBox[{"2.406258434389177`", " ", 
                    SqrtBox[
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.456291151835639 + 2.406258434389177 (10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.09783861}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4090.454754422499`"}], "+", 
                  RowBox[{"2626.290667839523`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"88.59336191632435`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-4090.454754422499 + 
                2626.290667839523 ArcTan[88.59336191632435 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.1275753}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "645533.0534427739`"}], "+", 
                  RowBox[{"411163.21892876737`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1306", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-645533.0534427739 + 
                411163.21892876737` ArcTan[1306 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.2029456}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.098454343116386`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2226385448528975`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.098454343116386 + 0.2226385448528975 (Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.2275303}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.135190489156352`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2203970126429854`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.135190489156352 + 0.2203970126429854 (Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.2347745}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.74181510882958`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.004256228741587193`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"8", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.74181510882958 + 0.004256228741587193 (8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.2663622}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.257224946277733`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.00514121628350096`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.257224946277733 + 0.00514121628350096 (3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.6025134999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.182853824435234`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.3011092105889481`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"19", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.182853824435234 + 1.3011092105889481` Log[19 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.6425157}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.560927487944038`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.008888053487456422`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.560927487944038 + 0.008888053487456422 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{43., 0.3385706}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.760851369737447`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.1812132141985946`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.760851369737447 + 0.1812132141985946 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{43., 0.3819354}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.860408215485915`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.17517214346143037`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.860408215485915 + 0.17517214346143037` (2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{43., 0.48220989999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.390125104943461`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.13930969472735394`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.390125104943461 + 0.13930969472735394` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{43., 0.5065944}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.376451793450134`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2543202163281248`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.376451793450134 + 0.2543202163281248 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{43., 0.6991431}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.447320449139458`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.04320694329335523`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.447320449139458 + 0.04320694329335523 (E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{43., 0.794781}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.185621486077684`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.000013313228721464516`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.185621486077684 + 0.000013313228721464516` (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.1215462}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.8561213379932475`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2306378001126783`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.8561213379932475` + 0.2306378001126783 (-Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.12429459999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.882801121212158`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22905641467684468`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.882801121212158 + 0.22905641467684468` (-Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.124416}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.637992607849565`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23025518800835107`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.637992607849565 + 0.23025518800835107` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.1251302}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.674197244572401`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22754914840984153`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.674197244572401 + 0.22754914840984153` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.1278716}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.658443987751872`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2291092286671078`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.658443987751872 + 0.2291092286671078 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.1287981}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.694290874035883`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22642657671646335`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.694290874035883 + 0.22642657671646335` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.1348796}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.004360690586477`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["116.94202343973058`", 
                   RowBox[{"10", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[14.004360690586477` - 116.94202343973058`/(10 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.1377727}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.821454359766988`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23363244186984325`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.821454359766988 + 0.23363244186984325` (Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.1402289}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"13.974206961164086`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["115.7369966348666`", 
                   RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[13.974206961164086` - 115.7369966348666/(10 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.2601696}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.399855169490787`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.13432544021827855`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.399855169490787 + 0.13432544021827855` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.37884419999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.610717943206177`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.668913045563452`", " ", 
                    SqrtBox[
                    RowBox[{
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.610717943206177 + 1.668913045563452 ((Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.5788592}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.685199234184905`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.21632486859513914`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.685199234184905 + 0.21632486859513914` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{44., 0.6276940999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.838510256305197`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.1040920978316646`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.838510256305197 + 1.1040920978316646` (Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{45., 0.1862309}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.153503067342647`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.21416818071440089`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.153503067342647 - 0.21416818071440089` (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.06145732}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "17.235590982926656`"}], "+", 
                  RowBox[{"18.566493726219413`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "0.13506945696943434`"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-17.235590982926656` + 18.566493726219413` (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^0.13506945696943434`, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.06388258000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.0085789543322812`"}], "+", 
                  RowBox[{"5.101688047409571`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "5", "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.0085789543322812` + 5.101688047409571 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[5], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.06554669}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.228827139745164`"}], "+", 
                  RowBox[{"6.224092901046108`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.228827139745164 + 6.224092901046108 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.06976679}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.793427969195571`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["712.9111739213446`", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"16.819747567586973`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "1.458463777236594`"]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.793427969195571` - 
                712.9111739213446 (16.819747567586973` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1.458463777236594), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.07033659}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.393113549408857`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.471449262187247`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "1", "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.393113549408857 + 1.471449262187247 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[1], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.07061453}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.68145377978156`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["675.322514851161`", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"16.251484817364336`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "1.458463777236594`"]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.68145377978156 - 
                675.322514851161 (16.251484817364336` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1.458463777236594), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.0816369}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"13.853603634634164`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["435.4593921719207`", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12.201733644632064`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "1.458463777236594`"]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               13.853603634634164` - 
                435.4593921719207 (12.201733644632064` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1.458463777236594), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.1304244}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.837240732859633`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23315878084054883`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Csc", "[", "8", "]"}], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.837240732859633 + 0.23315878084054883` (Csc[8] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.3089982}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.3072718372687417`"}], "+", 
                  RowBox[{"4.763517181126318`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.3072718372687417 + 4.763517181126318 ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.5111088}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.371657322285255`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.019476169337207333`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.371657322285255 + 0.019476169337207333` (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.5374038}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.421164505449911`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8437213216320703`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.421164505449911 + 1.8437213216320703` ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.5747127}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.678171275390223`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.019816276775891442`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.678171275390223 - 0.019816276775891442` (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.5816171}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.341209690835919`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.788753907569822`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.341209690835919 + 3.788753907569822 ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.6801256}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.70869012161449`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.0009147570641370097`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "9.125064325277467`"}], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               8.70869012161449 - 
                0.0009147570641370097 ((-9.125064325277467) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{47., 0.1094541}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "364.6222063083439`"}], "+", 
                  RowBox[{"243.16275800155339`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"18.423839036684562`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-364.6222063083439 + 
                243.16275800155339` ArcTan[18.423839036684562` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{47., 0.1150662}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "170.65439898316492`"}], "+", 
                  RowBox[{"118.19423387812358`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-170.65439898316492` + 
                118.19423387812358` ArcTan[10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{47., 0.1493677}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "155.4847151505851`"}], "+", 
                  RowBox[{"108.35958111302371`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"9.405851341424992`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-155.4847151505851 + 
                108.35958111302371` ArcTan[9.405851341424992 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{47., 0.1499719}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "152.4769913674793`"}], "+", 
                  RowBox[{"106.41497791321171`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-152.4769913674793 + 
                106.41497791321171` ArcTan[9.250902155733506 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{47., 0.22960699999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.235555137026972`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2116897177955699`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.235555137026972 + 0.2116897177955699 (Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{47., 0.6076853}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.036332642295346`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2051374917705204`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2.2597971036109357`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               8.036332642295346 + 
                0.2051374917705204 (-Cos[(2.2597971036109357` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.06184404}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.3120920761561987`"}], "+", 
                  RowBox[{"3.910003260643197`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SqrtBox["10"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.3120920761561987` + 
                3.910003260643197 Log[10^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.06662094}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.9131545831914369`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.285607462777398`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", "9", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.9131545831914369 + 3.285607462777398 Log[ArcTan[9] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.0713323}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.4318643369652033`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8382612561439184`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"Sin", "[", "1", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.4318643369652033` + 1.8382612561439184` (Sin[1] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.07217032}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.72675344130017`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["255.27639261112787`", 
                   RowBox[{"18", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[17.72675344130017 - 255.27639261112787`/(18 + Cos[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.20711739999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.960832038698067`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.21336094584679735`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.960832038698067 + 0.21336094584679735` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.2199561}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.0971887703192555`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2185233613513932`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.0971887703192555` + 0.2185233613513932 (Cos[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.4004416}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.426563006986301`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.318747615996268`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.6190706592532322`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.426563006986301 + 
                1.318747615996268 Log[3.6190706592532322` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.4143957}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.5719703428415572`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.471307206833123`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"8", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.5719703428415572` + 1.471307206833123 Log[8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{48., 0.6121755999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.444508709114828`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.008857374802959343`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.444508709114828 + 0.008857374802959343 (E^Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{49., 0.14077199999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.879530494844338`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23257454268706854`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.879530494844338 + 0.23257454268706854` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{49., 0.2500214}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.3519225737128915`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.135853484877052`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.3519225737128915` + 0.135853484877052 (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{49., 0.6735154}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.51224372257077`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.03736298495351579`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[8.51224372257077 + 0.03736298495351579 (E^(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{50., 0.1215462}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.8561213379932475`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.2306378001126783`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.8561213379932475` - 0.2306378001126783 (Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{50., 0.1238304}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.626308377129418`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2300748534062512`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.626308377129418 + 0.2300748534062512 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{50., 0.2957954}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.553202800443528`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.005845399932965058`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.553202800443528 + 0.005845399932965058 (-Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06147388}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "19.323411278135257`"}], "+", 
                  RowBox[{"20.574180508030185`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "8"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-19.323411278135257` + 20.574180508030185` (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 8], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06152044}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.829823873529328`"}], "+", 
                  RowBox[{"6.89924603740622`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.9372431736389757`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.829823873529328 + 
                6.89924603740622 (0.9372431736389757 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.061520530000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.819605878824292`"}], "+", 
                  RowBox[{"6.895069042957402`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.9304316456321475`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.819605878824292 + 
                6.895069042957402 (0.9304316456321475 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06152337}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.8851435845684836`"}], "+", 
                  RowBox[{"6.921835249154287`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.9742677911445741`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.8851435845684836` + 
                6.921835249154287 (0.9742677911445741 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06152867}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.9233764038659196`"}], "+", 
                  RowBox[{"6.937422936293051`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-3.9233764038659196` + 6.937422936293051 (1 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06188955}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.4475474057114814`"}], "+", 
                  RowBox[{"5.634422515280823`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "5", "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.4475474057114814` + 5.634422515280823 (1 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[5], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06225237}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4.822259177555754`"}], "+", 
                  RowBox[{"7.298616559475245`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.6352605637004558`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-4.822259177555754 + 
                7.298616559475245 (1.6352605637004558` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.062295170000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.0263489359326`"}], "+", 
                  RowBox[{"6.566064462369085`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.43053325267728976`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.0263489359326 + 
                6.566064462369085 (0.43053325267728976` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06317242}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.714016929787085`"}], "+", 
                  RowBox[{"6.433652293466553`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2518911998722272`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.714016929787085 + 
                6.433652293466553 (0.2518911998722272 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06326558}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.6879393806536442`"}], "+", 
                  RowBox[{"6.4225137855801036`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.23751881159651242`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.6879393806536442` + 
                6.4225137855801036` (0.23751881159651242` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06349851000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "16.30818725052314`"}], "+", 
                  RowBox[{"18.639407428315685`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "8"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-16.30818725052314 + 18.639407428315685` (1 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 8], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06529772}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "6.528338344387012`"}], "+", 
                  RowBox[{"7.9608068421943585`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.9640345605076606`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-6.528338344387012 + 
                7.9608068421943585` (2.9640345605076606` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06676593}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.989135565996738`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7550897887940957`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.02033930759711211`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.989135565996738 + 
                1.7550897887940957` ((0.02033930759711211 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06740567}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "7.511059620179566`"}], "+", 
                  RowBox[{"8.330922646420685`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.7822302614258803`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-7.511059620179566 + 
                8.330922646420685 (3.7822302614258803` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.06901264}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.24422862903763`"}], "+", 
                  RowBox[{"8.602470654038529`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.411692128965182`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-8.24422862903763 + 
                8.602470654038529 (4.411692128965182 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.07047576}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.915464079667029`"}], "+", 
                  RowBox[{"8.847960464258975`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"5", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-8.915464079667029 + 8.847960464258975 (5 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.0765266}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.635091927242598`"}], "+", 
                  RowBox[{"7.649659069328355`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6.922668618159915`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "5", "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-8.635091927242598 + 
                7.649659069328355 (6.922668618159915 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[5], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.07772734}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "9.170256261112606`"}], "+", 
                  RowBox[{"7.811079574302421`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.489937180799778`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "5", "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-9.170256261112606 + 
                7.811079574302421 (7.489937180799778 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[5], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.08084951}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "14.299426754944783`"}], "+", 
                  RowBox[{"10.729742753753525`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-14.299426754944783` + 10.729742753753525` (10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.08604297}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "17.746501627630785`"}], "+", 
                  RowBox[{"11.870630723953292`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.363559213849683`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-17.746501627630785` + 
                11.870630723953292` (13.363559213849683` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.09681984}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "28.041900499786983`"}], "+", 
                  RowBox[{"15.071337978328655`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"23.760244793426224`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-28.041900499786983` + 
                15.071337978328655` (23.760244793426224` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.1129741}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "66.49510171422111`"}], "+", 
                  RowBox[{"25.47492577296805`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"64", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-66.49510171422111 + 25.47492577296805 (64 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.1290069}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.697686711093992`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23158570231507875`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.697686711093992 + 0.23158570231507875` (ArcTan[
                    ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.1292925}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.613313908091773`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.24573398995502804`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.613313908091773 + 0.24573398995502804` (Sin[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.1305644}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.837482792373916`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.11719911113178567`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.837482792373916 + 0.11719911113178567` (2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.1328043}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.895789689990825`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23262185350076042`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.895789689990825 + 0.23262185350076042` (-Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.5876741}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.291138423143284`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["233.00898587279977`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               17.291138423143284` + 
                233.00898587279977`/(-24.060521364609343` + Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{51., 0.6733912}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.04979065607116`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.000060763711193188014`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.04979065607116 + 0.000060763711193188014` (3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.059666870000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.772299178763555`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"4.770799585789375`", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.77196225083388`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.772299178763555 + 4.770799585789375 Tan[
                   Log[8.77196225083388 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.06387303}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "70.03779902079992`"}], "+", 
                  RowBox[{"58.2955214224528`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-70.03779902079992 + 
                58.2955214224528 ArcTan[(10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.0644244}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "61.52475903662748`"}], "+", 
                  RowBox[{"56.58923040286507`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-61.52475903662748 + 56.58923040286507 ArcTan[
                   Log[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.06512104}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "699.9529378604716`"}], "+", 
                  RowBox[{"572.2278292534412`", " ", 
                    SqrtBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"17", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-699.9529378604716 + 
                572.2278292534412 ArcTan[17 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.06512169}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "775.0866326173345`"}], "+", 
                  RowBox[{"789.2380048505503`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"17.250902155733506`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-775.0866326173345 + 789.2380048505503 ArcTan[
                   ArcTan[17.250902155733506` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.0652242}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "148.56337996313087`"}], "+", 
                  RowBox[{"67.07265905975432`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.444304250805189`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-148.56337996313087` + 
                67.07265905975432 ArcTan[15.444304250805189` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.06556393}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "195.0391356284101`"}], "+", 
                  RowBox[{"86.30367642221451`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"19", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-195.0391356284101 + 
                86.30367642221451 ArcTan[19 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.07226858}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9007689840853663`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7197541527257102`", " ", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.4471368694705475`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9007689840853663` + 
                0.7197541527257102 Log[2.4471368694705475` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.07353382}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.546453123670124`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7409674313967997`", " ", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.139384984653288`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.546453123670124 + 
                0.7409674313967997 Log[3.139384984653288 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.07482935}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "76.00806137007096`"}], "+", 
                  RowBox[{"36.89737662243202`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-76.00806137007096 + 36.89737662243202 ArcTan[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.07512909}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.102112012203881`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.767054592955465`", " ", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.102112012203881 + 0.767054592955465 Log[4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.07794697}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "37.620000626864794`"}], "+", 
                  RowBox[{"38.28549836265025`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"5.430596917572559`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-37.620000626864794` + 38.28549836265025 ArcTan[
                   Log[5.430596917572559 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.07932291}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "15.559768408606764`"}], "-", 
                  RowBox[{"7.38767707073307`", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"15.624790525196431`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-15.559768408606764` - 7.38767707073307 
                Log[(15.624790525196431` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.08047586}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.4885565381348316`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.8572012132668946`", " ", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"7.085903183616281`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.4885565381348316` + 
                0.8572012132668946 Log[7.085903183616281 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.08055785}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "35.65138239911739`"}], "+", 
                  RowBox[{"36.76436048060342`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"5.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-35.65138239911739 + 36.76436048060342 ArcTan[
                   Log[5.141406940734484 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.09363928}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1505.646627103637`"}], "+", 
                  RowBox[{"622.9851285133059`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"74", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1505.646627103637 + 
                622.9851285133059 ArcTan[74 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.10106309999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2595.4655339794467`"}], "+", 
                  RowBox[{"1067.3628306374383`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"101.88305014681049`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2595.4655339794467` + 
                1067.3628306374383` ArcTan[101.88305014681049` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.1300742}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "15.392391073004305`"}], "+", 
                  RowBox[{"19.45119954195647`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.9372431736389757`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-15.392391073004305` + 
                19.45119954195647 ArcTan[(0.9372431736389757 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.6067212}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.162115387881974`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.10397544051766744`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.490264335021571`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               8.162115387881974 + 
                0.10397544051766744` (-ArcTan[8.490264335021571 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{53., 0.06181939}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.4619150263863834`"}], "+", 
                  RowBox[{"3.950666598337733`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", "5", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.4619150263863834` + 
                3.950666598337733 Log[3 + Cos[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{53., 0.06566415}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"16.578039106193582`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["190.91377066673246`", 
                   RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "9", "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               16.578039106193582` - 190.91377066673246`/(10 + ArcTan[9]^4 + 
                Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{53., 0.07212949}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "367.8117578231146`"}], "+", 
                  RowBox[{"245.27566242831952`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"18", "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-367.8117578231146 + 
                245.27566242831952` ArcTan[18 + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{53., 0.07824269}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.0756771399145941`"}], "+", 
                  RowBox[{"3.8302852285762814`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.0756771399145941` + 
                3.8302852285762814` Log[3.141406940734484 + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{53., 0.08791847}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "152.34893638948733`"}], "+", 
                  RowBox[{"106.39114336477475`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.760121933840146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-152.34893638948733` + 
                106.39114336477475` ArcTan[8.760121933840146 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{53., 0.08797459}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.838357960920655`"}], "+", 
                  RowBox[{"3.7632940701329827`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.838357960920655 + 3.7632940701329827` Log[3 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{53., 0.09647013}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.007222256833985`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8841537702330897`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"1.783246225570891`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.007222256833985 + 
                1.8841537702330897` (1.783246225570891 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{54., 0.061149760000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"19.799332746805998`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["407.07257369977054`", 
                   RowBox[{
                    RowBox[{"26.18617480394142`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               19.799332746805998` - 407.07257369977054`/(26.18617480394142 + 
                Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{54., 0.32659849999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.7999283480458046`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.0198684021695965`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.7999283480458046` + 2.0198684021695965` Log[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.06799867}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.6572473330187103`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7684931805152553`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.6572473330187103` + 1.7684931805152553` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.07085469}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.4985124751854446`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8287384917888867`", " ", 
                    SqrtBox[
                    RowBox[{
                    SqrtBox[
                    RowBox[{"Cos", "[", "1", "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.4985124751854446` + 
                1.8287384917888867` (Cos[1]^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.07562296}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.8078993745016358`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.923618081237131`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "5", "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.8078993745016358` + 1.923618081237131 (ArcTan[5]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.12266289999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.6621528265478115`"}], "+", 
                  RowBox[{"3.320796857645102`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.6621528265478115 + 
                3.320796857645102 Log[3.141406940734484 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.12353059999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.3457124309683421`"}], "+", 
                  RowBox[{"3.491015599896791`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.917599550587852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.3457124309683421` + 
                3.491015599896791 Log[3.917599550587852 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.1249903}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.055392284608486`"}], "+", 
                  RowBox[{"3.6646721217243017`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.75416114710645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.055392284608486 + 
                3.6646721217243017` Log[4.75416114710645 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.12641919999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.2197618148031686`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.8329398768352463`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.2235684347352738`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.2197618148031686` + 
                2.8329398768352463` Log[1.2235684347352738` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.129654}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.6375258697290667`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.7196944390651585`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"0.8596687117826329`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.6375258697290667` + 
                2.7196944390651585` Log[0.8596687117826329 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.1346735}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "170.188287448925`"}], "+", 
                  RowBox[{"117.26570956942615`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-170.188287448925 + 
                117.26570956942615` ArcTan[10 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.1465059}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "133.83659582054756`"}], "+", 
                  RowBox[{"93.82176024412855`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.924580058769152`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-133.83659582054756` + 
                93.82176024412855 ArcTan[7.924580058769152 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.1546418}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "118.09956080639905`"}], "+", 
                  RowBox[{"83.65900661728685`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"7", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-118.09956080639905` + 
                83.65900661728685 ArcTan[7 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.1548635}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.9113772980424155`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.11532976072422947`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.9113772980424155` + 0.11532976072422947` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.193374}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3442.5317047535505`"}], "+", 
                  RowBox[{"2209.2301337728077`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"100", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"1.9799691086980715`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3442.5317047535505` + 
                2209.2301337728077` ArcTan[100 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 1.9799691086980715` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{55., 0.23327189999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.313259983660849`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.13620901138177843`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.313259983660849 + 0.13620901138177843` (-Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{56., 0.06516859}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1138.4238272411003`"}], "+", 
                  RowBox[{"1155.4381437753163`", " ", 
                    SuperscriptBox["0.8297395066373736`", 
                    FractionBox["1", 
                    RowBox[{"16", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1138.4238272411003` + 
                1155.4381437753163` 0.8297395066373736^((16 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{56., 0.06521953}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "194.15351242463208`"}], "+", 
                  RowBox[{"43.881656402856635`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"15.286863325440356`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-194.15351242463208` + 
                43.881656402856635` E^ArcTan[15.286863325440356` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{56., 0.0804193}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"12.812357889080358`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.0059076894165321844`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"37.21805548865383`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               12.812357889080358` - 
                0.0059076894165321844` (37.21805548865383 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{56., 0.14712039999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.851293681495695`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.23627786723882208`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.851293681495695 - 0.23627786723882208` (-Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{56., 0.5303549}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.087890835346945`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"2.41849635492453`", " ", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[9.087890835346945 - 2.41849635492453 Cos[ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{57., 0.12457009999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.5645338959216035`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2322642656926955`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"3.0207721405755628`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.5645338959216035` + 
                0.2322642656926955 (ArcTan[3.0207721405755628` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{57., 0.1254855}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.801884929318195`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2335198583330202`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.801884929318195 + 0.2335198583330202 (Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{57., 0.1275458}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.699472534981254`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2289540404671463`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.699472534981254 + 0.2289540404671463 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{57., 0.28843569999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.425246403246899`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.197699449663592`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[6.425246403246899 + 0.197699449663592 (Cos[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{57., 0.5974982999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.902552182356827`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.20944357158049576`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.902552182356827 + 0.20944357158049576` (Cos[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{58., 0.11416209999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "81.11049669357705`"}], "+", 
                  RowBox[{"38.99430091632588`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-81.11049669357705 + 
                38.99430091632588 ArcTan[10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{58., 0.40051919999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.364883583838387`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.003344772628625309`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.795322405754767`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               7.364883583838387 + 
                0.003344772628625309 (7.795322405754767 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{59., 0.6765044}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.275952435032677`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"9.95661658787682`*^-7", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"24.060521364609343`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               8.275952435032677 + 
                9.95661658787682*^-7 (-(24.060521364609343` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{60., 0.061903770000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.1353315604026606`"}], "+", 
                  RowBox[{"3.861835075532683`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "3", "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.1353315604026606` + 
                3.861835075532683 Log[3 + Sin[3]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{60., 0.06489454}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.2259912390305816`"}], "+", 
                  RowBox[{"6.222483935726251`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.02033930759711211`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.2259912390305816` + 
                6.222483935726251 ((0.02033930759711211 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{60., 0.06758846}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.1577876118615467`"}], "+", 
                  RowBox[{"3.8590543019922845`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.1577876118615467` + 
                3.8590543019922845` Log[3.141406940734484 + Sin[
                    Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{60., 0.06934813000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "346.81305433411933`"}], "+", 
                  RowBox[{"231.82219844922722`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.722152125402594`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-346.81305433411933` + 
                231.82219844922722` ArcTan[16.722152125402594` + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{60., 0.06961041}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.3454078996145213`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8230358462040024`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.3548761998742915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.3454078996145213` + 
                1.8230358462040024` (0.3548761998742915 + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{60., 0.07148043}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.3629871085989365`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8189417574648086`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.3548761998742915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.3629871085989365` + 
                1.8189417574648086` (0.3548761998742915 + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{60., 0.07848597}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "188.91547716349038`"}], "+", 
                  RowBox[{"129.94538046485374`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-188.91547716349038` + 
                129.94538046485374` ArcTan[10 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06176717}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.3949875619304024`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.602434355626078`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.883770826008501`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.3949875619304024` + 
                1.602434355626078 Log[4.883770826008501 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.0618013}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.4423499690099264`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.594685186327236`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.6688673773074`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.4423499690099264` + 
                1.594685186327236 Log[4.6688673773074 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06181824}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.2370262976077857`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.628182585541052`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"5.636251487486348`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.2370262976077857` + 
                1.628182585541052 Log[5.636251487486348 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.062044}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.1011045994582105`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.6502241699165625`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.327356083675966`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.1011045994582105` + 
                1.6502241699165625` Log[6.327356083675966 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06226238}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "9.742767859622752`"}], "+", 
                  RowBox[{"8.118717659250404`", " ", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-9.742767859622752 + 8.118717659250404 (2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^
                  Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06238193}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.9757540578453231`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.6704624248115774`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"7", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.9757540578453231 + 1.6704624248115774` Log[7 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06274319}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"20.287412182960505`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.07051580236395409`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "16"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[20.287412182960505` - 0.07051580236395409 (-16 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06274466000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "17.597974248544414`"}], "+", 
                  RowBox[{"13.218705949484042`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.189126509606261`", "\[VeryThinSpace]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-17.597974248544414` + 
                13.218705949484042` Log[4.189126509606261 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06331188}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "462.61471345968783`"}], "+", 
                  RowBox[{"315.3323255269264`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-462.61471345968783` + 
                315.3323255269264 ArcTan[10 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06394687}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "392.15606192423843`"}], "+", 
                  RowBox[{"269.3355889269107`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-392.15606192423843` + 
                269.3355889269107 ArcTan[9 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.06500157}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"39.17654560853768`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.025802187136479585`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "37.59513596669617`"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               39.17654560853768 - 
                0.025802187136479585` (-37.59513596669617 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.1089161}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.591417451977695`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.426386700268679`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.591417451977695 + 1.426386700268679 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{61., 0.5037604}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.130401726895609`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.20963612370480644`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.130401726895609 + 0.20963612370480644` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{63., 0.06751412}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.977672782577548`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7570790921604609`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", "8"], "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.977672782577548 + 1.7570790921604609` (ArcTan[
                    Rational[1, 8]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{63., 0.06899292}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.6403273368340283`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.754290908673281`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.6403273368340283` + 1.754290908673281 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{63., 0.07032799}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.673699618433507`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.746763162288089`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.673699618433507 + 1.746763162288089 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{63., 0.5310547999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.235830865219164`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2290936700064957`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.235830865219164 + 0.2290936700064957 (Log[3 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.06183927}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.6993212029882294`"}], "+", 
                  RowBox[{"5.362583709096708`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"Tan", "[", "1", "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "5", "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.6993212029882294` + 5.362583709096708 (Log[
                    Tan[1]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[5], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.0623073}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.0207834361090744`"}], "+", 
                  RowBox[{"6.563720425647441`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "4", "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.0207834361090744` + 
                6.563720425647441 (Cos[4]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.06724254}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.9451962439623554`"}], "+", 
                  RowBox[{"6.450933994626187`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.9451962439623554` + 6.450933994626187 (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.06870293}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.89300567585771`"}], "+", 
                  RowBox[{"6.424793005634098`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.89300567585771 + 6.424793005634098 (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.0700537}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.0545993732751135`"}], "+", 
                  RowBox[{"6.505014794456015`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-3.0545993732751135` + 6.505014794456015 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.12356429999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.669395487034418`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22933817435681753`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Sin", "[", "6", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.669395487034418 + 0.22933817435681753` (ArcTan[Sin[6] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.1340499}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.768654047657762`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23014671123957958`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.768654047657762 + 0.23014671123957958` (Cos[E^(2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{64., 0.5920048}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "40.34046684542672`"}], "+", 
                  RowBox[{"12.407344595063092`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"48.56882229401438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-40.34046684542672 + 
                12.407344595063092` Log[48.56882229401438 + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{65., 0.06305985}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"29.254218226948375`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"4.668529971556548`*^-6", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "49"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}], "4"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[29.254218226948375` - 4.668529971556548*^-6 (-49 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^4, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{65., 0.06830095}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "103.02645017962398`"}], "+", 
                  RowBox[{"48.16449531346552`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    RowBox[{"ArcTan", "[", "81", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-103.02645017962398` + 
                48.16449531346552 ArcTan[10 + ArcTan[81] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{65., 0.1301319}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "26.262271731302903`"}], "+", 
                  RowBox[{"29.431934081569736`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-26.262271731302903` + 29.431934081569736` ArcTan[
                   Log[4 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{65., 0.1776693}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "139.15129764990306`"}], "+", 
                  RowBox[{"97.73532169993288`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-139.15129764990306` + 
                97.73532169993288 ArcTan[9 + ArcTan[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.04938061}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.062700090010495`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["216.51838510294067`", 
                   RowBox[{
                    RowBox[{"-", "16"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6.024244290186736`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               17.062700090010495` + 
                216.51838510294067`/(-16 + Cos[6.024244290186736 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.05215477}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"19.245161146459672`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["364.06960919841106`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6.024244290186736`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               19.245161146459672` + 
                364.06960919841106`/(-24.060521364609343` + 
                 Cos[6.024244290186736 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.05278378}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"19.240898874688227`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["363.9132826019152`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               19.240898874688227` + 
                363.9132826019152/(-24.060521364609343` + Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.05636119}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.295534321065237`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["126.1802047454759`", 
                   RowBox[{
                    RowBox[{"-", "10"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6.024244290186736`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15.295534321065237` + 
                126.1802047454759/(-10 + Cos[6.024244290186736 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.06109036}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.1724839234760664`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.638696016371992`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.1724839234760664` + 1.638696016371992 Log[6 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.06596250000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "210.14810935672256`"}], "+", 
                  RowBox[{"92.54515564645425`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "3"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-210.14810935672256` + 
                92.54515564645425 ArcTan[E^3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.06604022}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "268.42654483000206`"}], "+", 
                  RowBox[{"181.3280826326467`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "6", "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-268.42654483000206` + 
                181.3280826326467 ArcTan[10 + ArcTan[6]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.08511289}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "182.37067830027655`"}], "+", 
                  RowBox[{"125.62818305022715`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-182.37067830027655` + 
                125.62818305022715` ArcTan[10 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.1384891}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.806488961201289`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23393037161275534`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"4", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.806488961201289 + 0.23393037161275534` (-Cos[4 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.049422}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.3151529023225323`"}], "+", 
                  RowBox[{"3.9230706670920776`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.3151529023225323` + 
                3.9230706670920776` Log[3 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.05444476}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.9395196866106479`"}], "+", 
                  RowBox[{"4.087546483070614`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.6549198872311592`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.9395196866106479` + 
                4.087546483070614 Log[3.6549198872311592` + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.05545196}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.566541943012263`"}], "+", 
                  RowBox[{"4.517932337695823`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"5", "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.566541943012263 + 
                4.517932337695823 Log[5 + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.057312840000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.6730960535365664`"}], "+", 
                  RowBox[{"3.9961679750772623`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.133417881271985`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.6730960535365664` + 
                3.9961679750772623` Log[3.133417881271985 + Cos[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.058068140000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.095515460307382`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["217.47440092751532`", 
                   RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1000000", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               17.095515460307382` - 217.47440092751532`/(10 + 
                ArcTan[1000000 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^4 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.05807308}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.094427482916643`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["217.4295330994215`", 
                   RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10000", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               17.094427482916643` - 217.4295330994215/(10 + 
                ArcTan[10000 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^4 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.060283960000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "381.49218016528476`"}], "+", 
                  RowBox[{"254.07830005729232`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"18.011024089573652`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-381.49218016528476` + 
                254.07830005729232` ArcTan[18.011024089573652` + Cos[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.07148967}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8333608135405282`"}], "+", 
                  RowBox[{"4.04578742364312`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.6549198872311592`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{"3", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8333608135405282` + 
                4.04578742364312 Log[3.6549198872311592` + Sin[3 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.11564659999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"11.156405866245459`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"2.945701434279511`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               11.156405866245459` - 
                2.945701434279511 (Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.1330553}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "52.119688681164405`"}], "+", 
                  RowBox[{"44.7597507582747`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"8.407613482131985`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-52.119688681164405` + 
                44.7597507582747 ArcTan[(8.407613482131985 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.1532121}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.768866032418626`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.5162017817051089`", " ", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.768866032418626 + 0.5162017817051089 Log[1 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.15379479999999998`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.692468591556598`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.5202742151740243`", " ", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.2235684347352738`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.692468591556598 + 
                0.5202742151740243 Log[1.2235684347352738` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.26372219999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "10.27176919799898`"}], "-", 
                  RowBox[{"5.0781150945395375`", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"22.74308309413165`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-10.27176919799898 - 5.0781150945395375` 
                Log[(22.74308309413165 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 3 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.6221284}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.4293928161218705`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.1280511397899158`", " ", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.988615073697536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               7.4293928161218705` + 
                0.1280511397899158 Log[9.988615073697536 - Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{67., 0.6253018}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.229564726696885`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.002314598016353476`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"21.602091657192208`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               7.229564726696885 + 
                0.002314598016353476 ((21.602091657192208` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06126179}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.1141167727824228`"}], "+", 
                  RowBox[{"1.928218631817072`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.1141167727824228` + 1.928218631817072 Log[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06130269}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.3461841479834045`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.4566029471730157`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.2235684347352738`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.3461841479834045 + 
                3.4566029471730157` Log[1.2235684347352738` + Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06213814}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.3926002482752935`"}], "+", 
                  RowBox[{"4.219987409010468`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.226147468672337`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.3926002482752935` + 
                4.219987409010468 Log[8.226147468672337 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06516761}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "810.4307781169767`"}], "+", 
                  RowBox[{"587.9600607905962`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"19", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-810.4307781169767 + 
                587.9600607905962 ArcTan[ArcTan[19 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06536874}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "617.4234728825991`"}], "+", 
                  RowBox[{"403.74342055057537`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"30.46859714520918`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-617.4234728825991 + 
                403.74342055057537` ArcTan[30.46859714520918 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06564055}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.6100962650608626`"}], "+", 
                  RowBox[{"4.001532771819176`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.6100962650608626` + 
                4.001532771819176 Log[3.141406940734484 + Sin[
                    Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06566386}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "642.5744301723811`"}], "+", 
                  RowBox[{"468.1500497301281`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"16", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-642.5744301723811 + 
                468.1500497301281 ArcTan[ArcTan[16 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06585246}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "129.96074230297128`"}], "+", 
                  RowBox[{"98.7257775052239`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"1.4492459452397988`", "\[VeryThinSpace]"}], "+", 
                    
                    SqrtBox[
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-129.96074230297128` + 
                98.7257775052239 ArcTan[1.4492459452397988` + (10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06653107}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.1817426142688423`"}], "+", 
                  RowBox[{"3.8671880994982004`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.1817426142688423` + 
                3.8671880994982004` Log[3.141406940734484 + Sin[
                    Sin[
                    Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.06976162}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "328.21124718873733`"}], "+", 
                  RowBox[{"219.66430757635192`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"16", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-328.21124718873733` + 
                219.66430757635192` ArcTan[16 + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.08375001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.3679725756973599`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.4863913284218053`", " ", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.3679725756973599 + 1.4863913284218053` (9 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{68., 0.39715459999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.722053998273439`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7200000500847392`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"]}], ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.722053998273439 + 1.7200000500847392` (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{69., 0.35582569999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.895438100237639`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.6226882886998955`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"5.636251487486348`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.895438100237639 + 
                0.6226882886998955 Log[5.636251487486348 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{69., 0.4373622}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.758259578393919`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8635039575105767`", " ", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.758259578393919 + 1.8635039575105767` (2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^
                  Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{70., 0.1221872}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.417327170937012`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22208694946457258`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.417327170937012 + 0.22208694946457258` (Log[3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{70., 0.12343349999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.386697046672758`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22285231683511977`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.386697046672758 + 0.22285231683511977` (Log[4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{70., 0.1904291}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.939808272446758`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.22340884487097312`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.939808272446758 + 0.22340884487097312` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (1 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[-1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{70., 0.31568609999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "223.51090448475694`"}], "+", 
                  RowBox[{"151.7655482263212`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"17", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-223.51090448475694` + 
                151.7655482263212 ArcTan[17 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{71., 0.05955156}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.579128578666343`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8232752507408343`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"18.763659522142685`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.579128578666343 + 
                1.8232752507408343` (Sin[18.763659522142685` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{71., 0.07189146}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.3289762081567225`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8580584105327242`", " ", 
                    SqrtBox[
                    RowBox[{
                    SqrtBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.2062700391144091`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.3289762081567225` + 
                1.8580584105327242` (Cos[0.2062700391144091 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{71., 0.08155882}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.9302851885113002`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.9179398386177795`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"4", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.9302851885113002` + 1.9179398386177795` (ArcTan[4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{72., 0.06037431}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.1361999574069346`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.6446298680378355`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.1622658946312185`", "\[VeryThinSpace]"}], "-", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.1361999574069346` + 
                1.6446298680378355` Log[6.1622658946312185` - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{72., 0.06335043}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.4507548273808042`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7480250752289124`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.4507548273808042 + 1.7480250752289124` Log[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{72., 0.11810459999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.717012666942244`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.22277819261254236`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.717012666942244 - 0.22277819261254236` (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{72., 0.12050179999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.713399245797607`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.22297793082545833`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.713399245797607 - 0.22297793082545833` (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{72., 0.1620313}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.166740941485281`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.471984431952036`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.166740941485281 + 1.471984431952036 ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{72., 0.3230325}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "177.11199508428834`"}], "+", 
                  RowBox[{"150.5452506405691`", " ", 
                    SqrtBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"7", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-177.11199508428834` + 150.5452506405691 ArcTan[7 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{72., 0.4410574}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.135744494793512`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.19654147796122845`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.475624501166081`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               6.135744494793512 + 
                0.19654147796122845` (Log[8.475624501166081 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.06314481}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "226.94341720340074`"}], "+", 
                  RowBox[{"105.47683868962591`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-226.94341720340074` + 
                105.47683868962591` ArcTan[10 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.06509309}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.7790538018012407`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.5684827810043453`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.708296723714824`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.0717968402757023`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.7790538018012407` + 
                1.5684827810043453` Log[6.708296723714824 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (-1.0717968402757023` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.06524623}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "178.27816575043786`"}], "+", 
                  RowBox[{"79.37427676866963`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"16", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "4", "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-178.27816575043786` + 
                79.37427676866963 ArcTan[16 + ArcTan[4]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.0674516}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "19.86619476954651`"}], "+", 
                  RowBox[{"1.756410896126228`", " ", 
                    RowBox[{"Csc", "[", 
                    FractionBox["1", 
                    RowBox[{"13", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-19.86619476954651 + 1.756410896126228 Csc[(13 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.07129226}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.0043554278590316`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8708268132335895`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "49", "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.0043554278590316` + 1.8708268132335895` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Sin[49]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.07933909}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "36.53518722548201`"}], "+", 
                  RowBox[{"37.44759141934305`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    RowBox[{"Csc", "[", 
                    SqrtBox["5"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-36.53518722548201 + 37.44759141934305 ArcTan[
                   Log[4 + Csc[5^Rational[1, 2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.1629001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.09605801801886937`"}], "+", 
                  RowBox[{"3.4920129996969265`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.09605801801886937 + 
                3.4920129996969265` Log[3 + (-Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{73., 0.6291958999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.960098316178449`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2014796866257843`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.960098316178449 + 0.2014796866257843 (Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{74., 0.06274456}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"627.6648482170901`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"426.93489897251993`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               627.6648482170901 - 426.93489897251993` ArcTan[10 - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{74., 0.06605315}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "55.51497018696528`"}], "-", 
                  RowBox[{"51.912770948139475`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"8", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], " ", 
                    RowBox[{"Sec", "[", "3", "]"}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-55.51497018696528 - 51.912770948139475` 
                ArcTan[Log[8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] Sec[3]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{74., 0.06679554}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.5726066011507813`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7211859343768123`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.5726066011507813 + 1.7211859343768123` (ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{74., 0.07403658}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.1822303979276316`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.6363508221134149`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"1.8047949685514126`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.1822303979276316` + 
                1.6363508221134149` (ArcTan[1.8047949685514126` + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{74., 0.07663755}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.244688116667003`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"4.4161390468104855`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.8186074920677094`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               8.244688116667003 - 4.4161390468104855` 
                Cos[Rational[1, 2] (0.8186074920677094 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{74., 0.08441222}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.967727825307412`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.3362633929741206`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "64", "]"}], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.967727825307412 + 1.3362633929741206` Log[Sin[
                    Cos[64]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{74., 0.39383979999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.523094164574696`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.3021501491793244`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.523094164574696 + 
                1.3021501491793244` Log[3.141406940734484 + Sin[
                    Sin[
                    Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{75., 0.04743892}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.2810086035449966`"}], "+", 
                  RowBox[{"3.638864024099345`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.2810086035449966 + 
                3.638864024099345 Log[2 + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{75., 0.06734849}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "67.57022653261356`"}], "+", 
                  RowBox[{"76.75313249388833`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "2"], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-67.57022653261356 + 76.75313249388833 ArcTan[ArcTan[
                    Log[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{75., 0.1519075}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "230.2716066359415`"}], "+", 
                  RowBox[{"259.2777003847695`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-230.2716066359415 + 
                259.2777003847695 Log[1 + ArcTan[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{76., 0.04757755}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "346.6601167633575`"}], "+", 
                  RowBox[{"231.72139813524225`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-346.6601167633575 + 
                231.72139813524225` 
                 ArcTan[16.871489524120378` - Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{76., 0.05459061}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.1586536150243871`"}], "+", 
                  RowBox[{"3.87683692872403`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.1586536150243871` + 3.87683692872403 Log[3 + ArcTan[
                    Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{76., 0.06349648000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "340.87335623503566`"}], "+", 
                  RowBox[{"227.96502578118103`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"17.649648857300427`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-340.87335623503566` + 
                227.96502578118103` 
                 ArcTan[17.649648857300427` - ArcTan[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{76., 0.06594111}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.4849217837278152`"}], "+", 
                  RowBox[{"3.938888463750271`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.4849217837278152` + 
                3.938888463750271 Log[3 + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{76., 0.08490812}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.680560576152886`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.07296613063748036`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.680560576152886 + 0.07296613063748036 E^(2 ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{76., 0.08815905}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.383734584831676`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.0005477173633280527`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.383734584831676 + 0.0005477173633280527 E^(4 ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{77., 0.47969249999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "89.8559140668553`"}], "+", 
                  RowBox[{"65.71702585248444`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-89.8559140668553 + 65.71702585248444 ArcTan[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.06154533}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "9.741363510173185`"}], "+", 
                  RowBox[{"8.11795139862089`", " ", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.02033930759711211`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-9.741363510173185 + 
                8.11795139862089 (2 + ((0.02033930759711211 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^
                  Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.06198389}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.2456357328661676`"}], "+", 
                  RowBox[{"1.9428583097772365`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"0.16509018904474715`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.2456357328661676` + 
                1.9428583097772365` Log[0.16509018904474715` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.06798338}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "508.66291518481336`"}], "+", 
                  RowBox[{"334.0896453288071`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"26.011024089573652`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-508.66291518481336` + 
                334.0896453288071 ArcTan[26.011024089573652` + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.07028366}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.172350497394044`"}], "+", 
                  RowBox[{"3.4753206598239`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.172350497394044 + 3.4753206598239 Log[4 + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.07118014}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "16.265537593451967`"}], "+", 
                  RowBox[{"18.387232665992364`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.8543690866645973`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}], 
                    RowBox[{"1", "/", "8"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-16.265537593451967` + 18.387232665992364` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (0.8543690866645973 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^
                  Rational[1, 8], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.07324744}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.2748802575029379`"}], "+", 
                  RowBox[{"3.8992847872145213`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.2748802575029379` + 3.8992847872145213` Log[3 + Sin[
                    Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.118282}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1978.5666420532311`"}], "+", 
                  RowBox[{"1267.52305853879`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"17", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1978.5666420532311` + 1267.52305853879 ArcTan[17 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.1623626}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "26.04112674777279`"}], "+", 
                  RowBox[{"26.309143466510754`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"6", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-26.04112674777279 + 26.309143466510754` ArcTan[
                   Log[6 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.35141249999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "198.07452373787058`"}], "+", 
                  RowBox[{"136.204602346366`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"9.250902155733506`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"7.410249236385539`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-198.07452373787058` + 
                136.204602346366 
                 ArcTan[9.250902155733506 + Log[7.410249236385539 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{79., 0.5850354999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.726738410398485`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.09763595331201388`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.726738410398485 + 0.09763595331201388 (Log[3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{80., 0.048386570000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.3665169138401554`"}], "+", 
                  RowBox[{"6.725056091877989`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"18.763659522142685`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.3665169138401554` + 
                6.725056091877989 (Sin[18.763659522142685` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{80., 0.061403110000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.9341868610706086`"}], "+", 
                  RowBox[{"6.9516094106522885`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SqrtBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.2062700391144091`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.9341868610706086` + 
                6.9516094106522885` (Cos[0.2062700391144091 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{80., 0.06516905}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "152.726983572983`"}], "+", 
                  RowBox[{"68.79780993238121`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "49", "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-152.726983572983 + 
                68.79780993238121 ArcTan[10 + ArcTan[49]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{80., 0.06544307}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "139.22127313411`"}], "+", 
                  RowBox[{"63.199883341839644`", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "10", "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-139.22127313411 + 
                63.199883341839644` ArcTan[10 + ArcTan[10]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{80., 0.09202715}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "358.2824781827344`"}], "+", 
                  RowBox[{"371.38271523334873`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-358.2824781827344 + 371.38271523334873` ArcTan[
                   ArcTan[9 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{80., 0.12232889999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.774753833905041`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.23099287537708105`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "2"]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.774753833905041 - 0.23099287537708105` (-ArcTan[
                    Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]^2 + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{80., 0.1933272}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.46537553438199136`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.6181940556361978`", " ", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.46537553438199136` + 
                1.6181940556361978` (9 + ArcTan[E^Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{81., 0.06735595}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.284218083383291`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7530124369971796`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"37", "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]]}], 
                    "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.284218083383291 + 1.7530124369971796` (ArcTan[37 + E^Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{81., 0.35950859999999996`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.709087424798704`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.005248982048104594`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.37538201172230395`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               7.709087424798704 + 
                0.005248982048104594 (0.37538201172230395` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{82., 0.0681658}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.484428241960846`"}], "+", 
                  RowBox[{"4.443345417469124`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.282813881468968`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.484428241960846 + 
                4.443345417469124 
                 Log[3.141406940734484 + Log[6.282813881468968 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{82., 0.08641139}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "7.568991858634092`"}], "-", 
                  RowBox[{"4.464857414173227`", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"13.118292568935217`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-7.568991858634092 - 4.464857414173227 
                Log[(13.118292568935217` + 3 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{82., 0.1635254}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "25.475912635158767`"}], "+", 
                  RowBox[{"27.756152422047744`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-25.475912635158767` + 27.756152422047744` ArcTan[
                   Log[3.141406940734484 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{82., 0.5736612}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.687605883995242`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.21234384959162464`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.687605883995242 - 0.21234384959162464` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{83., 0.05011397}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.5547343503994592`"}], "+", 
                  RowBox[{"3.724348302372424`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.5547343503994592 + 
                3.724348302372424 Log[2.1914474950105785` + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{83., 0.06078792}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"16.99966048986046`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["213.69650994196766`", 
                   RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1000", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"]}],
                     "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               16.99966048986046 - 213.69650994196766`/(10 + ArcTan[1000 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^3]^4 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{83., 0.1192168}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.153961669416775`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.4453597460298386`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"7", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.153961669416775 + 1.4453597460298386` Log[7 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + ((-2) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{84., 0.12378829999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.15037742447920033`"}], "+", 
                  RowBox[{"1.8346924706113779`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"17.850666035275225`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.15037742447920033` + 
                1.8346924706113779` Log[17.850666035275225` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{84., 0.1412191}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.8342544316945208`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.9127856949805959`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"8", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.8342544316945208` - 0.9127856949805959 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] - Log[8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{85., 0.06482285}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.04663644506349962`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"3.5315386314627237`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"100", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.04663644506349962 + 
                3.5315386314627237` Log[2.1914474950105785` + Sin[(100 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{85., 0.07045988}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.12769237836677086`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7733456248936934`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"7.849991770513654`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.12769237836677086` + 
                1.7733456248936934` Log[7.849991770513654 + 5 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{85., 0.07727692}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "287.64544174619306`"}], "+", 
                  RowBox[{"193.6690751357168`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"15", "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"76", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-287.64544174619306` + 
                193.6690751357168 ArcTan[15 - Cos[76 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{85., 0.5114831}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.049468201545736`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.21858167325723815`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.049468201545736 + 0.21858167325723815` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Log[3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{86., 0.04533271}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"35.972394163224585`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["826.9352617805577`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               35.972394163224585` + 
                826.9352617805577/(-24.060521364609343` + Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - 2 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{86., 0.08737194}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"16.634583217422396`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.3330313440152148`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               16.634583217422396` - 
                0.3330313440152148 (4 + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{86., 0.1311221}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.1427145729245396`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.8304754831858716`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", "1", "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               1.1427145729245396` + 2.8304754831858716` Log[ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Sin[
                    Sin[1]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{87., 0.09276673}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.718862350769758`", "\[VeryThinSpace]"}], "-", 
                  FractionBox[
                   RowBox[{"57.938136607324125`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"8", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], 
                   RowBox[{
                    RowBox[{"8.760121933840146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               17.718862350769758` - 57.938136607324125` (Log[8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]/(8.760121933840146 + 
                 ArcTan[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{88., 0.06432078000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "146750.16347923692`"}], "+", 
                  RowBox[{"146653.6884159216`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"89.5943161942304`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "5", "]"}]]}], "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-146750.16347923692` + 146653.6884159216 ArcTan[
                   ArcTan[89.5943161942304 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[5]]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{88., 0.07950018}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "167.12487660469`"}], "+", 
                  RowBox[{"115.91751295568295`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    FractionBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-167.12487660469 + 115.91751295568295` ArcTan[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2/(1 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2) + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{90., 0.06173609}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.6809688685812287`"}], "+", 
                  RowBox[{"4.453614487156287`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.62851319920005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.1914474950105785`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.6809688685812287` + 
                4.453614487156287 
                 Log[3.62851319920005 + Log[3.1914474950105785` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{90., 0.06238317}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.901609257146886`"}], "+", 
                  RowBox[{"4.331342805329784`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.901609257146886 + 
                4.331342805329784 Log[3 + ArcTan[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{90., 0.06258124}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "96.71660066696694`"}], "+", 
                  RowBox[{"11.285772093351042`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}], "2"]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-96.71660066696694 + 
                11.285772093351042` E^(ArcTan[10 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{90., 0.06432501}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "64.80434672686678`"}], "+", 
                  RowBox[{"54.59037583063909`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"8.04939058240974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-64.80434672686678 + 
                54.59037583063909 ArcTan[(8.04939058240974 + ArcTan[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{90., 0.06524017}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"16.902882415828515`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["210.12154174546458`", 
                   RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"46", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               16.902882415828515` - 210.12154174546458`/(10 + 
                ArcTan[46 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 + Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{90., 0.0692436}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "436.57702630594537`"}], "+", 
                  RowBox[{"360.83163315489253`", " ", 
                    SqrtBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"26", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-436.57702630594537` + 
                360.83163315489253` ArcTan[10 + ArcTan[26 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{90., 0.06924656}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.5970864572179663`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7296852048845865`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"8", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.5970864572179663 + 1.7296852048845865` Log[8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{91., 0.06593433}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15018.86154801121`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"10434.838879971947`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"13.926364222835815`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15018.86154801121 - 10434.838879971947` 
                ArcTan[10 - ArcTan[13.926364222835815` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Sin[5]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{92., 0.06745933}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.805648174148475`"}], "+", 
                  RowBox[{"0.8781910168002474`", " ", 
                    RowBox[{"Csc", "[", 
                    FractionBox["1", 
                    RowBox[{"10", "+", 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.805648174148475 + 
                0.8781910168002474 Csc[(10 + 2 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{92., 0.5665467}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.641684035028745`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.2193733981877735`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}], "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[7.641684035028745 - 0.2193733981877735 (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - (-Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{94., 0.0592591}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.512197739739039`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7927138988863416`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.013409397288550739`", "\[VeryThinSpace]"}], 
                    "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.512197739739039 + 
                1.7927138988863416` (0.013409397288550739` + ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{94., 0.061812200000000005`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.2871499299160467`"}], "+", 
                  RowBox[{"0.9775644744419363`", " ", 
                    RowBox[{"Log", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.7298616904100044`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], ")"}], "2"], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.2871499299160467` + 
                0.9775644744419363 Log[(3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (2.7298616904100044` + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{94., 0.06323972}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.1644263939590528`"}], "+", 
                  RowBox[{"3.6222018931930084`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"1.4965212637647278`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.1644263939590528 + 
                3.6222018931930084` Log[1.4965212637647278` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (1 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[-1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{94., 0.07950314}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8023855154534965`"}], "+", 
                  RowBox[{"4.038038043728957`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.6549198872311592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.8023855154534965` + 
                4.038038043728957 Log[3.6549198872311592` - Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{94., 0.190742}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.03901395799801`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.2099413380821451`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"13", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"11.314780888636129`", "\[VeryThinSpace]"}], "+", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.03901395799801 + 
                0.2099413380821451 (Log[13 + (11.314780888636129` + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{95., 0.1118878}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.507013935396869`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20463071175219602`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.507013935396869 - 0.20463071175219602` (Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{95., 0.1138836}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.722972308189542`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.24195867940744603`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.722972308189542 + 0.24195867940744603` (Sin[
                    Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{96., 0.06182037}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "155291.8819752659`"}], "+", 
                  RowBox[{"155189.06664827294`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"89.5943161942304`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.495342400649929`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"Cos", "[", "5", "]"}]]}], "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-155291.8819752659 + 155189.06664827294` ArcTan[
                   ArcTan[89.5943161942304 + (0.495342400649929 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Cos[5]]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{96., 0.06541907}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.10249183119044987`"}], "+", 
                  RowBox[{"1.810351170670488`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.774454707379181`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.10249183119044987` + 
                1.810351170670488 Log[8.774454707379181 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{96., 0.07668868}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "158.38980938913366`"}], "+", 
                  RowBox[{"110.3149289638404`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "2"], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"17.250902155733506`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-158.38980938913366` + 
                110.3149289638404 
                 ArcTan[E^2 + ArcTan[17.250902155733506` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{96., 0.38596969999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9073643724933818`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.4167053243067182`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"6.282813881468968`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9073643724933818` + 
                1.4167053243067182` 
                 Log[3.141406940734484 + Log[6.282813881468968 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{97., 0.05329218}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.2537707306553085`"}], "+", 
                  RowBox[{"3.8964876286524053`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.2537707306553085` + 
                3.8964876286524053` Log[3 + Sin[2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{97., 0.5771151999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.957904139654285`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.182614579211618`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"10.400576499086725`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.07091200584018109`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.957904139654285 + 
                1.182614579211618 
                 Log[10.400576499086725` + (0.07091200584018109 + ArcTan[
                    Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{98., 0.06692973}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "6.434976510458728`"}], "+", 
                  RowBox[{"7.936124885397839`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"7", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Log", "[", "2", "]"}], "]"}]}], ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-6.434976510458728 + 
                7.936124885397839 (ArcTan[7 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Tan[
                    Log[2]])^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{98., 0.07081660000000001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.4150733632357326`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8088426821847825`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "4"], "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.4150733632357326` + 1.8088426821847825` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Sin[ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^4]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{99., 0.18144}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"12.16970180165483`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["29.620067755593247`", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"6.024244290186736`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               12.16970180165483 + 
                29.620067755593247`/(Cos[6.024244290186736 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2] - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{100., 0.0522657}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.335035211825201`"}], "+", 
                  RowBox[{"3.9279794691952454`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.8252914180515734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.335035211825201 + 
                3.9279794691952454` Log[2.8252914180515734` + Cos[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{100., 0.05282639}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.682169812042959`"}], "+", 
                  RowBox[{"4.290015352916522`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.917599550587852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.682169812042959 + 
                4.290015352916522 Log[3.917599550587852 + Cos[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{100., 0.06807885}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1697.1776053388005`"}], "+", 
                  RowBox[{"1109.5987182131296`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "10", "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "8"], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1697.1776053388005` + 
                1109.5987182131296` ArcTan[ArcTan[10 + ArcTan[10]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^8], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{101., 0.048815370000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.625118974736164`"}], "+", 
                  RowBox[{"0.1847016820968298`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-8.625118974736164 + 
                0.1847016820968298 (7.209308857575003 + 
                   Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{101., 0.04933377}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "209.67153122012866`"}], "+", 
                  RowBox[{"226.91026415199192`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"-", "16.12178642484267`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6.024244290186736`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-209.67153122012866` + 
                226.91026415199192` 
                 E^((-16.12178642484267 + Cos[6.024244290186736 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{101., 0.05246776}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "354.9151013004551`"}], "+", 
                  RowBox[{"374.29270991873386`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6.024244290186736`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-354.9151013004551 + 
                374.29270991873386` 
                 E^((-24.060521364609343` + Cos[6.024244290186736 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^(-1)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{101., 0.05639441}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.8343714476912036`"}], "+", 
                  RowBox[{"2.178381442706541`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.585630214406443`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.6549198872311592`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.8343714476912036` + 
                2.178381442706541 
                 Log[8.585630214406443 + (3.6549198872311592` + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{101., 0.07678372}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.38327466720405`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"4.29046765942961`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               8.38327466720405 - 4.29046765942961 
                Cos[Rational[1, 2] (Sin[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{101., 0.4435705}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.177967887660165`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"2.1449798505934625`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               7.177967887660165 - 2.1449798505934625` ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{102., 0.06799934}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "242.1486990298079`"}], "+", 
                  RowBox[{"291.9266708587222`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{"ArcTan", "[", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"8.407613482131985`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "]"}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-242.1486990298079 + 
                291.9266708587222 
                 ArcTan[ArcTan[(8.407613482131985 + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]]^
                   Rational[1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{103., 0.06459056}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "377.34315081093285`"}], "+", 
                  RowBox[{"251.393333117614`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"17", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"1.4001852434923845`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-377.34315081093285` + 
                251.393333117614 
                 ArcTan[17 + ArcTan[1.4001852434923845` + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{103., 0.4757094}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.389908798324601`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.4622205431802318`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.389908798324601 + 
                1.4622205431802318` E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{104., 0.06650336}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.002277195066387`"}], "+", 
                  RowBox[{"7.292213211843334`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "5", "]"}], "4"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.002277195066387 + 
                7.292213211843334 (ArcTan[ArcTan[5]^4] + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{105., 0.059019630000000003`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.280951660699894`"}], "+", 
                  RowBox[{"4.187147114128808`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.651149496787093`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.280951660699894 + 
                4.187147114128808 Log[3.651149496787093 + Sin[
                    Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{106., 0.07478163}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.7574500251021177`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7176312299740337`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", "10", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SqrtBox["10"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.7574500251021177` + 
                0.7176312299740337 (ArcTan[ArcTan[10] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                  Log[10^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{107., 0.06018663}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.220525152186882`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7988242883931143`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.220525152186882 + 1.7988242883931143` (ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{107., 0.06188401}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.285147374011872`"}], "+", 
                  RowBox[{"4.3413478010458215`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.141406940734484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.285147374011872 + 
                4.3413478010458215` 
                 Log[3.141406940734484 + Log[3.141406940734484 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{107., 0.06688676}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"19.306522798102414`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["380.73412827451847`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               19.306522798102414` + 
                380.73412827451847`/(-24.060521364609343` + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{107., 0.0734355}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.446900018302772`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.741225404773956`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SqrtBox["10"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.446900018302772 + 
                0.741225404773956 (ArcTan[9 + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + 
                  Log[10^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{108., 0.062197880000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.394161139694346`"}], "+", 
                  RowBox[{"0.9814436053645769`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.6688673773074`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.1335991965799153`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.394161139694346 + 
                0.9814436053645769 Log[4.6688673773074 + (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (3.1335991965799153` + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{108., 0.06336496}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.99368489330315`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.05763713388731387`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.99368489330315 + 0.05763713388731387 (E^(2 ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2) + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{108., 0.06515954}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.43719102262740595`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7231370566954793`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.43719102262740595` + 1.7231370566954793` (ArcTan[6 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{110., 0.055399330000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.7099906871330246`"}], "+", 
                  RowBox[{"1.8986543578731896`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Log", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-3.7099906871330246` + 
                1.8986543578731896` (ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Log[(3 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{111., 0.09152114}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "214.30935136813474`"}], "+", 
                  RowBox[{"104.48888773823367`", " ", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"9.822489058011255`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-214.30935136813474` + 
                104.48888773823367` (E^
                   ArcTan[9.822489058011255 + Cos[9 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{114., 0.04323986}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.5431128368434661`"}], "+", 
                  RowBox[{"3.994108811164531`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"18.93617477220362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.5431128368434661` + 3.994108811164531 Log[3 + ArcTan[
                    Tan[18.93617477220362 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{114., 0.07178}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.8819450123842536`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7069306825933103`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SqrtBox["10"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.8819450123842536` + 0.7069306825933103 (ArcTan[ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                  Log[10^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{117., 0.07203559}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.659548538305875`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.805197781114476`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2.084851058015854`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}], "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.659548538305875 + 
                1.805197781114476 (Sin[(2.084851058015854 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{118., 0.053949210000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "13.781449300820517`"}], "+", 
                  RowBox[{"13.895214748857668`", " ", 
                    SqrtBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.917599550587852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-13.781449300820517` + 
                13.895214748857668` Log[3.917599550587852 + Cos[E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{119., 0.043738070000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.325599080038583`"}], "+", 
                  RowBox[{"4.210081890106485`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.651149496787093`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.325599080038583 + 
                4.210081890106485 Log[3.651149496787093 + Sin[
                    Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{119., 0.04379955}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.5020745287096853`"}], "+", 
                  RowBox[{"3.9870341325164342`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.5020745287096853` + 3.9870341325164342` Log[3 + Sin[
                    Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{120., 0.05274915}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "570.0650642572922`"}], "+", 
                  RowBox[{"375.18056546633335`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"24.857076451974894`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-570.0650642572922 + 
                375.18056546633335` ArcTan[24.857076451974894` + ArcTan[
                    Cos[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[
                    Tan[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{120., 0.05495171}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.7616373767753631`"}], "+", 
                  RowBox[{"1.5772859103819985`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.6688673773074`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.7616373767753631 + 
                1.5772859103819985` (ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Log[4.6688673773074 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{120., 0.05526459}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "368.0164936519416`"}], "+", 
                  RowBox[{"245.3672702750265`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"18.026333642812094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-368.0164936519416 + 
                245.3672702750265 ArcTan[18.026333642812094` + ArcTan[
                    Cos[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[
                    Tan[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{121., 0.05440037}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.5698739057381148`"}], "+", 
                  RowBox[{"3.9934691631186627`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"4.483729200338189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "-", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.5698739057381148` + 
                3.9934691631186627` Log[3 - Sin[4.483729200338189 - 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{122., 0.049481870000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.831277940846697`"}], "+", 
                  RowBox[{"4.210546876772245`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Log", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.103651586729363`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-2.831277940846697 + 
                4.210546876772245 Log[Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                   Log[(7.103651586729363 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{122., 0.06336582}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "193.75442687044256`"}], "+", 
                  RowBox[{"143.30446278755355`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"10.95204228255524`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12.544750992301736`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-193.75442687044256` + 143.30446278755355` ArcTan[
                   Log[10.95204228255524 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (12.544750992301736` + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{125., 0.08784258}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.854263072694405`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.23361565211114954`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.854263072694405 - 0.23361565211114954` (ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 2 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{126., 0.09005742}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.8803746461485344`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.23178823419400926`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.8803746461485344` - 
                0.23178823419400926` (Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{127., 0.04969963}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "6.2719311645447045`"}], "+", 
                  RowBox[{"0.0001900211858885663`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"14.259060030307275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-6.2719311645447045` + 
                0.0001900211858885663 ((14.259060030307275` + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{127., 0.06748439}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.9547931294412373`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7424826199477523`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"10", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]], "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               2.9547931294412373` + 1.7424826199477523` (Cos[(10 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{128., 0.05849504}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "299.5075726063454`"}], "+", 
                  RowBox[{"201.37691303823954`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"29.47468436471718`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    RowBox[{"(", 
                    RowBox[{"100", "+", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]}], 
                    ")"}]}], "]"}], "4"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-299.5075726063454 + 
                201.37691303823954` ArcTan[9 + ArcTan[(29.47468436471718 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) (100 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{129., 0.05117879}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.049972101573201`"}], "+", 
                  RowBox[{"7.33730608190166`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.9898368790945385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.049972101573201 + 
                7.33730608190166 (0.9898368790945385 + ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{129., 0.05176961}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.809851191882552`"}], "+", 
                  RowBox[{"7.635311292089756`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.558515172156297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.809851191882552 + 
                7.635311292089756 (1.558515172156297 + ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{129., 0.05632016}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"20.317740899843923`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.07073541267405369`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "16"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.02033930759711211`", "\[VeryThinSpace]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[20.317740899843923` + 0.07073541267405369 (-Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - (-16 + ((
                    0.02033930759711211 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{129., 0.09163194}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "15.623609149964405`"}], "+", 
                  RowBox[{"24.346533567413726`", " ", 
                    SqrtBox[
                    RowBox[{"Log", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.78223026142588`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-15.623609149964405` + 24.346533567413726` Log[
                    Log[4.78223026142588 + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]]^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{130., 0.26237509999999997`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"7.365440418583293`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.0057269143253541105`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               7.365440418583293 + 0.0057269143253541105` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{134., 0.1042043}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"6.173179985416046`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.21818433528944248`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.16939734954746669`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               6.173179985416046 - 
                0.21818433528944248` (Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[0.16939734954746669` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{136., 0.08716316}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "2.286245975994742`"}], "+", 
                  RowBox[{"4.0947833433081025`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-2.286245975994742 + 4.0947833433081025` Log[4 + ArcTan[
                    ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] - ArcTan[Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{136., 0.09641052}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.691520413945595`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20935141346255795`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.691520413945595 - 0.20935141346255795` (Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2] - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{138., 0.05248121}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.261950098980763`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7226772131159379`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "+", 
                    RowBox[{
                    FractionBox["1", "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "8"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.261950098980763 + 0.7226772131159379 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 + 
                  Rational[1, 5] (-8 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{138., 0.0601497}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.1369077043311124`"}], "+", 
                  RowBox[{"2.221895606909378`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.1369077043311124` + 2.221895606909378 (-Cos[
                    Log[9 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{138., 0.06040052}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4.0609864272492135`"}], "+", 
                  RowBox[{"7.008897893959805`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.41169212896518204`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-4.0609864272492135` + 
                7.008897893959805 (0.41169212896518204` + Sin[ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{140., 0.04769697}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"20602.813012080624`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"14317.882226443458`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"10", "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"17.926364222835815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               20602.813012080624` - 14317.882226443458` 
                ArcTan[10 - ArcTan[
                  17.926364222835815` - Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Sin[5]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{140., 0.07579334}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"22.424742680793493`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"656.233240712471`", " ", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"-", "31.99308882617324`"}], "-", 
                    SqrtBox[
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.905152532247019`"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               22.424742680793493` + 
                656.233240712471 ArcTan[(-31.99308882617324 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (-4.905152532247019 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 2])^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{141., 0.05521456}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.133073685560648`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7910555524940974`", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.133073685560648 + 1.7910555524940974` (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2 + ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{141., 0.058958380000000005`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "31.566633069428406`"}], "+", 
                  RowBox[{"31.51537631539517`", " ", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"24.060521364609343`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], ")"}], 
                    RowBox[{"1", "/", "4"}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-31.566633069428406` + 
                31.51537631539517 ArcTan[(24.060521364609343` + (Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 4]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{141., 0.1028627}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.817963628407911`"}], "+", 
                  RowBox[{"4.7949097960792`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Log", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.103651586729363`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"84.67190206675369`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.817963628407911 + 
                4.7949097960792 Log[Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                   Log[(7.103651586729363 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 84.67190206675369 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{141., 0.1108183}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "16.615921249963673`"}], "+", 
                  RowBox[{"3.307404503927511`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SqrtBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}], "]"}]], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"32.548269141567665`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-16.615921249963673` + 3.307404503927511 (ArcTan[
                    ArcTan[9 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]]]^
                   Rational[1, 2] + (32.548269141567665` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{146., 0.04220061}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.665260415018132`"}], "+", 
                  RowBox[{"0.18470566659816035`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "2"], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-8.665260415018132 + 
                0.18470566659816035` ((7.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^2 + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{146., 0.04282297}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "12.229229482227762`"}], "+", 
                  RowBox[{"0.15315899665822694`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "2"], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-12.229229482227762` + 
                0.15315899665822694` ((9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^2 + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{152., 0.11750559999999999`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"11.659446353149018`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.10354399584042526`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               11.659446353149018` - 
                0.10354399584042526` ((
                   1.4005764990867249` + (0.6252252761254272 + 
                    Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2 - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{153., 0.0583367}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.144262037734365`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7172284644586521`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "+", 
                    RowBox[{
                    FractionBox["1", "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.144262037734365 + 0.7172284644586521 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 + 
                  Rational[1, 5] (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{155., 0.05373975}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.2884716746338105`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.6502734056133948`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "-", 
                    RowBox[{"0.23259141714259085`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.2884716746338105` + 0.6502734056133948 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 - 
                  0.23259141714259085` (Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{157., 0.05144116}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.465458460924556`"}], "+", 
                  RowBox[{"7.5009854662824855`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "5", "]"}], "4"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.465458460924556 + 
                7.5009854662824855` (ArcTan[ArcTan[5]^4] + ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{157., 0.05176678}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "19.48857067286376`"}], "+", 
                  RowBox[{"20.5988600784056`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "5", "]"}], "4"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "8"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-19.48857067286376 + 
                20.5988600784056 (ArcTan[ArcTan[5]^4] + ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 8], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{157., 0.055013980000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.897877979523039`"}], "+", 
                  RowBox[{"6.807204351785608`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "4"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-3.897877979523039 + 6.807204351785608 (ArcTan[ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^4] + ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{158., 0.04160966}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.510726705871336`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8287826185445848`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.0310692458406`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"18.93617477220362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.510726705871336 + 1.8287826185445848` (-Cos[
                    Log[3.0310692458406 + ArcTan[
                    Tan[18.93617477220362 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{158., 0.04164301}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.5836714672060235`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.829694782738983`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.5836714672060235` + 1.829694782738983 (-Cos[
                    Log[3 + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{158., 0.04268322}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.05376791508329`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.821545898503975`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.139542022520033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.05376791508329 + 1.821545898503975 (-Cos[
                    Log[4.139542022520033 + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{160., 0.05916832}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.9075859559247731`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.6781952333305694`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"7", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.9075859559247731 + 1.6781952333305694` Log[7 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (-Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{164., 0.1012303}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.377516948990166`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"138.35029506729265`", " ", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"-", "7.11480218364288`"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "6.024244290186736`"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.905152532247019`"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15.377516948990166` + 
                138.35029506729265` ArcTan[(-7.11480218364288 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> 
                    "Helvetica"] - (-6.024244290186736 + (-4.905152532247019 - 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 2])^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{166., 0.04081404}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "6.408272399695967`"}], "+", 
                  RowBox[{"5.231965694045441`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"7.3981294266783095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"90.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-6.408272399695967 + 
                5.231965694045441 Log[7.3981294266783095` + ArcTan[
                    Tan[90.39812942667831 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{167., 0.08091706}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.7075873014617069`"}], "+", 
                  RowBox[{"3.7142665857001753`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.133417881271985`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    SqrtBox[
                    RowBox[{
                    SqrtBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.2062700391144091`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.7075873014617069 + 
                3.7142665857001753` 
                 Log[3.133417881271985 + 
                   Cos[E^((Cos[0.2062700391144091 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2])] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{171., 0.07471346}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"13.145110458093443`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.270776490137496`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.15261977892104736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               13.145110458093443` - 
                0.270776490137496 (-Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (
                   1.4005764990867249` + (0.15261977892104736` + 
                    Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{176., 0.05404955}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4.20210705096986`"}], "+", 
                  RowBox[{"6.900190508763629`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-4.20210705096986 + 6.900190508763629 (ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{178., 0.1076273}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.380779899659984`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.23122930726665333`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "]"}], "]"}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[5.380779899659984 - 0.23122930726665333` (-(E^(E^ArcTan[
                    Cos[(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]]]))^
                   Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{182., 0.05305787}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.0925547527634443`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8432523551667161`", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.0925547527634443` + 1.8432523551667161` (ArcTan[
                    ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2]] + ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{183., 0.05200551}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.228814917919281`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.8427418320492523`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], ")"}], 
                    RowBox[{"1", "/", "4"}]], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.228814917919281 - 0.8427418320492523 (Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - ((Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 4] - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{186., 0.04760165}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.419916362804007`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.6591449060414855`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "-", 
                    RowBox[{"0.23259141714259085`", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.419916362804007 + 0.6591449060414855 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 - 
                  0.23259141714259085` (1 + Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{186., 0.06849479}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.448983363068871`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.6354331247681615`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "-", 
                    RowBox[{"0.23259141714259085`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.448983363068871 + 0.6354331247681615 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 - 
                  0.23259141714259085` (Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{187., 0.04275645}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"35.35434285524945`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["807.2918416709975`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], ")"}], 
                    RowBox[{"1", "/", "4"}]], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               35.35434285524945 + 
                807.2918416709975/(-24.060521364609343` + Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - ((Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 4] - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{187., 0.049688500000000003`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.319667309233644`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"231.8045627480128`", " ", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"-", "12"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.905152532247019`"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               17.319667309233644` + 
                231.8045627480128 ArcTan[(-12 + Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (-4.905152532247019 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 2])^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{187., 0.05990423}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"22.041671545619277`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"612.0624245852688`", " ", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    RowBox[{
                    RowBox[{"-", "30.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.905152532247019`"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]]}]], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               22.041671545619277` + 
                612.0624245852688 ArcTan[(-30.060521364609343` + Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (-4.905152532247019 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 2])^(-1)], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{198., 0.04564093}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.327016724282255`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.6546626164340924`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "-", 
                    RowBox[{"0.23259141714259085`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.327016724282255 + 0.6546626164340924 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 - 
                  0.23259141714259085` (2 Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{200., 0.05117337}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4.820381162803929`"}], "+", 
                  RowBox[{"7.231374148851507`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-4.820381162803929 + 7.231374148851507 (ArcTan[
                    ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2]] + ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{201., 0.05663567}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.293864850611095`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.6563707475407765`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "-", 
                    RowBox[{"0.23259141714259085`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.293864850611095 + 0.6563707475407765 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 - 
                  0.23259141714259085` (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{202., 0.04596336}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"19.225326476941195`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["375.37107793922956`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               19.225326476941195` + 
                375.37107793922956`/(-24.060521364609343` - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[1, 2] + Tan[
                   Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{206., 0.04880117}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "318.7952150267916`"}], "+", 
                  RowBox[{"213.7138665766102`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"16.489028932366253`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"0.9999669962244142`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]]]}], 
                    "]"}], "-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-318.7952150267916 + 
                213.7138665766102 
                 ArcTan[16.489028932366253` + 
                   Sin[0.9999669962244142 - E^(E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])] - Sin[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - (1 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[-1, 2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{208., 0.05117054}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "5.029943971906466`"}], "+", 
                  RowBox[{"7.3293690287855675`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", "2401", "]"}], "2"], "]"}], "4"], 
                    "]"}], "4"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-5.029943971906466 + 
                7.3293690287855675` (
                   ArcTan[ArcTan[ArcTan[ArcTan[2401]^2]^4]^4] + 
                   ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{211., 0.05118598}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.200495356049352`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7155761386415086`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "+", 
                    RowBox[{
                    FractionBox["1", "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.200495356049352 + 0.7155761386415086 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 + 
                  Rational[1, 5] (-Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{211., 0.0519417}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7809053124195087`"}], "+", 
                  RowBox[{"0.0005548844097207745`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"], "-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7809053124195087` + 
                0.0005548844097207745 (Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4 - Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{214., 0.04106804}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.5550254949756566`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8606215338573007`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]], 
                    "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.5550254949756566` + 1.8606215338573007` (-Cos[
                    Log[2 + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] - Cos[(9 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^Rational[1, 2]]]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{217., 0.0484796}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "4.3683638028475436`"}], "+", 
                  RowBox[{"7.028127859648984`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-4.3683638028475436` + 7.028127859648984 (ArcTan[
                    ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2]] + ArcTan[(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{222., 0.04038916}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.558707521450843`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8588497799841543`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2699146244271495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"18", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.558707521450843 + 1.8588497799841543` (-Cos[
                    Log[3.2699146244271495` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[18 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{225., 0.06962538}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"13.491432816295038`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.13956954015981576`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "-", 
                    RowBox[{"Sin", "[", "4", "]"}]}], ")"}]}], "]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.4005764990867249`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.6252252761254272`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               13.491432816295038` + 
                0.13956954015981576` (Cos[Rational[1, 3] (3 + E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Sin[4])] - (
                   1.4005764990867249` + (0.6252252761254272 + 
                    Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{230., 0.05482791}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "357.47137209400927`"}], "+", 
                  RowBox[{"238.64179408034119`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"18", "-", 
                    FractionBox[
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"2", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]]}]]], 
                    "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]], 
                    "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-357.47137209400927` + 
                238.64179408034119` ArcTan[18 - E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] (1 + E^(2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]))^Rational[-1, 2] - ArcTan[
                    Tan[E^(4 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{232., 0.06344128}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.477322997667605`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.195889365786905`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.477322997667605 - 
                0.195889365786905 (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{237., 0.03807967}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.0466567080008264`"}], "+", 
                  RowBox[{"1.8483187208963114`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.8481909635169274`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"16.93617477220362`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.0466567080008264` + 1.8483187208963114` (-Cos[
                    Log[2.8481909635169274` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (16.93617477220362 + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{239., 0.03744396}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.9510966548212272`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.788606155898491`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2699146244271495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.9510966548212272` + 1.788606155898491 (-Cos[
                    Log[3.2699146244271495` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{239., 0.08360893}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.974141482495981`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.22699715217068286`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"146.26826785689062`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.974141482495981 - 0.22699715217068286` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + ArcTan[
                   Cos[146.26826785689062` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[(E^5 Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{243., 0.03685862}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.7687235962755984`", "\[VeryThinSpace]"}], "+", 
                  FractionBox[
                   RowBox[{"19.907107273042147`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    FractionBox["57", "8"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}], 
                   RowBox[{
                    RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "4"], "]"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "4"], "]"}], "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.7687235962755984 + (19.907107273042147`/(10.651382597834791` + 
                  Cos[(2.4405983039138768` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^4]^2 + 
                  Cos[(18.424973303913877` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^4]^2)) 
                 Log[Rational[57, 8] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{243., 0.04545634}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.355753531928113`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.203686552814122`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.355753531928113 - 
                0.203686552814122 (-(E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{245., 0.036906180000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.02423589097826143`"}], "+", 
                  RowBox[{"1.8688206399472915`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.02423589097826143 + 1.8688206399472915` (-Cos[
                    Log[3 + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{245., 0.03742424}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.9786534739100075`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7299198121490142`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.0180437903700836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.9786534739100075` + 1.7299198121490142` (-Cos[
                    Log[3.0180437903700836` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[4 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{245., 0.03751274}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.5538131018447783`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7773873177964183`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2728416790979438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"3.1992936671566525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.774883499211256`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.5538131018447783` + 1.7773873177964183` (-Cos[
                    Log[3.2728416790979438` + ArcTan[
                    Tan[3.1992936671566525` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[4.774883499211256 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{245., 0.03775735}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"2.496178906494707`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.6555022133998347`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2728416790979438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"3.1992936671566525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.774883499211256`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"0.39812942667830953`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[2.496178906494707 + 1.6555022133998347` (-Cos[
                    Log[3.2728416790979438` + ArcTan[
                    Tan[3.1992936671566525` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[4.774883499211256 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (0.39812942667830953` + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{245., 0.03950599}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.6707875673142907`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.9820440881541816`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.0180437903700836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.6707875673142907 + 1.9820440881541816` (-Cos[
                    Log[3.0180437903700836` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{249., 0.052683270000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.3157281585672065`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20504850954535148`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.3157281585672065` - 
                0.20504850954535148` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{250., 0.05194972}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7820857312254423`"}], "+", 
                  RowBox[{"0.0005549470889379492`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7820857312254423` + 
                0.0005549470889379492 (
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{252., 0.04378252}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.420483271267981`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1997983034468342`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.420483271267981 - 
                0.1997983034468342 (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{252., 0.04431624}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.397838863628835`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.2004039141886161`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.397838863628835 - 
                0.2004039141886161 (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{254., 0.03676364}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.18326824617065812`"}], "+", 
                  RowBox[{"1.8669795464308316`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SqrtBox["11"], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.18326824617065812` + 1.8669795464308316` (-Cos[
                    Log[11^Rational[1, 2] + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{261., 0.043810470000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.48240127540162`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19583363361796874`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.48240127540162 - 
                0.19583363361796874` (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{262., 0.05237884}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.276880428132098`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.7379540974361469`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "4"], "+", 
                    RowBox[{
                    FractionBox["1", "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SqrtBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.2062700391144091`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], 
                    RowBox[{"1", "/", "4"}]]}], ")"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.276880428132098 + 0.7379540974361469 (ArcTan[1 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^4 + Rational[1, 5] (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (
                    Cos[0.2062700391144091 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^Rational[1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 4])), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{264., 0.03379812}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.330398741789349`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20463585506703005`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.330398741789349 - 
                0.20463585506703005` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{264., 0.05489903}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.447739080363267`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19813946311667813`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.447739080363267 - 
                0.19813946311667813` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{266., 0.03747056}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.7737831805235398`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.7502292995431623`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2728416790979438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"3.1992936671566525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"4.774883499211256`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", "2", "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.7737831805235398` + 1.7502292995431623` (-Cos[
                    Log[3.2728416790979438` + ArcTan[
                    Tan[3.1992936671566525` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[4.774883499211256 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + ArcTan[
                    Cos[2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{271., 0.05460752}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.366335774862043`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20387858320735527`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.366335774862043 - 
                0.20387858320735527` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{273., 0.03236365}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.396040187278021`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.2007067666082232`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.396040187278021 - 
                0.2007067666082232 (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{275., 0.04335924}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.504658404380401`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19524123760760073`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.504658404380401 - 
                0.19524123760760073` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{278., 0.03379812}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.330398741789349`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20463585506703005`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.330398741789349 - 
                0.20463585506703005` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{281., 0.036466200000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "3.810332656923505`"}], "+", 
                  RowBox[{"2.113071072857634`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SqrtBox["11"], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", "9", "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"18", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-3.810332656923505 + 2.113071072857634 (-Cos[
                    Log[11^Rational[1, 2] + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] - Cos[9]]] - Cos[
                   Log[2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (18 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{282., 0.03683061}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.5969883610810182`", "\[VeryThinSpace]"}], "+", 
                  FractionBox[
                   RowBox[{"10.07380813870113`", " ", 
                    RowBox[{"Log", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["449", "64"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], ")"}], "2"], "]"}]}], 
                   RowBox[{
                    RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "4"], "]"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "4"], "]"}], "2"]}]]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               0.5969883610810182 + (10.07380813870113/(10.651382597834791` + 
                  Cos[(2.4405983039138768` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^4]^2 + 
                  Cos[(18.424973303913877` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^4]^2)) 
                 Log[(Rational[449, 64] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{282., 0.05192958}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.781193749088709`"}], "+", 
                  RowBox[{"0.0005549073335577794`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.224020508492264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.781193749088709 + 
                0.0005549073335577794 (
                  Cos[(3.224020508492264 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{282., 0.051932030000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7819261223605671`"}], "+", 
                  RowBox[{"0.000554939507968174`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7819261223605671` + 
                0.000554939507968174 (
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{282., 0.07078188}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.9405669507259145`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18290414958348875`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.16939734954746669`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.9405669507259145` - 
                0.18290414958348875` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[(0.16939734954746669` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{283., 0.035968810000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.72026456733901`"}], "+", 
                  RowBox[{"2.3165125680547787`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2728416790979438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"3.1992936671566525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.72026456733901 + 2.3165125680547787` (-Cos[
                    Log[3.2728416790979438` + ArcTan[
                    Tan[3.1992936671566525` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[9 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{284., 0.038916150000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.885851494295231`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8416264785112677`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]], 
                    "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"13.563313949709638`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[1.885851494295231 + 1.8416264785112677` (-Cos[
                    Log[2 + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] - Cos[(9 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^Rational[1, 2]]]] - Cos[
                   Log[13.563313949709638` + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{286., 0.0360347}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.356107835692002`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20405396129260017`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.356107835692002 - 
                0.20405396129260017` (-(
                    E^(E^(-ArcTan[7.683763484795428 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{287., 0.03304203}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.404091531127221`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20026336432324202`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.404091531127221 - 
                0.20026336432324202` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{287., 0.038280800000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.444345730451633`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1986533729995616`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.444345730451633 - 
                0.1986533729995616 (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{287., 0.054892130000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.53395045270923`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20463867594701352`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.53395045270923 - 
                0.20463867594701352` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{290., 0.051943710000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7809647561425783`"}], "+", 
                  RowBox[{"0.0005548564201821241`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"], "+", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7809647561425783` + 
                0.0005548564201821241 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4 + Sin[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{291., 0.06322247}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.507596638220422`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19568053197605925`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.507596638220422 - 
                0.19568053197605925` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[(E^5 Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{296., 0.03254706}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.487113331793898`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19574929147072756`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.487113331793898 - 
                0.19574929147072756` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{296., 0.03677036}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.8963254536926593`"}], "+", 
                  RowBox[{"2.472406652772527`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2728416790979438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"3.1992936671566525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", "9", "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.8963254536926593` + 2.472406652772527 (-Cos[
                    Log[3.2728416790979438` + ArcTan[
                    Tan[3.1992936671566525` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[9 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + ArcTan[9] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{296., 0.056333}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.49412195259075`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20010578730179104`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.16939734954746669`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.49412195259075 - 
                0.20010578730179104` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[(0.16939734954746669` E^(Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{299., 0.02869448}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.38380518249006`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20260978641055233`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.38380518249006 - 
                0.20260978641055233` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{299., 0.02958008}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.351021259677713`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20371716260109518`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.351021259677713 - 
                0.20371716260109518` (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{299., 0.03066152}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.373273980214177`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.2026153110197049`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.373273980214177 - 
                0.2026153110197049 (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{299., 0.04479487}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.596648058152135`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19325542629719497`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.6775893981898667`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.596648058152135 - 
                0.19325542629719497` (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[0.6775893981898667 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{299., 0.04798975}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.389314882046344`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.2022665885948125`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"7.683763484795428`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.389314882046344 - 
                0.2022665885948125 (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[7.683763484795428 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{300., 0.045338790000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.080343286449288`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.21074857045975232`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               5.080343286449288 - 0.21074857045975232` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{301., 0.05615854}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "364.22489420344505`"}], "+", 
                  RowBox[{"242.93304709144383`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"18.590644811509534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"5.510522207940621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}]]]}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]]}], "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-364.22489420344505` + 
                242.93304709144383` ArcTan[18.590644811509534` - Sin[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - (
                    1 + (Sin[5.510522207940621 + ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2)^Rational[-1, 2]] + 
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (1 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[-1, 2]], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{302., 0.054770980000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.559628102752153`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19884019355494853`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.559628102752153 - 
                0.19884019355494853` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Cos[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{304., 0.035875370000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.3905456782441215`"}], "+", 
                  RowBox[{"2.270756581757656`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2728416790979438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"3.1992936671566525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"2", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", "2", "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.3905456782441215 + 2.270756581757656 (-Cos[
                    Log[3.2728416790979438` + ArcTan[
                    Tan[3.1992936671566525` + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[9 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (2 + ArcTan[
                    Cos[2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{305., 0.03251883}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.02100135928902416`"}], "+", 
                  RowBox[{"2.517681592345335`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    RowBox[{"Cos", "[", "9", "]"}]}]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"0.5080960709285205`", "\[VeryThinSpace]"}], "+", 
                    
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-0.02100135928902416 + 2.517681592345335 (-Cos[
                    Log[ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + (9 + Cos[9])^
                    Rational[1, 2] - Cos[0.5080960709285205 + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]]]] + (4 + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{307., 0.04673489}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.567432466939057`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1962699187783028`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"8", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.567432466939057 - 
                0.1962699187783028 (-(E^(E^(-ArcTan[8 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{309., 0.04280391}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.743992763719123`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1951458594724512`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.743992763719123 - 0.1951458594724512 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{309., 0.04870469}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.4707799783474345`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19814047653566688`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"4.258784172330445`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.4707799783474345` - 
                0.19814047653566688` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[(4.258784172330445 E^(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{313., 0.06968471}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.630387413787881`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1949787246704419`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"4", " ", 
                    RowBox[{"Cos", "[", "5", "]"}], " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.630387413787881 - 
                0.1949787246704419 (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[(4 Cos[5]) Tan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{314., 0.02756643}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.4678701093025515`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19874383197191242`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"8", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.4678701093025515` - 
                0.19874383197191242` (-(E^(E^(-ArcTan[8 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{316., 0.04719871}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.029420970365064`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1870920249689022`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "8"], 
                    "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.029420970365064 - 0.1870920249689022 (-E^ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^8] - (
                  E^(E^(-ArcTan[7.683763484795428 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{320., 0.05451134}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.586451831844002`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19788341442801563`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]]}], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.586451831844002 - 
                0.19788341442801563` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Cos[276.6154854526354 E^Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{322., 0.07144253}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.321012796360209`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20556608110351832`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"ArcTan", "[", "5", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Cos", "[", "4", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.321012796360209 - 
                0.20556608110351832` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[(E^5 ArcTan[5]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[(E^5 Cos[4]) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{330., 0.02878706}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8400044635249353`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19273504479735082`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8400044635249353` - 0.19273504479735082` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{337., 0.030364060000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.420919704490945`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20174627246471485`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.42358941220425095`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.420919704490945 - 
                0.20174627246471485` (-(
                    E^(E^(-ArcTan[6 - (-0.42358941220425095` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{338., 0.02651355}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.769279223977315`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1944393915962661`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.769279223977315 - 0.1944393915962661 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{342., 0.05192631}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7823330359090819`"}], "+", 
                  RowBox[{"0.0005549545387864046`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7823330359090819` + 
                0.0005549545387864046 (
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{343., 0.02257453}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8862166774471953`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19122035635058077`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8862166774471953` - 0.19122035635058077` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 2 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{345., 0.0519001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7802418545548955`"}], "+", 
                  RowBox[{"0.0005548267698794334`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7802418545548955` + 
                0.0005548267698794334 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{346., 0.03547885}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8805881873089993`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19006096447968443`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8805881873089993` - 0.19006096447968443` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{347., 0.02506017}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9206287697794546`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18913958732571748`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9206287697794546` - 0.18913958732571748` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{350., 0.02713585}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.064972964641763`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20418958043653695`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.064972964641763 - 
                0.20418958043653695` (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[6 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]] + Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{352., 0.02561087}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.269240503765517`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19895525420947166`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.269240503765517 - 
                0.19895525420947166` (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] - ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{352., 0.02651355}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.769279223977315`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1944393915962661`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.769279223977315 - 0.1944393915962661 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{359., 0.021534170000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.904830046344218`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19082962107576024`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.904830046344218 - 0.19082962107576024` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{360., 0.02810663}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.791844368095462`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1940241733334284`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.791844368095462 - 0.1940241733334284 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{360., 0.04757582}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.397293394440861`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20985351146843279`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"276.6154854526354`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.16939734954746669`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.397293394440861 - 
                0.20985351146843279` (-(E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[276.6154854526354 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[(0.16939734954746669` E^(6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{361., 0.025499380000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8432717107127927`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19084618422213112`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8432717107127927` - 0.19084618422213112` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{365., 0.02191001}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.7827639570700593`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19399378184769858`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.7827639570700593` - 0.19399378184769858` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 2 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{372., 0.01942232}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8885022818520762`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19126612394207465`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8885022818520762` - 0.19126612394207465` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 2 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{373., 0.02335637}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.796272239316569`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1934472644448655`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.796272239316569 - 0.1934472644448655 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{374., 0.02087755}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8557068596839685`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19043738327457935`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8557068596839685` - 0.19043738327457935` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 2 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{375., 0.04777945}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.961738218605324`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.004762150941481392`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"14", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[15.961738218605324` - 0.004762150941481392 (14 + Cos[
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{375., 0.05023919}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.331390319626495`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005766991328202146`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"10", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15.331390319626495` - 
                0.005766991328202146 (10 + Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{376., 0.02711727}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8968827668223405`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.188034984782076`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8968827668223405` - 0.188034984782076 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{376., 0.03953106}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.367194390772545`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.006628925423027498`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"8", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.84924443470927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.367194390772545` - 
                0.006628925423027498 (6 + 
                  Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(8 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (3.84924443470927 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{378., 0.051925860000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7823056351809687`"}], "+", 
                  RowBox[{"0.000554941019118174`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7823056351809687` + 
                0.000554941019118174 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{381., 0.02350806}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8487099814267784`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19216456771065638`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8487099814267784` - 0.19216456771065638` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{382., 0.03115687}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.886585933145073`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19097663356402209`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.42358941220425095`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.886585933145073 - 0.19097663356402209` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-0.42358941220425095` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{388., 0.01789098}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9162755175839314`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19047997994393376`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9162755175839314` - 0.19047997994393376` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{388., 0.03340925}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.5276452303382618`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.3466352919721545`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    RowBox[{"Cos", "[", "9", "]"}]}]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"ArcTan", "[", "7", "]"}], "]"}], "]"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.5276452303382618 + 2.3466352919721545` (-Cos[
                    Log[ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + (9 + Cos[9])^
                    Rational[1, 2] - Cos[Cos[9] + Cos[
                    Log[
                    ArcTan[7]]] - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]]]] + (4 + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{389., 0.05190307}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7807268740826128`"}], "+", 
                  RowBox[{"0.000554847471458108`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7807268740826128` + 
                0.000554847471458108 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{395., 0.02055953}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.091035531247189`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1907500056213427`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.091035531247189 - 0.1907500056213427 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + 
                 E^Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{402., 0.02627586}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9436331808181793`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19080842768040582`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.16939734954746669`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], " ", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]]}], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9436331808181793` - 0.19080842768040582` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[(0.16939734954746669` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{403., 0.02242774}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.025662240922804`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18790975166839105`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.4413791701244898`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.025662240922804 - 0.18790975166839105` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-1.4413791701244898` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{404., 0.02042783}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8493327431591227`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.192482443357406`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8493327431591227` - 0.192482443357406 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{404., 0.04065949}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.429344582040766`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.0062876792001552596`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.84924443470927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1848338320807754`", "\[VeryThinSpace]"}], "+", 
                    
                    FractionBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "4"]}], ")"}], "2"], "]"}]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.429344582040766` - 
                0.0062876792001552596` (5.84924443470927 + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 + 
                  Cos[(1.1848338320807754` + Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{408., 0.02802816}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.7590602060183196`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19409394524217205`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.7590602060183196` - 0.19409394524217205` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[(E^5 Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{411., 0.023162560000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.861778300624995`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19186480978288117`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.42358941220425095`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.861778300624995 - 0.19186480978288117` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-0.42358941220425095` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{414., 0.03756442}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "458.3808102437568`"}], "+", 
                  RowBox[{"303.4690902461682`", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"18", "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "]"}]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"9.886815165140113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "]"}], "4"], "]"}]}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"4", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]], 
                    "]"}], "]"}], "+", 
                    FractionBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], "]"}],
                     "2"]}]]], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-458.3808102437568 + 
                303.4690902461682 ArcTan[18 + E^ArcTan[
                    Cos[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                   ArcTan[9.886815165140113 - Sin[ArcTan[
                    Tan[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]^4]] - ArcTan[
                    Tan[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[
                    Tan[E^(4 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])]] + Cos[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] (1 + Cos[E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2)^Rational[-1, 2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{418., 0.022140820000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.7801352674422364`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18805699145347182`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "2"], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.7801352674422364` - 0.18805699145347182` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - ArcTan[
                 ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]^2] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{418., 0.024621670000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.6317008609403634`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1923410459007634`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"59.040221290275575`", "\[VeryThinSpace]"}], "-", 
                    
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.6317008609403634` - 0.1923410459007634 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[59.040221290275575` - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{418., 0.05191106}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7833096240358415`"}], "+", 
                  RowBox[{"0.0005550016373889768`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7833096240358415` + 
                0.0005550016373889768 (
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{425., 0.01935343}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8529935833561426`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19215015856295709`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.02841438402168173`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8529935833561426` - 0.19215015856295709` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[
                    7.683763484795428 - (-0.02841438402168173 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{425., 0.0224695}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9478273467407377`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1897779787044502`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9478273467407377` - 0.1897779787044502 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{426., 0.0205071}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.7356746960793026`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18899664913236497`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.7356746960793026` - 0.18899664913236497` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] - ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{434., 0.02020537}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.092748138682931`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18658616338475884`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6015660467699249`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.092748138682931 - 0.18658616338475884` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-1.6015660467699249` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{437., 0.02321266}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.020417716405652`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1879510063825085`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.020417716405652 - 0.1879510063825085 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{440., 0.01876168}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8748274568745154`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18542176356475248`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8748274568745154` - 0.18542176356475248` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - ArcTan[
                 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{441., 0.04045658}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.075730848681093`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005610745956100654`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"11", "+", 
                    RowBox[{"Cos", "[", "4", "]"}], "+", 
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"10.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"], "]"}]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15.075730848681093` - 
                0.005610745956100654 (11 + Cos[4] + Cos[9] + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Sin[
                  Log[10.660359172310152` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{442., 0.02162195}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.980409009343133`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18878295540482584`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.980409009343133 - 0.18878295540482584` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                    Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{444., 0.02812427}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.6103119525601737`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.191871793244516`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.6103119525601737` - 0.191871793244516 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[6 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]] + Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{450., 0.05190116}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7826142184176919`"}], "+", 
                  RowBox[{"0.0005549699992236858`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7826142184176919` + 
                0.0005549699992236858 (
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{454., 0.01908298}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.722760910350078`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18918931327147245`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.722760910350078 - 0.18918931327147245` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{454., 0.02027294}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9090159884081928`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18485630886008195`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9090159884081928` - 0.18485630886008195` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{454., 0.02110221}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.6018659661218297`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19195703216925597`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.6018659661218297` - 0.19195703216925597` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[6 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]] + Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{454., 0.03403434}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9776622021136547`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18742093460470644`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     ")"}], "2"]}]]], "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9776622021136547` - 0.18742093460470644` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + (
                   1 + (6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^2)^Rational[-1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{462., 0.01751612}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8735761014385757`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18561737438919954`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8735761014385757` - 0.18561737438919954` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{470., 0.02070056}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.5746992190368996`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19153005358826802`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.5746992190368996` - 0.19153005358826802` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[E^5 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]] + Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{472., 0.02754686}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.5257373673723493`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19351741652061494`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}]}], 
                    ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.5257373673723493` - 0.19351741652061494` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + 25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"])^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{473., 0.04397211}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.460431310603212`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005798128987218031`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"11", "+", 
                    RowBox[{"Cos", "[", "4", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Sin", "[", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"10.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "2"], "]"}]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15.460431310603212` - 
                0.005798128987218031 (11 + Cos[4] + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Sin[
                  Log[10.660359172310152` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]^2])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{476., 0.019591110000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8588137111259035`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19200938690029534`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8588137111259035` - 0.19200938690029534` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[
                    ArcTan[
                    Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{482., 0.04803281}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"16.62981941726476`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.3511718740709499`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"8", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.84924443470927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               16.62981941726476 - 
                0.3511718740709499 (Cos[(5.725136137948915 - Cos[
                    Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + 
                 Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                 Cos[(8 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                 Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                 Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (3.84924443470927 + 
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{485., 0.01672871}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.820737010009064`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18673601085163793`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.820737010009064 - 0.18673601085163793` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[
                    Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{485., 0.02041769}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.6263789114200202`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1915761276707424`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.6263789114200202` - 0.1915761276707424 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[6 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]] + Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{492., 0.01708043}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9188508019999104`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18460207377434726`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9188508019999104` - 0.18460207377434726` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{494., 0.03121978}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.138605870037327`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"2.464570060599257`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    RowBox[{"Cos", "[", "9", "]"}]}]], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", "9", "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"11", "-", 
                    RowBox[{"3", " ", "\[Pi]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", "18", "]"}], "]"}]}], "]"}], "]"}], 
                    "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{"4", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[0.138605870037327 + 2.464570060599257 (-Cos[
                    Log[ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + (9 + Cos[9])^
                    Rational[1, 2] - Cos[Cos[9] + Cos[
                    Log[11 - 3 Pi - Cos[
                    Log[18]]]] - (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]]]] + (4 + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{498., 0.01924162}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.7425422324813375`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18862588247243153`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.7425422324813375` - 0.18862588247243153` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[
                    ArcTan[
                    Cos[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]]]] - ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{498., 0.02038603}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8343930859021658`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18514417656294296`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8343930859021658` - 0.18514417656294296` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                    Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{503., 0.051900220000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7825698651135473`"}], "+", 
                  RowBox[{"0.0005549705496496878`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{"2", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-1.7825698651135473` + 
                0.0005549705496496878 (
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[(2 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{504., 0.03937057}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.39973488753291`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005079751067226722`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"12", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15.39973488753291 - 
                0.005079751067226722 (12 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{505., 0.01829764}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.988744005295915`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1886150803810753`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.988744005295915 - 0.1886150803810753 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{517., 0.01599068}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.919638964727381`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18436443329168598`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.919638964727381 - 0.18436443329168598` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + ArcTan[ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{522., 0.03740827}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.960532429514295`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.006068353752000542`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.725136137948915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.960532429514295` - 
                0.006068353752000542 (7.725136137948915 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{529., 0.05038591}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "112.52794176660636`"}], "+", 
                  RowBox[{"0.006550174123375059`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.0860356157778908`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-112.52794176660636` + 
                0.006550174123375059 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(2.0860356157778908` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{529., 0.050576340000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "112.60733415844854`"}], "+", 
                  RowBox[{"0.006554364117672642`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.498884370543349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-112.60733415844854` + 
                0.006554364117672642 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(3.498884370543349 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{529., 0.05093102}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "141.59474316151415`"}], "+", 
                  RowBox[{"0.0034430800450513`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.2240205084922642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"12", "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-141.59474316151415` + 
                0.0034430800450513 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.2240205084922642` - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (12 + 
                    Log[9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{532., 0.02010686}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8380225297652886`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18505509992439267`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8380225297652886` - 0.18505509992439267` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{537., 0.018622760000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.801673137233256`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18838456819966276`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"7.683763484795428`", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.801673137233256 - 0.18838456819966276` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + ArcTan[ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[(7.683763484795428 E^Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{547., 0.040228810000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"13.90730460201894`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.007733115303847481`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.84924443470927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               13.90730460201894 - 
                0.007733115303847481 (1.84924443470927 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{555., 0.03214202}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.704178690157573`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.006190530927314757`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.84924443470927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"8", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.84924443470927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.704178690157573` - 
                0.006190530927314757 (7.84924443470927 + 
                  Cos[(5.725136137948915 - Cos[
                    Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + 
                  Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(8 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (3.84924443470927 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{556., 0.05049469}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "112.55783988988962`"}], "+", 
                  RowBox[{"0.0065516214877484906`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.4988843705433492`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-112.55783988988962` + 
                0.0065516214877484906` (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.4988843705433492` + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{565., 0.051889080000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.781406772064479`"}], "+", 
                  RowBox[{"0.0005548957070431725`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.377239258778632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.781406772064479 + 
                0.0005548957070431725 (Cos[Cos[(5.377239258778632 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.7251361379489152` + Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{565., 0.05189833}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7815338750043141`"}], "+", 
                  RowBox[{"0.0005548994357320598`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7815338750043141` + 
                0.0005548994357320598 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.7251361379489152` + Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{586., 0.01949044}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.676192587784721`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1894177078058831`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"1.6837634847954277`", "\[VeryThinSpace]"}], "-", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[3.676192587784721 - 0.1894177078058831 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[
                 1.6837634847954277` - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{590., 0.019467830000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.829433229844661`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19388499500508696`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.4413791701244898`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     ")"}], "2"]}]]], "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.829433229844661 - 0.19388499500508696` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[(E^5 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]) (
                    1 + (6 - (-1.4413791701244898` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^2)^Rational[-1, 2]] - 
                 Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{590., 0.03761146}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"15.591811764066318`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.006172075101696743`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"10", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "3"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               15.591811764066318` - 
                0.006172075101696743 (10 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 3] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{597., 0.01903769}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.964728701785188`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18164710290259092`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Sin", "[", "5", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.964728701785188 - 0.18164710290259092` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                    Cos[(E^5 Sin[5]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + 2 Tan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{599., 0.02229794}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.016054879038913`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18797497043668304`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox["1", 
                    SqrtBox[
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "2"]}]]], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.016054879038913 - 0.18797497043668304` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[(1 + ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]^2)^Rational[-1, 2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{608., 0.01635161}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9089111542127384`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18306232473312628`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9089111542127384` - 0.18306232473312628` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                    Cos[(5 E^5) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + 2 Tan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{613., 0.01425767}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9991219611506588`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18098829743981493`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9991219611506588` - 0.18098829743981493` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{613., 0.0476959}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.727403721209106`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005791954608078028`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.856546274487839`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.1928702119270581`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.727403721209106` - 
                0.005791954608078028 (7.856546274487839 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(2 - Cos[0.1928702119270581 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{616., 0.050813040000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "112.44728025787937`"}], "+", 
                  RowBox[{"0.0065454733281493545`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.4988843705433492`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"3.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-112.44728025787937` + 
                0.0065454733281493545` (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.4988843705433492` + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[3.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (9.209308857575003 + 
                    Log[9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{626., 0.0161438}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9694477994646777`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18157165205159198`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Sin", "[", "5", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9694477994646777` - 0.18157165205159198` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                    Cos[(E^5 Sin[5]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + 2 Tan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{626., 0.051891480000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.7817838598488196`"}], "+", 
                  RowBox[{"0.000554916516697983`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.7817838598488196` + 
                0.000554916516697983 (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.7251361379489152` + Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{632., 0.02367709}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.076162549567413`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1796103968896518`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"5", "/", "2"}]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.076162549567413 - 0.1796103968896518 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[E^Rational[5, 2] - (-ArcTan[
                    Cos[(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{633., 0.01727044}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.941262170137053`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18234632004451473`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"7.683763484795428`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Sin", "[", "5", "]"}], " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.941262170137053 - 0.18234632004451473` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[7.683763484795428 - (-ArcTan[
                    Cos[(E^5 Sin[5]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{667., 0.01532846}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.12349825128857`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.17817696701764615`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"5", "/", "2"}]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.12349825128857 - 0.17817696701764615` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[E^Rational[5, 2] - (-ArcTan[
                    Cos[(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{693., 0.03504563}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.68602822723834`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005760950599782793`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.856546274487839`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.68602822723834 - 
                0.005760950599782793 (7.856546274487839 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{693., 0.03507051}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.547999181707748`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005931402022286163`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"7", "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.547999181707748` - 
                0.005931402022286163 (7 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{713., 0.01847446}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.085700576215966`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.17948618746275827`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"5", "/", "2"}]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", "5"], " ", 
                    RowBox[{"Sin", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "4", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.085700576215966 - 0.17948618746275827` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[E^Rational[5, 2] - (-ArcTan[
                    Cos[(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[(E^5 Sin[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]) Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[4] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{738., 0.01472611}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.00184311009455`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1809537082553138`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    FractionBox[
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", "6", "]"}]], "2"]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.16858835527469934`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               4.00184311009455 - 0.1809537082553138 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[E^(Rational[1, 2] E^ArcTan[6]) - (-ArcTan[
                    Cos[0.16858835527469934` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{739., 0.047363590000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "33.2471967221417`"}], "+", 
                  RowBox[{"0.0011213014224077773`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"6.660359172310152`", "\[VeryThinSpace]"}], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"5", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "2"], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "4"]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[-33.2471967221417 + 
                0.0011213014224077773` (Cos[Cos[(4 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                  Cos[(1.7251361379489152` + Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                   Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[6.660359172310152 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + (9.209308857575003 + 
                    Log[5 + (7.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^2 + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^4), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{765., 0.04495943}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.783106296893992`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005303292117102134`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9.282342032871398`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", "-", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.783106296893992` - 
                0.005303292117102134 (9.282342032871398 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] - Cos[
                  2 + Rational[-1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{767., 0.019822140000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.1504709172551`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.17979643101925175`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"5", "/", "2"}]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"5", "/", "2"}]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[4.1504709172551 - 0.17979643101925175` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[E^Rational[5, 2] - (-ArcTan[
                    Cos[(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[E^Rational[5, 2] - (-ArcTan[
                    Cos[(Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{807., 0.03234361}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.552372276306901`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005722253591927045`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.725136137948915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.552372276306901` - 
                0.005722253591927045 (7.725136137948915 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{807., 0.03923659}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.57649756218487`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.0058564507247969985`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.725136137948915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"Cos", "[", "2", "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.57649756218487 - 
                0.0058564507247969985` (7.725136137948915 + 
                  Cos[(6 + Cos[2] - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 4] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{819., 0.03068169}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.491677290832946`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005653308603092861`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.725136137948915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "4"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.491677290832946` - 
                0.005653308603092861 (7.725136137948915 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 4] Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Cos[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{819., 0.03139798}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.505642245728625`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005667936315305222`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.725136137948915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.613567469374913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "4"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.505642245728625` - 
                0.005667936315305222 (7.725136137948915 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.613567469374913 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 4] Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Cos[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{842., 0.03935015}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"13.854015864658361`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.006469368119776809`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.725136137948915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}]}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "4"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               13.854015864658361` - 
                0.006469368119776809 (3.725136137948915 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  2 Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 4] Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Cos[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{915., 0.013519660000000001`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8857890335038716`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18394571167435023`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.16780437583036`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8857890335038716` - 0.18394571167435023` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[(
                    E^(E^(-ArcTan[6 - (-0.16780437583036 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{917., 0.01375339}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8960965881947525`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.18369563946622944`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]], "+", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "-", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8960965881947525` + 0.18369563946622944` (E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] + (
                    E^(E^(-ArcTan[(E^(E^(-ArcTan[6 - (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] - Cos[
                  25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] - Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{922., 0.03264229}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"14.46947415973457`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.005650337863412468`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.725136137948915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.7251361379489152`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], ")"}], "2"], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    RowBox[{
                    RowBox[{"5.725136137948915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}]], "]"}]}], ")"}], "2"], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    
                    RowBox[{
                    RowBox[{"-", "6.660359172310152`"}], "-", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Tan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], ")"}], "2"], "]"}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    FractionBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], ")"}], "2"]}], ")"}], "2"]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               14.46947415973457 - 
                0.005650337863412468 (7.725136137948915 + 
                  Cos[(1.7251361379489152` + (5.725136137948915 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + 
                  Cos[(6 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(2 + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + (6 - Cos[
                    Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2 - 
                    Cos[(5.725136137948915 - Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^(-1) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2] + Cos[(6 - Cos[Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]/(-6.660359172310152 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)] + Cos[
                    Tan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]])^2] + (4 + 
                    Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Cos[Rational[1, 2] Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]])^2)^2, 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{936., 0.01375339}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8960965881947525`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18369563946622944`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[0, 0, 1], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8960965881947525` - 0.18369563946622944` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[(E^(E^(-ArcTan[6 - (-ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[0, 0, 1]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{19., 0.9948378999999999}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.738645862755826`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.04299638487230791`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[9.738645862755826 - 0.04299638487230791 (Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"] + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{22., 0.5394116}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"8.514962423423125`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.01978322299289958`", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[8.514962423423125 + (0.01978322299289958 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2) Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2, 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{29., 0.1305644}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"5.837482792373918`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"0.23439822226357157`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[5.837482792373918 + 0.23439822226357157` (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{33., 0.06511739}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.194850027250133`", "\[VeryThinSpace]"}], "-", 
                  FractionBox["226.3630943116557`", 
                   RowBox[{
                    RowBox[{"16.74308309413165`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               17.194850027250133` - 226.3630943116557/(16.74308309413165 + 
                Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{42., 0.061815220000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.56809988607475`"}], "+", 
                  RowBox[{"3.979397261764212`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.3700707745176537`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               
               Style[-1.56809988607475 + 
                3.979397261764212 Log[3.3700707745176537` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{46., 0.06145732}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "17.235590982926656`"}], "+", 
                  RowBox[{"18.566493726219413`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "0.13506945696943434`"]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[-17.235590982926656` + 18.566493726219413` (2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^0.13506945696943434`, 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{52., 0.059666870000000004`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"9.772299178763555`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"4.770799585789375`", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"8.77196225083388`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[9.772299178763555 + 4.770799585789375 Tan[
                   Log[8.77196225083388 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]], 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{66., 0.04938061}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"17.062700090010495`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["216.51838510294067`", 
                   RowBox[{
                    RowBox[{"-", "16"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6.024244290186736`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               17.062700090010495` + 
                216.51838510294067`/(-16 + Cos[6.024244290186736 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{75., 0.04743892}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.2810086035449966`"}], "+", 
                  RowBox[{"3.638864024099345`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               
               Style[-0.2810086035449966 + 
                3.638864024099345 Log[2 + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{86., 0.04533271}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"35.972394163224585`", "\[VeryThinSpace]"}], "+", 
                  FractionBox["826.9352617805577`", 
                   RowBox[{
                    RowBox[{"-", "24.060521364609343`"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"6", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}]}]]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               35.972394163224585` + 
                826.9352617805577/(-24.060521364609343` + Cos[6 Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - 2 (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{114., 0.04323986}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.5431128368434661`"}], "+", 
                  RowBox[{"3.994108811164531`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"3", "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"18.93617477220362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[-1.5431128368434661` + 3.994108811164531 Log[3 + ArcTan[
                    Tan[18.93617477220362 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{146., 0.04220061}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "8.665260415018132`"}], "+", 
                  RowBox[{"0.18470566659816035`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7.209308857575003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"9.201733644632064`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}], "2"], "+", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               
               Style[-8.665260415018132 + 
                0.18470566659816035` ((7.209308857575003 + 
                    Log[2 + Cos[9.201733644632064 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2])^2 + Sin[4 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{158., 0.04160966}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.510726705871336`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8287826185445848`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.0310692458406`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"18.93617477220362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[3.510726705871336 + 1.8287826185445848` (-Cos[
                    Log[3.0310692458406 + ArcTan[
                    Tan[18.93617477220362 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{166., 0.04081404}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "6.408272399695967`"}], "+", 
                  RowBox[{"5.231965694045441`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"7.3981294266783095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"90.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               
               Style[-6.408272399695967 + 
                5.231965694045441 Log[7.3981294266783095` + ArcTan[
                    Tan[90.39812942667831 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2], 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{222., 0.04038916}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.558707521450843`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.8588497799841543`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2699146244271495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"18", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[1.558707521450843 + 1.8588497799841543` (-Cos[
                    Log[3.2699146244271495` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[18 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{237., 0.03807967}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "1.0466567080008264`"}], "+", 
                  RowBox[{"1.8483187208963114`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"2.8481909635169274`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"16.93617477220362`", "\[VeryThinSpace]"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[-1.0466567080008264` + 1.8483187208963114` (-Cos[
                    Log[2.8481909635169274` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (16.93617477220362 + 
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{239., 0.03744396}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"1.9510966548212272`", "\[VeryThinSpace]"}], "+", 
                  RowBox[{"1.788606155898491`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{"3.2699146244271495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "4"]}]}], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[1.9510966548212272` + 1.788606155898491 (-Cos[
                    Log[3.2699146244271495` + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{243., 0.03685862}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"0.7687235962755984`", "\[VeryThinSpace]"}], "+", 
                  FractionBox[
                   RowBox[{"19.907107273042147`", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    FractionBox["57", "8"], "+", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"]}], "]"}]}], 
                   RowBox[{
                    RowBox[{"10.651382597834791`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2.4405983039138768`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "4"], "]"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18.424973303913877`", "\[VeryThinSpace]"}], "+", 
                    
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "4"], "]"}], "2"]}]]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               0.7687235962755984 + (19.907107273042147`/(10.651382597834791` + 
                  Cos[(2.4405983039138768` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^4]^2 + 
                  Cos[(18.424973303913877` + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^4]^2)) 
                 Log[Rational[57, 8] + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] + (Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2], 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{254., 0.03676364}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"-", "0.18326824617065812`"}], "+", 
                  RowBox[{"1.8669795464308316`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    SqrtBox["11"], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    RowBox[{"9.39812942667831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}]}
                    ], "]"}], "]"}]}], "]"}], "]"}]}], "-", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Log", "[", 
                    RowBox[{"2", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "]"}], "+", 
                    SqrtBox[
                    RowBox[{"9", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], 
                    "2"]}]]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[-0.18326824617065812` + 1.8669795464308316` (-Cos[
                    Log[11^Rational[1, 2] + ArcTan[
                    Tan[9.39812942667831 + 2 Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4]]]] - Cos[
                   Log[2 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2]] + (9 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^Rational[1, 2]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{264., 0.03379812}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.330398741789349`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20463585506703005`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               4.330398741789349 - 
                0.20463585506703005` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{273., 0.03236365}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.396040187278021`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.2007067666082232`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               4.396040187278021 - 
                0.2007067666082232 (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + Cos[
                   Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{299., 0.02869448}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.38380518249006`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.20260978641055233`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               4.38380518249006 - 
                0.20260978641055233` (-(
                    E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{314., 0.02756643}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"4.4678701093025515`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19874383197191242`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"8", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]]}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               4.4678701093025515` - 
                0.19874383197191242` (-(E^(E^(-ArcTan[8 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{338., 0.02651355}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.769279223977315`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.1944393915962661`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"6.871489524120378`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[3.769279223977315 - 0.1944393915962661 (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6.871489524120378 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{343., 0.02257453}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8862166774471953`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19122035635058077`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8862166774471953` - 0.19122035635058077` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 2 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{359., 0.021534170000000002`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.904830046344218`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19082962107576024`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.904830046344218 - 0.19082962107576024` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{372., 0.01942232}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8885022818520762`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19126612394207465`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}]}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8885022818520762` - 0.19126612394207465` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 2 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{388., 0.01789098}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9162755175839314`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.19047997994393376`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"9", "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9162755175839314` - 0.19047997994393376` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[9 - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + 
                 Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{462., 0.01751612}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8735761014385757`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18561737438919954`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", "3", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8735761014385757` - 0.18561737438919954` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[3] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + 2 ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] - ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{485., 0.01672871}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.820737010009064`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18673601085163793`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.820737010009064 - 0.18673601085163793` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[
                    Cos[
                    Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - Style[
                   TraditionalForm[
                    Subscript["x", "2"]], 
                   Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{517., 0.01599068}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.919638964727381`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18436443329168598`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "]"}], 
                    "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.919638964727381 - 0.18436443329168598` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[6 - (-ArcTan[Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   ArcTan[
                    Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]] + ArcTan[ArcTan[
                    Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{613., 0.01425767}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.9991219611506588`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18098829743981493`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"8.275178113041791`", "\[VeryThinSpace]"}], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.9991219611506588` - 0.18098829743981493` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[8.275178113041791 - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ], 
             TagBox[
              TooltipBox[{
                Opacity[0.], 
                PointBox[{{915., 0.013519660000000001`}}]}, 
               StyleBox[
                RowBox[{
                  RowBox[{"3.8857890335038716`", "\[VeryThinSpace]"}], "-", 
                  RowBox[{"0.18394571167435023`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ArcTan", "[", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "]"}]]}], "-", 
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    SqrtBox[
                    SuperscriptBox["\[ExponentialE]", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.16780437583036`"}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]}],
                     "]"}]}]]]], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.020730394225662`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}], "+", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"6", "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "5", "]"}]}], "+", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     ")"}], "2"], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"]}],
                     "]"}], "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "-", 
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"1\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "2"], 
                    "-", 
                    SqrtBox[
                    SuperscriptBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False], "4"]], 
                    "+", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"25.140795789942956`", " ", 
                    StyleBox[
                    TagBox[
                    FormBox[
                    SubscriptBox["\"x\"", "\"2\""], TraditionalForm], 
                    TraditionalForm, Editable -> True], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica", StripOnInput -> False]}], 
                    "]"}], "]"}]}], ")"}]}]}], 
                RGBColor[1, 0, 0], StripOnInput -> False]], Annotation[#, 
               Style[
               3.8857890335038716` - 0.18394571167435023` (-E^ArcTan[(-Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 + Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2] - (
                  E^(E^(-ArcTan[(
                    E^(E^(-ArcTan[6 - (-0.16780437583036 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] - (-ArcTan[
                    Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4])))^Rational[1, 2] + ArcTan[
                   Cos[25.020730394225662` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]] + ArcTan[6 + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2 - (-Sin[5] + Style[
                    TraditionalForm[
                    Subscript["x", "1"]], 
                    Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2)^2 - Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^2] + 
                 Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]] - Style[
                   TraditionalForm[
                    Subscript["x", "1"]], 
                   Hue[
                    Rational[1, 16], 1, 
                    Rational[5, 6]], FontWeight -> "Plain", FontSize -> 10, 
                   FontFamily -> "Helvetica"]^2 - (Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]^4)^Rational[1, 2] + Tan[
                   Cos[25.140795789942956` Style[
                    TraditionalForm[
                    Subscript["x", "2"]], 
                    Hue[
                    Rational[1, 8], 1, 
                    Rational[1, 2]], FontWeight -> "Plain", FontSize -> 10, 
                    FontFamily -> "Helvetica"]]]), 
                RGBColor[1, 0, 0]], "Tooltip"]& ]}}}, AspectRatio -> 0.5, 
          Axes -> None, AxesOrigin -> {0, 0}, Frame -> True, FrameLabel -> {
            FormBox["\"Complexity\"", TraditionalForm], 
            FormBox["\"1-\\!\\(R\\^2\\)\"", TraditionalForm]}, GridLines -> 
          Automatic, ImageSize -> 250, PlotRange -> {All, All}, 
          PlotRangeClipping -> True, 
          PlotRangePadding -> {Automatic, Automatic}], StripOnInput -> False, 
         FontFamily -> "Helvetica", FontSize -> 10, FontWeight -> "Plain", 
         FontSlant -> "Plain", FontColor -> GrayLevel[0], 
         DataModeler`UtilityFunctions`NumberFormatting -> {4, 1}]}}, 
      GridBoxDividers -> {
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}}]],TagBox[
     TooltipBox[
      StyleBox[
      "\"Variable Combination Table\"", StripOnInput -> False, FontFamily -> 
       "Helvetica", FontSize -> 12, FontWeight -> "Bold", FontSlant -> 
       "Plain", FontColor -> GrayLevel[0], Background -> None], 
      GraphicsBox[{{{}, {
          Hue[0.67, 0.6, 0.6], 
          PointBox[CompressedData["
1:eJw1mHlczPkfx3OssFrHOmI3OSKKnImQVyVSIZ26p/tujqaZcZZ1bNhCoYjU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           "]]}, {}}}, {
       AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> 
        True, AxesOrigin -> {0, 0}, Frame -> True, FrameLabel -> {
          FormBox["\"Popularity-Ordered Combinations\"", TraditionalForm], 
          FormBox["\"Cumulative Percent\"", TraditionalForm]}, GridLines -> 
        Automatic, PlotLabel -> FormBox[
          StyleBox[
          "\"The 5677 models have 403 VariableCombinations\"", {
           FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
            FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
            None}, StripOnInput -> False], TraditionalForm], 
        PlotRange -> {{0., 403.}, {0, 99.99999999999966}}, PlotRangeClipping -> 
        True, PlotRangePadding -> {
          Scaled[0.02], 
          Scaled[0.02]}}]], Annotation[#, 
      Graphics[{{{}, {
          Hue[0.67, 0.6, 0.6], 
          Point[CompressedData["
1:eJw1mHlczPkfx3OssFrHOmI3OSKKnImQVyVSIZ26p/tujqaZcZZ1bNhCoYjU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           "]]}, {}}}, {
       AspectRatio -> GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
        Frame -> True, 
        FrameLabel -> {
         "Popularity-Ordered Combinations", "Cumulative Percent"}, GridLines -> 
        Automatic, PlotLabel -> 
        Style["The 5677 models have 403 VariableCombinations", {
          FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
           FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
           None}], PlotRange -> {{0., 403.}, {0, 99.99999999999966}}, 
        PlotRangeClipping -> True, PlotRangePadding -> {
          Scaled[0.02], 
          Scaled[0.02]}}], "Tooltip"]& ]},
   "Labeled",
   DisplayFunction->(GridBox[{{
       ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
       TagBox[
        ItemBox[
         PaneBox[
          TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
          BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
        "SkipImageSizeLevel"]}}, 
     GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
     AutoDelete -> False, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      BaselinePosition -> {2, 1}]& ),
   InterpretationFunction->(RowBox[{"Labeled", "[", 
      RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.59930154861817*^9, 3.599558814948998*^9, 3.599560946087989*^9, 
   3.599866084055171*^9, {3.599904917843405*^9, 3.599904940517007*^9}, 
   3.600032892408456*^9, 3.600175364674657*^9, 3.600868433833865*^9, {
   3.600868551476656*^9, 3.600868600349115*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Create an ensemble for prediction\
\>", "Subsection",
 CellChangeTimes->{{3.532853939269116*^9, 3.532853945860551*^9}, 
   3.561457205031646*^9, {3.6001709777393713`*^9, 3.600170979841782*^9}, {
   3.6001757138861933`*^9, 3.600175721548986*^9}, {3.600969818348151*^9, 
   3.6009698188518267`*^9}}],

Cell["\<\
To make predictions, we need an \[OpenCurlyDoubleQuote]ensemble\
\[CloseCurlyDoubleQuote] data structure with only the robust models, without \
asymptotic behavior or discontinuities.\
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6009698267329483`*^9, 
   3.600969850716566*^9}, {3.600973151881069*^9, 3.600973185745076*^9}, 
   3.6009734341687403`*^9, {3.600973808256486*^9, 3.6009738091256933`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"ensemble1", "=", 
   RowBox[{"CreateModelEnsemble", "[", 
    RowBox[{"RobustModels", "@", "highQualityModels1"}], "]"}]}], 
  ";"}]], "Code",
 CellChangeTimes->{{3.599302076564765*^9, 3.599302080609962*^9}, 
   3.5995606860401154`*^9, 3.600175733695755*^9, {3.6001768368694973`*^9, 
   3.600176839357205*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.600973816645752*^9, 3.60097381926294*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Observe the response surface behavior of the models\
\>", "Subsection",
 CellChangeTimes->{{3.532853939269116*^9, 3.532853945860551*^9}, 
   3.561457205031646*^9, {3.6001709777393713`*^9, 3.600170979841782*^9}, {
   3.6001757138861933`*^9, 3.600175721548986*^9}, {3.600177352646035*^9, 
   3.600177380308042*^9}, {3.600969856148325*^9, 3.600969858620216*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResponsePlot", "[", 
  RowBox[{"ensemble1", ",", 
   RowBox[{"VariablesToPlot", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}]}], "]"}]], "Code",
 CellChangeTimes->{{3.600176818454296*^9, 3.600176821976297*^9}, {
  3.6001768977637157`*^9, 3.600176898612524*^9}, {3.6007703402288113`*^9, 
  3.600770364162546*^9}, {3.60077058978299*^9, 3.6007706132057037`*^9}, {
  3.600868474991453*^9, 3.6008684753491173`*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwUmnc8Vf8fx5GRfc+9RtncVSnJLMp5hySEysomIYlCkoqSSqJUkgqJjCgp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       
       "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
         {RGBColor[1, 1, 0.85], EdgeForm[None], 
          GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwV1nf8l2MbxvGf0UaFSFN7D5QG0U5Lae/S0N57L1TaaS8qaQ/tpaUtq0J7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            "]]]}, {}, {}, {}}, {{}, {}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwl2QW4FlXXBuBDN9LdJSjdICgdUgIqoogSKiIlLSoYGHRLl1JSAoKBgkFj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             "]]},
           RowBox[{"{", 
             RowBox[{
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x2\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x3\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x4\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x5\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x6\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x7\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x8\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x9\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x10\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x11\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x12\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x13\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x14\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x15\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False]}], "}"}]],
          Annotation[#, {
            Style[
            "\!\(TraditionalForm\`x2\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x3\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x4\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x5\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x6\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x7\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x8\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x9\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x10\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x11\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x12\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x13\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x14\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x15\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}]}, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {GrayLevel[0.5], LineBox[CompressedData["
1:eJwV03e8z1UYwPGfIjMju2EL116V6mavJpfcEMkuokIoMsqeDS0ZWYVQ2VkZ
UTYNK1vZijSNej9/vH3Oef74fe/rnKNw2+4p3dIkEolk/ySlTyRyZUgkdulU
XqUzT1KaMpSlHOWpQEUqUZkqVOUu7uYeqnEv93E/yTxAbt/ZrR8xgGdoRSHz
g/opI+kZ3zE7ryv5gOrkMftOU3Wa1tUbGBjf1991Hc+SZH9Sl/B2fN/+SnxP
N2uKZqM9re0L6yGdxyh6UYO85t/rdAbRhacoYn5Y5zOal6hJPvMfdAaD6Rrn
aHZKlzKBNhQ1O6ILGBPnZf+XbqR3nLH9BV3FxPht++u6jVrkt/9RZ1LP+kZe
izvQy7qe5+L+7E/rMh6yzsA7cZ56VbfQxDo7T1sX06P6GQ2s0zE27lL/jneh
m7SR3kyfeAv6q7bQ1fqIZqItH8bfq//Fuel2fVxvoQO17W/VPfqEztL6mpY2
vB5vSv/QlrpBH9MstKNbvE89o811uT6sGXk37lCvaWvdqk01R/xt1sX1mH5O
Q+ubGBdvVv/Rb2hsnZW+8d71N13Do9aZmWRdWxPssK7DbdZ79WOGxP8H+z/1
a7pTzv6sfsl7tONOs+P6BeN5Od43t5vv008YyvO0p4T5CV3IG7wS74A7zPfr
bIbxAuXNzukK3qcDJc1+1kU8aJ0+7p837ZP1X/2WflSxv6hfMTnuhwJmB3QO
w3mRjvFm4izjN+O9xV3Ee4jzinuLdxNnSkq8u7iPeA80IzXeQNxjvCUK+sZP
OpcR9KATpcx/0cW8RX+qml3StUyJe7BPw874bc1JR1ra/w855pus
             "]]},
           RowBox[{"{", 
             RowBox[{
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x2\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x3\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x4\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x5\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x6\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x7\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x8\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x9\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x10\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x11\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x12\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x13\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x14\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x15\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False]}], "}"}]],
          Annotation[#, {
            Style[
            "\!\(TraditionalForm\`x2\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x3\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x4\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x5\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x6\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x7\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x8\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x9\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x10\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x11\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x12\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x13\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x14\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x15\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}]}, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {GrayLevel[0.5], LineBox[CompressedData["
1:eJwV12WYVVUUBuCrIt3d3SHSJR3SDZLSjYR0d3eIgol0g0GIigi2KKFY2IoK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             "]]},
           RowBox[{"{", 
             RowBox[{
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x2\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x3\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x4\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x5\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x6\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x7\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x8\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x9\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x10\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x11\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x12\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x13\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x14\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x15\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False]}], "}"}]],
          Annotation[#, {
            Style[
            "\!\(TraditionalForm\`x2\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x3\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x4\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x5\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x6\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x7\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x8\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x9\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x10\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x11\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x12\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x13\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x14\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x15\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}]}, "Tooltip"]& ]}}],
      AspectRatio->1,
      AxesLabel->{
        FormBox[
         StyleBox["x1", 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]], Background -> None, StripOnInput -> False], 
         TraditionalForm], None},
      AxesOrigin->{0, 0},
      Epilog->{
        RGBColor[0, 1, 0], 
        PointSize[Large], 
        PointBox[{-0.10000000000000009`, 4.371138003652891}]},
      Frame->True,
      FrameLabel->{
        FormBox[
         StyleBox["x1", 
          Hue[
           Rational[1, 16], 1, 
           Rational[5, 6]], Background -> None, StripOnInput -> False], 
         TraditionalForm], None},
      FrameTicks->{None, Automatic},
      ImageSize->200,
      LabelStyle->Directive[
        GrayLevel[0], Bold],
      Method->{"AxesInFront" -> True},
      PlotRange->{-5.447886099162929, 12.941268296989335`},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {100, -102.5}, ImageScaled[{0.5, 0.5}], {200, 200.}], 
    InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwUmnk0VP8fxu37Mgsj+8yYGYrstMl9fyUJRcpOIVtChbTJFiVbJWuEKBWF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       
       "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
         {RGBColor[1, 1, 0.85], EdgeForm[None], 
          GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwV1WXYFeUWBuAPMOijSJuICCoGCiahhAI22GJ3gQFi0t156O4SASmDsEFR
ygYVWxSwBQX1fn7c17PWO3tm75lZM7vKrW1atC5cUFBQiGJFCgoaFS8oaFii
oKAI76qn0ZN2NKYJ53MBTWlGcy6kkX32Y716Or14lCuslWObeimjuCjHs7Y/
G9Qz6M3N+irsUL9Ce67Ul6cLX+gfk2fRi2X6NvIU9qpHc6e6Or+q13Bxfrf+
ADaqZ9Inx+ESLuUyLqcFLfOb871cxdU5Z/seyCb1LPryONfkWlgvymb1bPrx
RPa1VoEv1csZw7W5btaK8Z56Dv15Mt9jrSJfqZ9nLNflGlsrzvvquQzgFv3R
7FS/ylP5LfpKfK1+gXHcpa/Bb+q1XJ/7pS/BB+p53K8+kT3qgdyqrsou9Ws8
rD6Nf9VP5xzUlfkm10CezYvqB2Ut9qk7yAaMV98tj6Mrv+dcZV1685a+raxD
DwrRkXPpQ6vMlixJZz7MTMkz6Mkz+gfkSXTjr1wLWY9B6tvkMfyUeyLP4XX1
I7I2BXTIdZaH8q36JR5Sn8o/6gncoz6eP9Rvc0NmWF+Kj9TzGczt+mr8rH6D
jrnm+sP4Tr2CidyYubRWmo/VzzKETrSydjjfq1cyiZsyq9b+xyfqBQylc56Z
zLD1g9iiXsgwumROcj9zHfLbuCPPR+Yi9yXnxb2Zf/sezFb1IobTNedp7Qi2
q1cxOZ/Xn8Cf6nXcl2dHX4ZP1e3lmTynbi1Ppjt/Z35kff6f3yKP5Rf1m3TL
ddEfyQ/q1UzJfOa5tHYIn6kXM4Luuff5Dtpk/nLfMq+5v7T0+bJ8rl7CSHrk
Wlo7ih/VLzM156CvyW71O7RTn05hOnEefWmb+ZAXlnLPSrof8nJ5shwod3II
DfSTZIGsJ6vIJ+XHfG//xvpZ6qKyqawhe8iv2Z8z9CPlnzk2lfQPyLdZl7mT
51gbJ/fm8xyubyc3s9VnGuqn53iykawmO8vP2ZNnWj9U/QtVKae/Ra7iRdub
6+erS8vL5ElygNxBGerrJ8p/qctR+ifkR3xn/wtkdWvd5Vfsx+n6EfKPHI+K
+vvlWzm37KOfqy4hL5YnyL5yOyU5Wz9W/p1jcZi+rdzEFvtPy/dYayg78Rm7
866UZa3fLFfyQp51iqhP5D7W5nfk+cpsU0V/Eyt4Xr+cZSxlCYsz4yxiIQt4
lvl5LzGPucxhNmvzrOcdkvlzzBt5iVn6NXmP5P2Y+bd2Q+4BM/XfZA7VNbmX
NbyZdyG/5fnUt8o5MUP/dd6juXbck8/yhrUSsg6PsJEPrP2ad436+pwj0/Me
yGzxOB/m3lk7X3bjy8w0x3N3jsvrtl8k+2S2Kc4Y/qI2D7OB931uqiziPpwn
j5Ed5aeZwbxv9UPUP+e+5jnSXyeXM832Zvpn1KXkpblvsr/8kYOop58g/8mc
cKT+sZxnfrf9Z8oDrTWRXfkis5t3kfyd47gr58NrecZl78wyxTiNh1jPe7af
KzuwNb85/x/yWpYxNe9qeRbtc+75vvyfUEN9Z76DV/VF5ak8yLtszv8VldXX
sJQp+m3so7r+juzLK/pN7KKS/mqWMDnvPfbmHau/PZ/lZf1GdlJRfxWLmaRf
zQZ2UMHalTzHRP0ExjOOsYxhNKMYyYhcR4YzjKEMYTCDGMgq1ue9S3nHLeNe
XCEXMSDv9vxHUMf6cGu/UY0K+tvy21mZWdTPyZzJ5plF2Ut+m/uba64fLfdQ
i0P1beQ7ub55l+unqAvLBrKqfFpu4Qfba+kHq3+iHAfrW8qF9Le9qX6euqS8
RNaU/bIvpamrHy/3cSZH6B/NzGTW7d9IP0N9gGwsj5Vd5LY8M7bX1g9T/5pn
hPL6W+VqVtjeRD87MymbZW5lT/lNjpnv1I+SuzmFyvrWcl2uQeZWP1ldSNaX
R8un5Cdst/0U/SD1Lsrm2dK3kAvoZ/t/pTWlDg==
            
            "]]]}, {}, {}, {}}, {{}, {}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwl2gW4lVXbReFDd0pKdzcICEp3d3d3IwJKd3eDEhbd3d3d3Y1IN//9fv91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             "]]},
           RowBox[{"{", 
             RowBox[{
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x1\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x3\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x4\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x5\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x6\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x7\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x8\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x9\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x10\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x11\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x12\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x13\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x14\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x15\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False]}], "}"}]],
          Annotation[#, {
            Style[
            "\!\(TraditionalForm\`x1\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x3\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x4\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x5\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x6\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x7\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x8\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x9\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x10\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x11\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x12\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x13\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x14\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x15\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}]}, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {GrayLevel[0.5], LineBox[CompressedData["
1:eJwV03lgj3UcB/DfiGoTSSodslzpLiREZUoroU3pWKlFFG3SZhRjY3eUEFFR
lKtLl+7SnRA6UVGE3IUOJK/PH6993p/Pfs/v9zzf7/dJzc7NyElKJBLp/qQl
JxKdUhKJ6nwlP0MZ+XTmcq6gC1eSzlVcTZprDmO5/CzlDKGnWX1+kRfyGF3j
+8xqsEKeTQW36VPZLn9EAdfpj6OYX/VD1baU84Y+Vz2PA/JU7pSbs1v+gmvi
vvU1WSnPoTK+h250pwfXkkFm3HP8LtfTK57ZtYfztTyXKoZxQ6yF+RF8I8/j
Qe6Pa82OZ738JtO4MdbN7Ei+leczlgfid8xOYIP8Fo9zU6yxWTLfyc8xjtv1
p7FD/pjhcS/6Bvwmv80T9NOfzh55MTfHfulT+F5+noHy2fwrP0S23Jid8icM
llvyvzwinkE+kY2xBmo73pEHqefzn1yoXsKTcn+1BaPZG8+qXkwFX+rz1NaU
ksRILqWSrDhbai2K+CHOlNqGMl7Q36Oewxj2xVqoHXhYvkNtwq7YE7U9n8r3
qa1IUBjrrJ7EJvld7pUv4KA8nbvkM/hLXsItcYb1R7FKfpHx9NE35Q/5M0bG
mutPZrP8HjO4Nc6lWW1Wyy/xCKPIMjuF3+X3eYrecVbN6rBGXsAEiuKdiTNs
fjQ/yi8zkeI4J7GfsQ5xb/SN9yPORexLPBd3x/l3bV1+kl9hEqPjOc0askX+
gKfj8/oz+VteyoB4d/TH8LNcoF7Eq3KOei4l7I/zo3bk0bgXtRl/yp8zJtZF
fypb5UXMjPMZ76VZPdbKrzGZktj7+A1y4/zFvsV5jf0l0+ePZZ38OlMojbU0
a8Q2+UNmxTPoz+IfeRn58oVUYxSXUUWe/x0CFI6sQw==
             "]]},
           RowBox[{"{", 
             RowBox[{
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x1\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x3\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x4\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x5\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x6\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x7\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x8\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x9\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x10\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x11\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x12\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x13\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x14\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x15\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False]}], "}"}]],
          Annotation[#, {
            Style[
            "\!\(TraditionalForm\`x1\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x3\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x4\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x5\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x6\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x7\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x8\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x9\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x10\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x11\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x12\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x13\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x14\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x15\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}]}, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {GrayLevel[0.5], LineBox[CompressedData["
1:eJwV1GUAVEUUhuFFKSWlBEWUElQkDEAkRFDKxG7FLrC7O+juli67AFEJg7DA
AmwQEFQwKOP5frz7nm/m3t17Z85szW49unYvUigUFvjoWapQeL50odAV5csU
CpX4V/RFY3mj+a/V96GW3JqL8Hg+jpebX6bujv3kxrwdw9BcLs7r8CQOkTvx
XjyNT+D57n9b3Q1V5Dq8DQNxlLzT/HfqR3Cw3J6L82Rux2vNr1TfgRpyc/4H
o9FSLsub0BMN5FO4NM/kjtzL/S+oz8A+cmX+Df3QRN5kfrX6ftSW2/AePIHb
8grzy9U9sL/chHdgOI6RS/B6PIVD5c68N0/nE/kt97+jvhz7ynX5DwzC0fIu
89+gN140diYqGK/Cvxj7CAvQB33RD/0xAAMxCIMxBEMxDMMxAiMxCqMxBmPx
ku89K8+CzfLH2R+Mw8vGzkZVbJE/ybPjXfmK7A92y99iPF6Rz0G19JT8aa7F
QvlK1MteZX8xAa/K56aPsgfyZ1ihvglHoCQWGlvEV6E+/pW/xyr1nVlzlMNE
Y6/xedkX/C6v4QfSt1iZteObcWR6Ej/jaXTBIvOL+er0Lf7EYPyX3+NH078o
YS+m8A/GP+e7cKCxFnk2jEEruXz2C71wuHwql+FZ3Imfc//r6vNRUa6eZ0b/
vLu81fxa9YOoI7flPXkir8o+8S05M9iJEekzbMAzOAmLXbeEr0kvopDnxmPp
Rfxo/gu+G8fmPGCSsTf4AhyAbXnP7L361vQoSmGJsff4WhyGIvjJ2GS8qb4Q
NdLb+Y1ci/fl69AgZwrrjE3BXPVFWcesu/xlrsVUzDN2MQ7CX/JX+ADTMB0z
MBOzMBtz8v+WM57zk/5OH6c302/pkax73hHzfeclqIm/87+HD/P98vXZt6w5
1ued8Jb6UlSyD7V4e84qP4TjUTT7yqvT+3wbqhtryrswEi3k0rwRz2bt5JOz
pjyDO/DSPIf6BlSVG+bdMQRN5aLZOzyOenKH9HLWje/JWhlrmd7FWLSWK/Bm
9EZD+TQuy7O5M8/N/4r6MlSWa/NWDMh5kXfknKsfRl25HRfjSXl3XpPzq749
fSM3490Yld6Sy/Ay1yzlG1HNWKOsO4aimVwsPYQnUF/uyCV5KrfnDdl/9b3Z
M7lVeprHcRuuyFvQB43k07kcz+EuPM/9/wPqAftt
             "]]},
           RowBox[{"{", 
             RowBox[{
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x1\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x3\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x4\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x5\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x6\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x7\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x8\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x9\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x10\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x11\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x12\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x13\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x14\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False], ",", 
               StyleBox[
               "\"\\!\\(TraditionalForm\\`x15\\) \[RightArrow] \
\\!\\(TraditionalForm\\`\\*TagBox[InterpretationBox[\\\"\\\\\\\"-0.10\\\\\\\"\
\\\", -0.10000000000000009`, Rule[AutoDelete, True]], \
Function[NumberForm[Slot[1], List[8, 2], Rule[NumberPadding, List[\\\"\\\", \
\\\"0\\\"]]]]]\\)\"", {
                FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
                 FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
                 None}, StripOnInput -> False]}], "}"}]],
          Annotation[#, {
            Style[
            "\!\(TraditionalForm\`x1\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x3\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x4\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x5\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x6\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x7\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x8\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x9\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x10\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x11\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x12\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x13\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x14\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}], 
            Style[
            "\!\(TraditionalForm\`x15\) \[RightArrow] \
\!\(TraditionalForm\`\*TagBox[InterpretationBox[\"\\\"-0.10\\\"\", \
-0.10000000000000009`, Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[8, 2], Rule[NumberPadding, List[\"\", \"0\"]]]]]\)", {
             FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, 
              FontColor -> GrayLevel[0], FontSlant -> "Plain", Background -> 
              None}]}, "Tooltip"]& ]}}],
      AspectRatio->1,
      AxesLabel->{
        FormBox[
         StyleBox["x2", 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]], Background -> None, StripOnInput -> False], 
         TraditionalForm], None},
      AxesOrigin->{0, 0},
      Epilog->{
        RGBColor[0, 1, 0], 
        PointSize[Large], 
        PointBox[{-0.10000000000000009`, 4.371138003652891}]},
      Frame->True,
      FrameLabel->{
        FormBox[
         StyleBox["x2", 
          Hue[
           Rational[1, 8], 1, 
           Rational[1, 2]], Background -> None, StripOnInput -> False], 
         TraditionalForm], None},
      FrameTicks->{None, Automatic},
      ImageSize->200,
      LabelStyle->Directive[
        GrayLevel[0], Bold],
      Method->{"AxesInFront" -> True},
      PlotRange->{-5.447886099162929, 12.941268296989335`},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {300, -102.5}, 
     ImageScaled[{0.5, 0.5}], {200, 200.}]}, {}},
  AspectRatio->Automatic,
  Axes->False,
  ContentSelectable->True,
  FrameTicks->{None, Automatic},
  ImageSize->400,
  LabelStyle->Directive[
    GrayLevel[0], Bold],
  PlotLabel->FormBox[
    TagBox[
     TooltipBox["\"x16\"", 
      StyleBox[
      "\"ModelEnsemble\"", {
       FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, FontColor -> 
        GrayLevel[0], FontSlant -> "Plain", Background -> None}, StripOnInput -> 
       False], LabelStyle -> "TextStyling"], Annotation[#, 
      Style[
      "ModelEnsemble", {
       FontFamily -> "Times", FontWeight -> "Bold", FontSize -> 12, FontColor -> 
        GrayLevel[0], FontSlant -> "Plain", Background -> None}], 
      "Tooltip"]& ], TraditionalForm],
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.600868507695221*^9}]
}, Open  ]],

Cell["\<\
We observe large model disagreement in the global minimum of the function. \
This area requires more sampling in the next modeling iteration.\
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.600903187794518*^9, 3.600903190812448*^9}, {3.600969872916668*^9, 
   3.600969983428858*^9}, 3.6009734374989147`*^9, {3.600973892658176*^9, 
   3.600973893205886*^9}},
 FontSize->16],

Cell["", "PageBreak",
 CellOpen->True,
 PageBreakBelow->True],

Cell["\<\
The predicted 3D surface with the surrogate models captures the general \
behavior of the simulator though refinements are needed. \
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.600903187794518*^9, 3.600903193609004*^9}, {3.600970028396882*^9, 
   3.600970119444821*^9}, {3.60097324213142*^9, 3.600973253121471*^9}, 
   3.600973440896233*^9},
 FontSize->16],

Cell[BoxData[
 RowBox[{"ResponseSurfacePlot", "[", "\n", "\t", 
  RowBox[{"ensemble1", ",", " ", "\n", "\t", 
   RowBox[{"VariablesToPlot", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(x\), \(2\)]\)\>\"", ",", 
      "\"\<\!\(\*OverscriptBox[\(f\), \(~\)]\)(\!\(\*SubscriptBox[\(x\), \
\(1\)]\),\!\(\*SubscriptBox[\(x\), \(2\)]\))\>\""}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<DarkRainbow\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", " ", 
   RowBox[{"PlotLabel", "\[Rule]", "None"}]}], "\n", "]"}]], "Code",
 CellChangeTimes->{{3.599905314558704*^9, 3.599905329102543*^9}, {
  3.6001778651043653`*^9, 3.600177865289034*^9}, {3.600588392241022*^9, 
  3.600588435081997*^9}, {3.600595845590613*^9, 3.6005958559257936`*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQdbG1f+/r3/63kNG1d67yCh3nvvBYkiegfTjcEYMKb33nuxccWADcYY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    "], {{0, 400}, {400, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 400},
  PlotRange->{{0, 400}, {0, 400}}]], "Input", "Input",
 CellChangeTimes->{{3.601017058606612*^9, 3.6010170726209373`*^9}},
 ImageSize->{404, 400},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["", "PageBreak",
 CellOpen->True,
 PageBreakBelow->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Next Iteration", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
   3.5993008258216963`*^9, 3.5993008286762953`*^9}, {3.5993010107053013`*^9, 
   3.599301013542656*^9}, {3.6001711914512777`*^9, 3.6001711945150337`*^9}, {
   3.6001712802345123`*^9, 3.600171281104623*^9}, {3.6001780560498867`*^9, 
   3.600178065343547*^9}, {3.6001781745408077`*^9, 3.600178186429015*^9}, {
   3.6009734455425777`*^9, 3.600973455242489*^9}, 3.6009734986635427`*^9},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell["1. Design of experiment", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.6001710989041557`*^9, 3.6001711037897463`*^9}, {3.600171261690658*^9, 
  3.6001712623296328`*^9}, {3.6009714695679197`*^9, 3.600971469807272*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell[TextData[{
 "To improve the quality of our surrogate models we need to focus our design \
on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "2"], ".", " "}], TraditionalForm]]],
 "We added 250 points to the original space filling design for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]]],
 " homogeneously. It is also possible to sample especially the area of the \
predicted global minimum more into detail. \n\nThe new design:"
}], "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.6005862485556517`*^9, 3.6005862668939342`*^9}, {3.600586412388502*^9, 
   3.6005865058251038`*^9}, {3.600586578180017*^9, 3.6005866395451927`*^9}, {
   3.600588479459343*^9, 3.600588503344942*^9}, {3.6005885539786253`*^9, 
   3.600588563245933*^9}, {3.600588637411227*^9, 3.6005886865167723`*^9}, {
   3.600588757444914*^9, 3.600588760524742*^9}, {3.600970168662475*^9, 
   3.600970241656358*^9}, {3.6009702769971867`*^9, 3.600970335524807*^9}, {
   3.600970559808975*^9, 3.600970641126026*^9}, {3.6009707120831337`*^9, 
   3.600970777599243*^9}, {3.600970987131569*^9, 3.600971140094902*^9}, {
   3.6009732660439787`*^9, 3.6009732912413397`*^9}, 3.6009734653991117`*^9, {
   3.600973947344923*^9, 3.600973948486768*^9}, {3.601017427668562*^9, 
   3.6010174809119167`*^9}},
 FontSize->16],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxVV3l8jFcXnplkMktmMluqKbETFBWKLyV6j53UErWFKiliaxBFqVrGnuAj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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox[
     SubscriptBox["x", "1"], TraditionalForm], 
    FormBox[
     SubscriptBox["x", "2"], TraditionalForm]},
  ImageSize->{363., Automatic},
  PlotRange->{{-5., 4.800000000000001}, {-5., 4.800000000000001}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.600584434069352*^9}],

Cell["\<\
We repeated the previously described approach with the new input design...\
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.6005862485556517`*^9, 3.6005862668939342`*^9}, {3.600586412388502*^9, 
   3.6005865058251038`*^9}, {3.600586578180017*^9, 3.6005866395451927`*^9}, {
   3.600588479459343*^9, 3.600588503344942*^9}, {3.6005885539786253`*^9, 
   3.600588563245933*^9}, {3.600588637411227*^9, 3.6005886865167723`*^9}, {
   3.600588757444914*^9, 3.600588760524742*^9}, {3.600970168662475*^9, 
   3.600970241656358*^9}, {3.6009702769971867`*^9, 3.600970335524807*^9}, {
   3.600970559808975*^9, 3.600970641126026*^9}, {3.6009707120831337`*^9, 
   3.600970777599243*^9}, {3.600970987131569*^9, 3.600971263039379*^9}, {
   3.6009733031858063`*^9, 3.600973310281653*^9}},
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Simulation model", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.6001710989041557`*^9, 3.600171118085607*^9}, {3.600171265618634*^9, 
  3.6001712662330837`*^9}, {3.600971460073779*^9, 3.600971480279573*^9}, {
  3.6009715176978903`*^9, 3.600971525866523*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell["...", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.6005862485556517`*^9, 3.6005862668939342`*^9}, {3.600586412388502*^9, 
   3.6005865058251038`*^9}, {3.600586578180017*^9, 3.6005866395451927`*^9}, {
   3.600588479459343*^9, 3.600588503344942*^9}, {3.6005885539786253`*^9, 
   3.600588563245933*^9}, {3.600588637411227*^9, 3.6005886865167723`*^9}, {
   3.600588757444914*^9, 3.600588760524742*^9}, {3.600970168662475*^9, 
   3.600970241656358*^9}, {3.6009702769971867`*^9, 3.600970335524807*^9}, {
   3.600970559808975*^9, 3.600970641126026*^9}, {3.6009707120831337`*^9, 
   3.600970777599243*^9}, {3.600970987131569*^9, 3.600971263039379*^9}, {
   3.6009716008103323`*^9, 3.600971664591941*^9}},
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Surrogate modeling", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.5993008258216963`*^9, 3.5993008286762953`*^9}, {3.6001623397538767`*^9, 
  3.6001623438470097`*^9}, {3.600171183507821*^9, 3.600171186339514*^9}, {
  3.60017127213841*^9, 3.600171274936657*^9}, {3.600971558591898*^9, 
  3.600971558903894*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell["...", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.6005862485556517`*^9, 3.6005862668939342`*^9}, {3.600586412388502*^9, 
   3.6005865058251038`*^9}, {3.600586578180017*^9, 3.6005866395451927`*^9}, {
   3.600588479459343*^9, 3.600588503344942*^9}, {3.6005885539786253`*^9, 
   3.600588563245933*^9}, {3.600588637411227*^9, 3.6005886865167723`*^9}, {
   3.600588757444914*^9, 3.600588760524742*^9}, {3.600970168662475*^9, 
   3.600970241656358*^9}, {3.6009702769971867`*^9, 3.600970335524807*^9}, {
   3.600970559808975*^9, 3.600970641126026*^9}, {3.6009707120831337`*^9, 
   3.600970777599243*^9}, {3.600970987131569*^9, 3.600971263039379*^9}, {
   3.6009716008103323`*^9, 3.600971651288197*^9}, {3.600971708402285*^9, 
   3.600971708679994*^9}},
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. System understanding", "Subtitle",
 CellChangeTimes->{{3.5992989961870003`*^9, 3.599299001976911*^9}, {
  3.5993008258216963`*^9, 3.5993008286762953`*^9}, {3.5993010107053013`*^9, 
  3.599301013542656*^9}, {3.6001711914512777`*^9, 3.6001711945150337`*^9}, {
  3.6001712802345123`*^9, 3.600171281104623*^9}, {3.600971561104061*^9, 
  3.600971561687839*^9}},
 Background->RGBColor[
  0.5545433737697414, 0.9177080949111162, 0.5686274509803921]],

Cell[CellGroupData[{

Cell["\<\
The response surface behavior of the new surrogate models\
\>", "Subsection",
 CellChangeTimes->{{3.532853939269116*^9, 3.532853945860551*^9}, 
   3.561457205031646*^9, {3.6001709777393713`*^9, 3.600170979841782*^9}, {
   3.6001757138861933`*^9, 3.600175721548986*^9}, {3.600177352646035*^9, 
   3.600177380308042*^9}, {3.600971213168068*^9, 3.600971236302784*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResponsePlot", "[", 
  RowBox[{"ensemble2", ",", 
   RowBox[{"VariablesToPlot", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", " ", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<\>\""}]}], "]"}]], "Code",
 CellChangeTimes->{{3.600176818454296*^9, 3.600176821976297*^9}, {
   3.6001768977637157`*^9, 3.600176898612524*^9}, 3.600583928448563*^9, {
   3.600585041279325*^9, 3.6005850581690702`*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnQdcW+X6x+lSW20dreP2b9V6rastXse9ar0OXHXj1XsdLfdaraK12tZF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    "], {{0, 227}, {399, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{399, 227},
  PlotRange->{{0, 399}, {0, 227}}]], "Output",
 CellChangeTimes->{
  3.6005839334970503`*^9, {3.600584228934573*^9, 3.6005842352166233`*^9}, {
   3.600585047330085*^9, 3.6005850610753*^9}},
 ImageSize->{403, 227},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The model disagreement decreased and the behavior of the surrogate models \
represent the original simulator. \
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.6005871108454638`*^9, 3.600587116547543*^9}, {3.600587752838406*^9, 
   3.600587843864202*^9}, 3.600903297923505*^9, {3.600971275447942*^9, 
   3.600971352719677*^9}, {3.6009733353220387`*^9, 3.600973349546026*^9}, 
   3.600973470607038*^9},
 FontSize->16],

Cell["\<\

The response surface plot of the surrogate models:\
\>", "Text",
 CellChangeTimes->{{3.5993011483324137`*^9, 3.599301223192924*^9}, {
   3.60017072661863*^9, 3.6001707278573217`*^9}, {3.600176188688569*^9, 
   3.600176282388323*^9}, {3.600176353667214*^9, 3.600176489318808*^9}, {
   3.600176853484318*^9, 3.600176912458119*^9}, {3.6001770905339003`*^9, 
   3.600177163754574*^9}, {3.600177207490049*^9, 3.600177224232491*^9}, {
   3.600177286607842*^9, 3.6001773171991253`*^9}, {3.6001773958767157`*^9, 
   3.600177398309943*^9}, {3.600177438915573*^9, 3.6001775581908283`*^9}, {
   3.600177815184369*^9, 3.600177839495172*^9}, {3.600178131262218*^9, 
   3.600178163197858*^9}, 3.6004231205930223`*^9, {3.600499191142714*^9, 
   3.600499201130006*^9}, {3.600499372058793*^9, 3.600499430141076*^9}, {
   3.6005871108454638`*^9, 3.600587116547543*^9}, {3.600587752838406*^9, 
   3.600587843864202*^9}, 3.600903297923505*^9, {3.600971362027028*^9, 
   3.600971376079401*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"ResponseSurfacePlot", "[", "\n", "\t", 
  RowBox[{"ensemble2", ",", " ", "\n", "\t", 
   RowBox[{"VariablesToPlot", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(x\), \(2\)]\)\>\"", ",", 
      "\"\<\!\(\*OverscriptBox[\(f\), \(~\)]\)(\!\(\*SubscriptBox[\(x\), \
\(1\)]\),\!\(\*SubscriptBox[\(x\), \(2\)]\))\>\""}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", "\n", "\t", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<DarkRainbow\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", " ", 
   RowBox[{"PlotLabel", "\[Rule]", "None"}]}], "\n", "]"}]], "Code",
 CellChangeTimes->{{3.599905314558704*^9, 3.599905329102543*^9}, {
   3.6001778651043653`*^9, 3.600177865289034*^9}, 3.600584049892933*^9, {
   3.600584142464498*^9, 3.600584154881174*^9}, {3.600585007296816*^9, 
   3.600585015054399*^9}, {3.600595878744432*^9, 3.600595887729376*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQdbFNnaqL3P9f2L8042kXPonHPOuZsooIBEQQUkCJLBgEQRJIMISFZB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    "], {{0, 408}, {408, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{368., Automatic},
  ImageSizeRaw->{408, 408},
  PlotRange->{{0, 408}, {0, 408}}]], "Input",
 CellChangeTimes->{{3.601017077029827*^9, 3.601017077129047*^9}, 
   3.601017112361602*^9},
 ImageSize->{412, 408},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 804},
WindowMargins->{{61, Automatic}, {Automatic, -22}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], " ", "|", " ", 
      StyleBox[
       RowBox[{
        "Protocol", " ", "S1", ":", " ", "Step", "-", "by", "-", "step", " ", 
         "example"}], "Header"]}], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, None}, {
  None, None, 
   Cell[
    TextData[{
      StyleBox[
       RowBox[{"Protocol", " ", "S1"}], "Header"], 
      StyleBox[" ", "Header"], "|", " ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 552, 11, 70, "Title"],
Cell[1134, 35, 288, 5, 62, "Subtitle"],
Cell[1425, 42, 634, 12, 49, "Text"],
Cell[2062, 56, 965, 31, 47, "Text"],
Cell[3030, 89, 1698, 47, 121, "Code"],
Cell[4731, 138, 849, 31, 30, "Text"],
Cell[5583, 171, 1158, 23, 89, "Code"],
Cell[6744, 196, 197, 3, 30, "Text"],
Cell[6944, 201, 1704, 37, 134, "Code",
 InitializationCell->False],
Cell[8651, 240, 153951, 2531, 390, "Input"],
Cell[162605, 2773, 61, 2, 6, "PageBreak",
 CellOpen->True,
 PageBreakBelow->True],
Cell[CellGroupData[{
Cell[162691, 2779, 349, 5, 62, "Subtitle"],
Cell[163043, 2786, 309, 6, 30, "Text"],
Cell[163355, 2794, 725, 18, 104, "Code",
 InitializationCell->False],
Cell[164083, 2814, 297, 6, 30, "Text"],
Cell[164383, 2822, 92, 1, 27, "Input"],
Cell[164478, 2825, 308, 6, 30, "Text"],
Cell[164789, 2833, 724, 18, 30, "Text"],
Cell[CellGroupData[{
Cell[165538, 2855, 954, 25, 59, "Code",
 InitializationCell->False],
Cell[166495, 2882, 4944, 89, 251, "Output"]
}, Open  ]],
Cell[171454, 2974, 89, 1, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171580, 2980, 392, 6, 62, "Subtitle"],
Cell[171975, 2988, 460, 8, 30, "Text"],
Cell[172438, 2998, 623, 14, 43, "Code"],
Cell[173064, 3014, 133, 2, 43, "Input"],
Cell[173200, 3018, 440, 6, 30, "Text"],
Cell[173643, 3026, 482, 14, 43, "Code"],
Cell[174128, 3042, 91, 1, 27, "Input"],
Cell[174222, 3045, 61, 2, 6, "PageBreak",
 CellOpen->True,
 PageBreakBelow->True],
Cell[174286, 3049, 515, 8, 30, "Text"],
Cell[174804, 3059, 1044, 25, 104, "Code"],
Cell[175851, 3086, 81229, 1339, 376, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257117, 4430, 444, 7, 62, "Subtitle"],
Cell[257564, 4439, 833, 16, 87, "Text"],
Cell[258400, 4457, 319, 6, 59, "Code"],
Cell[258722, 4465, 626, 13, 68, "Text"],
Cell[259351, 4480, 1836, 37, 134, "Code"],
Cell[261190, 4519, 87, 1, 43, "Input"],
Cell[261280, 4522, 44, 1, 4, "PageBreak",
 PageBreakBelow->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[261361, 4528, 451, 7, 62, "Subtitle"],
Cell[CellGroupData[{
Cell[261837, 4539, 162, 2, 34, "Subsection"],
Cell[262002, 4543, 368, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[262395, 4554, 332, 7, 43, "Code"],
Cell[262730, 4563, 23814, 397, 282, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[286593, 4966, 168, 2, 34, "Subsection"],
Cell[286764, 4970, 524, 9, 30, "Text"],
Cell[287291, 4981, 628, 15, 43, "Code"],
Cell[CellGroupData[{
Cell[287944, 5000, 505, 11, 74, "Code"],
Cell[288452, 5013, 7048418, 180173, 279, 7025006, 179788, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[7336885, 185189, 44, 1, 4, "PageBreak",
 PageBreakBelow->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7336966, 185195, 179, 2, 34, "Subsection"],
Cell[7337148, 185199, 966, 22, 49, "Text"],
Cell[CellGroupData[{
Cell[7338139, 185225, 306, 7, 43, "Code"],
Cell[7338448, 185234, 3563111, 77772, 199, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10901608, 263012, 307, 6, 34, "Subsection"],
Cell[10901918, 263020, 811, 13, 30, "Text"],
Cell[10902732, 263035, 375, 9, 43, "Code"],
Cell[10903110, 263046, 91, 1, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10903238, 263052, 369, 6, 34, "Subsection"],
Cell[CellGroupData[{
Cell[10903632, 263062, 486, 10, 43, "Code"],
Cell[10904121, 263074, 241144, 4074, 242, "Output"]
}, Open  ]],
Cell[11145280, 267151, 1089, 17, 30, "Text"],
Cell[11146372, 267170, 61, 2, 6, "PageBreak",
 CellOpen->True,
 PageBreakBelow->True],
Cell[11146436, 267174, 1076, 17, 30, "Text"],
Cell[11147515, 267193, 1263, 25, 151, "Code"],
Cell[11148781, 267220, 111663, 1837, 415, "Input"],
Cell[11260447, 269059, 61, 2, 6, "PageBreak",
 CellOpen->True,
 PageBreakBelow->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11260557, 269067, 572, 8, 62, "Subtitle"],
Cell[11261132, 269077, 349, 5, 62, "Subtitle"],
Cell[11261484, 269084, 2184, 43, 87, "Text"],
Cell[11263671, 269129, 5415, 99, 252, "Output"],
Cell[11269089, 269230, 1500, 22, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11270626, 269257, 392, 6, 62, "Subtitle"],
Cell[11271021, 269265, 1421, 20, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11272479, 269290, 444, 7, 62, "Subtitle"],
Cell[11272926, 269299, 1471, 21, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11274434, 269325, 451, 7, 62, "Subtitle"],
Cell[CellGroupData[{
Cell[11274910, 269336, 375, 6, 34, "Subsection"],
Cell[CellGroupData[{
Cell[11275310, 269346, 472, 10, 43, "Code"],
Cell[11275785, 269358, 24935, 416, 242, "Output"]
}, Open  ]],
Cell[11300735, 269777, 1132, 18, 30, "Text"],
Cell[11301870, 269797, 999, 17, 49, "Text"],
Cell[11302872, 269816, 1335, 26, 151, "Code"],
Cell[11304210, 269844, 122491, 2015, 383, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
